(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    362125,       9656]*)
(*NotebookOutlinePosition[    363046,       9686]*)
(*  CellTagsIndexPosition[    363002,       9682]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Non Linear Permanent Magnet Modelling\n A",
    FontSize->24],
  StyleBox["pplication to a  Sphere",
    FontSize->18]
}], "Title",
  TextAlignment->Center],

Cell["Joel Chavanne, ESRF", "Author"],

Cell[CellGroupData[{

Cell["Introduction", "Section 1"],

Cell[CellGroupData[{

Cell["Motivation", "Subsection"],

Cell[TextData[{
  "This ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " notebook is dedicated to the non linear modelling of permanent magnet \
material. The methodology is illustrated with a tutorial example (a permanent \
magnet sphere) but this simple object can be replaced with more complicated \
permanent magnet assemblies.\nThere are two main reasons for the development \
of this non linear model:\nThe first one is to determine in detail the \
required intrinsic coecivity (Hcj) of permanent magnet material for the \
sturcture being studied. In the case of NdFeB material, the choice of a too \
large coercivity may be detrimental to the the amplitude of the remanence and \
therfore the field in the structure or too small coercivity may result in \
partial demagnetisation of the material.\nThe second one is related to \
temperature effect on permanent magnet material. If the magnetic structure is \
subjected to temperature elevation (accidental or planed within a specific \
baking) the potential partial demagnetisation has to be checked. This is the \
case for in vacuum permanent magnet structures where an initial baking is \
required.Here the modelling allows to determine an optimum baking temperature \
compatible with the permanent magnet material properties.\n"
}], "Text",
  CellFrame->True,
  Background->RGBColor[1, 0.950011, 0.996674]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Material description", "Subsection"],

Cell[TextData[{
  "Obviously the description of the permanent magnet material has to include \
a larger number of parameters than in the linear case.The required elements \
for the description are as follow:\n\n",
  StyleBox["1- the curve M vs H at room temperature (or  a given temperature \
T0) parallel to the easy axis",
    FontWeight->"Bold"],
  ".\nThis is done with a model under the form\n\
M(H)=Ms1*Tanh(ksi1/Ms1*(H+Hcj)+Ms2*Tanh(ksi2/Ms2*(H+Hcj)+Ms3*Tanh(ksi3/Ms3*(H+\
Hcj),a set of 3 hyperbolic tangents passing through the point (Hcj,0).The \
values of Ms1, Ksi1, Ms2, Ksi2, Ms3 and Ksi3 are obtained with a fit from the \
data.The model should be limited to the 2 first quadrants ( positive and null \
values of magnetization).\n\n",
  StyleBox["2- Description of the behavior perpendicular to the easy axis",
    FontWeight->"Bold"],
  ",\nassumed to be linear Mper=Ksiperp*Hperp.This assumption is only valid \
for anisotropic material (with uniaxial anisotropy) which is the case for \
high performance material (rare earth-transition metal alloys).The model \
suppose also indirectly that there is no angular distribution of the easy \
axis in the material texture (i.e all grains of the material have their easy \
axis in the same direction) which is a good approximation.Remark,the model is \
not adequate for isotropic permanent magnet material (with easy axis \
distributed isotropically).Ksiperp is given at temperature T0.\n\n",
  StyleBox["3- Description of the temperature dependence of Hcj and Br ",
    FontWeight->"Bold"],
  "under the form:\nBr(T)=(1+a1Br*(T-T0)+a2Br*(T-T0)**2)*Br(T0),\n\
Hcj(T)=(1+a1Hcj*(T-T0)+a2Hcj*(T-T0)**2)*Hcj(T0)\n Both descriptions use a \
second order polynomial fit.\n \n One important feature with RADIA is the \
possibility to modify dynamically the material properties during the \
resolution of the problem. This issue is of practical use in the last section \
where the problem is analyzed with a varying temperature. The interaction \
matrix is independent of the materials and only depend on the problem \
geometry. Therefore, at each temperature step, there is no need to re-build \
the interaction matrix and only relaxation is proceeded. This is  important \
since most of the time taken in a resolution is related to the construction \
of the interaction matrix .\n On key point is the way the relaxation is \
handled, the method use a succession of \"manual\" iterations loop since he \
automatic relaxation is not adequate (more or less reserved for soft magnetic \
materials). Nevertheless this method is relatively easy to handle and can be \
automated to get desired accuracy."
}], "Text",
  CellFrame->True,
  Background->RGBColor[1, 0.950011, 0.996674]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Notebook structure", "Subsection"],

Cell[TextData[{
  "This notebook is separated into several sections:\n\nThe first one load \
RADIA and necessary packages.\n\n",
  StyleBox["FUNCTIONS",
    FontWeight->"Bold"],
  "\n-",
  StyleBox["sphere creation",
    FontWeight->"Bold"],
  ": create a sphere using a polyhedron\n-",
  StyleBox["material coefficient vs temperature:\n",
    FontWeight->"Bold"],
  "Create permanent magnet material at temperature T using material \
description performed at temperature T0.\n-",
  StyleBox["M vs H  function.\n",
    FontWeight->"Bold"],
  "Gives value of magnetization (mu0*M) at H field (mu0*h) for a given \
temperature T. Useful for plotting the magnetization curves at different \
temperature (check various parameters of the model).",
  StyleBox["\n",
    FontWeight->"Bold"],
  " \n ",
  StyleBox["MATERIAL PARAMETERS\n ",
    FontWeight->"Bold"],
  "A description of two generic permanent magnet materials (NdFeB, \
Sm2Co17).Each list has the form:\n \
{{Ksi1,Ms1},{Ksi2,Ms2},{Ksi3,Ms3},Hcj,Ksiperp,{a1Br,a2Br},{a1Hc,a2Hc},T0}, \
all the parameters in the list a defined in the \"material description\" \
section above.\n \n",
  StyleBox["PLOT MAGNETIZATION CURVES AT DIFFERENT TEMPEARTURES\n",
    FontWeight->"Bold"],
  "A practical use of the function MvsH as explain above.\n\n",
  StyleBox["SOLVING\nSolve problem at constant temperature with varying \
applied field.\n",
    FontWeight->"Bold"],
  "Take the sphere at constant temperature Temp and apply  successive H field \
in order to get the resulting magnetization. This example has limited \
practical interest since everything can be computed manually using the \
material description. The main goal is to check the relaxation process is \
properly handled. Note the difference between the applied external field H",
  StyleBox["ext",
    FontSize->10],
  " and internal field in the middle of the sphere H",
  StyleBox["tot",
    FontSize->10],
  ".",
  StyleBox["\n\nVarying temperature\n",
    FontWeight->"Bold"],
  "Here the permanent magnet sphere is submitted to a varying temperature. At \
each temperature the problem is solved (needs only to perform relaxation with \
the initial interaction matrix) and resulting magnetization (uniform within \
the sphere) is computed.\nFinally, the ",
  StyleBox["irreversible losses on the magnetization",
    FontWeight->"Bold"],
  " are derived from the loop on the temperature. "
}], "Text",
  CellFrame->True,
  Background->RGBColor[1, 0.950011, 0.996674]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Load packages", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(<< Radia`;\)\), "\n", 
    \(\(<< \ Graphics`MultipleListPlot`;\)\), "\n", 
    \(\(Off[General::"\<spell1\>"];\)\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Radia Version: "\[InvisibleSpace]4.098`\
\[InvisibleSpace]" is loaded"\),
      SequenceForm[ "Radia Version: ", 4.0979999999999999, " is loaded"],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Radia is copyright ESRF, Grenoble France \nPortions copyright Wolfram \
Research, Inc."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Functions", "Section"],

Cell[CellGroupData[{

Cell["sphere creation", "Subsection"],

Cell[BoxData[
    \(\(SphericalVolume[R_, nn\[CurlyPhi]_, nz_, {mx_, my_, mz_}] := 
        Module[{z, dz, \[Theta], cos\[Theta], \[CurlyPhi], d\[CurlyPhi], 
            SlicePgn, AllSlicePgns}, dz = 2. *R/nz; \tz = \(-R\) + dz; \ 
          d\[CurlyPhi] = 
            2. *\[Pi]/
                nn\[CurlyPhi]; \[IndentingNewLine]AllSlicePgns = {{{{0. , 
                    0. }}, \(-R\)}}; \[IndentingNewLine]For[i = 1, 
            i \[LessEqual] \((nz - 1)\), \(i++\), \[Theta] = ArcSin[z/R]; \ 
            cos\[Theta] = Cos[\[Theta]]; \ \[CurlyPhi] = 
              d\[CurlyPhi]; \[IndentingNewLine]SlicePgn = {{R*cos\[Theta], 
                  0. }}; \[IndentingNewLine]For[k = 1, 
              k \[LessEqual] \((nn\[CurlyPhi] - 1)\), \(k++\), 
              SlicePgn = 
                Append[SlicePgn, {R*Cos[\[CurlyPhi]]*cos\[Theta], 
                    R*Sin[\[CurlyPhi]]*cos\[Theta]}]; \ \[CurlyPhi] += 
                d\[CurlyPhi];]; \[IndentingNewLine]AllSlicePgns = 
              Append[AllSlicePgns, {SlicePgn, z}]; \[IndentingNewLine]z += 
              dz;]; \[IndentingNewLine]AllSlicePgns = 
            Append[AllSlicePgns, {{{0. , 0. }}, 
                R}]; \[IndentingNewLine]radObjMltExtPgn[AllSlicePgns, 
            N[{mx, my, mz}]]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Material coefficients vs temperature", "Subsection"],

Cell[BoxData[
    \(\(MatCoef[mat_List, 
          T_] := \[IndentingNewLine]Module[\[IndentingNewLine]{Ksi1, Ms1, 
            Ksi2, Ms2, Ksi3, Ms3, Ksit, a1Hc, a1Br, a2Hc, a2Br, Br0, Br1, 
            Hc0, Hc, T0, cf1, 
            cf2}, \[IndentingNewLine]\[IndentingNewLine]Ksi1 = 
            mat[\([1, 1, 1]\)]; \[IndentingNewLine]Ms1 = 
            mat[\([1, 1, 2]\)]; \[IndentingNewLine]Ksi2 = 
            mat[\([1, 2, 1]\)]; \[IndentingNewLine]Ms2 = 
            mat[\([1, 2, 2]\)]; \[IndentingNewLine]Ksi3 = 
            mat[\([1, 3, 1]\)]; \[IndentingNewLine]Ms3 = 
            mat[\([1, 3, 2]\)]; \[IndentingNewLine]Hc0 = 
            mat[\([2]\)]; \[IndentingNewLine]Ksit = 
            mat[\([3]\)]; \[IndentingNewLine]a1Br = 
            mat[\([4, 1]\)]; \[IndentingNewLine]a2Br = 
            mat[\([4, 2]\)]; \[IndentingNewLine]a1Hc = 
            mat[\([5, 1]\)]; \[IndentingNewLine]a2Hc = 
            mat[\([5, 2]\)]; \[IndentingNewLine]T0 = 
            mat[\([6]\)]; \[IndentingNewLine]\[IndentingNewLine]Hc = \((1 + 
                  a1Hc\ \((T - T0)\) + 
                  a2Hc\ \((T - T0)\)^2)\)\ Hc0; \[IndentingNewLine]Br0 = 
            Ms1\ Tanh[Ksi1/Ms1\ \((\(-Hc0\))\)] + 
              Ms2\ Tanh[Ksi2/Ms2\ \((\(-Hc0\))\)] + 
              Ms3\ Tanh[Ksi3/Ms3\ \((\(-Hc0\))\)]; \[IndentingNewLine]Br1 = 
            Ms1*Tanh[Ksi1/Ms1\ \((\(-Hc\))\)] + 
              Ms2*Tanh[Ksi2/Ms2\ \((\(-Hc\))\)] + 
              Ms3*Tanh[Ksi3/Ms3\ \((\(-Hc\))\)]; \[IndentingNewLine]cf1 = 
            Br1/Br0; \[IndentingNewLine]cf2 = 
            1 + a1Br\ \((T - T0)\) + 
              a2Br\ \((T - T0)\)^2; \[IndentingNewLine]{{{Ksi1, Ms1}\ cf2/
                  cf1, {Ksi2, Ms2}\ cf2/cf1, {Ksi3, Ms3}\ cf2/cf1, 0, Hc}, 
            Ksit*\((1 + a1Br*\((T - T0)\) + 
                  a2Br\ \((T - T0)\)^2)\)}\[IndentingNewLine]];\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["M vs H  function", "Subsection"],

Cell[BoxData[
    \(\(MvsH[mat_List, H_, 
          Temp_] := \[IndentingNewLine]Module[{v, 
            mat2}, \[IndentingNewLine]\[IndentingNewLine]mat2 = 
            MatCoef[mat, Temp]; \[IndentingNewLine]v1 = 
            mat2[\([1, 1, 2]\)]*
                Tanh[mat2[\([1, 1, 1]\)]/
                      mat2[\([1, 1, 2]\)]\ \((H - mat2[\([1, 5]\)])\)\ ] + 
              mat2[\([1, 2, 2]\)]*
                Tanh[mat2[\([1, 2, 1]\)]/
                      mat2[\([1, 2, 2]\)]\ \((H - mat2[\([1, 5]\)])\)\ ] + 
              mat2[\([1, 3, 2]\)]*
                Tanh[mat2[\([1, 3, 1]\)]/
                      mat2[\([1, 3, 2]\)]\ \((H - 
                        mat2[\([1, 
                            5]\)])\)\ ]; \[IndentingNewLine]v1\
\[IndentingNewLine]\[IndentingNewLine]];\)\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Material Parameters", "Section"],

Cell[BoxData[{
    \(\(matNdFeB = {{{18.08, 1.049}, {0.643, 0.0711}, {0.047, 
              0.2059}}, \(-2.1\), 
          0.17, {\(-0.000972887\), \(-2.683\)\ 10^\(-7\)}, {\(-0.007018\), 
            1.16\ 10^\(-5\)}, 20};\)\), "\[IndentingNewLine]", 
    \(\(matSm2Co17 = {{{7.344, 0.9125}, {0.494, 0.0618}, {0.049, 
              0.25}}, \(-1.9\), 
          0.06, {\(-0.000343\), 0}, {\(-0.0020029\), 1.756\ 10^\(-7\)}, 
          24};\)\)}], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot Magnetization Curves for several Temperatures", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(m = matNdFeB;\)\), "\[IndentingNewLine]", 
    \(\(t1 = 20;\)\), "\[IndentingNewLine]", 
    \(\(t2 = 60;\)\), "\[IndentingNewLine]", 
    \(\(t3 = 120;\)\), "\[IndentingNewLine]", 
    \(\(Print["\<magnetization curves at \>", t1, "\< ,\>", 
        t2, "\< and \>", \ 
        t3, "\< degrees C\>"];\)\), "\[IndentingNewLine]", 
    \(Plot[{MvsH[m, H, t1], MvsH[m, H, t2], MvsH[m, H, t3]}, {H, \(-2.5\), 
        0}, PlotStyle \[Rule] {RGBColor[1, 0, 0], RGBColor[0, 1, 0], 
          RGBColor[0, 0, 1]}, PlotRange \[Rule] {0, 1.3}, 
      AxesLabel \[Rule] {\[Mu]0H, \[Mu]0M}]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("magnetization curves at "\[InvisibleSpace]20\
\[InvisibleSpace]" ,"\[InvisibleSpace]60\[InvisibleSpace]" and "\
\[InvisibleSpace]120\[InvisibleSpace]" degrees C"\),
      SequenceForm[ 
      "magnetization curves at ", 20, " ,", 60, " and ", 120, " degrees C"],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.97619 0.380952 0 0.475411 [
[.02381 -0.0125 -12 -9 ]
[.02381 -0.0125 12 0 ]
[.21429 -0.0125 -6 -9 ]
[.21429 -0.0125 6 0 ]
[.40476 -0.0125 -12 -9 ]
[.40476 -0.0125 12 0 ]
[.59524 -0.0125 -6 -9 ]
[.59524 -0.0125 6 0 ]
[.78571 -0.0125 -12 -9 ]
[.78571 -0.0125 12 0 ]
[1.025 0 0 -6 ]
[1.025 0 22 6 ]
[.96369 .09508 -18 -4.5 ]
[.96369 .09508 0 4.5 ]
[.96369 .19016 -18 -4.5 ]
[.96369 .19016 0 4.5 ]
[.96369 .28525 -18 -4.5 ]
[.96369 .28525 0 4.5 ]
[.96369 .38033 -18 -4.5 ]
[.96369 .38033 0 4.5 ]
[.96369 .47541 -6 -4.5 ]
[.96369 .47541 0 4.5 ]
[.96369 .57049 -18 -4.5 ]
[.96369 .57049 0 4.5 ]
[.97619 .64303 -11 0 ]
[.97619 .64303 11 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 0 m
.02381 .00625 L
s
[(-2.5)] .02381 -0.0125 0 1 Mshowa
.21429 0 m
.21429 .00625 L
s
[(-2)] .21429 -0.0125 0 1 Mshowa
.40476 0 m
.40476 .00625 L
s
[(-1.5)] .40476 -0.0125 0 1 Mshowa
.59524 0 m
.59524 .00625 L
s
[(-1)] .59524 -0.0125 0 1 Mshowa
.78571 0 m
.78571 .00625 L
s
[(-0.5)] .78571 -0.0125 0 1 Mshowa
.125 Mabswid
.0619 0 m
.0619 .00375 L
s
.1 0 m
.1 .00375 L
s
.1381 0 m
.1381 .00375 L
s
.17619 0 m
.17619 .00375 L
s
.25238 0 m
.25238 .00375 L
s
.29048 0 m
.29048 .00375 L
s
.32857 0 m
.32857 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.44286 0 m
.44286 .00375 L
s
.48095 0 m
.48095 .00375 L
s
.51905 0 m
.51905 .00375 L
s
.55714 0 m
.55714 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.67143 0 m
.67143 .00375 L
s
.70952 0 m
.70952 .00375 L
s
.74762 0 m
.74762 .00375 L
s
.82381 0 m
.82381 .00375 L
s
.8619 0 m
.8619 .00375 L
s
.9 0 m
.9 .00375 L
s
.9381 0 m
.9381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0H) show
1.000 setlinewidth
grestore
.97619 .09508 m
.98244 .09508 L
s
[(0.2)] .96369 .09508 1 0 Mshowa
.97619 .19016 m
.98244 .19016 L
s
[(0.4)] .96369 .19016 1 0 Mshowa
.97619 .28525 m
.98244 .28525 L
s
[(0.6)] .96369 .28525 1 0 Mshowa
.97619 .38033 m
.98244 .38033 L
s
[(0.8)] .96369 .38033 1 0 Mshowa
.97619 .47541 m
.98244 .47541 L
s
[(1)] .96369 .47541 1 0 Mshowa
.97619 .57049 m
.98244 .57049 L
s
[(1.2)] .96369 .57049 1 0 Mshowa
.125 Mabswid
.97619 .02377 m
.97994 .02377 L
s
.97619 .04754 m
.97994 .04754 L
s
.97619 .07131 m
.97994 .07131 L
s
.97619 .11885 m
.97994 .11885 L
s
.97619 .14262 m
.97994 .14262 L
s
.97619 .16639 m
.97994 .16639 L
s
.97619 .21393 m
.97994 .21393 L
s
.97619 .23771 m
.97994 .23771 L
s
.97619 .26148 m
.97994 .26148 L
s
.97619 .30902 m
.97994 .30902 L
s
.97619 .33279 m
.97994 .33279 L
s
.97619 .35656 m
.97994 .35656 L
s
.97619 .4041 m
.97994 .4041 L
s
.97619 .42787 m
.97994 .42787 L
s
.97619 .45164 m
.97994 .45164 L
s
.97619 .49918 m
.97994 .49918 L
s
.97619 .52295 m
.97994 .52295 L
s
.97619 .54672 m
.97994 .54672 L
s
.97619 .59426 m
.97994 .59426 L
s
.25 Mabswid
.97619 0 m
.97619 .61803 L
s
gsave
.97619 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0M) show
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.17624 0 m
.18458 .18775 L
.18937 .27761 L
.19459 .35505 L
.19952 .40938 L
.20409 .44595 L
.20891 .4735 L
.21165 .48526 L
.21423 .49426 L
.21941 .50777 L
.22233 .5133 L
.225 .51741 L
.22974 .52293 L
.23239 .52529 L
.2348 .52707 L
.2395 .5298 L
.24392 .5317 L
.24909 .53336 L
.25386 .53452 L
.25909 .53552 L
.26462 .53636 L
.27406 .53746 L
.2842 .53838 L
.30251 .53972 L
.34379 .54228 L
.38355 .5446 L
.42179 .54681 L
.46249 .54914 L
.50167 .55136 L
.54331 .5537 L
.58343 .55593 L
.62203 .55805 L
.66309 .56028 L
.70262 .5624 L
.74065 .56441 L
.78113 .56651 L
.82009 .56851 L
.8615 .57059 L
.9014 .57255 L
.93978 .57441 L
.97619 .57614 L
s
0 1 0 r
.38597 0 m
.39261 .1489 L
.39811 .25473 L
.40327 .33373 L
.40765 .38501 L
.41237 .42617 L
.41492 .44335 L
.41761 .45828 L
.42013 .46979 L
.42242 .47849 L
.427 .49193 L
.42952 .49752 L
.4319 .5019 L
.43613 .50798 L
.44072 .51272 L
.44578 .51642 L
.44834 .51785 L
.45114 .51917 L
.4561 .52099 L
.46075 .52228 L
.46573 .52335 L
.47115 .52426 L
.48103 .5255 L
.49065 .52642 L
.49957 .52713 L
.53875 .52964 L
.58039 .53205 L
.62051 .53432 L
.65911 .53648 L
.70016 .53877 L
.7397 .54095 L
.77773 .54302 L
.8182 .54521 L
.85717 .54729 L
.89858 .54947 L
.93848 .55154 L
.97619 .55347 L
s
0 0 1 r
.64478 0 m
.64621 .03034 L
.65491 .20814 L
.65949 .28358 L
.66446 .34789 L
.66719 .37589 L
.6697 .39761 L
.67465 .43063 L
.6789 .4508 L
.68358 .46661 L
.68593 .47266 L
.68846 .47805 L
.69302 .48549 L
.69557 .48865 L
.69828 .49142 L
.70315 .49521 L
.70614 .49697 L
.70895 .49833 L
.7142 .5003 L
.71923 .50169 L
.72386 .50267 L
.7289 .50352 L
.7343 .50426 L
.74406 .50529 L
.75316 .50605 L
.77384 .50746 L
.81525 .50985 L
.85515 .51204 L
.89353 .51412 L
.93436 .51631 L
.97368 .51841 L
.97619 .51854 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{438.375, 270.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006f00013R000`400?l00000o`00003oo`3IfMVg
0=WIf@004@3IfMT5000000<0fMWI00<000000=WIf@3IfMT00P3IfMT3000003h0fMWI1@00000o0=WI
f@<00000103IfMT00`000000fMWI0=WIf@020=WIf@<00000?`3IfMT300000400fMWI0P0000040=WI
f@030000003IfMT0fMWI0080fMWI0`00001d0=WIf@004P3IfMT010000000fMWI0=WIf@0000070=WI
f@050000003IfMT0fMWI0=WIf@000000?P3IfMT010000000fMWI0=WIf@0000100=WIf@030000003I
fMT0fMWI00L0fMWI00D000000=WIf@3IfMT0fMWI0000000o0=WIf@030000003IfMT0fMWI03h0fMWI
00@000000=WIf@3IfMT000001`3IfMT01@000000fMWI0=WIf@3IfMT0000007<0fMWI000;0=WIf@D0
00000`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI03D0fMWI1@0000030=WIf@03
0000003IfMT0fMWI03P0fMWI1@0000030=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3I
fMT0=@3IfMT5000000<0fMWI00<000000=WIf@3IfMT0=`3IfMT500000080fMWI00@000000=WIf@3I
fMT000002`3IfMT00`000000fMWI0=WIf@1a0=WIf@00503IfMT00`000000fMWI0=WIf@0:0=WIf@03
0000003IfMT0fMWI03h0fMWI00<000000=WIf@3IfMT0?`3IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI03d0fMWI00<000000=WIf@3IfMT0?P3IfMT010000000fMWI0=WIf@00000;0=WI
f@030000003IfMT0fMWI0740fMWI000A0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT40000
03h0fMWI00D000000=WIf@3IfMT0fMWI000000100=WIf@030000003IfMT0fMWI00L0fMWI10000010
0=WIf@030000003IfMT0fMWI03h0fMWI00@000000=WIf@3IfMT000001`3IfMT4000007@0fMWI000A
0=WIf@050000003IfMT0fMWI0=WIf@0000001`3IfMT00`000000fMWI0=WIf@0o0=WIf@050000003I
fMT0fMWI0=WIf@000000?`3IfMT2000000T0fMWI00<000000=WIf@3IfMT0@03IfMT200000400fMWI
00@000000=WIf@3IfMT000001`3IfMT00`000000fMWI0=WIf@1e0=WIf@004P3IfMT3000000P0fMWI
1@00000n0=WIf@<00000@@3IfMT00`000000fMWI0=WIf@070=WIf@D00000?`3IfMT00`000000fMWI
0=WIf@0o0=WIf@800000203IfMT5000007<0fMWI003o0=WIfKL0fMWI003o0=WIfIH0fMWI00<00000
0=WIf@3IfMT07P3IfMT00?l0fMWIUP3IfMT00`000000fMWI0=WIf@0N0=WIf@00o`3IfMVF0=WIf@H0
00000P3IfMT200000080fMWI0`0000000`3IfMT000000000000?0=WIf@00o`3IfMVF0=WIf@050000
003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI
00000100fMWI000>0=WIfD<0000000<0o`00000000000000C@0000000`00o`0000000000001O0000
00030000o`000000000008D000002`3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0
fMWI00000080fMWI00@000000=WIf@3IfMT00000403IfMT001L0fMWI00<000000=WIf@3IfMT0303I
fMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0303I
fMT00`3o0000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02`3I
fMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT01@3I
fMT00`00o`00fMWI0=WIf@040=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0303I
fMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02`3I
fMT00`000000fMWI0=WIf@0<0=WIf@050000003IfMT0fMWI0=WIf@000?l02@3IfMT00`000000fMWI
0=WIf@0;0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI
0=WIf@0<0=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI
0=WIf@0;0=WIf@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT04P3IfMT01`000000fMWI
0=WIf@3IfMT000000=WIf@0000000P3IfMT00`000000fMWI0=WIf@0400000100fMWI000G0=WIf@03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI00`0fMWI00<0o`000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI00D0fMWI00<00?l00=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0;0=WIf@03
0000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0<0=WIf@03
0000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT0303IfMT01@000000fMWI0=WIf@3IfMT0003o
00T0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI
00/0fMWI00<000000=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI
00`0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0<0=WIf@030000003IfMT0fMWI
0180fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT000000080fMWI00@000000=WIf@3IfMT00000
0P3IfMT00`000000fMWI0=WIf@0>0=WIf@005`3IfMT00`000000fMWI0=WIf@0g0=WIf@030?l0003I
fMT0fMWI00/0fMWI00<000000=WIf@3IfMT0?`3IfMT00`00o`00fMWI0=WIf@040=WIf@030000003I
fMT0fMWI04D0fMWI00<000000=WIf@3IfMT0403IfMT00`000?l0fMWI0=WIf@0b0=WIf@030000003I
fMT0fMWI04H0fMWI00<000000=WIf@3IfMT0603IfMT010000000fMWI0=WIf@0000020=WIf@040000
003IfMT0fMWI00000100fMWI001A0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0
G`3IfMT00`000?l0fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI01T0fMWI0P0000020=WIf@<00000
00<0fMWI0000000000003`3IfMT00540fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WI
f@1O0=WIf@030000o`3IfMT0fMWI07/0fMWI00<000000=WIf@3IfMT0<P3IfMT00540fMWI00<0o`00
0=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07/0fMWI00<00000
0=WIf@3IfMT0<P3IfMT00540fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WI
f@030000o`3IfMT0fMWI07/0fMWI00<000000=WIf@3IfMT0<P3IfMT00540fMWI00<0o`000=WIf@3I
fMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07/0fMWI00<000000=WIf@3I
fMT0<P3IfMT00540fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000
o`3IfMT0fMWI07/0fMWI0P00000c0=WIf@00D@3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003I
fMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0N`3IfMT00`000000fMWI0=WIf@0b0=WIf@00D@3IfMT0
0`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0N`3IfMT0
0`000000fMWI0=WIf@0b0=WIf@00D@3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI
05l0fMWI00<0003o0=WIf@3IfMT0N`3IfMT00`000000fMWI0=WIf@0b0=WIf@00DP3IfMT00`3o0000
fMWI0=WIf@1<0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0N`3IfMT00`000000
fMWI0=WIf@0b0=WIf@00DP3IfMT00`3o0000fMWI0=WIf@1<0=WIf@03003o003IfMT0fMWI05l0fMWI
00<0003o0=WIf@3IfMT0N`3IfMT00`000000fMWI0=WIf@0b0=WIf@00DP3IfMT00`3o0000fMWI0=WI
f@1=0=WIf@03003o003IfMT0fMWI05h0fMWI00<0003o0=WIf@3IfMT0N`3IfMT00`000000fMWI0=WI
f@0b0=WIf@00DP3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05h0fMWI00<0003o
0=WIf@3IfMT0N`3IfMT00`000000fMWI0=WIf@0b0=WIf@00DP3IfMT00`3o0000fMWI0=WIf@1=0=WI
f@03003o003IfMT0fMWI05h0fMWI00<0003o0=WIf@3IfMT0N`3IfMT00`000000fMWI0=WIf@0b0=WI
f@00DP3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05h0fMWI00<0003o0=WIf@3I
fMT0N`3IfMT2000003<0fMWI001B0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0
GP3IfMT00`000?l0fMWI0=WIf@1k0=WIf@030000003IfMT0fMWI0380fMWI001B0=WIf@030?l0003I
fMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0GP3IfMT00`000?l0fMWI0=WIf@1k0=WIf@030000003I
fMT0fMWI0380fMWI001B0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT0
0`000?l0fMWI0=WIf@1j0=WIf@030000003IfMT0fMWI0380fMWI001B0=WIf@030?l0003IfMT0fMWI
04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1j0=WIf@030000003IfMT0fMWI
0380fMWI001B0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0
fMWI0=WIf@1j0=WIf@030000003IfMT0fMWI0380fMWI001B0=WIf@030?l0003IfMT0fMWI04d0fMWI
00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1j0=WIf@030000003IfMT0fMWI0380fMWI
001B0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WI
f@1j0=WIf@030000003IfMT0fMWI0380fMWI001B0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l0
0=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1j0=WIf@030000003IfMT0fMWI0380fMWI001B0=WI
f@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1j0=WI
f@800000<`3IfMT00580fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@03
0000o`3IfMT0fMWI07X0fMWI00<000000=WIf@3IfMT0<P3IfMT00580fMWI00<0o`000=WIf@3IfMT0
C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07X0fMWI00<000000=WIf@3IfMT0
<P3IfMT00580fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3I
fMT0fMWI07X0fMWI00<000000=WIf@3IfMT0<P3IfMT00580fMWI00<0o`000=WIf@3IfMT0C@3IfMT0
0`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07X0fMWI00<000000=WIf@3IfMT0<P3IfMT0
0580fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI
07X0fMWI00<000000=WIf@3IfMT0<P3IfMT00580fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00
fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07X0fMWI00<000000=WIf@3IfMT0<P3IfMT00580fMWI
00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI06D0fMWI
0P0000040=WIf@040000003IfMT0fMWI0=WIf@D000001P3IfMT00`000000fMWI0=WIf@0b0=WIf@00
DP3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0
I03IfMT010000000fMWI0=WIf@0000080=WIf@040000003IfMT0fMWI000000H0fMWI00<000000=WI
f@3IfMT0<P3IfMT00580fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@03
0000o`3IfMT0fMWI06@0fMWI00@000000=WIf@3IfMT000002@3IfMT00`000000fMWI0=WIf@060=WI
f@<00000<P3IfMT005<0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00o`00fMWI0=WIf@1O0=WIf@03
0000o`3IfMT0fMWI06@0fMWI00@000000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@050=WI
f@030000003IfMT0fMWI0380fMWI001C0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3I
fMT0H03IfMT00`000?l0fMWI0=WIf@1S0=WIf@040000003IfMT0fMWI000000L0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0380fMWI001C0=WIf@030?l0003IfMT0fMWI
04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1S0=WIf@040000003IfMT0fMWI
000000L0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0380fMWI001C
0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1T
0=WIf@8000002@3IfMT3000000L0fMWI00<000000=WIf@3IfMT0<P3IfMT005<0fMWI00<0o`000=WI
f@3IfMT0C03IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07T0fMWI00<000000=WI
f@3IfMT0<P3IfMT005<0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00o`00fMWI0=WIf@1P0=WIf@03
0000o`3IfMT0fMWI07T0fMWI00<000000=WIf@3IfMT0<P3IfMT005<0fMWI00<0o`000=WIf@3IfMT0
C03IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07T0fMWI00<000000=WIf@3IfMT0
<P3IfMT005<0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3I
fMT0fMWI07T0fMWI00<000000=WIf@3IfMT0<P3IfMT005<0fMWI00<0o`000=WIf@3IfMT0C@3IfMT0
0`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07T0fMWI0P00000c0=WIf@00D`3IfMT00`3o
0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0N@3IfMT00`00
0000fMWI0=WIf@0b0=WIf@00D`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0
fMWI00<0003o0=WIf@3IfMT0N@3IfMT00`000000fMWI0=WIf@0b0=WIf@00D`3IfMT00`3o0000fMWI
0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0N@3IfMT00`000000fMWI
0=WIf@0b0=WIf@00D`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0
003o0=WIf@3IfMT0N@3IfMT00`000000fMWI0=WIf@0b0=WIf@00D`3IfMT00`3o0000fMWI0=WIf@1=
0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0N@3IfMT00`000000fMWI0=WIf@0b
0=WIf@00D`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WI
f@3IfMT0N@3IfMT00`000000fMWI0=WIf@0b0=WIf@00D`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03
003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0N@3IfMT00`000000fMWI0=WIf@0b0=WIf@00
D`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0
N@3IfMT00`000000fMWI0=WIf@0b0=WIf@00D`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003I
fMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0N@3IfMT2000003<0fMWI001C0=WIf@030?l0003IfMT0
fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1h0=WIf@030000003IfMT0
fMWI0380fMWI001C0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`00
0?l0fMWI0=WIf@1h0=WIf@030000003IfMT0fMWI0380fMWI001C0=WIf@030?l0003IfMT0fMWI04d0
fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1h0=WIf@030000003IfMT0fMWI0380
fMWI001C0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI
0=WIf@1h0=WIf@030000003IfMT0fMWI0380fMWI001C0=WIf@030?l0003IfMT0fMWI04d0fMWI00<0
0?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1h0=WIf@030000003IfMT0fMWI0380fMWI001C
0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1h
0=WIf@030000003IfMT0fMWI0380fMWI001D0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WI
f@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1h0=WIf@030000003IfMT0fMWI0380fMWI001D0=WIf@03
0?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1h0=WIf@03
0000003IfMT0fMWI0380fMWI001D0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0
H03IfMT00`000?l0fMWI0=WIf@1h0=WIf@800000<`3IfMT005@0fMWI00<0o`000=WIf@3IfMT0C03I
fMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07P0fMWI00<000000=WIf@3IfMT0<P3I
fMT005@0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0
fMWI07P0fMWI00<000000=WIf@3IfMT0<P3IfMT005@0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00
o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07P0fMWI00<000000=WIf@3IfMT0<P3IfMT005@0
fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07P0
fMWI00<000000=WIf@3IfMT0<P3IfMT005@0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI
0=WIf@1O0=WIf@030000o`3IfMT0fMWI07P0fMWI00<000000=WIf@3IfMT0<P3IfMT005@0fMWI00<0
o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07P0fMWI00<0
00000=WIf@3IfMT0<P3IfMT005@0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O
0=WIf@030000o`3IfMT0fMWI06<0fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI0`000006
0=WIf@030000003IfMT0fMWI0380fMWI001D0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WI
f@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1R0=WIf@040000003IfMT0fMWI000000X0fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0b0=WIf@00E03IfMT00`3o0000fMWI0=WIf@1=0=WI
f@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0H@3IfMT010000000fMWI0=WIf@000007
0=WIf@D000001P3IfMT00`000000fMWI0=WIf@0b0=WIf@00E03IfMT00`3o0000fMWI0=WIf@1=0=WI
f@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0H@3IfMT010000000fMWI0=WIf@000007
0=WIf@040000003IfMT0fMWI000000L0fMWI0`00000b0=WIf@00E03IfMT00`3o0000fMWI0=WIf@1=
0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0H@3IfMT010000000fMWI0=WIf@00
00080=WIf@030000003IfMT0000000L0fMWI00<000000=WIf@3IfMT0<P3IfMT005@0fMWI00<0o`00
0=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI0640fMWI00@00000
0=WIf@3IfMT000002@3IfMT2000000L0fMWI00<000000=WIf@3IfMT0<P3IfMT005@0fMWI00<0o`00
0=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI0680fMWI0P00000;
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0<P3IfMT005@0fMWI00<0o`000=WI
f@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07L0fMWI00<000000=WI
f@3IfMT0<P3IfMT005@0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1P0=WIf@03
0000o`3IfMT0fMWI07L0fMWI00<000000=WIf@3IfMT0<P3IfMT005@0fMWI00<0o`000=WIf@3IfMT0
C@3IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07L0fMWI00<000000=WIf@3IfMT0
<P3IfMT005@0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3I
fMT0fMWI07L0fMWI00<000000=WIf@3IfMT0<P3IfMT005D0fMWI00<0o`000=WIf@3IfMT0C03IfMT0
0`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07L0fMWI00<000000=WIf@3IfMT0<P3IfMT0
05D0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI
07L0fMWI0P00000c0=WIf@00E@3IfMT00`3o0000fMWI0=WIf@1<0=WIf@03003o003IfMT0fMWI0600
fMWI00<0003o0=WIf@3IfMT0M`3IfMT00`000000fMWI0=WIf@0b0=WIf@00E@3IfMT00`3o0000fMWI
0=WIf@1<0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0M`3IfMT00`000000fMWI
0=WIf@0b0=WIf@00E@3IfMT00`3o0000fMWI0=WIf@1<0=WIf@03003o003IfMT0fMWI0600fMWI00<0
003o0=WIf@3IfMT0M`3IfMT00`000000fMWI0=WIf@0b0=WIf@00E@3IfMT00`3o0000fMWI0=WIf@1<
0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0M`3IfMT00`000000fMWI0=WIf@0b
0=WIf@00E@3IfMT00`3o0000fMWI0=WIf@1<0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o0=WI
f@3IfMT0M`3IfMT00`000000fMWI0=WIf@0b0=WIf@00E@3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03
003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0M`3IfMT00`000000fMWI0=WIf@0b0=WIf@00
E@3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0
M`3IfMT00`000000fMWI0=WIf@0b0=WIf@00E@3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003I
fMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0M`3IfMT00`000000fMWI0=WIf@0b0=WIf@00E@3IfMT0
0`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0M`3IfMT2
000003<0fMWI001E0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`00
0?l0fMWI0=WIf@1g0=WIf@030000003IfMT0fMWI0380fMWI001E0=WIf@030?l0003IfMT0fMWI04d0
fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1g0=WIf@030000003IfMT0fMWI0380
fMWI001E0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI
0=WIf@1f0=WIf@030000003IfMT0fMWI0380fMWI001E0=WIf@030?l0003IfMT0fMWI04d0fMWI00<0
0?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1f0=WIf@030000003IfMT0fMWI0380fMWI001E
0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1f
0=WIf@030000003IfMT0fMWI0380fMWI001E0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WI
f@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1f0=WIf@030000003IfMT0fMWI0380fMWI001F0=WIf@03
0?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1f0=WIf@03
0000003IfMT0fMWI0380fMWI001F0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0
H03IfMT00`000?l0fMWI0=WIf@1f0=WIf@030000003IfMT0fMWI0380fMWI001F0=WIf@030?l0003I
fMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1f0=WIf@800000<`3I
fMT005H0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0
fMWI07H0fMWI00<000000=WIf@3IfMT0<P3IfMT005H0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00
o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07H0fMWI00<000000=WIf@3IfMT0<P3IfMT005H0
fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07H0
fMWI00<000000=WIf@3IfMT0<P3IfMT005H0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00o`00fMWI
0=WIf@1P0=WIf@030000o`3IfMT0fMWI07H0fMWI00<000000=WIf@3IfMT0<P3IfMT005H0fMWI00<0
o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07H0fMWI00<0
00000=WIf@3IfMT0<P3IfMT005H0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O
0=WIf@030000o`3IfMT0fMWI0640fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`000007
0=WIf@030000003IfMT0fMWI0380fMWI001F0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WI
f@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1P0=WIf@040000003IfMT0fMWI000000L0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0380fMWI001F0=WIf@030?l0003IfMT0
fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1P0=WIf@040000003IfMT0
fMWI000000L0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0380fMWI
001F0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WI
f@1P0=WIf@040000003IfMT0fMWI000000L0fMWI100000070=WIf@<00000<P3IfMT005H0fMWI00<0
o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI0600fMWI00@0
00000=WIf@3IfMT000001`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0380fMWI
001F0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WI
f@1P0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@0b0=WIf@00EP3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0
003o0=WIf@3IfMT0H@3IfMT2000000X0fMWI0P0000070=WIf@030000003IfMT0fMWI0380fMWI001F
0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1f
0=WIf@030000003IfMT0fMWI0380fMWI001G0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WI
f@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1f0=WIf@030000003IfMT0fMWI0380fMWI001G0=WIf@03
0?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1e0=WIf@03
0000003IfMT0fMWI0380fMWI001G0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0
H03IfMT00`000?l0fMWI0=WIf@1e0=WIf@030000003IfMT0fMWI0380fMWI001G0=WIf@030?l0003I
fMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1e0=WIf@030000003I
fMT0fMWI0380fMWI001G0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT0
0`000?l0fMWI0=WIf@1e0=WIf@800000<`3IfMT005L0fMWI00<0o`000=WIf@3IfMT0C03IfMT00`00
o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI07D0fMWI00<000000=WIf@3IfMT0<P3IfMT005L0
fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07D0
fMWI00<000000=WIf@3IfMT0<P3IfMT005L0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI
0=WIf@1O0=WIf@030000o`3IfMT0fMWI07D0fMWI00<000000=WIf@3IfMT0<P3IfMT005L0fMWI00<0
o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07D0fMWI00<0
00000=WIf@3IfMT0<P3IfMT005L0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O
0=WIf@030000o`3IfMT0fMWI07D0fMWI00<000000=WIf@3IfMT0<P3IfMT005L0fMWI00<0o`000=WI
f@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07D0fMWI00<000000=WI
f@3IfMT0<P3IfMT005L0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@03
0000o`3IfMT0fMWI07D0fMWI00<000000=WIf@3IfMT0<P3IfMT005L0fMWI00<0o`000=WIf@3IfMT0
C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI07D0fMWI00<000000=WIf@3IfMT0
<P3IfMT005L0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3I
fMT0fMWI07@0fMWI0P00000c0=WIf@00E`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0
fMWI0600fMWI00<0003o0=WIf@3IfMT0M03IfMT00`000000fMWI0=WIf@0b0=WIf@00F03IfMT00`3o
0000fMWI0=WIf@1<0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0M03IfMT00`00
0000fMWI0=WIf@0b0=WIf@00F03IfMT00`3o0000fMWI0=WIf@1<0=WIf@03003o003IfMT0fMWI0600
fMWI00<0003o0=WIf@3IfMT0M03IfMT00`000000fMWI0=WIf@0b0=WIf@00F03IfMT00`3o0000fMWI
0=WIf@1<0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0M03IfMT00`000000fMWI
0=WIf@0b0=WIf@00F03IfMT00`3o0000fMWI0=WIf@1<0=WIf@03003o003IfMT0fMWI0600fMWI00<0
003o0=WIf@3IfMT0M03IfMT00`000000fMWI0=WIf@0b0=WIf@00F03IfMT00`3o0000fMWI0=WIf@1=
0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0M03IfMT00`000000fMWI0=WIf@0b
0=WIf@00F03IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WI
f@3IfMT0M03IfMT00`000000fMWI0=WIf@0b0=WIf@00F03IfMT00`3o0000fMWI0=WIf@1=0=WIf@03
003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0M03IfMT00`000000fMWI0=WIf@0b0=WIf@00
F03IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0
M03IfMT2000003<0fMWI001H0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3I
fMT00`000?l0fMWI0=WIf@1d0=WIf@030000003IfMT0fMWI0380fMWI001H0=WIf@030?l0003IfMT0
fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1c0=WIf@030000003IfMT0
fMWI0380fMWI001H0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`00
0?l0fMWI0=WIf@1c0=WIf@030000003IfMT0fMWI0380fMWI001H0=WIf@030?l0003IfMT0fMWI04d0
fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1c0=WIf@030000003IfMT0fMWI0380
fMWI001I0=WIf@030?l0003IfMT0fMWI04`0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI
0=WIf@1c0=WIf@030000003IfMT0fMWI0380fMWI001I0=WIf@030?l0003IfMT0fMWI04`0fMWI00<0
0?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1N0=WIf@800000103IfMT00`000000fMWI0=WI
f@020=WIf@<000001`3IfMT00`000000fMWI0=WIf@0b0=WIf@00F@3IfMT00`3o0000fMWI0=WIf@1=
0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0G@3IfMT010000000fMWI0=WIf@00
00070=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@0b0=WIf@00F@3I
fMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0G@3I
fMT010000000fMWI0=WIf@0000070=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000
fMWI0=WIf@0b0=WIf@00F@3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI
00<0003o0=WIf@3IfMT0G@3IfMT010000000fMWI0=WIf@0000080=WIf@<000001`3IfMT300000380
fMWI001I0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI
0=WIf@1M0=WIf@040000003IfMT0fMWI000000L0fMWI00D000000=WIf@3IfMT0fMWI000000060=WI
f@030000003IfMT0fMWI0380fMWI001I0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3I
fMT0G`3IfMT00`000?l0fMWI0=WIf@1M0=WIf@040000003IfMT0fMWI000000L0fMWI00D000000=WI
f@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0380fMWI001I0=WIf@030?l0003IfMT0fMWI
04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1M0=WIf@8000002@3IfMT30000
00L0fMWI00<000000=WIf@3IfMT0<P3IfMT005T0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00
fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI0780fMWI00<000000=WIf@3IfMT0<P3IfMT005T0fMWI
00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI0780fMWI
00<000000=WIf@3IfMT0<P3IfMT005T0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WI
f@1P0=WIf@030000o`3IfMT0fMWI0780fMWI00<000000=WIf@3IfMT0<P3IfMT005X0fMWI00<0o`00
0=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI0780fMWI00<00000
0=WIf@3IfMT0<P3IfMT005X0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WI
f@030000o`3IfMT0fMWI0780fMWI00<000000=WIf@3IfMT0<P3IfMT005X0fMWI00<0o`000=WIf@3I
fMT0C@3IfMT00`00o`00fMWI0=WIf@1O0=WIf@030000o`3IfMT0fMWI0780fMWI0P00000c0=WIf@00
FP3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0
L@3IfMT00`000000fMWI0=WIf@0b0=WIf@00FP3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003I
fMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0L@3IfMT00`000000fMWI0=WIf@0b0=WIf@00FP3IfMT0
0`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0L@3IfMT0
0`000000fMWI0=WIf@0b0=WIf@00FP3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI
0600fMWI00<0003o0=WIf@3IfMT0L@3IfMT00`000000fMWI0=WIf@0b0=WIf@00FP3IfMT00`3o0000
fMWI0=WIf@1>0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0L@3IfMT00`000000
fMWI0=WIf@0b0=WIf@00F`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI05l0fMWI
00<0003o0=WIf@3IfMT0L@3IfMT00`000000fMWI0=WIf@0b0=WIf@00F`3IfMT00`3o0000fMWI0=WI
f@1=0=WIf@03003o003IfMT0fMWI05l0fMWI00<0003o0=WIf@3IfMT0L@3IfMT00`000000fMWI0=WI
f@0b0=WIf@00F`3IfMT00`3o0000fMWI0=WIf@1=0=WIf@03003o003IfMT0fMWI0600fMWI00<0003o
0=WIf@3IfMT0L03IfMT00`000000fMWI0=WIf@0b0=WIf@00F`3IfMT00`3o0000fMWI0=WIf@1=0=WI
f@03003o003IfMT0fMWI0600fMWI00<0003o0=WIf@3IfMT0L03IfMT2000003<0fMWI001K0=WIf@03
0?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1`0=WIf@03
0000003IfMT0fMWI0380fMWI001K0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0
H03IfMT00`000?l0fMWI0=WIf@1`0=WIf@030000003IfMT0fMWI0380fMWI001K0=WIf@030?l0003I
fMT0fMWI04h0fMWI00<00?l00=WIf@3IfMT0G`3IfMT00`000?l0fMWI0=WIf@1`0=WIf@030000003I
fMT0fMWI0380fMWI001L0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT0
0`000?l0fMWI0=WIf@1_0=WIf@030000003IfMT0fMWI0380fMWI001L0=WIf@030?l0003IfMT0fMWI
04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1_0=WIf@030000003IfMT0fMWI
0380fMWI001L0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H03IfMT00`000?l0
fMWI0=WIf@1_0=WIf@030000003IfMT0fMWI0380fMWI001L0=WIf@030?l0003IfMT0fMWI04d0fMWI
00<00?l00=WIf@3IfMT0H@3IfMT00`000?l0fMWI0=WIf@1^0=WIf@030000003IfMT0fMWI0380fMWI
001L0=WIf@030?l0003IfMT0fMWI04d0fMWI00<00?l00=WIf@3IfMT0H@3IfMT00`000?l0fMWI0=WI
f@1^0=WIf@030000003IfMT0fMWI0380fMWI001L0=WIf@030?l0003IfMT0fMWI04h0fMWI00<00?l0
0=WIf@3IfMT0H03IfMT00`000?l0fMWI0=WIf@1^0=WIf@800000<`3IfMT005`0fMWI00<0o`000=WI
f@3IfMT0CP3IfMT00`00o`00fMWI0=WIf@1P0=WIf@030000o`3IfMT0fMWI06h0fMWI00<000000=WI
f@3IfMT0<P3IfMT005`0fMWI00<0o`000=WIf@3IfMT0CP3IfMT00`00o`00fMWI0=WIf@1Q0=WIf@03
0000o`3IfMT0fMWI06d0fMWI00<000000=WIf@3IfMT0<P3IfMT005`0fMWI00<0o`000=WIf@3IfMT0
CP3IfMT00`00o`00fMWI0=WIf@1Q0=WIf@030000o`3IfMT0fMWI06d0fMWI00<000000=WIf@3IfMT0
<P3IfMT005d0fMWI00<0o`000=WIf@3IfMT0C@3IfMT00`00o`00fMWI0=WIf@1Q0=WIf@030000o`3I
fMT0fMWI06d0fMWI00<000000=WIf@3IfMT0<P3IfMT005d0fMWI00<0o`000=WIf@3IfMT0CP3IfMT0
0`00o`00fMWI0=WIf@1Q0=WIf@030000o`3IfMT0fMWI06`0fMWI00<000000=WIf@3IfMT0<P3IfMT0
05d0fMWI00<0o`000=WIf@3IfMT0CP3IfMT00`00o`00fMWI0=WIf@1Q0=WIf@030000o`3IfMT0fMWI
0680fMWI0`0000070=WIf@030000003IfMT0fMWI0380fMWI001M0=WIf@030?l0003IfMT0fMWI04h0
fMWI00<00?l00=WIf@3IfMT0H@3IfMT00`000?l0fMWI0=WIf@1S0=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0<P3IfMT005d0fMWI00<0o`000=WIf@3IfMT0CP3IfMT00`00o`00fMWI
0=WIf@1R0=WIf@030000o`3IfMT0fMWI0680fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI
0=WIf@0b0=WIf@00G@3IfMT00`3o0000fMWI0=WIf@1>0=WIf@03003o003IfMT0fMWI0680fMWI00<0
003o0=WIf@3IfMT0HP3IfMT00`000000fMWI0=WIf@060=WIf@<00000<P3IfMT005d0fMWI00<0o`00
0=WIf@3IfMT0CP3IfMT00`00o`00fMWI0=WIf@1R0=WIf@030000o`3IfMT0fMWI0680fMWI00<00000
0=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0b0=WIf@00GP3IfMT00`3o0000fMWI0=WIf@1=0=WI
f@03003o003IfMT0fMWI0680fMWI00<0003o0=WIf@3IfMT0H@3IfMT2000000P0fMWI00<000000=WI
f@3IfMT0<P3IfMT005h0fMWI00<0o`000=WIf@3IfMT0CP3IfMT00`00o`00fMWI0=WIf@1R0=WIf@03
0000o`3IfMT0fMWI0640fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@0b0=WIf@00
GP3IfMT00`3o0000fMWI0=WIf@1>0=WIf@03003o003IfMT0fMWI06<0fMWI00<0003o0=WIf@3IfMT0
J@3IfMT00`000000fMWI0=WIf@0b0=WIf@00GP3IfMT00`3o0000fMWI0=WIf@1>0=WIf@03003o003I
fMT0fMWI06@0fMWI00<0003o0=WIf@3IfMT0J03IfMT00`000000fMWI0=WIf@0b0=WIf@00G`3IfMT0
0`3o0000fMWI0=WIf@1>0=WIf@03003o003IfMT0fMWI06@0fMWI0P000?mX0=WIf@030000003IfMT0
fMWI0380fMWI001O0=WIf@030?l0003IfMT0fMWI04h0fMWI00<00?l00=WIf@3IfMT0IP3IfMT00`00
0?l0fMWI0=WIf@1U0=WIf@030000003IfMT0fMWI0380fMWI001O0=WIf@030?l0003IfMT0fMWI04l0
fMWI00<00?l00=WIf@3IfMT0IP3IfMT00`000?l0fMWI0=WIf@1T0=WIf@030000003IfMT0fMWI0380
fMWI001P0=WIf@030?l0003IfMT0fMWI04h0fMWI00<00?l00=WIf@3IfMT0I`3IfMT40000of80fMWI
0P00000c0=WIf@00H03IfMT00`3o0000fMWI0=WIf@1?0=WIf@03003o003IfMT0fMWI06X0fMWI1000
0?mN0=WIf@030000003IfMT0fMWI0380fMWI001P0=WIf@030?l0003IfMT0fMWI0500fMWI00<00?l0
0=WIf@3IfMT0K@3IfMT>0000oe00fMWI00<000000=WIf@3IfMT0<P3IfMT00640fMWI00<0o`000=WI
f@3IfMT0D03IfMT00`00o`00fMWI0=WIf@1j0=WIf@`0003oA03IfMT00`000000fMWI0=WIf@0b0=WI
f@00H@3IfMT00`3o0000fMWI0=WIf@1@0=WIf@03003o003IfMT0fMWI08H0fMWI40000?ld0=WIf@03
0000003IfMT0fMWI0380fMWI001R0=WIf@030?l0003IfMT0fMWI0500fMWI0P00o`2F0=WIf@h0003o
9P3IfMT00`000000fMWI0=WIf@0b0=WIf@00HP3IfMT00`3o0000fMWI0=WIf@1B0=WIf@03003o003I
fMT0fMWI0:40fMWI7`000?l70=WIf@030000003IfMT0fMWI0380fMWI001S0=WIf@030?l0003IfMT0
fMWI0580fMWI0`00o`2o0=WIf@P0003o=03IfMT006@0fMWI00<0o`000=WIf@3IfMT0E03IfMT2003o
0<@0fMWI00<000000=WIf@3IfMT0<P3IfMT006D0fMWI00<0o`000=WIf@3IfMT0E@3IfMT7003o0;d0
fMWI0P00000c0=WIf@00IP3IfMT30?l005/0fMWI4@00o`2/0=WIf@030000003IfMT0fMWI0380fMWI
001Y0=WIf@80o`00JP3IfMT?003o09d0fMWI00<000000=WIf@3IfMT0<P3IfMT006/0fMWI0P3o001g
0=WIf@l00?l0SP3IfMT00`000000fMWI0=WIf@0b0=WIf@00K@3IfMT30?l008<0fMWI3`00o`1o0=WI
f@030000003IfMT0fMWI0380fMWI001`0=WIf@T0o`00R@3IfMT?003o0700fMWI00<000000=WIf@3I
fMT0<P3IfMT007T0fMWI4@3o00270=WIfA000?l0H03IfMT00`000000fMWI0=WIf@0b0=WIf@00RP3I
fMT@0?l008L0fMWI3P00o`1B0=WIf@030000003IfMT0fMWI0380fMWI002J0=WIf@h0o`00Q`3IfMTO
003o03<0fMWI00<000000=WIf@3IfMT0<P3IfMT00:P0fMWI3`3o002G0=WIf@l00?l0903IfMT20000
03<0fMWI002g0=WIfA00o`00UP3IfMT?003o01D0fMWI00<000000=WIf@3IfMT0<P3IfMT00<L0fMWI
3`3o002F0=WIfAH00?l0=03IfMT00=H0fMWI7P3o002=0=WIf@030000003IfMT0fMWI0380fMWI003d
0=WIf@l0o`00OP3IfMT00`000000fMWI0=WIf@0b0=WIf@00o`3IfMT40=WIfA00o`00KP3IfMT00`00
0000fMWI0=WIf@0b0=WIf@00o`3IfMTD0=WIf@h0o`00BP3IfMT3000000@0fMWI00@000000=WIf@3I
fMT0fMWI1@0000060=WIf@030000003IfMT0fMWI0380fMWI003o0=WIfB80fMWI7P3o000]0=WIf@03
0000003IfMT0fMWI00P0fMWI00@000000=WIf@3IfMT000001P3IfMT00`000000fMWI0=WIf@0b0=WI
f@00o`3IfMU00=WIf@l0o`007P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0fMWI00H0
fMWI00<000000=WIf@3IfMT0<P3IfMT00?l0fMWIC`3IfMT@0?l000h0fMWI00<000000=WIf@3IfMT0
2P3IfMT00`000000fMWI0=WIf@050=WIf@<00000<P3IfMT00?l0fMWIG`3IfMTM0?l000H0fMWI00<0
00000=WIf@3IfMT0<P3IfMT00?l0fMWIK03IfMT2000000T0fMWI00D000000=WIf@3IfMT0fMWI0000
00070?l003@0fMWI003o0=WIfFd0fMWI00<000000=WIf@3IfMT0203IfMT3000000L0fMWI00<00000
0=WIf@3IfMT0<P3IfMT00?l0fMWIPP3IfMT00`000000fMWI0=WIf@0b0=WIf@00o`3IfMV20=WIf@03
0000003IfMT0fMWI0380fMWI003o0=WIfH80fMWI00<000000=WIf@3IfMT0<P3IfMT00?l0fMWIPP3I
fMT00`000000fMWI0=WIf@0b0=WIf@00o`3IfMV20=WIf@030000003IfMT0fMWI0380fMWI003o0=WI
fH80fMWI0P00000c0=WIf@00o`3IfMV20=WIf@030000003IfMT0fMWI0380fMWI003o0=WIfH80fMWI
00<000000=WIf@3IfMT0<P3IfMT00?l0fMWIPP3IfMT00`000000fMWI0=WIf@0b0=WIf@00o`3IfMV2
0=WIf@030000003IfMT0fMWI0380fMWI003o0=WIfH80fMWI00<000000=WIf@3IfMT0<P3IfMT00?l0
fMWIPP3IfMT00`000000fMWI0=WIf@0b0=WIf@00o`3IfMV20=WIf@030000003IfMT0fMWI0380fMWI
003o0=WIfH80fMWI00<000000=WIf@3IfMT0<P3IfMT00?l0fMWIPP3IfMT00`000000fMWI0=WIf@0b
0=WIf@00o`3IfMVg0=WIf@00o`3IfMVg0=WIf@00o`3IfMVg0=WIf@00o`3IfMVg0=WIf@00o`3IfMVg
0=WIf@00o`3IfMVg0=WIf@00o`3IfMVg0=WIf@00o`3IfMVg0=WIf@00o`3IfMVg0=WIf@00o`3IfMVg
0=WIf@00o`3IfMUi0=WIf@030000003IfMT0fMWI03/0fMWI003o0=WIfGT0fMWI00<000000=WIf@3I
fMT0>`3IfMT00?l0fMWIN@3IfMT600000080fMWI0P0000020=WIf@80000000@0fMWI000000000000
0000;03IfMT00?l0fMWIN@3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00H000000=WIf@3I
fMT000000=WIf@0000030=WIf@030000003IfMT0fMWI02/0fMWI003o0=WIfGX0fMWI00@000000=WI
f@3IfMT000000P3IfMT01P000000fMWI0=WIf@000000fMWI000000<0fMWI00<000000=WIf@3IfMT0
:`3IfMT00?l0fMWINP3IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000000P3IfMT00`000000
fMWI000000030=WIf@030000003IfMT0fMWI02/0fMWI003o0=WIfGX0fMWI00L000000=WIf@3IfMT0
fMWI0000003IfMT000000080fMWI00L000000=WIf@000000fMWI0000003IfMT0000002d0fMWI003o
0=WIfH00fMWI00D000000=WIf@3IfMT000000=WIf@02000000030=WIf@000000000002d0fMWI003o
0=WIfH40fMWI0P0000020=WIf@040000003IfMT0fMWI0=WIf@800000;03IfMT00?l0fMWI]`3IfMT0
0?l0fMWI]`3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 437.375}, {269.938, 0}} -> {-2.66306, -0.0761516, \
0.00691252, 0.00553908}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving", "Section"],

Cell[CellGroupData[{

Cell["\<\
Solve problem at constant temperature with varying applied \
field\
\>", "Subsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Prec = 0.00001;\)\), "\n", 
    \(\(Nmax = 300;\)\), "\[IndentingNewLine]", 
    \(\(mat = matNdFeB;\)\), "\[IndentingNewLine]", 
    \(\(Temp = 20;\)\), "\[IndentingNewLine]", 
    \(\(H1 = \(-2.1\);\)\), "\[IndentingNewLine]", 
    \(\(H2 = 1. ;\)\), "\[IndentingNewLine]", 
    \(\(Npt = 30;\)\), "\[IndentingNewLine]", 
    \(\(dH = \((H2 - H1)\)/\((Npt - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(Tb1 = Table[{H, 0}, {H, H1, H2, dH}];\)\), "\[IndentingNewLine]", 
    \(\(Tb2 = Tb1;\)\), "\[IndentingNewLine]", 
    \(\(t1 = AbsoluteTime[];\)\), "\n", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        SphericalVolume[1. , 15, 
          15, {0, 0. , 1}];\)\), "\[IndentingNewLine]", 
    \(\(radObjDrwAtr[g, {0, 0.5, 0.8}];\)\), "\[IndentingNewLine]", 
    \(\(mat2 = MatCoef[mat, Temp];\)\), "\[IndentingNewLine]", 
    \(\(matp = 
        radMatSatAniso[mat2[\([1]\)], 
          mat2[\([2]\)]];\)\), "\[IndentingNewLine]", 
    \(\(radMatApl[g, matp];\)\), "\[IndentingNewLine]", 
    \(\(Do[\[IndentingNewLine]extfield = 
          radObjBckg[{0, 0, H1 + \((i - 1)\)*dH}]; \[IndentingNewLine]Grp = 
          radObjCnt[{g, extfield}]; \[IndentingNewLine]Mtrx = 
          radRlxPre[Grp]; \[IndentingNewLine]radRlxMan[Mtrx, 2, 200, 
          0.001]; \[IndentingNewLine]radRlxMan[Mtrx, 2, 200, 
          0.01]; \[IndentingNewLine]radRlxMan[Mtrx, 2, 300, 
          0.1]; \[IndentingNewLine]Tb2[\([i, 1]\)] = 
          radFld[Grp, "\<hz\>", {0.01, 0, 0}]; \[IndentingNewLine]Tb1[\([i, 
              2]\)] = radFld[
            Grp, "\<mz\>", {0.01, 0, 0}]; \[IndentingNewLine]Tb2[\([i, 
              2]\)] = Tb1[\([i, 2]\)]; \[IndentingNewLine]radUtiDel[
          Grp], \[IndentingNewLine]{i, 1, 
          Npt}\[IndentingNewLine]];\)\), "\[IndentingNewLine]", 
    \(\(t2 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solved in \>", \ 
        t2 - t1, "\< Sec.\>"];\)\), "\[IndentingNewLine]", 
    \(MultipleListPlot[Tb1, Tb2, PlotRange \[Rule] All, 
      PlotJoined \[Rule] True, AxesLabel \[Rule] {\[Mu]0H, \[Mu]0M}, 
      PlotLegend \[Rule] {"\<\[Mu]0M(\[Mu]0Hext)\>", \
"\<\[Mu]0M(\[Mu]0Htot)\>"}, LegendSize \[Rule] {0.5, 0.25}, 
      LegendPosition \[Rule] {0.3, 0.0}]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Solved in "\[InvisibleSpace]5.`6.4185\
\[InvisibleSpace]" Sec."\),
      SequenceForm[ "Solved in ", 5.`6.4185, " Sec."],
      Editable->False]], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.668971 0.30722 0.0147151 0.477515 [
[.05453 .00222 -6 -9 ]
[.05453 .00222 6 0 ]
[.20814 .00222 -12 -9 ]
[.20814 .00222 12 0 ]
[.36175 .00222 -6 -9 ]
[.36175 .00222 6 0 ]
[.51536 .00222 -12 -9 ]
[.51536 .00222 12 0 ]
[.82258 .00222 -9 -9 ]
[.82258 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 22 6 ]
[.65647 .11022 -18 -4.5 ]
[.65647 .11022 0 4.5 ]
[.65647 .20572 -18 -4.5 ]
[.65647 .20572 0 4.5 ]
[.65647 .30122 -18 -4.5 ]
[.65647 .30122 0 4.5 ]
[.65647 .39673 -18 -4.5 ]
[.65647 .39673 0 4.5 ]
[.65647 .49223 -6 -4.5 ]
[.65647 .49223 0 4.5 ]
[.65647 .58773 -18 -4.5 ]
[.65647 .58773 0 4.5 ]
[.66897 .64303 -11 0 ]
[.66897 .64303 11 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05453 .01472 m
.05453 .02097 L
s
[(-2)] .05453 .00222 0 1 Mshowa
.20814 .01472 m
.20814 .02097 L
s
[(-1.5)] .20814 .00222 0 1 Mshowa
.36175 .01472 m
.36175 .02097 L
s
[(-1)] .36175 .00222 0 1 Mshowa
.51536 .01472 m
.51536 .02097 L
s
[(-0.5)] .51536 .00222 0 1 Mshowa
.82258 .01472 m
.82258 .02097 L
s
[(0.5)] .82258 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(1)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.08525 .01472 m
.08525 .01847 L
s
.11598 .01472 m
.11598 .01847 L
s
.1467 .01472 m
.1467 .01847 L
s
.17742 .01472 m
.17742 .01847 L
s
.23886 .01472 m
.23886 .01847 L
s
.26959 .01472 m
.26959 .01847 L
s
.30031 .01472 m
.30031 .01847 L
s
.33103 .01472 m
.33103 .01847 L
s
.39247 .01472 m
.39247 .01847 L
s
.4232 .01472 m
.4232 .01847 L
s
.45392 .01472 m
.45392 .01847 L
s
.48464 .01472 m
.48464 .01847 L
s
.54608 .01472 m
.54608 .01847 L
s
.5768 .01472 m
.5768 .01847 L
s
.60753 .01472 m
.60753 .01847 L
s
.63825 .01472 m
.63825 .01847 L
s
.69969 .01472 m
.69969 .01847 L
s
.73041 .01472 m
.73041 .01847 L
s
.76114 .01472 m
.76114 .01847 L
s
.79186 .01472 m
.79186 .01847 L
s
.8533 .01472 m
.8533 .01847 L
s
.88402 .01472 m
.88402 .01847 L
s
.91475 .01472 m
.91475 .01847 L
s
.94547 .01472 m
.94547 .01847 L
s
.02381 .01472 m
.02381 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0H) show
1.000 setlinewidth
grestore
.66897 .11022 m
.67522 .11022 L
s
[(0.2)] .65647 .11022 1 0 Mshowa
.66897 .20572 m
.67522 .20572 L
s
[(0.4)] .65647 .20572 1 0 Mshowa
.66897 .30122 m
.67522 .30122 L
s
[(0.6)] .65647 .30122 1 0 Mshowa
.66897 .39673 m
.67522 .39673 L
s
[(0.8)] .65647 .39673 1 0 Mshowa
.66897 .49223 m
.67522 .49223 L
s
[(1)] .65647 .49223 1 0 Mshowa
.66897 .58773 m
.67522 .58773 L
s
[(1.2)] .65647 .58773 1 0 Mshowa
.125 Mabswid
.66897 .03859 m
.67272 .03859 L
s
.66897 .06247 m
.67272 .06247 L
s
.66897 .08634 m
.67272 .08634 L
s
.66897 .13409 m
.67272 .13409 L
s
.66897 .15797 m
.67272 .15797 L
s
.66897 .18185 m
.67272 .18185 L
s
.66897 .2296 m
.67272 .2296 L
s
.66897 .25347 m
.67272 .25347 L
s
.66897 .27735 m
.67272 .27735 L
s
.66897 .3251 m
.67272 .3251 L
s
.66897 .34898 m
.67272 .34898 L
s
.66897 .37285 m
.67272 .37285 L
s
.66897 .4206 m
.67272 .4206 L
s
.66897 .44448 m
.67272 .44448 L
s
.66897 .46835 m
.67272 .46835 L
s
.66897 .51611 m
.67272 .51611 L
s
.66897 .53998 m
.67272 .53998 L
s
.66897 .56386 m
.67272 .56386 L
s
.66897 .61161 m
.67272 .61161 L
s
.25 Mabswid
.66897 0 m
.66897 .61803 L
s
gsave
.66897 .64303 -72 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0M) show
1.000 setlinewidth
grestore
.001 w
.02381 .01472 m
.05665 .14594 L
.08949 .27455 L
.12233 .39587 L
.15517 .49693 L
.18801 .54606 L
.22085 .55478 L
.25369 .55772 L
.28654 .56014 L
.31938 .56248 L
.35222 .5648 L
.38506 .56709 L
.4179 .56937 L
.45074 .57163 L
.48358 .57386 L
.51642 .57607 L
.54926 .57825 L
.5821 .5804 L
.61494 .58251 L
.64778 .5846 L
.68062 .58665 L
.71346 .58866 L
.74631 .59063 L
.77915 .59257 L
.81199 .59446 L
.84483 .59632 L
.87767 .59813 L
.91051 .5999 L
.94335 .60163 L
.97619 .60332 L
s
.0001 w
.02381 .01472 -1.875 0 Mabsadd m
.02381 .01472 0 2.5 Mabsadd L
.02381 .01472 1.875 0 Mabsadd L
.02381 .01472 0 -2.5 Mabsadd L
.02381 .01472 -1.875 0 Mabsadd L closepath F
.05665 .14594 -1.875 0 Mabsadd m
.05665 .14594 0 2.5 Mabsadd L
.05665 .14594 1.875 0 Mabsadd L
.05665 .14594 0 -2.5 Mabsadd L
.05665 .14594 -1.875 0 Mabsadd L closepath F
.08949 .27455 -1.875 0 Mabsadd m
.08949 .27455 0 2.5 Mabsadd L
.08949 .27455 1.875 0 Mabsadd L
.08949 .27455 0 -2.5 Mabsadd L
.08949 .27455 -1.875 0 Mabsadd L closepath F
.12233 .39587 -1.875 0 Mabsadd m
.12233 .39587 0 2.5 Mabsadd L
.12233 .39587 1.875 0 Mabsadd L
.12233 .39587 0 -2.5 Mabsadd L
.12233 .39587 -1.875 0 Mabsadd L closepath F
.15517 .49693 -1.875 0 Mabsadd m
.15517 .49693 0 2.5 Mabsadd L
.15517 .49693 1.875 0 Mabsadd L
.15517 .49693 0 -2.5 Mabsadd L
.15517 .49693 -1.875 0 Mabsadd L closepath F
.18801 .54606 -1.875 0 Mabsadd m
.18801 .54606 0 2.5 Mabsadd L
.18801 .54606 1.875 0 Mabsadd L
.18801 .54606 0 -2.5 Mabsadd L
.18801 .54606 -1.875 0 Mabsadd L closepath F
.22085 .55478 -1.875 0 Mabsadd m
.22085 .55478 0 2.5 Mabsadd L
.22085 .55478 1.875 0 Mabsadd L
.22085 .55478 0 -2.5 Mabsadd L
.22085 .55478 -1.875 0 Mabsadd L closepath F
.25369 .55772 -1.875 0 Mabsadd m
.25369 .55772 0 2.5 Mabsadd L
.25369 .55772 1.875 0 Mabsadd L
.25369 .55772 0 -2.5 Mabsadd L
.25369 .55772 -1.875 0 Mabsadd L closepath F
.28654 .56014 -1.875 0 Mabsadd m
.28654 .56014 0 2.5 Mabsadd L
.28654 .56014 1.875 0 Mabsadd L
.28654 .56014 0 -2.5 Mabsadd L
.28654 .56014 -1.875 0 Mabsadd L closepath F
.31938 .56248 -1.875 0 Mabsadd m
.31938 .56248 0 2.5 Mabsadd L
.31938 .56248 1.875 0 Mabsadd L
.31938 .56248 0 -2.5 Mabsadd L
.31938 .56248 -1.875 0 Mabsadd L closepath F
.35222 .5648 -1.875 0 Mabsadd m
.35222 .5648 0 2.5 Mabsadd L
.35222 .5648 1.875 0 Mabsadd L
.35222 .5648 0 -2.5 Mabsadd L
.35222 .5648 -1.875 0 Mabsadd L closepath F
.38506 .56709 -1.875 0 Mabsadd m
.38506 .56709 0 2.5 Mabsadd L
.38506 .56709 1.875 0 Mabsadd L
.38506 .56709 0 -2.5 Mabsadd L
.38506 .56709 -1.875 0 Mabsadd L closepath F
.4179 .56937 -1.875 0 Mabsadd m
.4179 .56937 0 2.5 Mabsadd L
.4179 .56937 1.875 0 Mabsadd L
.4179 .56937 0 -2.5 Mabsadd L
.4179 .56937 -1.875 0 Mabsadd L closepath F
.45074 .57163 -1.875 0 Mabsadd m
.45074 .57163 0 2.5 Mabsadd L
.45074 .57163 1.875 0 Mabsadd L
.45074 .57163 0 -2.5 Mabsadd L
.45074 .57163 -1.875 0 Mabsadd L closepath F
.48358 .57386 -1.875 0 Mabsadd m
.48358 .57386 0 2.5 Mabsadd L
.48358 .57386 1.875 0 Mabsadd L
.48358 .57386 0 -2.5 Mabsadd L
.48358 .57386 -1.875 0 Mabsadd L closepath F
.51642 .57607 -1.875 0 Mabsadd m
.51642 .57607 0 2.5 Mabsadd L
.51642 .57607 1.875 0 Mabsadd L
.51642 .57607 0 -2.5 Mabsadd L
.51642 .57607 -1.875 0 Mabsadd L closepath F
.54926 .57825 -1.875 0 Mabsadd m
.54926 .57825 0 2.5 Mabsadd L
.54926 .57825 1.875 0 Mabsadd L
.54926 .57825 0 -2.5 Mabsadd L
.54926 .57825 -1.875 0 Mabsadd L closepath F
.5821 .5804 -1.875 0 Mabsadd m
.5821 .5804 0 2.5 Mabsadd L
.5821 .5804 1.875 0 Mabsadd L
.5821 .5804 0 -2.5 Mabsadd L
.5821 .5804 -1.875 0 Mabsadd L closepath F
.61494 .58251 -1.875 0 Mabsadd m
.61494 .58251 0 2.5 Mabsadd L
.61494 .58251 1.875 0 Mabsadd L
.61494 .58251 0 -2.5 Mabsadd L
.61494 .58251 -1.875 0 Mabsadd L closepath F
.64778 .5846 -1.875 0 Mabsadd m
.64778 .5846 0 2.5 Mabsadd L
.64778 .5846 1.875 0 Mabsadd L
.64778 .5846 0 -2.5 Mabsadd L
.64778 .5846 -1.875 0 Mabsadd L closepath F
.68062 .58665 -1.875 0 Mabsadd m
.68062 .58665 0 2.5 Mabsadd L
.68062 .58665 1.875 0 Mabsadd L
.68062 .58665 0 -2.5 Mabsadd L
.68062 .58665 -1.875 0 Mabsadd L closepath F
.71346 .58866 -1.875 0 Mabsadd m
.71346 .58866 0 2.5 Mabsadd L
.71346 .58866 1.875 0 Mabsadd L
.71346 .58866 0 -2.5 Mabsadd L
.71346 .58866 -1.875 0 Mabsadd L closepath F
.74631 .59063 -1.875 0 Mabsadd m
.74631 .59063 0 2.5 Mabsadd L
.74631 .59063 1.875 0 Mabsadd L
.74631 .59063 0 -2.5 Mabsadd L
.74631 .59063 -1.875 0 Mabsadd L closepath F
.77915 .59257 -1.875 0 Mabsadd m
.77915 .59257 0 2.5 Mabsadd L
.77915 .59257 1.875 0 Mabsadd L
.77915 .59257 0 -2.5 Mabsadd L
.77915 .59257 -1.875 0 Mabsadd L closepath F
.81199 .59446 -1.875 0 Mabsadd m
.81199 .59446 0 2.5 Mabsadd L
.81199 .59446 1.875 0 Mabsadd L
.81199 .59446 0 -2.5 Mabsadd L
.81199 .59446 -1.875 0 Mabsadd L closepath F
.84483 .59632 -1.875 0 Mabsadd m
.84483 .59632 0 2.5 Mabsadd L
.84483 .59632 1.875 0 Mabsadd L
.84483 .59632 0 -2.5 Mabsadd L
.84483 .59632 -1.875 0 Mabsadd L closepath F
.87767 .59813 -1.875 0 Mabsadd m
.87767 .59813 0 2.5 Mabsadd L
.87767 .59813 1.875 0 Mabsadd L
.87767 .59813 0 -2.5 Mabsadd L
.87767 .59813 -1.875 0 Mabsadd L closepath F
.91051 .5999 -1.875 0 Mabsadd m
.91051 .5999 0 2.5 Mabsadd L
.91051 .5999 1.875 0 Mabsadd L
.91051 .5999 0 -2.5 Mabsadd L
.91051 .5999 -1.875 0 Mabsadd L closepath F
.94335 .60163 -1.875 0 Mabsadd m
.94335 .60163 0 2.5 Mabsadd L
.94335 .60163 1.875 0 Mabsadd L
.94335 .60163 0 -2.5 Mabsadd L
.94335 .60163 -1.875 0 Mabsadd L closepath F
.97619 .60332 -1.875 0 Mabsadd m
.97619 .60332 0 2.5 Mabsadd L
.97619 .60332 1.875 0 Mabsadd L
.97619 .60332 0 -2.5 Mabsadd L
.97619 .60332 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .01472 m
.0284 .14594 L
.03356 .27455 L
.04029 .39587 L
.05138 .49693 L
.07364 .54606 L
.1046 .55478 L
.13681 .55772 L
.16913 .56014 L
.20147 .56248 L
.23381 .5648 L
.26616 .56709 L
.29851 .56937 L
.33086 .57163 L
.36322 .57386 L
.39559 .57607 L
.42796 .57825 L
.46034 .5804 L
.49272 .58251 L
.52512 .5846 L
.55752 .58665 L
.58992 .58866 L
.62234 .59063 L
.65476 .59257 L
.6872 .59446 L
.71964 .59632 L
.75209 .59813 L
.78455 .5999 L
.81702 .60163 L
.84949 .60332 L
s
.0001 w
[ ] 0 setdash
.02381 .01472 0 2.5 Mabsadd m
.02381 .01472 -0.56518 .7779 Mabsadd L
.02381 .01472 -2.37764 .77254 Mabsadd L
.02381 .01472 -0.91448 -0.29713 Mabsadd L
.02381 .01472 -1.46946 -2.02254 Mabsadd L
.02381 .01472 0 -0.96154 Mabsadd L
.02381 .01472 1.46946 -2.02254 Mabsadd L
.02381 .01472 .91448 -0.29713 Mabsadd L
.02381 .01472 2.37764 .77254 Mabsadd L
.02381 .01472 .56518 .7779 Mabsadd L
.02381 .01472 0 2.5 Mabsadd L closepath F
.0284 .14594 0 2.5 Mabsadd m
.0284 .14594 -0.56518 .7779 Mabsadd L
.0284 .14594 -2.37764 .77254 Mabsadd L
.0284 .14594 -0.91448 -0.29713 Mabsadd L
.0284 .14594 -1.46946 -2.02254 Mabsadd L
.0284 .14594 0 -0.96154 Mabsadd L
.0284 .14594 1.46946 -2.02254 Mabsadd L
.0284 .14594 .91448 -0.29713 Mabsadd L
.0284 .14594 2.37764 .77254 Mabsadd L
.0284 .14594 .56518 .7779 Mabsadd L
.0284 .14594 0 2.5 Mabsadd L closepath F
.03356 .27455 0 2.5 Mabsadd m
.03356 .27455 -0.56518 .7779 Mabsadd L
.03356 .27455 -2.37764 .77254 Mabsadd L
.03356 .27455 -0.91448 -0.29713 Mabsadd L
.03356 .27455 -1.46946 -2.02254 Mabsadd L
.03356 .27455 0 -0.96154 Mabsadd L
.03356 .27455 1.46946 -2.02254 Mabsadd L
.03356 .27455 .91448 -0.29713 Mabsadd L
.03356 .27455 2.37764 .77254 Mabsadd L
.03356 .27455 .56518 .7779 Mabsadd L
.03356 .27455 0 2.5 Mabsadd L closepath F
.04029 .39587 0 2.5 Mabsadd m
.04029 .39587 -0.56518 .7779 Mabsadd L
.04029 .39587 -2.37764 .77254 Mabsadd L
.04029 .39587 -0.91448 -0.29713 Mabsadd L
.04029 .39587 -1.46946 -2.02254 Mabsadd L
.04029 .39587 0 -0.96154 Mabsadd L
.04029 .39587 1.46946 -2.02254 Mabsadd L
.04029 .39587 .91448 -0.29713 Mabsadd L
.04029 .39587 2.37764 .77254 Mabsadd L
.04029 .39587 .56518 .7779 Mabsadd L
.04029 .39587 0 2.5 Mabsadd L closepath F
.05138 .49693 0 2.5 Mabsadd m
.05138 .49693 -0.56518 .7779 Mabsadd L
.05138 .49693 -2.37764 .77254 Mabsadd L
.05138 .49693 -0.91448 -0.29713 Mabsadd L
.05138 .49693 -1.46946 -2.02254 Mabsadd L
.05138 .49693 0 -0.96154 Mabsadd L
.05138 .49693 1.46946 -2.02254 Mabsadd L
.05138 .49693 .91448 -0.29713 Mabsadd L
.05138 .49693 2.37764 .77254 Mabsadd L
.05138 .49693 .56518 .7779 Mabsadd L
.05138 .49693 0 2.5 Mabsadd L closepath F
.07364 .54606 0 2.5 Mabsadd m
.07364 .54606 -0.56518 .7779 Mabsadd L
.07364 .54606 -2.37764 .77254 Mabsadd L
.07364 .54606 -0.91448 -0.29713 Mabsadd L
.07364 .54606 -1.46946 -2.02254 Mabsadd L
.07364 .54606 0 -0.96154 Mabsadd L
.07364 .54606 1.46946 -2.02254 Mabsadd L
.07364 .54606 .91448 -0.29713 Mabsadd L
.07364 .54606 2.37764 .77254 Mabsadd L
.07364 .54606 .56518 .7779 Mabsadd L
.07364 .54606 0 2.5 Mabsadd L closepath F
.1046 .55478 0 2.5 Mabsadd m
.1046 .55478 -0.56518 .7779 Mabsadd L
.1046 .55478 -2.37764 .77254 Mabsadd L
.1046 .55478 -0.91448 -0.29713 Mabsadd L
.1046 .55478 -1.46946 -2.02254 Mabsadd L
.1046 .55478 0 -0.96154 Mabsadd L
.1046 .55478 1.46946 -2.02254 Mabsadd L
.1046 .55478 .91448 -0.29713 Mabsadd L
.1046 .55478 2.37764 .77254 Mabsadd L
.1046 .55478 .56518 .7779 Mabsadd L
.1046 .55478 0 2.5 Mabsadd L closepath F
.13681 .55772 0 2.5 Mabsadd m
.13681 .55772 -0.56518 .7779 Mabsadd L
.13681 .55772 -2.37764 .77254 Mabsadd L
.13681 .55772 -0.91448 -0.29713 Mabsadd L
.13681 .55772 -1.46946 -2.02254 Mabsadd L
.13681 .55772 0 -0.96154 Mabsadd L
.13681 .55772 1.46946 -2.02254 Mabsadd L
.13681 .55772 .91448 -0.29713 Mabsadd L
.13681 .55772 2.37764 .77254 Mabsadd L
.13681 .55772 .56518 .7779 Mabsadd L
.13681 .55772 0 2.5 Mabsadd L closepath F
.16913 .56014 0 2.5 Mabsadd m
.16913 .56014 -0.56518 .7779 Mabsadd L
.16913 .56014 -2.37764 .77254 Mabsadd L
.16913 .56014 -0.91448 -0.29713 Mabsadd L
.16913 .56014 -1.46946 -2.02254 Mabsadd L
.16913 .56014 0 -0.96154 Mabsadd L
.16913 .56014 1.46946 -2.02254 Mabsadd L
.16913 .56014 .91448 -0.29713 Mabsadd L
.16913 .56014 2.37764 .77254 Mabsadd L
.16913 .56014 .56518 .7779 Mabsadd L
.16913 .56014 0 2.5 Mabsadd L closepath F
.20147 .56248 0 2.5 Mabsadd m
.20147 .56248 -0.56518 .7779 Mabsadd L
.20147 .56248 -2.37764 .77254 Mabsadd L
.20147 .56248 -0.91448 -0.29713 Mabsadd L
.20147 .56248 -1.46946 -2.02254 Mabsadd L
.20147 .56248 0 -0.96154 Mabsadd L
.20147 .56248 1.46946 -2.02254 Mabsadd L
.20147 .56248 .91448 -0.29713 Mabsadd L
.20147 .56248 2.37764 .77254 Mabsadd L
.20147 .56248 .56518 .7779 Mabsadd L
.20147 .56248 0 2.5 Mabsadd L closepath F
.23381 .5648 0 2.5 Mabsadd m
.23381 .5648 -0.56518 .7779 Mabsadd L
.23381 .5648 -2.37764 .77254 Mabsadd L
.23381 .5648 -0.91448 -0.29713 Mabsadd L
.23381 .5648 -1.46946 -2.02254 Mabsadd L
.23381 .5648 0 -0.96154 Mabsadd L
.23381 .5648 1.46946 -2.02254 Mabsadd L
.23381 .5648 .91448 -0.29713 Mabsadd L
.23381 .5648 2.37764 .77254 Mabsadd L
.23381 .5648 .56518 .7779 Mabsadd L
.23381 .5648 0 2.5 Mabsadd L closepath F
.26616 .56709 0 2.5 Mabsadd m
.26616 .56709 -0.56518 .7779 Mabsadd L
.26616 .56709 -2.37764 .77254 Mabsadd L
.26616 .56709 -0.91448 -0.29713 Mabsadd L
.26616 .56709 -1.46946 -2.02254 Mabsadd L
.26616 .56709 0 -0.96154 Mabsadd L
.26616 .56709 1.46946 -2.02254 Mabsadd L
.26616 .56709 .91448 -0.29713 Mabsadd L
.26616 .56709 2.37764 .77254 Mabsadd L
.26616 .56709 .56518 .7779 Mabsadd L
.26616 .56709 0 2.5 Mabsadd L closepath F
.29851 .56937 0 2.5 Mabsadd m
.29851 .56937 -0.56518 .7779 Mabsadd L
.29851 .56937 -2.37764 .77254 Mabsadd L
.29851 .56937 -0.91448 -0.29713 Mabsadd L
.29851 .56937 -1.46946 -2.02254 Mabsadd L
.29851 .56937 0 -0.96154 Mabsadd L
.29851 .56937 1.46946 -2.02254 Mabsadd L
.29851 .56937 .91448 -0.29713 Mabsadd L
.29851 .56937 2.37764 .77254 Mabsadd L
.29851 .56937 .56518 .7779 Mabsadd L
.29851 .56937 0 2.5 Mabsadd L closepath F
.33086 .57163 0 2.5 Mabsadd m
.33086 .57163 -0.56518 .7779 Mabsadd L
.33086 .57163 -2.37764 .77254 Mabsadd L
.33086 .57163 -0.91448 -0.29713 Mabsadd L
.33086 .57163 -1.46946 -2.02254 Mabsadd L
.33086 .57163 0 -0.96154 Mabsadd L
.33086 .57163 1.46946 -2.02254 Mabsadd L
.33086 .57163 .91448 -0.29713 Mabsadd L
.33086 .57163 2.37764 .77254 Mabsadd L
.33086 .57163 .56518 .7779 Mabsadd L
.33086 .57163 0 2.5 Mabsadd L closepath F
.36322 .57386 0 2.5 Mabsadd m
.36322 .57386 -0.56518 .7779 Mabsadd L
.36322 .57386 -2.37764 .77254 Mabsadd L
.36322 .57386 -0.91448 -0.29713 Mabsadd L
.36322 .57386 -1.46946 -2.02254 Mabsadd L
.36322 .57386 0 -0.96154 Mabsadd L
.36322 .57386 1.46946 -2.02254 Mabsadd L
.36322 .57386 .91448 -0.29713 Mabsadd L
.36322 .57386 2.37764 .77254 Mabsadd L
.36322 .57386 .56518 .7779 Mabsadd L
.36322 .57386 0 2.5 Mabsadd L closepath F
.39559 .57607 0 2.5 Mabsadd m
.39559 .57607 -0.56518 .7779 Mabsadd L
.39559 .57607 -2.37764 .77254 Mabsadd L
.39559 .57607 -0.91448 -0.29713 Mabsadd L
.39559 .57607 -1.46946 -2.02254 Mabsadd L
.39559 .57607 0 -0.96154 Mabsadd L
.39559 .57607 1.46946 -2.02254 Mabsadd L
.39559 .57607 .91448 -0.29713 Mabsadd L
.39559 .57607 2.37764 .77254 Mabsadd L
.39559 .57607 .56518 .7779 Mabsadd L
.39559 .57607 0 2.5 Mabsadd L closepath F
.42796 .57825 0 2.5 Mabsadd m
.42796 .57825 -0.56518 .7779 Mabsadd L
.42796 .57825 -2.37764 .77254 Mabsadd L
.42796 .57825 -0.91448 -0.29713 Mabsadd L
.42796 .57825 -1.46946 -2.02254 Mabsadd L
.42796 .57825 0 -0.96154 Mabsadd L
.42796 .57825 1.46946 -2.02254 Mabsadd L
.42796 .57825 .91448 -0.29713 Mabsadd L
.42796 .57825 2.37764 .77254 Mabsadd L
.42796 .57825 .56518 .7779 Mabsadd L
.42796 .57825 0 2.5 Mabsadd L closepath F
.46034 .5804 0 2.5 Mabsadd m
.46034 .5804 -0.56518 .7779 Mabsadd L
.46034 .5804 -2.37764 .77254 Mabsadd L
.46034 .5804 -0.91448 -0.29713 Mabsadd L
.46034 .5804 -1.46946 -2.02254 Mabsadd L
.46034 .5804 0 -0.96154 Mabsadd L
.46034 .5804 1.46946 -2.02254 Mabsadd L
.46034 .5804 .91448 -0.29713 Mabsadd L
.46034 .5804 2.37764 .77254 Mabsadd L
.46034 .5804 .56518 .7779 Mabsadd L
.46034 .5804 0 2.5 Mabsadd L closepath F
.49272 .58251 0 2.5 Mabsadd m
.49272 .58251 -0.56518 .7779 Mabsadd L
.49272 .58251 -2.37764 .77254 Mabsadd L
.49272 .58251 -0.91448 -0.29713 Mabsadd L
.49272 .58251 -1.46946 -2.02254 Mabsadd L
.49272 .58251 0 -0.96154 Mabsadd L
.49272 .58251 1.46946 -2.02254 Mabsadd L
.49272 .58251 .91448 -0.29713 Mabsadd L
.49272 .58251 2.37764 .77254 Mabsadd L
.49272 .58251 .56518 .7779 Mabsadd L
.49272 .58251 0 2.5 Mabsadd L closepath F
.52512 .5846 0 2.5 Mabsadd m
.52512 .5846 -0.56518 .7779 Mabsadd L
.52512 .5846 -2.37764 .77254 Mabsadd L
.52512 .5846 -0.91448 -0.29713 Mabsadd L
.52512 .5846 -1.46946 -2.02254 Mabsadd L
.52512 .5846 0 -0.96154 Mabsadd L
.52512 .5846 1.46946 -2.02254 Mabsadd L
.52512 .5846 .91448 -0.29713 Mabsadd L
.52512 .5846 2.37764 .77254 Mabsadd L
.52512 .5846 .56518 .7779 Mabsadd L
.52512 .5846 0 2.5 Mabsadd L closepath F
.55752 .58665 0 2.5 Mabsadd m
.55752 .58665 -0.56518 .7779 Mabsadd L
.55752 .58665 -2.37764 .77254 Mabsadd L
.55752 .58665 -0.91448 -0.29713 Mabsadd L
.55752 .58665 -1.46946 -2.02254 Mabsadd L
.55752 .58665 0 -0.96154 Mabsadd L
.55752 .58665 1.46946 -2.02254 Mabsadd L
.55752 .58665 .91448 -0.29713 Mabsadd L
.55752 .58665 2.37764 .77254 Mabsadd L
.55752 .58665 .56518 .7779 Mabsadd L
.55752 .58665 0 2.5 Mabsadd L closepath F
.58992 .58866 0 2.5 Mabsadd m
.58992 .58866 -0.56518 .7779 Mabsadd L
.58992 .58866 -2.37764 .77254 Mabsadd L
.58992 .58866 -0.91448 -0.29713 Mabsadd L
.58992 .58866 -1.46946 -2.02254 Mabsadd L
.58992 .58866 0 -0.96154 Mabsadd L
.58992 .58866 1.46946 -2.02254 Mabsadd L
.58992 .58866 .91448 -0.29713 Mabsadd L
.58992 .58866 2.37764 .77254 Mabsadd L
.58992 .58866 .56518 .7779 Mabsadd L
.58992 .58866 0 2.5 Mabsadd L closepath F
.62234 .59063 0 2.5 Mabsadd m
.62234 .59063 -0.56518 .7779 Mabsadd L
.62234 .59063 -2.37764 .77254 Mabsadd L
.62234 .59063 -0.91448 -0.29713 Mabsadd L
.62234 .59063 -1.46946 -2.02254 Mabsadd L
.62234 .59063 0 -0.96154 Mabsadd L
.62234 .59063 1.46946 -2.02254 Mabsadd L
.62234 .59063 .91448 -0.29713 Mabsadd L
.62234 .59063 2.37764 .77254 Mabsadd L
.62234 .59063 .56518 .7779 Mabsadd L
.62234 .59063 0 2.5 Mabsadd L closepath F
.65476 .59257 0 2.5 Mabsadd m
.65476 .59257 -0.56518 .7779 Mabsadd L
.65476 .59257 -2.37764 .77254 Mabsadd L
.65476 .59257 -0.91448 -0.29713 Mabsadd L
.65476 .59257 -1.46946 -2.02254 Mabsadd L
.65476 .59257 0 -0.96154 Mabsadd L
.65476 .59257 1.46946 -2.02254 Mabsadd L
.65476 .59257 .91448 -0.29713 Mabsadd L
.65476 .59257 2.37764 .77254 Mabsadd L
.65476 .59257 .56518 .7779 Mabsadd L
.65476 .59257 0 2.5 Mabsadd L closepath F
.6872 .59446 0 2.5 Mabsadd m
.6872 .59446 -0.56518 .7779 Mabsadd L
.6872 .59446 -2.37764 .77254 Mabsadd L
.6872 .59446 -0.91448 -0.29713 Mabsadd L
.6872 .59446 -1.46946 -2.02254 Mabsadd L
.6872 .59446 0 -0.96154 Mabsadd L
.6872 .59446 1.46946 -2.02254 Mabsadd L
.6872 .59446 .91448 -0.29713 Mabsadd L
.6872 .59446 2.37764 .77254 Mabsadd L
.6872 .59446 .56518 .7779 Mabsadd L
.6872 .59446 0 2.5 Mabsadd L closepath F
.71964 .59632 0 2.5 Mabsadd m
.71964 .59632 -0.56518 .7779 Mabsadd L
.71964 .59632 -2.37764 .77254 Mabsadd L
.71964 .59632 -0.91448 -0.29713 Mabsadd L
.71964 .59632 -1.46946 -2.02254 Mabsadd L
.71964 .59632 0 -0.96154 Mabsadd L
.71964 .59632 1.46946 -2.02254 Mabsadd L
.71964 .59632 .91448 -0.29713 Mabsadd L
.71964 .59632 2.37764 .77254 Mabsadd L
.71964 .59632 .56518 .7779 Mabsadd L
.71964 .59632 0 2.5 Mabsadd L closepath F
.75209 .59813 0 2.5 Mabsadd m
.75209 .59813 -0.56518 .7779 Mabsadd L
.75209 .59813 -2.37764 .77254 Mabsadd L
.75209 .59813 -0.91448 -0.29713 Mabsadd L
.75209 .59813 -1.46946 -2.02254 Mabsadd L
.75209 .59813 0 -0.96154 Mabsadd L
.75209 .59813 1.46946 -2.02254 Mabsadd L
.75209 .59813 .91448 -0.29713 Mabsadd L
.75209 .59813 2.37764 .77254 Mabsadd L
.75209 .59813 .56518 .7779 Mabsadd L
.75209 .59813 0 2.5 Mabsadd L closepath F
.78455 .5999 0 2.5 Mabsadd m
.78455 .5999 -0.56518 .7779 Mabsadd L
.78455 .5999 -2.37764 .77254 Mabsadd L
.78455 .5999 -0.91448 -0.29713 Mabsadd L
.78455 .5999 -1.46946 -2.02254 Mabsadd L
.78455 .5999 0 -0.96154 Mabsadd L
.78455 .5999 1.46946 -2.02254 Mabsadd L
.78455 .5999 .91448 -0.29713 Mabsadd L
.78455 .5999 2.37764 .77254 Mabsadd L
.78455 .5999 .56518 .7779 Mabsadd L
.78455 .5999 0 2.5 Mabsadd L closepath F
.81702 .60163 0 2.5 Mabsadd m
.81702 .60163 -0.56518 .7779 Mabsadd L
.81702 .60163 -2.37764 .77254 Mabsadd L
.81702 .60163 -0.91448 -0.29713 Mabsadd L
.81702 .60163 -1.46946 -2.02254 Mabsadd L
.81702 .60163 0 -0.96154 Mabsadd L
.81702 .60163 1.46946 -2.02254 Mabsadd L
.81702 .60163 .91448 -0.29713 Mabsadd L
.81702 .60163 2.37764 .77254 Mabsadd L
.81702 .60163 .56518 .7779 Mabsadd L
.81702 .60163 0 2.5 Mabsadd L closepath F
.84949 .60332 0 2.5 Mabsadd m
.84949 .60332 -0.56518 .7779 Mabsadd L
.84949 .60332 -2.37764 .77254 Mabsadd L
.84949 .60332 -0.91448 -0.29713 Mabsadd L
.84949 .60332 -1.46946 -2.02254 Mabsadd L
.84949 .60332 0 -0.96154 Mabsadd L
.84949 .60332 1.46946 -2.02254 Mabsadd L
.84949 .60332 .91448 -0.29713 Mabsadd L
.84949 .60332 2.37764 .77254 Mabsadd L
.84949 .60332 .56518 .7779 Mabsadd L
.84949 .60332 0 2.5 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 g
.64286 .30902 m
.64286 .42806 L
.88095 .42806 L
.88095 .30902 L
F
1 g
.64286 .30902 m
.64286 .42806 L
.88095 .42806 L
.88095 .30902 L
F
0 g
.001 w
[ ] 0 setdash
.64286 .30902 m
.88095 .30902 L
.88095 .42806 L
.64286 .42806 L
.64286 .30902 L
s
% Start of sub-graphic
p
0.642857 0.309017 0.880952 0.428065 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0198413 0.198413 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0357143 0.35119 0.234127 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00748 w
[ .5 3 ] 0 Mabsdash
0 .5 m
1 .5 L
s
.00075 w
[ ] 0 setdash
.5 .5 0 2.5 Mabsadd m
.5 .5 -0.56518 .7779 Mabsadd L
.5 .5 -2.37764 .77254 Mabsadd L
.5 .5 -0.91448 -0.29713 Mabsadd L
.5 .5 -1.46946 -2.02254 Mabsadd L
.5 .5 0 -0.96154 Mabsadd L
.5 .5 1.46946 -2.02254 Mabsadd L
.5 .5 .91448 -0.29713 Mabsadd L
.5 .5 2.37764 .77254 Mabsadd L
.5 .5 .56518 .7779 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .13492 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0M) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(H) show
87.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0Htot) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(L) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.265873 0.35119 0.464286 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
.00075 w
.5 .5 -1.875 0 Mabsadd m
.5 .5 0 2.5 Mabsadd L
.5 .5 1.875 0 Mabsadd L
.5 .5 0 -2.5 Mabsadd L
.5 .5 -1.875 0 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .36508 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0M) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.000 moveto
(H) show
87.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0Hext) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.000 13.000 moveto
(L) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{488.125, 301.688},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007X0001;B000`400?l00000o`00003oo`3IfMWY
0=WIf@00o`3IfMWY0=WIf@00o`3IfMWY0=WIf@00o`3IfMWY0=WIf@00o`3IfMWY0=WIf@00o`3IfMWY
0=WIf@00o`3IfMWY0=WIf@00o`3IfMWY0=WIf@00:P3IfMT5000003H0fMWI0`0000040=WIf@030000
003IfMT0fMWI0080fMWI0`00000g0=WIf@<00000=`3IfMT2000000@0fMWI00<000000=WIf@3IfMT0
0P3IfMT3000006h0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`00000g0=WIf@<00000
?`3IfMT002/0fMWI00@000000=WIf@3IfMT00000=`3IfMT00`000000fMWI0=WIf@070=WIf@050000
003IfMT0fMWI0=WIf@000000=`3IfMT00`000000fMWI0=WIf@0e0=WIf@040000003IfMT0fMWI0000
00L0fMWI00D000000=WIf@3IfMT0fMWI0000001/0=WIf@040000003IfMT0fMWI000000L0fMWI00D0
00000=WIf@3IfMT0fMWI0000000g0=WIf@030000003IfMT0fMWI03h0fMWI000T0=WIf@D000000`3I
fMT00`000000fMWI0=WIf@0_0=WIf@D000000`3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003I
fMT0fMWI02d0fMWI1@0000030=WIf@030000003IfMT0fMWI02h0fMWI1@0000020=WIf@040000003I
fMT0fMWI000000/0fMWI00<000000=WIf@3IfMT0JP3IfMT010000000fMWI0=WIf@00000;0=WIf@03
0000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT0?P3IfMT002d0fMWI00<000000=WIf@3IfMT0
=P3IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI03D0fMWI00<000000=WIf@3IfMT0
=@3IfMT010000000fMWI0=WIf@00000;0=WIf@030000003IfMT0fMWI06X0fMWI00@000000=WIf@3I
fMT000002`3IfMT00`000000fMWI0=WIf@0e0=WIf@030000003IfMT0fMWI03h0fMWI000Z0=WIf@05
0000003IfMT0fMWI0=WIf@000000=`3IfMT00`000000fMWI0=WIf@070=WIf@@00000>03IfMT00`00
0000fMWI0=WIf@0e0=WIf@040000003IfMT0fMWI000000L0fMWI1000001]0=WIf@040000003IfMT0
fMWI000000L0fMWI1000000h0=WIf@030000003IfMT0fMWI03h0fMWI000Z0=WIf@050000003IfMT0
fMWI0=WIf@000000=P3IfMT2000000T0fMWI00<000000=WIf@3IfMT0>03IfMT2000003L0fMWI00@0
00000=WIf@3IfMT000001`3IfMT00`000000fMWI0=WIf@1^0=WIf@040000003IfMT0fMWI000000L0
fMWI00<000000=WIf@3IfMT0>03IfMT200000400fMWI000[0=WIf@<00000>03IfMT00`000000fMWI
0=WIf@070=WIf@D00000=`3IfMT00`000000fMWI0=WIf@0f0=WIf@800000203IfMT5000006d0fMWI
0P0000080=WIf@D00000=`3IfMT00`000000fMWI0=WIf@0n0=WIf@00o`3IfMTZ0=WIf@030000003I
fMT0fMWI0;`0fMWI003o0=WIfBX0fMWI00<000000=WIf@3IfMT0_03IfMT00?l0fMWI:P3IfMT00`00
0000fMWI0=WIf@2B0=WIf@030000003IfMT0fMWI02L0fMWI003o0=WIfBX0fMWI00<000000=WIf@3I
fMT0TP3IfMT00`000000fMWI0=WIf@0W0=WIf@00o`3IfMTZ0=WIf@030000003IfMT0fMWI0980fMWI
1P0000020=WIf@8000000P3IfMT3000000030=WIf@000000000001P0fMWI000L0=WIf@<00000o`3I
fMT;0=WIf@030000003IfMT0fMWI0980fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000
003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT000006@3IfMT001@0fMWIo`00002P000000`0
fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0
fMWI000001T0fMWI000L0=WIf@@000002P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@030000003IfMT0
fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0
fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0D0=WIf@070000003IfMT0
fMWI0=WIf@000000fMWI000000020=WIf@030000003IfMT0fMWI00@000006@3IfMT001d0fMWI0`00
000:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@090=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00T0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02@3IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI01@0fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT000000080
fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0G0=WIf@007P3IfMT2000000X0
fMWI00<000000=WIf@3IfMT0?@3IfMT00`000000fMWI0=WIf@0m0=WIf@030000003IfMT0fMWI03`0
fMWI00<000000=WIf@3IfMT0?@3IfMT00`000000fMWI0=WIf@0l0=WIf@030000003IfMT0fMWI03d0
fMWI00<000000=WIf@3IfMT06P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI
000001T0fMWI000N0=WIf@800000o`3IfMT:0=WIf@030000003IfMT0fMWI09X0fMWI0P0000020=WI
f@<0000000<0fMWI000000000000603IfMT001l0fMWI00<000000=WIf@3IfMT0o`3IfMT80=WIf@03
0000003IfMT0fMWI0;`0fMWI000O0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT00`000000fMWI
0=WIf@2l0=WIf@007P3IfMT00`000000fMWI0000003o0=WIf@T0fMWI00<000000=WIf@3IfMT0_03I
fMT001h0fMWI00<000000=WIf@000000o`3IfMT90=WIf@030000003IfMT0fMWI0;`0fMWI000P0=WI
f@030000003IfMT0fMWI0?l0fMWI1`3IfMT00`000000fMWI0=WIf@2l0=WIf@00803IfMT00`000000
fMWI0=WIf@3o0=WIf@L0fMWI0P00002m0=WIf@007P3IfMT00`000000fMWI0000003o0=WIf@T0fMWI
00<000000=WIf@3IfMT0_03IfMT00240fMWI00<000000=WIf@3IfMT0o`3IfMT60=WIf@030000003I
fMT0fMWI0;`0fMWI000Q0=WIf@030000003IfMT0fMWI0?l0fMWI1P3IfMT00`000000fMWI0=WIf@2l
0=WIf@007P3IfMT010000000fMWI0=WIf@00003o0=WIf@P0fMWI00<000000=WIf@3IfMT0_03IfMT0
01h0fMWI00@000000=WIf@3IfMT00000o`3IfMT80=WIf@030000003IfMT0fMWI0;`0fMWI000R0=WI
f@030000003IfMT0fMWI0?l0fMWI1@3IfMT00`000000fMWI0=WIf@2l0=WIf@008P3IfMT00`000000
fMWI0=WIf@3o0=WIf@D0fMWI00<000000=WIf@3IfMT0_03IfMT001h0fMWI00D000000=WIf@3IfMT0
fMWI0000003o0=WIf@L0fMWI00<000000=WIf@3IfMT0_03IfMT00280fMWI00<000000=WIf@3IfMT0
o`3IfMT50=WIf@030000003IfMT0fMWI0;`0fMWI000S0=WIf@030000003IfMT0fMWI0?l0fMWI103I
fMT200000;d0fMWI000N0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0o`3IfMT4
0=WIf@030000003IfMT0fMWI0;`0fMWI000N0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WI
f@3IfMT0o`3IfMT40=WIf@030000003IfMT0fMWI0;`0fMWI000S0=WIf@030000003IfMT0fMWI0?l0
fMWI103IfMT00`000000fMWI0=WIf@2l0=WIf@00903IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI
00<000000=WIf@3IfMT0_03IfMT001h0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@3o0=WIf@<0fMWI00<000000=WIf@3IfMT0_03IfMT002@0fMWI00<000000=WIf@3IfMT0o`3IfMT3
0=WIf@030000003IfMT0fMWI0;`0fMWI000T0=WIf@030000003IfMT0fMWI0?l0fMWI0`3IfMT00`00
0000fMWI0=WIf@2l0=WIf@007`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI0?l0
fMWI0P3IfMT00`000000fMWI0=WIf@2l0=WIf@007`3IfMT00`000000fMWI0=WIf@030=WIf@030000
003IfMT0fMWI0?l0fMWI0P3IfMT00`000000fMWI0=WIf@2l0=WIf@009@3IfMT00`000000fMWI0=WI
f@3o0=WIf@80fMWI0P00002m0=WIf@009@3IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI00<00000
0=WIf@3IfMT0_03IfMT001l0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@3o0=WI
f@80fMWI00<000000=WIf@3IfMT0_03IfMT002H0fMWI00<000000=WIf@3IfMT0o`3IfMT10=WIf@03
0000003IfMT0fMWI0;`0fMWI000V0=WIf@030000003IfMT0fMWI0?l0fMWI0@3IfMT00`000000fMWI
0=WIf@2l0=WIf@007`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWI0@3I
fMT00`000000fMWI0=WIf@2l0=WIf@007`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0
fMWI0?l0fMWI0@3IfMT00`000000fMWI0=WIf@2l0=WIf@009`3IfMT00`000000fMWI0=WIf@3Z0=WI
f@800000103IfMT010000000fMWI0=WIf@3IfMT5000000H0fMWI00<000000=WIf@3IfMT0_03IfMT0
02L0fMWI00<000000=WIf@3IfMT0j@3IfMT010000000fMWI0=WIf@0000080=WIf@040000003IfMT0
fMWI000000H0fMWI00<000000=WIf@3IfMT0_03IfMT001l0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@3Y0=WIf@040000003IfMT0fMWI000000T0fMWI00<000000=WIf@3IfMT01P3I
fMT00`000000fMWI0=WIf@2l0=WIf@009`3IfMT00`000000fMWI0=WIf@3Y0=WIf@040000003IfMT0
fMWI000000X0fMWI00<000000=WIf@3IfMT01@3IfMT300000;`0fMWI000X0=WIf@030000003IfMT0
fMWI0>P0fMWI00@000000=WIf@3IfMT000001`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00<000000=WIf@3IfMT0_03IfMT001l0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@3X0=WIf@040000003IfMT0fMWI000000L0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@03
0000003IfMT0fMWI0;`0fMWI000O0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT0
j@3IfMT2000000T0fMWI0`0000070=WIf@030000003IfMT0fMWI0;`0fMWI000X0=WIf@030000003I
fMT0fMWI0?h0fMWI00<000000=WIf@3IfMT0_03IfMT002T0fMWI00<000000=WIf@3IfMT0o@3IfMT0
0`000000fMWI0=WIf@2l0=WIf@007`3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI
0?d0fMWI00<000000=WIf@3IfMT0_03IfMT002T0fMWI00<000000=WIf@3IfMT0o@3IfMT00`000000
fMWI0=WIf@2l0=WIf@00:@3IfMT00`000000fMWI0=WIf@3m0=WIf@030000003IfMT0fMWI0;`0fMWI
000O0=WIf@030000003IfMT0fMWI00L0fMWI00<000000=WIf@3IfMT0o@3IfMT00`000000fMWI0=WI
f@2l0=WIf@007`3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0?`0fMWI0P00002m
0=WIf@00:P3IfMT00`000000fMWI0=WIf@3l0=WIf@030000003IfMT0fMWI0;`0fMWI000Z0=WIf@03
0000003IfMT0fMWI0?`0fMWI00<000000=WIf@3IfMT0_03IfMT001h0fMWI0P00000:0=WIf@030000
003IfMT0fMWI0?`0fMWI00<000000=WIf@3IfMT0_03IfMT001l0fMWI00<000000=WIf@3IfMT02@3I
fMT00`000000fMWI0=WIf@3k0=WIf@030000003IfMT0fMWI0;`0fMWI000N0=WIf@@00000203IfMT3
00000?`0fMWI00<000000=WIf@3IfMT0_03IfMT001l0fMWI0P0000090=WIf@<00000o03IfMT00`00
0000fMWI0=WIf@2l0=WIf@00803IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0?/0
fMWI00<000000=WIf@3IfMT0_03IfMT002`0fMWI00<000000=WIf@3IfMT0nP3IfMT00`000000fMWI
0=WIf@2l0=WIf@00;03IfMT00`000000fMWI0=WIf@3j0=WIf@800000_@3IfMT00200fMWI00<00000
0=WIf@3IfMT02@3IfMT00`000000fMWI0=WIf@3j0=WIf@030000003IfMT0fMWI0;`0fMWI000/0=WI
f@030000003IfMT0fMWI0?X0fMWI00<000000=WIf@3IfMT0_03IfMT002d0fMWI00<000000=WIf@3I
fMT0n@3IfMT00`000000fMWI0=WIf@2l0=WIf@00803IfMT00`000000fMWI0=WIf@0:0=WIf@030000
003IfMT0fMWI0?T0fMWI00<000000=WIf@3IfMT0_03IfMT00200fMWI00<000000=WIf@3IfMT02P3I
fMT00`000000fMWI0=WIf@3i0=WIf@030000003IfMT0fMWI0;`0fMWI000^0=WIf@030000003IfMT0
fMWI0?P0fMWI00<000000=WIf@3IfMT0_03IfMT002h0fMWI00<000000=WIf@3IfMT0n03IfMT00`00
0000fMWI0=WIf@2l0=WIf@00803IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI0?P0
fMWI00<000000=WIf@3IfMT0_03IfMT002h0fMWI00<000000=WIf@3IfMT0n03IfMT00`000000fMWI
0=WIf@2l0=WIf@00;`3IfMT00`000000fMWI0=WIf@3g0=WIf@800000_@3IfMT00200fMWI00<00000
0=WIf@3IfMT0303IfMT00`000000fMWI0=WIf@3g0=WIf@030000003IfMT0fMWI0;`0fMWI000P0=WI
f@030000003IfMT0fMWI00`0fMWI00<000000=WIf@3IfMT0m`3IfMT00`000000fMWI0=WIf@2l0=WI
f@00;`3IfMT00`000000fMWI0=WIf@3g0=WIf@030000003IfMT0fMWI0;`0fMWI000`0=WIf@030000
003IfMT0fMWI0?H0fMWI00<000000=WIf@3IfMT0_03IfMT00200fMWI00<000000=WIf@3IfMT03@3I
fMT00`000000fMWI0=WIf@3f0=WIf@030000003IfMT0fMWI0;`0fMWI000`0=WIf@030000003IfMT0
fMWI0?H0fMWI00<000000=WIf@3IfMT0_03IfMT00300fMWI00<000000=WIf@3IfMT0mP3IfMT00`00
0000fMWI0=WIf@2l0=WIf@00803IfMT00`000000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI0>00
fMWI0P0000040=WIf@030000003IfMT0fMWI00<0fMWI0`0000060=WIf@030000003IfMT0fMWI0;`0
fMWI000P0=WIf@030000003IfMT0fMWI00h0fMWI00<000000=WIf@3IfMT0g`3IfMT010000000fMWI
0=WIf@00000:0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0_03IfMT00340fMWI
00<000000=WIf@3IfMT0g`3IfMT010000000fMWI0=WIf@0000070=WIf@D000001P3IfMT300000;`0
fMWI000a0=WIf@030000003IfMT0fMWI0=l0fMWI00@000000=WIf@3IfMT000001`3IfMT010000000
fMWI0=WIf@0000070=WIf@030000003IfMT0fMWI0;`0fMWI000Q0=WIf@030000003IfMT0fMWI00h0
fMWI00<000000=WIf@3IfMT0gP3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT00000
00L0fMWI00<000000=WIf@3IfMT0_03IfMT00380fMWI00<000000=WIf@3IfMT0gP3IfMT010000000
fMWI0=WIf@0000090=WIf@8000001`3IfMT00`000000fMWI0=WIf@2l0=WIf@00<P3IfMT00`000000
fMWI0=WIf@3O0=WIf@8000002`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0;`0
fMWI000Q0=WIf@030000003IfMT0fMWI00l0fMWI00<000000=WIf@3IfMT0l`3IfMT00`000000fMWI
0=WIf@2l0=WIf@008@3IfMT00`000000fMWI0=WIf@0?0=WIf@030000003IfMT0fMWI0?<0fMWI00<0
00000=WIf@3IfMT0_03IfMT003<0fMWI00<000000=WIf@3IfMT0l`3IfMT00`000000fMWI0=WIf@2l
0=WIf@00<`3IfMT00`000000fMWI0=WIf@3c0=WIf@030000003IfMT0fMWI0;`0fMWI000Q0=WIf@03
0000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0lP3IfMT00`000000fMWI0=WIf@2l0=WIf@00
=03IfMT00`000000fMWI0=WIf@3b0=WIf@800000_@3IfMT003@0fMWI00<000000=WIf@3IfMT0lP3I
fMT00`000000fMWI0=WIf@2l0=WIf@008@3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0
fMWI0?80fMWI00<000000=WIf@3IfMT0_03IfMT00240fMWI00<000000=WIf@3IfMT04@3IfMT00`00
0000fMWI0=WIf@3a0=WIf@030000003IfMT0fMWI0;`0fMWI000e0=WIf@030000003IfMT0fMWI0?40
fMWI00<000000=WIf@3IfMT0_03IfMT003D0fMWI00<000000=WIf@3IfMT0l@3IfMT00`000000fMWI
0=WIf@2l0=WIf@008@3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0?40fMWI00<0
00000=WIf@3IfMT0_03IfMT003H0fMWI00<000000=WIf@3IfMT0l03IfMT00`000000fMWI0=WIf@2l
0=WIf@00=P3IfMT00`000000fMWI0=WIf@3`0=WIf@030000003IfMT0fMWI0;`0fMWI000Q0=WIf@03
0000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT0l03IfMT00`000000fMWI0=WIf@2l0=WIf@00
8@3IfMT00`000000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI0?00fMWI0P00002m0=WIf@00=`3I
fMT00`000000fMWI0=WIf@3_0=WIf@030000003IfMT0fMWI0;`0fMWI000g0=WIf@030000003IfMT0
fMWI0>l0fMWI00<000000=WIf@3IfMT0_03IfMT00240fMWI00<000000=WIf@3IfMT04`3IfMT00`00
0000fMWI0=WIf@3_0=WIf@030000003IfMT0fMWI0;`0fMWI000h0=WIf@030000003IfMT0fMWI0>h0
fMWI00<000000=WIf@3IfMT0_03IfMT003P0fMWI00<000000=WIf@3IfMT0kP3IfMT00`000000fMWI
0=WIf@2l0=WIf@008P3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI0>h0fMWI00<0
00000=WIf@3IfMT0_03IfMT00280fMWI00<000000=WIf@3IfMT04`3IfMT00`000000fMWI0=WIf@3^
0=WIf@030000003IfMT0fMWI0;`0fMWI000Q0=WIf@030000003IfMT0fMWI01D0fMWI00<000000=WI
f@3IfMT0k@3IfMT00`000000fMWI0=WIf@2l0=WIf@008@3IfMT2000001D0fMWI0`00003^0=WIf@03
0000003IfMT0fMWI0;`0fMWI000P0=WIf@@00000503IfMT300000>h0fMWI0P00002m0=WIf@00>@3I
fMT00`000000fMWI0=WIf@3]0=WIf@030000003IfMT0fMWI0;`0fMWI000j0=WIf@030000003IfMT0
fMWI0>`0fMWI00<000000=WIf@3IfMT0_03IfMT00280fMWI00<000000=WIf@3IfMT05@3IfMT00`00
0000fMWI0=WIf@3/0=WIf@030000003IfMT0fMWI0;`0fMWI000R0=WIf@030000003IfMT0fMWI01D0
fMWI00<000000=WIf@3IfMT0k03IfMT00`000000fMWI0=WIf@2l0=WIf@00>P3IfMT00`000000fMWI
0=WIf@3/0=WIf@030000003IfMT0fMWI0;`0fMWI000k0=WIf@030000003IfMT0fMWI0>/0fMWI00<0
00000=WIf@3IfMT0_03IfMT00280fMWI00<000000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@3F
0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@<000001`3IfMT00`000000fMWI0=WIf@2l
0=WIf@00>`3IfMT00`000000fMWI0=WIf@3E0=WIf@040000003IfMT0fMWI000000L0fMWI00D00000
0=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI0;`0fMWI000k0=WIf@030000003IfMT0
fMWI0=D0fMWI00@000000=WIf@3IfMT000001`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI
00<000000=WIf@3IfMT0_03IfMT00280fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WI
f@3D0=WIf@040000003IfMT0fMWI000000L0fMWI100000070=WIf@<00000_03IfMT00280fMWI00<0
00000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@3D0=WIf@040000003IfMT0fMWI000000L0fMWI
00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@2l0=WIf@00?03IfMT00`000000fMWI0=WI
f@3D0=WIf@040000003IfMT0fMWI000000P0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@2l0=WIf@00?@3IfMT00`000000fMWI0=WIf@3D0=WIf@8000002P3IfMT2000000L0fMWI00<0
00000=WIf@3IfMT0_03IfMT00280fMWI0P00000I0=WIf@030000003IfMT0fMWI0>T0fMWI00<00000
0=WIf@3IfMT0_03IfMT003d0fMWI00<000000=WIf@3IfMT0j@3IfMT00`000000fMWI0=WIf@2l0=WI
f@00?@3IfMT00`000000fMWI0=WIf@3Y0=WIf@030000003IfMT0fMWI0;`0fMWI000S0=WIf@030000
003IfMT0fMWI01P0fMWI00<000000=WIf@3IfMT0j03IfMT00`000000fMWI0=WIf@2l0=WIf@008`3I
fMT00`000000fMWI0=WIf@0H0=WIf@030000003IfMT0fMWI0>P0fMWI00<000000=WIf@3IfMT0_03I
fMT003h0fMWI00<000000=WIf@3IfMT0j03IfMT00`000000fMWI0=WIf@2l0=WIf@00?P3IfMT00`00
0000fMWI0=WIf@3X0=WIf@8000003P3IfMUd000003/0fMWI000S0=WIf@030000003IfMT0fMWI01T0
fMWI00<000000=WIf@3IfMT0i`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700
oooo00<000000=WIf@3IfMT0>@3IfMT003l0fMWI00<000000=WIf@3IfMT0i`3IfMT00`000000fMWI
0=WIf@0=0=WIf@030000003oool0oooo0700oooo00<000000=WIf@3IfMT0>@3IfMT003l0fMWI00<0
00000=WIf@3IfMT0i`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo00<0
00000=WIf@3IfMT0>@3IfMT002<0fMWI00<000000=WIf@3IfMT06@3IfMT00`000000fMWI0=WIf@3W
0=WIf@030000003IfMT0fMWI00d0fMWI00<000000?ooo`3oool0L03oool00`000000fMWI0=WIf@0i
0=WIf@008`3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI0>H0fMWI00<000000=WI
f@3IfMT03@3IfMT00`000000oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0fMWI00100=WIf@03
0000003IfMT0fMWI0>H0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`1`0?ooo`03
0000003IfMT0fMWI03T0fMWI00100=WIf@030000003IfMT0fMWI0>H0fMWI00<000000=WIf@3IfMT0
3@3IfMT00`000000oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0fMWI000S0=WIf@030000003I
fMT0fMWI01X0fMWI00<000000=WIf@3IfMT0iP3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003o
ool0oooo0700oooo00<000000=WIf@3IfMT0>@3IfMT00440fMWI00<000000=WIf@3IfMT0i@3IfMT0
0`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo00<000000=WIf@3IfMT0>@3IfMT0
0440fMWI00<000000=WIf@3IfMT0i@3IfMT2000000h0fMWI00<000000?ooo`3oool0L03oool00`00
0000fMWI0=WIf@0i0=WIf@008`3IfMT00`000000fMWI0=WIf@0K0=WIf@030000003IfMT0fMWI0>D0
fMWI00<000000=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0
fMWI000S0=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT0i@3IfMT00`000000fMWI
0=WIf@0=0=WIf@030000003oool0oooo02`0oooo00<000000?ooo`3oool04`3oool00`000000oooo
0000000T0?ooo`030000003oool0oooo00@0oooo00<000000=WIf@3IfMT0>@3IfMT00480fMWI00<0
00000=WIf@3IfMT0i03IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo02`0oooo00<0
00000?ooo`3oool04P3oool010000000oooo0?ooo`00000U0?ooo`030000003oool0oooo00<0oooo
00<000000=WIf@3IfMT0>@3IfMT00480fMWI00<000000=WIf@3IfMT0i03IfMT00`000000fMWI0=WI
f@0=0=WIf@030000003oool0oooo02`0oooo1P0000020?ooo`8000000P3oool2000000040?ooo`00
0000000000000080oooo00@000000?ooo`3oool0oooo1P0000020?ooo`8000000P3oool300000003
0?ooo`00000000000080oooo0P0000030?ooo`<00000103oool2000000D0oooo00<000000?ooo`3o
ool00P3oool00`000000fMWI0=WIf@0i0=WIf@00903IfMT00`000000fMWI0=WIf@0K0=WIf@030000
003IfMT0fMWI0>@0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`0C0?ooo`030000
003oool0oooo01H0oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003oool0oooo0000
003oool000000`3oool01@000000oooo0?ooo`3oool0000000<0oooo00D000000?ooo`3oool0oooo
000000020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool01P00
0000oooo0?ooo`000000oooo000000<0oooo00@000000?ooo`3oool000000P3oool00`000000oooo
0?ooo`020?ooo`030000003oool0oooo0080oooo00<000000=WIf@3IfMT0>@3IfMT00480fMWI00<0
00000=WIf@3IfMT0i03IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo00P0oooo0P00
00020?ooo`030000003oool0oooo008000000P3oool2000000030?ooo`00000000000080oooo00<0
00000?ooo`3oool00P00000>0?ooo`040000003oool0oooo00000080oooo00H000000?ooo`3oool0
00000?ooo`0000030?ooo`050000003oool0oooo0?ooo`000000103oool010000000oooo0?ooo`00
00020?ooo`040000003oool0oooo00000080oooo00@000000?ooo`3oool000000P3oool00`000000
oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000000P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0080oooo00<000000=WIf@3IfMT0>@3IfMT004<0fMWI00<000000=WIf@3I
fMT0h`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo01<0oooo0`00000G0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0000000<0oooo00D00000
0?ooo`3oool0oooo000000040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`03
0000003oool0oooo00@000000P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000000P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00<000000=WI
f@3IfMT0>@3IfMT002@0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@3S0=WIf@03
0000003IfMT0fMWI00d0fMWI00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0F0?ooo`07
0000003oool0oooo0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo
000000040?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo000000020?ooo`04
0000003oool0oooo00000080oooo00<000000?ooo`0000000`0000030?ooo`<000000P3oool40000
00@0oooo00<000000?ooo`3oool00`3oool00`000000fMWI0=WIf@0i0=WIf@00903IfMT00`000000
fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI0><0fMWI0P00000>0=WIf@030000003oool0oooo03<0
oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000000000D0oooo00<000000?oo
o`3oool01P3oool010000000oooo0?ooo`0000020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`3oool02@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00@0oooo00<0
00000=WIf@3IfMT0>@3IfMT004@0fMWI00<000000=WIf@3IfMT0hP3IfMT00`000000fMWI0=WIf@0=
0=WIf@030000003oool0oooo03@0oooo0P0000020?ooo`040000003oool0oooo0?ooo`8000003P3o
ool200000080oooo0`0000001@3oool000000000003oool0000000/0oooo00<000000?ooo`3oool0
2P3oool00`000000fMWI0=WIf@0i0=WIf@00A03IfMT00`000000fMWI0=WIf@3R0=WIf@030000003I
fMT0fMWI00d0fMWI00<000000?ooo`3oool0L03oool00`000000fMWI0=WIf@0i0=WIf@00903IfMT0
0`000000fMWI0=WIf@0M0=WIf@030000003IfMT0fMWI0>80fMWI00<000000=WIf@3IfMT03@3IfMT0
0`000000oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0fMWI00140=WIf@030000003IfMT0fMWI
0>80fMWI00<000000=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`1`0?ooo`030000003IfMT0fMWI
03T0fMWI00150=WIf@030000003IfMT0fMWI0>40fMWI00<000000=WIf@3IfMT03@3IfMT00`000000
oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0fMWI000T0=WIf@030000003IfMT0fMWI01h0fMWI
00<000000=WIf@3IfMT0h@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo
00<000000=WIf@3IfMT0>@3IfMT002@0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WI
f@3Q0=WIf@030000003IfMT0fMWI00d0fMWI00<000000?ooo`3oool0L03oool00`000000fMWI0=WI
f@0i0=WIf@00A@3IfMT00`000000fMWI0=WIf@3<0=WIf@800000103IfMT00`000000fMWI0=WIf@02
0=WIf@<000001`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo00<00000
0=WIf@3IfMT0>@3IfMT002<0fMWI00<000000=WIf@000000803IfMT00`000000fMWI0=WIf@3:0=WI
f@040000003IfMT0fMWI000000L0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003I
fMT0fMWI00d0fMWI00<000000?ooo`3oool0L03oool00`000000fMWI0=WIf@0i0=WIf@00903IfMT2
00000200fMWI0P00003;0=WIf@040000003IfMT0fMWI000000L0fMWI00D000000=WIf@3IfMT0fMWI
000000060=WIf@<000003@3IfMT00`000000oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0fMWI
000S0=WIf@@000007P3IfMT300000</0fMWI00@000000=WIf@3IfMT00000203IfMT3000000L0fMWI
00<000000=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0fMWI
000T0=WIf@030000003IfMT0fMWI01l0fMWI0P00003;0=WIf@040000003IfMT0fMWI000000L0fMWI
00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI00d0fMWI00<000000?ooo`3o
ool0L03oool00`000000fMWI0=WIf@0i0=WIf@00903IfMT200000200fMWI0P00003;0=WIf@040000
003IfMT0fMWI000000L0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003IfMT0fMWI
00d0fMWI00<000000?ooo`3oool0L03oool00`000000fMWI0=WIf@0i0=WIf@009@3IfMT00`000000
fMWI0=WIf@0O0=WIf@030000003IfMT0fMWI0<X0fMWI0P0000090=WIf@<000001`3IfMT00`000000
fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo00<000000=WIf@3IfMT0>@3IfMT004P0fMWI
00<000000=WIf@3IfMT0gP3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo
00<000000=WIf@3IfMT0>@3IfMT002D0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WI
f@3N0=WIf@030000003IfMT0fMWI00d0fMWI00<000000?ooo`3oool0L03oool00`000000fMWI0=WI
f@0i0=WIf@009@3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI0=h0fMWI00<00000
0=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0fMWI00190=WI
f@030000003IfMT0fMWI0=d0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`1`0?oo
o`030000003IfMT0fMWI03T0fMWI00190=WIf@030000003IfMT0fMWI0=d0fMWI00<000000=WIf@3I
fMT03@3IfMT00`000000oooo0?ooo`0/0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`00
0000903oool00`000000oooo0?ooo`040?ooo`030000003IfMT0fMWI03T0fMWI000V0=WIf@030000
003IfMT0fMWI0200fMWI00<000000=WIf@3IfMT0g@3IfMT2000000h0fMWI00<000000?ooo`3oool0
;03oool00`000000oooo0?ooo`0B0?ooo`040000003oool0oooo000002D0oooo00<000000?ooo`3o
ool00`3oool00`000000fMWI0=WIf@0i0=WIf@00BP3IfMT00`000000fMWI0=WIf@3L0=WIf@030000
003IfMT0fMWI00d0fMWI00<000000?ooo`3oool0;03oool600000080oooo0P0000020?ooo`800000
00@0oooo00000000000000000P3oool010000000oooo0?ooo`3oool600000080oooo0P0000020?oo
o`<0000000@0oooo000000000000oooo0`0000020?ooo`80000000<0oooo0000000000000`3oool2
000000D0oooo00<000000?ooo`3oool00P3oool00`000000fMWI0=WIf@0i0=WIf@00BP3IfMT00`00
0000fMWI0=WIf@3L0=WIf@030000003IfMT0fMWI00d0fMWI00<000000?ooo`3oool0503oool00`00
0000oooo0?ooo`0E0?ooo`050000003oool0oooo0?ooo`0000000P3oool01P000000oooo0?ooo`00
0000oooo000000<0oooo00D000000?ooo`3oool0oooo000000030?ooo`050000003oool0oooo0?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool00000
1P3oool00`000000oooo000000030?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3o
ool00P3oool00`000000fMWI0=WIf@0i0=WIf@009P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000
003IfMT0fMWI0=`0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`080?oooaP00000
3@3oool010000000oooo0?ooo`0000020?ooo`060000003oool0oooo0000003oool000000`3oool0
1@000000oooo0?ooo`3oool0000000@0oooo00@000000?ooo`3oool000000P3oool010000000oooo
0?ooo`0000020?ooo`050000003oool0oooo0000003oool01@0000030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003IfMT0fMWI
03T0fMWI000V0=WIf@030000003IfMT0fMWI0280fMWI00<000000=WIf@3IfMT0f`3IfMT00`000000
fMWI0=WIf@0=0=WIf@030000003oool0oooo0180oooo1000000G0?ooo`070000003oool0oooo0?oo
o`000000oooo000000020?ooo`030000003oool0000000<0oooo00D000000?ooo`3oool0oooo0000
00040?ooo`070000003oool0oooo0?ooo`000000oooo000000020?ooo`030000003oool0oooo00@0
000000<0oooo0000003oool00P3oool01P000000oooo0?ooo`000000oooo000000<0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`020?ooo`030000003IfMT0fMWI03T0fMWI001;0=WI
f@030000003IfMT0fMWI0=/0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000oooo0?ooo`0C0?oo
o`<000005`3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool01`000000oooo0000
003oool000000?ooo`000000103oool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?oo
o`0000000P3oool010000000oooo0?ooo`0000020?ooo`030000003oool0oooo00<000000P3oool2
000000040?ooo`00000000000?ooo`@00000103oool00`000000oooo0?ooo`030?ooo`030000003I
fMT0fMWI03T0fMWI001;0=WIf@030000003IfMT0fMWI0=/0fMWI00<000000=WIf@3IfMT03@3IfMT0
0`000000oooo0?ooo`0D0?ooo`030000003oool0oooo01`0oooo00D000000?ooo`3oool000000?oo
o`02000000030?ooo`000000000000D0oooo00<000000?ooo`3oool01P3oool010000000oooo0?oo
o`0000020?ooo`040000003oool0oooo000000h0oooo00<000000?ooo`3oool00`3oool00`000000
oooo0?ooo`040?ooo`030000003IfMT0fMWI03T0fMWI000V0=WIf@030000003IfMT0fMWI02<0fMWI
00<000000=WIf@3IfMT0fP3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo03@0oooo
0P0000020?ooo`040000003oool0oooo0?ooo`8000003P3oool200000080oooo0`0000000`3oool0
00000000000=0?ooo`030000003oool0oooo00X0oooo00<000000=WIf@3IfMT0>@3IfMT004`0fMWI
00<000000=WIf@3IfMT0fP3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo
00<000000=WIf@3IfMT0>@3IfMT004`0fMWI00<000000=WIf@3IfMT0fP3IfMT00`000000fMWI0=WI
f@0=0=WIf@030000003oool0oooo0700oooo00<000000=WIf@3IfMT0>@3IfMT002L0fMWI00<00000
0=WIf@3IfMT08`3IfMT00`000000fMWI0=WIf@3I0=WIf@8000003P3IfMT00`000000oooo0?ooo`1`
0?ooo`030000003IfMT0fMWI03T0fMWI000W0=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WI
f@3IfMT0f@3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo00<000000=WI
f@3IfMT0>@3IfMT004d0fMWI00<000000=WIf@3IfMT0f@3IfMT00`000000fMWI0=WIf@0=0=WIf@03
0000003oool0oooo0700oooo00<000000=WIf@3IfMT0>@3IfMT004h0fMWI00<000000=WIf@3IfMT0
f03IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo00<000000=WIf@3IfMT0
>@3IfMT002L0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@3H0=WIf@030000003I
fMT0fMWI00d0fMWI00<000000?ooo`3oool0L03oool00`000000fMWI0=WIf@0i0=WIf@00CP3IfMT0
0`000000fMWI0=WIf@3H0=WIf@030000003IfMT0fMWI00d0fMWI00<000000?ooo`3oool0L03oool0
0`000000fMWI0=WIf@0i0=WIf@00C`3IfMT00`000000fMWI0=WIf@3G0=WIf@030000003IfMT0fMWI
00d0fMWI00<000000?ooo`3oool0L03oool00`000000fMWI0=WIf@0i0=WIf@009`3IfMT00`000000
fMWI0=WIf@0U0=WIf@030000003IfMT0fMWI0=L0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000
oooo0?ooo`1`0?ooo`030000003IfMT0fMWI03T0fMWI000X0=WIf@030000003IfMT0fMWI02@0fMWI
00<000000=WIf@3IfMT0e`3IfMT00`000000fMWI0=WIf@0=0=WIf@030000003oool0oooo0700oooo
00<000000=WIf@3IfMT0>@3IfMT00500fMWI00<000000=WIf@3IfMT0eP3IfMT00`000000fMWI0=WI
f@0=0=WIfG@00000>`3IfMT00500fMWI00<000000=WIf@3IfMT0eP3IfMT200000;d0fMWI000X0=WI
f@030000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0eP3IfMT00`000000fMWI0=WIf@2l0=WI
f@00D@3IfMT00`000000fMWI0=WIf@3E0=WIf@030000003IfMT0fMWI0;`0fMWI001A0=WIf@030000
003IfMT0fMWI0=D0fMWI00<000000=WIf@3IfMT0_03IfMT002P0fMWI00<000000=WIf@3IfMT09P3I
fMT00`000000fMWI0=WIf@3E0=WIf@030000003IfMT0fMWI0;`0fMWI000X0=WIf@030000003IfMT0
fMWI02L0fMWI00<000000=WIf@3IfMT0e03IfMT00`000000fMWI0=WIf@2l0=WIf@00DP3IfMT00`00
0000fMWI0=WIf@3D0=WIf@030000003IfMT0fMWI0;`0fMWI001B0=WIf@030000003IfMT0fMWI0<X0
fMWI0`0000070=WIf@030000003IfMT0fMWI0;`0fMWI000Y0=WIf@030000003IfMT0fMWI02L0fMWI
00<000000=WIf@3IfMT0bP3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0;`0fMWI
001C0=WIf@030000003IfMT0fMWI0<X0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@2l0=WIf@00D`3IfMT00`000000fMWI0=WIf@3:0=WIf@030000003IfMT0fMWI00H0fMWI0`00002l
0=WIf@00:03IfMT3000002T0fMWI00<000000=WIf@3IfMT0b@3IfMT00`000000fMWI0=WIf@060=WI
f@030000003IfMT0fMWI0;`0fMWI000X0=WIf@<00000:03IfMT300000<T0fMWI0P0000080=WIf@03
0000003IfMT0fMWI0;`0fMWI000X0=WIf@<00000:03IfMT300000<X0fMWI00<000000=WIf@3IfMT0
1P3IfMT00`000000fMWI0=WIf@2l0=WIf@00:@3IfMT00`000000fMWI0=WIf@0X0=WIf@800000d`3I
fMT00`000000fMWI0=WIf@2l0=WIf@00:P3IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0
fMWI0=00fMWI00<000000=WIf@3IfMT0_03IfMT005H0fMWI00<000000=WIf@3IfMT0d03IfMT00`00
0000fMWI0=WIf@2l0=WIf@00E`3IfMT00`000000fMWI0=WIf@3?0=WIf@030000003IfMT0fMWI0;`0
fMWI000/0=WIf@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT0cP3IfMT00`000000fMWI
0=WIf@2l0=WIf@00F@3IfMT00`000000fMWI0=WIf@3=0=WIf@030000003IfMT0fMWI0;`0fMWI001I
0=WIf@030000003IfMT0fMWI0<d0fMWI0P00002m0=WIf@00;@3IfMT00`000000fMWI0=WIf@0Z0=WI
f@030000003IfMT0fMWI0<`0fMWI00<000000=WIf@3IfMT0_03IfMT005/0fMWI00<000000=WIf@3I
fMT0b`3IfMT00`000000fMWI0=WIf@2l0=WIf@00F`3IfMT00`000000fMWI0=WIf@3;0=WIf@030000
003IfMT0fMWI0;`0fMWI000_0=WIf@030000003IfMT0fMWI02X0fMWI00<000000=WIf@3IfMT0bP3I
fMT00`000000fMWI0=WIf@2l0=WIf@00;`3IfMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0
fMWI0<T0fMWI00<000000=WIf@3IfMT0_03IfMT005d0fMWI00<000000=WIf@3IfMT0b@3IfMT00`00
0000fMWI0=WIf@2l0=WIf@00<03IfMT00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0fMWI0<P0
fMWI00<000000=WIf@3IfMT0_03IfMT00300fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI
0=WIf@370=WIf@030000003IfMT0fMWI0;`0fMWI001P0=WIf@030000003IfMT0fMWI0<H0fMWI00<0
00000=WIf@3IfMT0_03IfMT00340fMWI00<000000=WIf@3IfMT0;03IfMT00`000000fMWI0=WIf@36
0=WIf@800000_@3IfMT00340fMWI0`00000]0=WIf@800000aP3IfMT00`000000fMWI0=WIf@2l0=WI
f@00<@3IfMT3000002d0fMWI100000340=WIf@030000003IfMT0fMWI0;`0fMWI000a0=WIf@@00000
:`3IfMT4000000040=WIf@000000000000000<40fMWI00<000000=WIf@3IfMT0_03IfMT00380fMWI
00<000000=WIf@3IfMT00P3IfMT2000002P0fMWI0`0000040=WIf@<00000_P3IfMT00`000000fMWI
0=WIf@2l0=WIf@00<P3IfMT00`000000fMWI0=WIf@050=WIf@8000000P3IfMT00`000000fMWI0000
000Q0=WIf@030000003IfMT0fMWI00H0fMWI0`0000000`3IfMT000000=WIf@2h0=WIf@030000003I
fMT0fMWI0;`0fMWI000n0=WIf@D000000P3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0
00000200fMWI2@0000060=WIf@030000003IfMT0fMWI0:T0fMWI00<000000=WIf@3IfMT0_03IfMT0
03h0fMWI0`0000070=WIf@8000000P3IfMT2000000030=WIf@000000000000L0fMWI0P00000D0=WI
f@<000001P3IfMT>000000D0fMWI00<000000=WIf@3IfMT0W03IfMT00`000000fMWI0=WIf@2l0=WI
f@00?`3IfMT00`000000fMWI0=WIf@090=WIf@@00000103IfMT00`000000fMWI0=WIf@0200000003
0=WIf@00000000000080fMWI0P0000070=WIf@030000003IfMT0000000H0fMWI00<000000=WIf@3I
fMT02@3IfMT4000000H0fMWI3@0000060=WIf@030000003IfMT0fMWI08h0fMWI00<000000=WIf@3I
fMT0_03IfMT004`0fMWI00<000000=WIf@3IfMT02@3IfMT4000000D0fMWI00<000000=WIf@3IfMT0
1@0000020=WIf@8000001P3IfMT2000000L0fMWI0`00000:0=WIf@<000001P3IfMT>000000H0fMWI
00<000000=WIf@3IfMT0P03IfMT00`000000fMWI0=WIf@2l0=WIf@00C03IfMT00`000000fMWI0=WI
f@0:0=WIf@030000003IfMT0fMWI00X0fMWI100000050=WIf@030000003IfMT0fMWI00D000000P3I
fMT200000080fMWI00D000000=WIf@3IfMT0fMWI000000080=WIf@8000002P3IfMT4000000H0fMWI
3P0000050=WIf@030000003IfMT0fMWI07<0fMWI0P00002m0=WIf@00I`3IfMT00`000000fMWI0=WI
f@090=WIf@@000001P3IfMT00`000000fMWI0=WIf@03000000040=WIf@000000fMWI0=WIf@800000
00<0fMWI0000003IfMT00P3IfMT00`000000fMWI000000060=WIf@<000002`3IfMT3000000H0fMWI
3@0000060=WIf@030000003IfMT0fMWI06D0fMWI00<000000=WIf@3IfMT0_03IfMT006L0fMWI00<0
00000=WIf@3IfMT05`3IfMT3000000L0fMWI00<000000=WIf@3IfMT00`000000103IfMT000000=WI
f@3IfMT2000000040=WIf@000000fMWI0=WIf@8000002@3IfMT00`000000fMWI0=WIf@090=WIf@<0
00001P3IfMT>000000D0fMWI00<000000=WIf@3IfMT0F03IfMT00`000000fMWI0=WIf@2l0=WIf@00
PP3IfMT00`000000fMWI0=WIf@090=WIf@@000001`3IfMT00`000000fMWI0=WIf@0200000080fMWI
00<000000=WIf@3IfMT00P0000020=WIf@050000003IfMT000000=WIf@0000001`3IfMT00`000000
fMWI0=WIf@0:0=WIf@<000001P3IfMT=000000H0fMWI00<000000=WIf@3IfMT0BP3IfMT00`000000
fMWI0=WIf@2l0=WIf@00S`3IfMT00`000000fMWI0=WIf@090=WIf@@00000203IfMT00`000000fMWI
00000003000000050=WIf@000000fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000090=WI
f@030000003IfMT0fMWI00T0fMWI0`0000060=WIf@h000001P3IfMT00`000000fMWI0=WIf@0l0=WI
f@030000003IfMT0fMWI0;`0fMWI002Z0=WIf@8000002@3IfMT5000000030=WIf@00000000000080
fMWI00<000000=WIf@3IfMT00`0000090=WIf@060000003IfMT0fMWI0000003IfMT000001`3IfMT3
000000H0fMWI3P0000050=WIf@030000003IfMT0fMWI00/0fMWI00<000000=WIf@3IfMT08@3IfMT0
0`000000fMWI0=WIf@2l0=WIf@00ZP3IfMT00`000000fMWI0=WIf@0:0=WIf@030000003IfMT0fMWI
00X0fMWI0`0000020=WIf@8000000P3IfMT00`000000fMWI0=WIf@04000000P0fMWI00@000000=WI
f@00000000002@3IfMT3000000H0fMWI6`0000050=WIf@030000003IfMT0fMWI01@0fMWI00<00000
0=WIf@3IfMT0_03IfMT00<@0fMWI0P00000;0=WIf@@000000P3IfMT200000080fMWI00<000000=WI
f@3IfMT00`0000000`3IfMT000000=WIf@060=WIf@050000003IfMT000000=WIf@0000001`3IfMT3
000000X0fMWI100000060=WIf@h000000`3IfMT5000000H0fMWI00<000000=WIf@3IfMT0_03IfMT0
0<D0fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@090=WIf@@000000`3IfMT20000
0080fMWI00<000000=WIf@3IfMT00`0000000`3IfMT000000=WIf@050=WIf@040000003IfMT00000
000000T0fMWI0`00000:0=WIf@@000001@3IfMT>000000030=WIf@000000fMWI00<0fMWI00<00000
0=WIf@3IfMT0]`3IfMT00=80fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0:0=WI
f@@000000`3IfMT200000080fMWI00<000000=WIf@3IfMT00P0000020=WIf@030000003IfMT0fMWI
008000000P3IfMT01@000000fMWI0000003IfMT0000000P0fMWI0`0000090=WIf@@000001P3IfMT>
000000D0fMWI00<000000=WIf@3IfMT0ZP3IfMT00>d0fMWI00<000000=WIf@3IfMT02@3IfMT40000
00P0fMWI00<000000=WIf@0000000P0000020=WIf@030000003IfMT0fMWI0080000000<0fMWI0000
003IfMT00P0000090=WIf@<000001`3IfMT00`000000fMWI0=WIf@04000000H0fMWI3@0000060=WI
f@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT0S`3IfMT00>d0fMWI00<000000=WIf@3I
fMT02P3IfMT00`000000fMWI0=WIf@0:0=WIf@<000002@3IfMT500000080fMWI00<000000=WIf@3I
fMT00P000000103IfMT000000000000000060=WIf@040000003IfMT0fMWI0=WIf@<0000000<0fMWI
0000003IfMT01`3IfMT3000000H0fMWI6`0000060=WIf@030000003IfMT0fMWI0840fMWI003o0=WI
f@T0fMWI00<000000=WIf@3IfMT0203IfMT3000000P0fMWI00@000000=WIf@3IfMT0fMWI10000002
0=WIf@80000000@0fMWI000000000000fMWI1P0000070=WIf@<000002P3IfMT3000000X0fMWI0`00
00060=WIf@h000001P3IfMT00`000000fMWI0=WIf@1c0=WIf@00o`3IfMTE0=WIf@030000003IfMT0
fMWI00P0fMWI1@0000050=WIf@030000003IfMT0fMWI00<0fMWI100000030=WIf@030000003IfMT0
fMWI008000000P3IfMT2000000030=WIf@00000000000080fMWI00<000000=WIf@3IfMT00P3IfMT2
000000030=WIf@000000fMWI00P0fMWI0P00000:0=WIf@@000001P3IfMT>000000D0fMWI00<00000
0=WIf@3IfMT0IP3IfMT00?l0fMWI903IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT02@3IfMT4000000L0fMWI0P0000001@3IfMT00000000000000000
fMWI008000000P3IfMT00`000000fMWI0=WIf@02000000030=WIf@000000fMWI00T0fMWI0`000000
0`3IfMT000000=WIf@070=WIf@@000001P3IfMT=000000H0fMWI00<000000=WIf@3IfMT02P3IfMT0
0`000000fMWI0=WIf@1;0=WIf@00o`3IfMTZ0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT02P3IfMT00`000000fMWI0=WIf@0:0=WIf@@000002@3IfMT4000000030=WIf@0000000000
0080fMWI00<000000=WIf@3IfMT01@0000020=WIf@8000001@3IfMT3000000X0fMWI0`0000060=WI
fA/000001P3IfMT00`000000fMWI0=WIf@0m0=WIf@00o`3IfMTZ0=WIf@030000003IfMT0fMWI01l0
fMWI00<000000=WIf@3IfMT02P3IfMT00`000000fMWI0=WIf@0:0=WIf@@000001@3IfMT00`000000
fMWI0=WIf@04000000X0fMWI00<000000=WIf@3IfMT02P3IfMT3000000X0fMWI0`0000060=WIf@P0
0000?P3IfMT00?l0fMWI:P3IfMT00`000000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI00T0fMWI
1000000G0=WIf@030000003IfMT0fMWI00X0fMWI0P00000;0=WIf@<00000?P3IfMT00?l0fMWI:P3I
fMT00`000000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI0340fMWI00<000000=WIf@3IfMT02`3I
fMT00`000000fMWI0=WIf@0m0=WIf@00o`3IfMTZ0=WIf@800000_@3IfMT00?l0fMWI:P3IfMT00`00
0000fMWI0=WIf@2l0=WIf@00o`3IfMTZ0=WIf@030000003IfMT0fMWI0;`0fMWI003o0=WIfBX0fMWI
00<000000=WIf@3IfMT0_03IfMT00?l0fMWIj@3IfMT00?l0fMWIj@3IfMT00?l0fMWIj@3IfMT00?l0
fMWIj@3IfMT00?l0fMWIj@3IfMT00?l0fMWIj@3IfMT00?l0fMWIj@3IfMT00?l0fMWIj@3IfMT00?l0
fMWIj@3IfMT00?l0fMWIj@3IfMT00?l0fMWIj@3IfMT00?l0fMWI8@3IfMT00`000000fMWI0=WIf@35
0=WIf@00o`3IfMTQ0=WIf@030000003IfMT0fMWI0<D0fMWI003o0=WIfB40fMWI1P0000020=WIf@80
00000P3IfMT2000000040=WIf@000000000000000;H0fMWI003o0=WIfB40fMWI00D000000=WIf@3I
fMT0fMWI000000020=WIf@060000003IfMT0fMWI0000003IfMT000000`3IfMT00`000000fMWI0=WI
f@2e0=WIf@00o`3IfMTR0=WIf@040000003IfMT0fMWI00000080fMWI00H000000=WIf@3IfMT00000
0=WIf@0000030=WIf@030000003IfMT0fMWI0;D0fMWI003o0=WIfB80fMWI00L000000=WIf@3IfMT0
fMWI0000003IfMT000000080fMWI00<000000=WIf@0000000`3IfMT00`000000fMWI0=WIf@2e0=WI
f@00o`3IfMTR0=WIf@070000003IfMT0fMWI0=WIf@000000fMWI000000020=WIf@070000003IfMT0
00000=WIf@000000fMWI0000002g0=WIf@00o`3IfMTX0=WIf@050000003IfMT0fMWI0000003IfMT0
0P0000000`3IfMT000000000002g0=WIf@00o`3IfMTY0=WIf@8000000P3IfMT010000000fMWI0=WI
f@3IfMT200000;H0fMWI003o0=WIfNT0fMWI003o0=WIfNT0fMWI003o0=WIfNT0fMWI003o0=WIfNT0
fMWI003o0=WIfNT0fMWI003o0=WIfNT0fMWI003o0=WIfNT0fMWI003o0=WIfNT0fMWI003o0=WIfNT0
fMWI0000\
\>"],
  ImageRangeCache->{{{0, 487.125}, {300.688, 0}} -> {-1.0513, -0.648943, \
0.00431637, 0.00431637}, {{11.875, 475.188}, {293.5, 7.125}} -> {-2.33701, \
-0.108033, 0.00786003, 0.00505693}, {{313.062, 428.875}, {150.312, 92.375}} -> \
{-9.18281, -6.64486, 0.0290127, 0.043519}, {{319.25, 353.688}, {146.125, \
123.125}} -> {-29.2584, -14.4404, 0.0869574, 0.0869574}, {{319.25, 353.688}, \
{119.5, 96.5}} -> {-29.2584, -16.7556, 0.0869574, 0.0869574}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Varying temperature ", "Subsection"],

Cell[CellGroupData[{

Cell["Loop on temperature", "Subsubsection"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(mat = matNdFeB;\)\), "\[IndentingNewLine]", 
    \(\(T0 = mat[\([6]\)];\)\), "\[IndentingNewLine]", 
    \(\(Temp = 120;\)\), "\[IndentingNewLine]", 
    \(\(T1 = 20;\)\), "\[IndentingNewLine]", 
    \(\(T2 = 200;\)\), "\[IndentingNewLine]", 
    \(\(Npt = 41;\)\), "\[IndentingNewLine]", 
    \(\(dT = \((T2 - T1)\)/\((Npt - 1)\);\)\), "\[IndentingNewLine]", 
    \(\(TbB = Table[{T, 0}, {T, T1, T2, dT}];\)\), "\[IndentingNewLine]", 
    \(\(TbM = TbB;\)\), "\[IndentingNewLine]", 
    \(\(t1 = AbsoluteTime[];\)\), "\n", 
    \(\(radUtiDelAll[];\)\), "\[IndentingNewLine]", 
    \(\(g = 
        SphericalVolume[1. , 15, 
          15, {0, 0. , 1}];\)\), "\[IndentingNewLine]", 
    \(\(radObjDrwAtr[g, {0, 0.5, 0.8}];\)\), "\[IndentingNewLine]", 
    \(\(mat2 = MatCoef[mat, T0];\)\), "\[IndentingNewLine]", 
    \(\(matp = 
        radMatSatAniso[mat2[\([1]\)], 
          mat2[\([2]\)]];\)\), "\[IndentingNewLine]", 
    \(\(radMatApl[g, matp];\)\), "\[IndentingNewLine]", 
    \(\(Mtrx = radRlxPre[g];\)\), "\[IndentingNewLine]", 
    \(\(Do[\[IndentingNewLine]Temp = 
          T1 + \((i - 1)\)*dT; \[IndentingNewLine]mat2 = 
          MatCoef[mat, Temp]; \[IndentingNewLine]matp = 
          radMatSatAniso[mat2[\([1]\)], 
            mat2[\([2]\)]]; \[IndentingNewLine]radMatApl[g, 
          matp]; \[IndentingNewLine]radRlxMan[Mtrx, 2, 200, 
          0.001]; \[IndentingNewLine]radRlxMan[Mtrx, 2, 200, 
          0.01]; \[IndentingNewLine]radRlxMan[Mtrx, 2, 300, 
          0.1]; \[IndentingNewLine]TbB[\([i, 1]\)] = 
          Temp; \[IndentingNewLine]TbM[\([i, 1]\)] = 
          Temp; \[IndentingNewLine]TbB[\([i, 2]\)] = 
          radFld[g, "\<bz\>", {0, 0, 0}]; \[IndentingNewLine]TbM[\([i, 
              2]\)] = radFld[g, "\<Mz\>", {0, 0, 0}], {i, 1, 
          Npt}\[IndentingNewLine]\[IndentingNewLine]];\)\), "\
\[IndentingNewLine]", 
    \(\(radUtiDel[Mtrx];\)\), "\[IndentingNewLine]", 
    \(\(t2 = AbsoluteTime[];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Solved in \>", \ 
        t2 - t1, "\< Sec.\>"];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Magnetization (mu0M) and Induction vs.temperature\>"];\)\), \
"\[IndentingNewLine]", 
    \(MultipleListPlot[TbB, TbM, PlotRange \[Rule] All, 
      PlotJoined \[Rule] True, 
      AxesLabel \[Rule] {"\<Temp.[deg. C]\>", "\<\[Mu]0M,B [T]\>"}, 
      PlotLegend \[Rule] {"\<B\>", "\<\[Mu]0M\>"}, 
      LegendSize \[Rule] {0.5, 0.25}, 
      LegendPosition \[Rule] {0.3, 0.3}]\)}], "Input"],

Cell[BoxData[
    InterpretationBox[\("Solved in "\[InvisibleSpace]5.`6.4185\
\[InvisibleSpace]" Sec."\),
      SequenceForm[ "Solved in ", 5.`6.4185, " Sec."],
      Editable->False]], "Print"],

Cell[BoxData[
    \("Magnetization (mu0M) and Induction vs.temperature"\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.47619 0.309017 0.47619 [
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
% Start of sub-graphic
p
0.0238095 0.0147151 0.97619 0.603319 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0820106 0.00529101 -0.268525 0.72884 [
[.18254 .44781 -6 -9 ]
[.18254 .44781 6 0 ]
[.31481 .44781 -6 -9 ]
[.31481 .44781 6 0 ]
[.44709 .44781 -9 -9 ]
[.44709 .44781 9 0 ]
[.57937 .44781 -9 -9 ]
[.57937 .44781 9 0 ]
[.71164 .44781 -9 -9 ]
[.71164 .44781 9 0 ]
[.84392 .44781 -9 -9 ]
[.84392 .44781 9 0 ]
[.97619 .44781 -9 -9 ]
[.97619 .44781 9 0 ]
[1.025 .46031 0 -6 ]
[1.025 .46031 82 6 ]
[.03776 .02301 -18 -4.5 ]
[.03776 .02301 0 4.5 ]
[.03776 .16878 -18 -4.5 ]
[.03776 .16878 0 4.5 ]
[.03776 .31455 -18 -4.5 ]
[.03776 .31455 0 4.5 ]
[.03776 .60608 -18 -4.5 ]
[.03776 .60608 0 4.5 ]
[.05026 .64303 -29 0 ]
[.05026 .64303 29 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .46031 m
.18254 .46656 L
s
[(50)] .18254 .44781 0 1 Mshowa
.31481 .46031 m
.31481 .46656 L
s
[(75)] .31481 .44781 0 1 Mshowa
.44709 .46031 m
.44709 .46656 L
s
[(100)] .44709 .44781 0 1 Mshowa
.57937 .46031 m
.57937 .46656 L
s
[(125)] .57937 .44781 0 1 Mshowa
.71164 .46031 m
.71164 .46656 L
s
[(150)] .71164 .44781 0 1 Mshowa
.84392 .46031 m
.84392 .46656 L
s
[(175)] .84392 .44781 0 1 Mshowa
.97619 .46031 m
.97619 .46656 L
s
[(200)] .97619 .44781 0 1 Mshowa
.125 Mabswid
.07672 .46031 m
.07672 .46406 L
s
.10317 .46031 m
.10317 .46406 L
s
.12963 .46031 m
.12963 .46406 L
s
.15608 .46031 m
.15608 .46406 L
s
.20899 .46031 m
.20899 .46406 L
s
.23545 .46031 m
.23545 .46406 L
s
.2619 .46031 m
.2619 .46406 L
s
.28836 .46031 m
.28836 .46406 L
s
.34127 .46031 m
.34127 .46406 L
s
.36772 .46031 m
.36772 .46406 L
s
.39418 .46031 m
.39418 .46406 L
s
.42063 .46031 m
.42063 .46406 L
s
.47354 .46031 m
.47354 .46406 L
s
.5 .46031 m
.5 .46406 L
s
.52646 .46031 m
.52646 .46406 L
s
.55291 .46031 m
.55291 .46406 L
s
.60582 .46031 m
.60582 .46406 L
s
.63228 .46031 m
.63228 .46406 L
s
.65873 .46031 m
.65873 .46406 L
s
.68519 .46031 m
.68519 .46406 L
s
.7381 .46031 m
.7381 .46406 L
s
.76455 .46031 m
.76455 .46406 L
s
.79101 .46031 m
.79101 .46406 L
s
.81746 .46031 m
.81746 .46406 L
s
.87037 .46031 m
.87037 .46406 L
s
.89683 .46031 m
.89683 .46406 L
s
.92328 .46031 m
.92328 .46406 L
s
.94974 .46031 m
.94974 .46406 L
s
.02381 .46031 m
.02381 .46406 L
s
.25 Mabswid
0 .46031 m
1 .46031 L
s
gsave
1.025 .46031 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temp) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(@) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(deg) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 13.000 moveto
(D) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05026 .02301 m
.05651 .02301 L
s
[(0.4)] .03776 .02301 1 0 Mshowa
.05026 .16878 m
.05651 .16878 L
s
[(0.6)] .03776 .16878 1 0 Mshowa
.05026 .31455 m
.05651 .31455 L
s
[(0.8)] .03776 .31455 1 0 Mshowa
.05026 .60608 m
.05651 .60608 L
s
[(1.2)] .03776 .60608 1 0 Mshowa
.125 Mabswid
.05026 .05945 m
.05401 .05945 L
s
.05026 .09589 m
.05401 .09589 L
s
.05026 .13234 m
.05401 .13234 L
s
.05026 .20522 m
.05401 .20522 L
s
.05026 .24166 m
.05401 .24166 L
s
.05026 .2781 m
.05401 .2781 L
s
.05026 .35099 m
.05401 .35099 L
s
.05026 .38743 m
.05401 .38743 L
s
.05026 .42387 m
.05401 .42387 L
s
.05026 .49676 m
.05401 .49676 L
s
.05026 .5332 m
.05401 .5332 L
s
.05026 .56964 m
.05401 .56964 L
s
.25 Mabswid
.05026 0 m
.05026 .61803 L
s
gsave
.05026 .64303 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0M) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 13.000 moveto
(@) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(T) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 13.000 moveto
(D) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.02381 .31163 m
.04762 .30901 L
.07143 .3064 L
.09524 .30378 L
.11905 .30116 L
.14286 .29853 L
.16667 .29591 L
.19048 .29328 L
.21429 .29065 L
.2381 .28802 L
.2619 .28539 L
.28571 .28275 L
.30952 .28011 L
.33333 .27747 L
.35714 .27482 L
.38095 .27217 L
.40476 .26952 L
.42857 .26687 L
.45238 .26421 L
.47619 .26155 L
.5 .25889 L
.52381 .25622 L
.54762 .25354 L
.57143 .25086 L
.59524 .24817 L
.61905 .24546 L
.64286 .24272 L
.66667 .23992 L
.69048 .23699 L
.71429 .2338 L
.7381 .23003 L
.7619 .22494 L
.78571 .21712 L
.80952 .20464 L
.83333 .18638 L
.85714 .16294 L
.88095 .13584 L
.90476 .10657 L
.92857 .07618 L
.95238 .0454 L
.97619 .01472 L
s
.0001 w
.02381 .31163 -1.875 0 Mabsadd m
.02381 .31163 0 2.5 Mabsadd L
.02381 .31163 1.875 0 Mabsadd L
.02381 .31163 0 -2.5 Mabsadd L
.02381 .31163 -1.875 0 Mabsadd L closepath F
.04762 .30901 -1.875 0 Mabsadd m
.04762 .30901 0 2.5 Mabsadd L
.04762 .30901 1.875 0 Mabsadd L
.04762 .30901 0 -2.5 Mabsadd L
.04762 .30901 -1.875 0 Mabsadd L closepath F
.07143 .3064 -1.875 0 Mabsadd m
.07143 .3064 0 2.5 Mabsadd L
.07143 .3064 1.875 0 Mabsadd L
.07143 .3064 0 -2.5 Mabsadd L
.07143 .3064 -1.875 0 Mabsadd L closepath F
.09524 .30378 -1.875 0 Mabsadd m
.09524 .30378 0 2.5 Mabsadd L
.09524 .30378 1.875 0 Mabsadd L
.09524 .30378 0 -2.5 Mabsadd L
.09524 .30378 -1.875 0 Mabsadd L closepath F
.11905 .30116 -1.875 0 Mabsadd m
.11905 .30116 0 2.5 Mabsadd L
.11905 .30116 1.875 0 Mabsadd L
.11905 .30116 0 -2.5 Mabsadd L
.11905 .30116 -1.875 0 Mabsadd L closepath F
.14286 .29853 -1.875 0 Mabsadd m
.14286 .29853 0 2.5 Mabsadd L
.14286 .29853 1.875 0 Mabsadd L
.14286 .29853 0 -2.5 Mabsadd L
.14286 .29853 -1.875 0 Mabsadd L closepath F
.16667 .29591 -1.875 0 Mabsadd m
.16667 .29591 0 2.5 Mabsadd L
.16667 .29591 1.875 0 Mabsadd L
.16667 .29591 0 -2.5 Mabsadd L
.16667 .29591 -1.875 0 Mabsadd L closepath F
.19048 .29328 -1.875 0 Mabsadd m
.19048 .29328 0 2.5 Mabsadd L
.19048 .29328 1.875 0 Mabsadd L
.19048 .29328 0 -2.5 Mabsadd L
.19048 .29328 -1.875 0 Mabsadd L closepath F
.21429 .29065 -1.875 0 Mabsadd m
.21429 .29065 0 2.5 Mabsadd L
.21429 .29065 1.875 0 Mabsadd L
.21429 .29065 0 -2.5 Mabsadd L
.21429 .29065 -1.875 0 Mabsadd L closepath F
.2381 .28802 -1.875 0 Mabsadd m
.2381 .28802 0 2.5 Mabsadd L
.2381 .28802 1.875 0 Mabsadd L
.2381 .28802 0 -2.5 Mabsadd L
.2381 .28802 -1.875 0 Mabsadd L closepath F
.2619 .28539 -1.875 0 Mabsadd m
.2619 .28539 0 2.5 Mabsadd L
.2619 .28539 1.875 0 Mabsadd L
.2619 .28539 0 -2.5 Mabsadd L
.2619 .28539 -1.875 0 Mabsadd L closepath F
.28571 .28275 -1.875 0 Mabsadd m
.28571 .28275 0 2.5 Mabsadd L
.28571 .28275 1.875 0 Mabsadd L
.28571 .28275 0 -2.5 Mabsadd L
.28571 .28275 -1.875 0 Mabsadd L closepath F
.30952 .28011 -1.875 0 Mabsadd m
.30952 .28011 0 2.5 Mabsadd L
.30952 .28011 1.875 0 Mabsadd L
.30952 .28011 0 -2.5 Mabsadd L
.30952 .28011 -1.875 0 Mabsadd L closepath F
.33333 .27747 -1.875 0 Mabsadd m
.33333 .27747 0 2.5 Mabsadd L
.33333 .27747 1.875 0 Mabsadd L
.33333 .27747 0 -2.5 Mabsadd L
.33333 .27747 -1.875 0 Mabsadd L closepath F
.35714 .27482 -1.875 0 Mabsadd m
.35714 .27482 0 2.5 Mabsadd L
.35714 .27482 1.875 0 Mabsadd L
.35714 .27482 0 -2.5 Mabsadd L
.35714 .27482 -1.875 0 Mabsadd L closepath F
.38095 .27217 -1.875 0 Mabsadd m
.38095 .27217 0 2.5 Mabsadd L
.38095 .27217 1.875 0 Mabsadd L
.38095 .27217 0 -2.5 Mabsadd L
.38095 .27217 -1.875 0 Mabsadd L closepath F
.40476 .26952 -1.875 0 Mabsadd m
.40476 .26952 0 2.5 Mabsadd L
.40476 .26952 1.875 0 Mabsadd L
.40476 .26952 0 -2.5 Mabsadd L
.40476 .26952 -1.875 0 Mabsadd L closepath F
.42857 .26687 -1.875 0 Mabsadd m
.42857 .26687 0 2.5 Mabsadd L
.42857 .26687 1.875 0 Mabsadd L
.42857 .26687 0 -2.5 Mabsadd L
.42857 .26687 -1.875 0 Mabsadd L closepath F
.45238 .26421 -1.875 0 Mabsadd m
.45238 .26421 0 2.5 Mabsadd L
.45238 .26421 1.875 0 Mabsadd L
.45238 .26421 0 -2.5 Mabsadd L
.45238 .26421 -1.875 0 Mabsadd L closepath F
.47619 .26155 -1.875 0 Mabsadd m
.47619 .26155 0 2.5 Mabsadd L
.47619 .26155 1.875 0 Mabsadd L
.47619 .26155 0 -2.5 Mabsadd L
.47619 .26155 -1.875 0 Mabsadd L closepath F
.5 .25889 -1.875 0 Mabsadd m
.5 .25889 0 2.5 Mabsadd L
.5 .25889 1.875 0 Mabsadd L
.5 .25889 0 -2.5 Mabsadd L
.5 .25889 -1.875 0 Mabsadd L closepath F
.52381 .25622 -1.875 0 Mabsadd m
.52381 .25622 0 2.5 Mabsadd L
.52381 .25622 1.875 0 Mabsadd L
.52381 .25622 0 -2.5 Mabsadd L
.52381 .25622 -1.875 0 Mabsadd L closepath F
.54762 .25354 -1.875 0 Mabsadd m
.54762 .25354 0 2.5 Mabsadd L
.54762 .25354 1.875 0 Mabsadd L
.54762 .25354 0 -2.5 Mabsadd L
.54762 .25354 -1.875 0 Mabsadd L closepath F
.57143 .25086 -1.875 0 Mabsadd m
.57143 .25086 0 2.5 Mabsadd L
.57143 .25086 1.875 0 Mabsadd L
.57143 .25086 0 -2.5 Mabsadd L
.57143 .25086 -1.875 0 Mabsadd L closepath F
.59524 .24817 -1.875 0 Mabsadd m
.59524 .24817 0 2.5 Mabsadd L
.59524 .24817 1.875 0 Mabsadd L
.59524 .24817 0 -2.5 Mabsadd L
.59524 .24817 -1.875 0 Mabsadd L closepath F
.61905 .24546 -1.875 0 Mabsadd m
.61905 .24546 0 2.5 Mabsadd L
.61905 .24546 1.875 0 Mabsadd L
.61905 .24546 0 -2.5 Mabsadd L
.61905 .24546 -1.875 0 Mabsadd L closepath F
.64286 .24272 -1.875 0 Mabsadd m
.64286 .24272 0 2.5 Mabsadd L
.64286 .24272 1.875 0 Mabsadd L
.64286 .24272 0 -2.5 Mabsadd L
.64286 .24272 -1.875 0 Mabsadd L closepath F
.66667 .23992 -1.875 0 Mabsadd m
.66667 .23992 0 2.5 Mabsadd L
.66667 .23992 1.875 0 Mabsadd L
.66667 .23992 0 -2.5 Mabsadd L
.66667 .23992 -1.875 0 Mabsadd L closepath F
.69048 .23699 -1.875 0 Mabsadd m
.69048 .23699 0 2.5 Mabsadd L
.69048 .23699 1.875 0 Mabsadd L
.69048 .23699 0 -2.5 Mabsadd L
.69048 .23699 -1.875 0 Mabsadd L closepath F
.71429 .2338 -1.875 0 Mabsadd m
.71429 .2338 0 2.5 Mabsadd L
.71429 .2338 1.875 0 Mabsadd L
.71429 .2338 0 -2.5 Mabsadd L
.71429 .2338 -1.875 0 Mabsadd L closepath F
.7381 .23003 -1.875 0 Mabsadd m
.7381 .23003 0 2.5 Mabsadd L
.7381 .23003 1.875 0 Mabsadd L
.7381 .23003 0 -2.5 Mabsadd L
.7381 .23003 -1.875 0 Mabsadd L closepath F
.7619 .22494 -1.875 0 Mabsadd m
.7619 .22494 0 2.5 Mabsadd L
.7619 .22494 1.875 0 Mabsadd L
.7619 .22494 0 -2.5 Mabsadd L
.7619 .22494 -1.875 0 Mabsadd L closepath F
.78571 .21712 -1.875 0 Mabsadd m
.78571 .21712 0 2.5 Mabsadd L
.78571 .21712 1.875 0 Mabsadd L
.78571 .21712 0 -2.5 Mabsadd L
.78571 .21712 -1.875 0 Mabsadd L closepath F
.80952 .20464 -1.875 0 Mabsadd m
.80952 .20464 0 2.5 Mabsadd L
.80952 .20464 1.875 0 Mabsadd L
.80952 .20464 0 -2.5 Mabsadd L
.80952 .20464 -1.875 0 Mabsadd L closepath F
.83333 .18638 -1.875 0 Mabsadd m
.83333 .18638 0 2.5 Mabsadd L
.83333 .18638 1.875 0 Mabsadd L
.83333 .18638 0 -2.5 Mabsadd L
.83333 .18638 -1.875 0 Mabsadd L closepath F
.85714 .16294 -1.875 0 Mabsadd m
.85714 .16294 0 2.5 Mabsadd L
.85714 .16294 1.875 0 Mabsadd L
.85714 .16294 0 -2.5 Mabsadd L
.85714 .16294 -1.875 0 Mabsadd L closepath F
.88095 .13584 -1.875 0 Mabsadd m
.88095 .13584 0 2.5 Mabsadd L
.88095 .13584 1.875 0 Mabsadd L
.88095 .13584 0 -2.5 Mabsadd L
.88095 .13584 -1.875 0 Mabsadd L closepath F
.90476 .10657 -1.875 0 Mabsadd m
.90476 .10657 0 2.5 Mabsadd L
.90476 .10657 1.875 0 Mabsadd L
.90476 .10657 0 -2.5 Mabsadd L
.90476 .10657 -1.875 0 Mabsadd L closepath F
.92857 .07618 -1.875 0 Mabsadd m
.92857 .07618 0 2.5 Mabsadd L
.92857 .07618 1.875 0 Mabsadd L
.92857 .07618 0 -2.5 Mabsadd L
.92857 .07618 -1.875 0 Mabsadd L closepath F
.95238 .0454 -1.875 0 Mabsadd m
.95238 .0454 0 2.5 Mabsadd L
.95238 .0454 1.875 0 Mabsadd L
.95238 .0454 0 -2.5 Mabsadd L
.95238 .0454 -1.875 0 Mabsadd L closepath F
.97619 .01472 -1.875 0 Mabsadd m
.97619 .01472 0 2.5 Mabsadd L
.97619 .01472 1.875 0 Mabsadd L
.97619 .01472 0 -2.5 Mabsadd L
.97619 .01472 -1.875 0 Mabsadd L closepath F
.001 w
[ .5 3 ] 0 Mabsdash
.02381 .60332 m
.04762 .59939 L
.07143 .59546 L
.09524 .59152 L
.11905 .58758 L
.14286 .58364 L
.16667 .5797 L
.19048 .57575 L
.21429 .5718 L
.2381 .56784 L
.2619 .56388 L
.28571 .55992 L
.30952 .55595 L
.33333 .55198 L
.35714 .54801 L
.38095 .54403 L
.40476 .54004 L
.42857 .53605 L
.45238 .53206 L
.47619 .52806 L
.5 .52406 L
.52381 .52005 L
.54762 .51603 L
.57143 .512 L
.59524 .50795 L
.61905 .50388 L
.64286 .49976 L
.66667 .49555 L
.69048 .49115 L
.71429 .48637 L
.7381 .4807 L
.7619 .47305 L
.78571 .46128 L
.80952 .44253 L
.83333 .4151 L
.85714 .37986 L
.88095 .33915 L
.90476 .29516 L
.92857 .24949 L
.95238 .20324 L
.97619 .15712 L
s
.0001 w
[ ] 0 setdash
.02381 .60332 0 2.5 Mabsadd m
.02381 .60332 -0.56518 .7779 Mabsadd L
.02381 .60332 -2.37764 .77254 Mabsadd L
.02381 .60332 -0.91448 -0.29713 Mabsadd L
.02381 .60332 -1.46946 -2.02254 Mabsadd L
.02381 .60332 0 -0.96154 Mabsadd L
.02381 .60332 1.46946 -2.02254 Mabsadd L
.02381 .60332 .91448 -0.29713 Mabsadd L
.02381 .60332 2.37764 .77254 Mabsadd L
.02381 .60332 .56518 .7779 Mabsadd L
.02381 .60332 0 2.5 Mabsadd L closepath F
.04762 .59939 0 2.5 Mabsadd m
.04762 .59939 -0.56518 .7779 Mabsadd L
.04762 .59939 -2.37764 .77254 Mabsadd L
.04762 .59939 -0.91448 -0.29713 Mabsadd L
.04762 .59939 -1.46946 -2.02254 Mabsadd L
.04762 .59939 0 -0.96154 Mabsadd L
.04762 .59939 1.46946 -2.02254 Mabsadd L
.04762 .59939 .91448 -0.29713 Mabsadd L
.04762 .59939 2.37764 .77254 Mabsadd L
.04762 .59939 .56518 .7779 Mabsadd L
.04762 .59939 0 2.5 Mabsadd L closepath F
.07143 .59546 0 2.5 Mabsadd m
.07143 .59546 -0.56518 .7779 Mabsadd L
.07143 .59546 -2.37764 .77254 Mabsadd L
.07143 .59546 -0.91448 -0.29713 Mabsadd L
.07143 .59546 -1.46946 -2.02254 Mabsadd L
.07143 .59546 0 -0.96154 Mabsadd L
.07143 .59546 1.46946 -2.02254 Mabsadd L
.07143 .59546 .91448 -0.29713 Mabsadd L
.07143 .59546 2.37764 .77254 Mabsadd L
.07143 .59546 .56518 .7779 Mabsadd L
.07143 .59546 0 2.5 Mabsadd L closepath F
.09524 .59152 0 2.5 Mabsadd m
.09524 .59152 -0.56518 .7779 Mabsadd L
.09524 .59152 -2.37764 .77254 Mabsadd L
.09524 .59152 -0.91448 -0.29713 Mabsadd L
.09524 .59152 -1.46946 -2.02254 Mabsadd L
.09524 .59152 0 -0.96154 Mabsadd L
.09524 .59152 1.46946 -2.02254 Mabsadd L
.09524 .59152 .91448 -0.29713 Mabsadd L
.09524 .59152 2.37764 .77254 Mabsadd L
.09524 .59152 .56518 .7779 Mabsadd L
.09524 .59152 0 2.5 Mabsadd L closepath F
.11905 .58758 0 2.5 Mabsadd m
.11905 .58758 -0.56518 .7779 Mabsadd L
.11905 .58758 -2.37764 .77254 Mabsadd L
.11905 .58758 -0.91448 -0.29713 Mabsadd L
.11905 .58758 -1.46946 -2.02254 Mabsadd L
.11905 .58758 0 -0.96154 Mabsadd L
.11905 .58758 1.46946 -2.02254 Mabsadd L
.11905 .58758 .91448 -0.29713 Mabsadd L
.11905 .58758 2.37764 .77254 Mabsadd L
.11905 .58758 .56518 .7779 Mabsadd L
.11905 .58758 0 2.5 Mabsadd L closepath F
.14286 .58364 0 2.5 Mabsadd m
.14286 .58364 -0.56518 .7779 Mabsadd L
.14286 .58364 -2.37764 .77254 Mabsadd L
.14286 .58364 -0.91448 -0.29713 Mabsadd L
.14286 .58364 -1.46946 -2.02254 Mabsadd L
.14286 .58364 0 -0.96154 Mabsadd L
.14286 .58364 1.46946 -2.02254 Mabsadd L
.14286 .58364 .91448 -0.29713 Mabsadd L
.14286 .58364 2.37764 .77254 Mabsadd L
.14286 .58364 .56518 .7779 Mabsadd L
.14286 .58364 0 2.5 Mabsadd L closepath F
.16667 .5797 0 2.5 Mabsadd m
.16667 .5797 -0.56518 .7779 Mabsadd L
.16667 .5797 -2.37764 .77254 Mabsadd L
.16667 .5797 -0.91448 -0.29713 Mabsadd L
.16667 .5797 -1.46946 -2.02254 Mabsadd L
.16667 .5797 0 -0.96154 Mabsadd L
.16667 .5797 1.46946 -2.02254 Mabsadd L
.16667 .5797 .91448 -0.29713 Mabsadd L
.16667 .5797 2.37764 .77254 Mabsadd L
.16667 .5797 .56518 .7779 Mabsadd L
.16667 .5797 0 2.5 Mabsadd L closepath F
.19048 .57575 0 2.5 Mabsadd m
.19048 .57575 -0.56518 .7779 Mabsadd L
.19048 .57575 -2.37764 .77254 Mabsadd L
.19048 .57575 -0.91448 -0.29713 Mabsadd L
.19048 .57575 -1.46946 -2.02254 Mabsadd L
.19048 .57575 0 -0.96154 Mabsadd L
.19048 .57575 1.46946 -2.02254 Mabsadd L
.19048 .57575 .91448 -0.29713 Mabsadd L
.19048 .57575 2.37764 .77254 Mabsadd L
.19048 .57575 .56518 .7779 Mabsadd L
.19048 .57575 0 2.5 Mabsadd L closepath F
.21429 .5718 0 2.5 Mabsadd m
.21429 .5718 -0.56518 .7779 Mabsadd L
.21429 .5718 -2.37764 .77254 Mabsadd L
.21429 .5718 -0.91448 -0.29713 Mabsadd L
.21429 .5718 -1.46946 -2.02254 Mabsadd L
.21429 .5718 0 -0.96154 Mabsadd L
.21429 .5718 1.46946 -2.02254 Mabsadd L
.21429 .5718 .91448 -0.29713 Mabsadd L
.21429 .5718 2.37764 .77254 Mabsadd L
.21429 .5718 .56518 .7779 Mabsadd L
.21429 .5718 0 2.5 Mabsadd L closepath F
.2381 .56784 0 2.5 Mabsadd m
.2381 .56784 -0.56518 .7779 Mabsadd L
.2381 .56784 -2.37764 .77254 Mabsadd L
.2381 .56784 -0.91448 -0.29713 Mabsadd L
.2381 .56784 -1.46946 -2.02254 Mabsadd L
.2381 .56784 0 -0.96154 Mabsadd L
.2381 .56784 1.46946 -2.02254 Mabsadd L
.2381 .56784 .91448 -0.29713 Mabsadd L
.2381 .56784 2.37764 .77254 Mabsadd L
.2381 .56784 .56518 .7779 Mabsadd L
.2381 .56784 0 2.5 Mabsadd L closepath F
.2619 .56388 0 2.5 Mabsadd m
.2619 .56388 -0.56518 .7779 Mabsadd L
.2619 .56388 -2.37764 .77254 Mabsadd L
.2619 .56388 -0.91448 -0.29713 Mabsadd L
.2619 .56388 -1.46946 -2.02254 Mabsadd L
.2619 .56388 0 -0.96154 Mabsadd L
.2619 .56388 1.46946 -2.02254 Mabsadd L
.2619 .56388 .91448 -0.29713 Mabsadd L
.2619 .56388 2.37764 .77254 Mabsadd L
.2619 .56388 .56518 .7779 Mabsadd L
.2619 .56388 0 2.5 Mabsadd L closepath F
.28571 .55992 0 2.5 Mabsadd m
.28571 .55992 -0.56518 .7779 Mabsadd L
.28571 .55992 -2.37764 .77254 Mabsadd L
.28571 .55992 -0.91448 -0.29713 Mabsadd L
.28571 .55992 -1.46946 -2.02254 Mabsadd L
.28571 .55992 0 -0.96154 Mabsadd L
.28571 .55992 1.46946 -2.02254 Mabsadd L
.28571 .55992 .91448 -0.29713 Mabsadd L
.28571 .55992 2.37764 .77254 Mabsadd L
.28571 .55992 .56518 .7779 Mabsadd L
.28571 .55992 0 2.5 Mabsadd L closepath F
.30952 .55595 0 2.5 Mabsadd m
.30952 .55595 -0.56518 .7779 Mabsadd L
.30952 .55595 -2.37764 .77254 Mabsadd L
.30952 .55595 -0.91448 -0.29713 Mabsadd L
.30952 .55595 -1.46946 -2.02254 Mabsadd L
.30952 .55595 0 -0.96154 Mabsadd L
.30952 .55595 1.46946 -2.02254 Mabsadd L
.30952 .55595 .91448 -0.29713 Mabsadd L
.30952 .55595 2.37764 .77254 Mabsadd L
.30952 .55595 .56518 .7779 Mabsadd L
.30952 .55595 0 2.5 Mabsadd L closepath F
.33333 .55198 0 2.5 Mabsadd m
.33333 .55198 -0.56518 .7779 Mabsadd L
.33333 .55198 -2.37764 .77254 Mabsadd L
.33333 .55198 -0.91448 -0.29713 Mabsadd L
.33333 .55198 -1.46946 -2.02254 Mabsadd L
.33333 .55198 0 -0.96154 Mabsadd L
.33333 .55198 1.46946 -2.02254 Mabsadd L
.33333 .55198 .91448 -0.29713 Mabsadd L
.33333 .55198 2.37764 .77254 Mabsadd L
.33333 .55198 .56518 .7779 Mabsadd L
.33333 .55198 0 2.5 Mabsadd L closepath F
.35714 .54801 0 2.5 Mabsadd m
.35714 .54801 -0.56518 .7779 Mabsadd L
.35714 .54801 -2.37764 .77254 Mabsadd L
.35714 .54801 -0.91448 -0.29713 Mabsadd L
.35714 .54801 -1.46946 -2.02254 Mabsadd L
.35714 .54801 0 -0.96154 Mabsadd L
.35714 .54801 1.46946 -2.02254 Mabsadd L
.35714 .54801 .91448 -0.29713 Mabsadd L
.35714 .54801 2.37764 .77254 Mabsadd L
.35714 .54801 .56518 .7779 Mabsadd L
.35714 .54801 0 2.5 Mabsadd L closepath F
.38095 .54403 0 2.5 Mabsadd m
.38095 .54403 -0.56518 .7779 Mabsadd L
.38095 .54403 -2.37764 .77254 Mabsadd L
.38095 .54403 -0.91448 -0.29713 Mabsadd L
.38095 .54403 -1.46946 -2.02254 Mabsadd L
.38095 .54403 0 -0.96154 Mabsadd L
.38095 .54403 1.46946 -2.02254 Mabsadd L
.38095 .54403 .91448 -0.29713 Mabsadd L
.38095 .54403 2.37764 .77254 Mabsadd L
.38095 .54403 .56518 .7779 Mabsadd L
.38095 .54403 0 2.5 Mabsadd L closepath F
.40476 .54004 0 2.5 Mabsadd m
.40476 .54004 -0.56518 .7779 Mabsadd L
.40476 .54004 -2.37764 .77254 Mabsadd L
.40476 .54004 -0.91448 -0.29713 Mabsadd L
.40476 .54004 -1.46946 -2.02254 Mabsadd L
.40476 .54004 0 -0.96154 Mabsadd L
.40476 .54004 1.46946 -2.02254 Mabsadd L
.40476 .54004 .91448 -0.29713 Mabsadd L
.40476 .54004 2.37764 .77254 Mabsadd L
.40476 .54004 .56518 .7779 Mabsadd L
.40476 .54004 0 2.5 Mabsadd L closepath F
.42857 .53605 0 2.5 Mabsadd m
.42857 .53605 -0.56518 .7779 Mabsadd L
.42857 .53605 -2.37764 .77254 Mabsadd L
.42857 .53605 -0.91448 -0.29713 Mabsadd L
.42857 .53605 -1.46946 -2.02254 Mabsadd L
.42857 .53605 0 -0.96154 Mabsadd L
.42857 .53605 1.46946 -2.02254 Mabsadd L
.42857 .53605 .91448 -0.29713 Mabsadd L
.42857 .53605 2.37764 .77254 Mabsadd L
.42857 .53605 .56518 .7779 Mabsadd L
.42857 .53605 0 2.5 Mabsadd L closepath F
.45238 .53206 0 2.5 Mabsadd m
.45238 .53206 -0.56518 .7779 Mabsadd L
.45238 .53206 -2.37764 .77254 Mabsadd L
.45238 .53206 -0.91448 -0.29713 Mabsadd L
.45238 .53206 -1.46946 -2.02254 Mabsadd L
.45238 .53206 0 -0.96154 Mabsadd L
.45238 .53206 1.46946 -2.02254 Mabsadd L
.45238 .53206 .91448 -0.29713 Mabsadd L
.45238 .53206 2.37764 .77254 Mabsadd L
.45238 .53206 .56518 .7779 Mabsadd L
.45238 .53206 0 2.5 Mabsadd L closepath F
.47619 .52806 0 2.5 Mabsadd m
.47619 .52806 -0.56518 .7779 Mabsadd L
.47619 .52806 -2.37764 .77254 Mabsadd L
.47619 .52806 -0.91448 -0.29713 Mabsadd L
.47619 .52806 -1.46946 -2.02254 Mabsadd L
.47619 .52806 0 -0.96154 Mabsadd L
.47619 .52806 1.46946 -2.02254 Mabsadd L
.47619 .52806 .91448 -0.29713 Mabsadd L
.47619 .52806 2.37764 .77254 Mabsadd L
.47619 .52806 .56518 .7779 Mabsadd L
.47619 .52806 0 2.5 Mabsadd L closepath F
.5 .52406 0 2.5 Mabsadd m
.5 .52406 -0.56518 .7779 Mabsadd L
.5 .52406 -2.37764 .77254 Mabsadd L
.5 .52406 -0.91448 -0.29713 Mabsadd L
.5 .52406 -1.46946 -2.02254 Mabsadd L
.5 .52406 0 -0.96154 Mabsadd L
.5 .52406 1.46946 -2.02254 Mabsadd L
.5 .52406 .91448 -0.29713 Mabsadd L
.5 .52406 2.37764 .77254 Mabsadd L
.5 .52406 .56518 .7779 Mabsadd L
.5 .52406 0 2.5 Mabsadd L closepath F
.52381 .52005 0 2.5 Mabsadd m
.52381 .52005 -0.56518 .7779 Mabsadd L
.52381 .52005 -2.37764 .77254 Mabsadd L
.52381 .52005 -0.91448 -0.29713 Mabsadd L
.52381 .52005 -1.46946 -2.02254 Mabsadd L
.52381 .52005 0 -0.96154 Mabsadd L
.52381 .52005 1.46946 -2.02254 Mabsadd L
.52381 .52005 .91448 -0.29713 Mabsadd L
.52381 .52005 2.37764 .77254 Mabsadd L
.52381 .52005 .56518 .7779 Mabsadd L
.52381 .52005 0 2.5 Mabsadd L closepath F
.54762 .51603 0 2.5 Mabsadd m
.54762 .51603 -0.56518 .7779 Mabsadd L
.54762 .51603 -2.37764 .77254 Mabsadd L
.54762 .51603 -0.91448 -0.29713 Mabsadd L
.54762 .51603 -1.46946 -2.02254 Mabsadd L
.54762 .51603 0 -0.96154 Mabsadd L
.54762 .51603 1.46946 -2.02254 Mabsadd L
.54762 .51603 .91448 -0.29713 Mabsadd L
.54762 .51603 2.37764 .77254 Mabsadd L
.54762 .51603 .56518 .7779 Mabsadd L
.54762 .51603 0 2.5 Mabsadd L closepath F
.57143 .512 0 2.5 Mabsadd m
.57143 .512 -0.56518 .7779 Mabsadd L
.57143 .512 -2.37764 .77254 Mabsadd L
.57143 .512 -0.91448 -0.29713 Mabsadd L
.57143 .512 -1.46946 -2.02254 Mabsadd L
.57143 .512 0 -0.96154 Mabsadd L
.57143 .512 1.46946 -2.02254 Mabsadd L
.57143 .512 .91448 -0.29713 Mabsadd L
.57143 .512 2.37764 .77254 Mabsadd L
.57143 .512 .56518 .7779 Mabsadd L
.57143 .512 0 2.5 Mabsadd L closepath F
.59524 .50795 0 2.5 Mabsadd m
.59524 .50795 -0.56518 .7779 Mabsadd L
.59524 .50795 -2.37764 .77254 Mabsadd L
.59524 .50795 -0.91448 -0.29713 Mabsadd L
.59524 .50795 -1.46946 -2.02254 Mabsadd L
.59524 .50795 0 -0.96154 Mabsadd L
.59524 .50795 1.46946 -2.02254 Mabsadd L
.59524 .50795 .91448 -0.29713 Mabsadd L
.59524 .50795 2.37764 .77254 Mabsadd L
.59524 .50795 .56518 .7779 Mabsadd L
.59524 .50795 0 2.5 Mabsadd L closepath F
.61905 .50388 0 2.5 Mabsadd m
.61905 .50388 -0.56518 .7779 Mabsadd L
.61905 .50388 -2.37764 .77254 Mabsadd L
.61905 .50388 -0.91448 -0.29713 Mabsadd L
.61905 .50388 -1.46946 -2.02254 Mabsadd L
.61905 .50388 0 -0.96154 Mabsadd L
.61905 .50388 1.46946 -2.02254 Mabsadd L
.61905 .50388 .91448 -0.29713 Mabsadd L
.61905 .50388 2.37764 .77254 Mabsadd L
.61905 .50388 .56518 .7779 Mabsadd L
.61905 .50388 0 2.5 Mabsadd L closepath F
.64286 .49976 0 2.5 Mabsadd m
.64286 .49976 -0.56518 .7779 Mabsadd L
.64286 .49976 -2.37764 .77254 Mabsadd L
.64286 .49976 -0.91448 -0.29713 Mabsadd L
.64286 .49976 -1.46946 -2.02254 Mabsadd L
.64286 .49976 0 -0.96154 Mabsadd L
.64286 .49976 1.46946 -2.02254 Mabsadd L
.64286 .49976 .91448 -0.29713 Mabsadd L
.64286 .49976 2.37764 .77254 Mabsadd L
.64286 .49976 .56518 .7779 Mabsadd L
.64286 .49976 0 2.5 Mabsadd L closepath F
.66667 .49555 0 2.5 Mabsadd m
.66667 .49555 -0.56518 .7779 Mabsadd L
.66667 .49555 -2.37764 .77254 Mabsadd L
.66667 .49555 -0.91448 -0.29713 Mabsadd L
.66667 .49555 -1.46946 -2.02254 Mabsadd L
.66667 .49555 0 -0.96154 Mabsadd L
.66667 .49555 1.46946 -2.02254 Mabsadd L
.66667 .49555 .91448 -0.29713 Mabsadd L
.66667 .49555 2.37764 .77254 Mabsadd L
.66667 .49555 .56518 .7779 Mabsadd L
.66667 .49555 0 2.5 Mabsadd L closepath F
.69048 .49115 0 2.5 Mabsadd m
.69048 .49115 -0.56518 .7779 Mabsadd L
.69048 .49115 -2.37764 .77254 Mabsadd L
.69048 .49115 -0.91448 -0.29713 Mabsadd L
.69048 .49115 -1.46946 -2.02254 Mabsadd L
.69048 .49115 0 -0.96154 Mabsadd L
.69048 .49115 1.46946 -2.02254 Mabsadd L
.69048 .49115 .91448 -0.29713 Mabsadd L
.69048 .49115 2.37764 .77254 Mabsadd L
.69048 .49115 .56518 .7779 Mabsadd L
.69048 .49115 0 2.5 Mabsadd L closepath F
.71429 .48637 0 2.5 Mabsadd m
.71429 .48637 -0.56518 .7779 Mabsadd L
.71429 .48637 -2.37764 .77254 Mabsadd L
.71429 .48637 -0.91448 -0.29713 Mabsadd L
.71429 .48637 -1.46946 -2.02254 Mabsadd L
.71429 .48637 0 -0.96154 Mabsadd L
.71429 .48637 1.46946 -2.02254 Mabsadd L
.71429 .48637 .91448 -0.29713 Mabsadd L
.71429 .48637 2.37764 .77254 Mabsadd L
.71429 .48637 .56518 .7779 Mabsadd L
.71429 .48637 0 2.5 Mabsadd L closepath F
.7381 .4807 0 2.5 Mabsadd m
.7381 .4807 -0.56518 .7779 Mabsadd L
.7381 .4807 -2.37764 .77254 Mabsadd L
.7381 .4807 -0.91448 -0.29713 Mabsadd L
.7381 .4807 -1.46946 -2.02254 Mabsadd L
.7381 .4807 0 -0.96154 Mabsadd L
.7381 .4807 1.46946 -2.02254 Mabsadd L
.7381 .4807 .91448 -0.29713 Mabsadd L
.7381 .4807 2.37764 .77254 Mabsadd L
.7381 .4807 .56518 .7779 Mabsadd L
.7381 .4807 0 2.5 Mabsadd L closepath F
.7619 .47305 0 2.5 Mabsadd m
.7619 .47305 -0.56518 .7779 Mabsadd L
.7619 .47305 -2.37764 .77254 Mabsadd L
.7619 .47305 -0.91448 -0.29713 Mabsadd L
.7619 .47305 -1.46946 -2.02254 Mabsadd L
.7619 .47305 0 -0.96154 Mabsadd L
.7619 .47305 1.46946 -2.02254 Mabsadd L
.7619 .47305 .91448 -0.29713 Mabsadd L
.7619 .47305 2.37764 .77254 Mabsadd L
.7619 .47305 .56518 .7779 Mabsadd L
.7619 .47305 0 2.5 Mabsadd L closepath F
.78571 .46128 0 2.5 Mabsadd m
.78571 .46128 -0.56518 .7779 Mabsadd L
.78571 .46128 -2.37764 .77254 Mabsadd L
.78571 .46128 -0.91448 -0.29713 Mabsadd L
.78571 .46128 -1.46946 -2.02254 Mabsadd L
.78571 .46128 0 -0.96154 Mabsadd L
.78571 .46128 1.46946 -2.02254 Mabsadd L
.78571 .46128 .91448 -0.29713 Mabsadd L
.78571 .46128 2.37764 .77254 Mabsadd L
.78571 .46128 .56518 .7779 Mabsadd L
.78571 .46128 0 2.5 Mabsadd L closepath F
.80952 .44253 0 2.5 Mabsadd m
.80952 .44253 -0.56518 .7779 Mabsadd L
.80952 .44253 -2.37764 .77254 Mabsadd L
.80952 .44253 -0.91448 -0.29713 Mabsadd L
.80952 .44253 -1.46946 -2.02254 Mabsadd L
.80952 .44253 0 -0.96154 Mabsadd L
.80952 .44253 1.46946 -2.02254 Mabsadd L
.80952 .44253 .91448 -0.29713 Mabsadd L
.80952 .44253 2.37764 .77254 Mabsadd L
.80952 .44253 .56518 .7779 Mabsadd L
.80952 .44253 0 2.5 Mabsadd L closepath F
.83333 .4151 0 2.5 Mabsadd m
.83333 .4151 -0.56518 .7779 Mabsadd L
.83333 .4151 -2.37764 .77254 Mabsadd L
.83333 .4151 -0.91448 -0.29713 Mabsadd L
.83333 .4151 -1.46946 -2.02254 Mabsadd L
.83333 .4151 0 -0.96154 Mabsadd L
.83333 .4151 1.46946 -2.02254 Mabsadd L
.83333 .4151 .91448 -0.29713 Mabsadd L
.83333 .4151 2.37764 .77254 Mabsadd L
.83333 .4151 .56518 .7779 Mabsadd L
.83333 .4151 0 2.5 Mabsadd L closepath F
.85714 .37986 0 2.5 Mabsadd m
.85714 .37986 -0.56518 .7779 Mabsadd L
.85714 .37986 -2.37764 .77254 Mabsadd L
.85714 .37986 -0.91448 -0.29713 Mabsadd L
.85714 .37986 -1.46946 -2.02254 Mabsadd L
.85714 .37986 0 -0.96154 Mabsadd L
.85714 .37986 1.46946 -2.02254 Mabsadd L
.85714 .37986 .91448 -0.29713 Mabsadd L
.85714 .37986 2.37764 .77254 Mabsadd L
.85714 .37986 .56518 .7779 Mabsadd L
.85714 .37986 0 2.5 Mabsadd L closepath F
.88095 .33915 0 2.5 Mabsadd m
.88095 .33915 -0.56518 .7779 Mabsadd L
.88095 .33915 -2.37764 .77254 Mabsadd L
.88095 .33915 -0.91448 -0.29713 Mabsadd L
.88095 .33915 -1.46946 -2.02254 Mabsadd L
.88095 .33915 0 -0.96154 Mabsadd L
.88095 .33915 1.46946 -2.02254 Mabsadd L
.88095 .33915 .91448 -0.29713 Mabsadd L
.88095 .33915 2.37764 .77254 Mabsadd L
.88095 .33915 .56518 .7779 Mabsadd L
.88095 .33915 0 2.5 Mabsadd L closepath F
.90476 .29516 0 2.5 Mabsadd m
.90476 .29516 -0.56518 .7779 Mabsadd L
.90476 .29516 -2.37764 .77254 Mabsadd L
.90476 .29516 -0.91448 -0.29713 Mabsadd L
.90476 .29516 -1.46946 -2.02254 Mabsadd L
.90476 .29516 0 -0.96154 Mabsadd L
.90476 .29516 1.46946 -2.02254 Mabsadd L
.90476 .29516 .91448 -0.29713 Mabsadd L
.90476 .29516 2.37764 .77254 Mabsadd L
.90476 .29516 .56518 .7779 Mabsadd L
.90476 .29516 0 2.5 Mabsadd L closepath F
.92857 .24949 0 2.5 Mabsadd m
.92857 .24949 -0.56518 .7779 Mabsadd L
.92857 .24949 -2.37764 .77254 Mabsadd L
.92857 .24949 -0.91448 -0.29713 Mabsadd L
.92857 .24949 -1.46946 -2.02254 Mabsadd L
.92857 .24949 0 -0.96154 Mabsadd L
.92857 .24949 1.46946 -2.02254 Mabsadd L
.92857 .24949 .91448 -0.29713 Mabsadd L
.92857 .24949 2.37764 .77254 Mabsadd L
.92857 .24949 .56518 .7779 Mabsadd L
.92857 .24949 0 2.5 Mabsadd L closepath F
.95238 .20324 0 2.5 Mabsadd m
.95238 .20324 -0.56518 .7779 Mabsadd L
.95238 .20324 -2.37764 .77254 Mabsadd L
.95238 .20324 -0.91448 -0.29713 Mabsadd L
.95238 .20324 -1.46946 -2.02254 Mabsadd L
.95238 .20324 0 -0.96154 Mabsadd L
.95238 .20324 1.46946 -2.02254 Mabsadd L
.95238 .20324 .91448 -0.29713 Mabsadd L
.95238 .20324 2.37764 .77254 Mabsadd L
.95238 .20324 .56518 .7779 Mabsadd L
.95238 .20324 0 2.5 Mabsadd L closepath F
.97619 .15712 0 2.5 Mabsadd m
.97619 .15712 -0.56518 .7779 Mabsadd L
.97619 .15712 -2.37764 .77254 Mabsadd L
.97619 .15712 -0.91448 -0.29713 Mabsadd L
.97619 .15712 -1.46946 -2.02254 Mabsadd L
.97619 .15712 0 -0.96154 Mabsadd L
.97619 .15712 1.46946 -2.02254 Mabsadd L
.97619 .15712 .91448 -0.29713 Mabsadd L
.97619 .15712 2.37764 .77254 Mabsadd L
.97619 .15712 .56518 .7779 Mabsadd L
.97619 .15712 0 2.5 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
MathSubEnd
P
% End of sub-graphic
0 g
.64286 .45187 m
.64286 .57092 L
.88095 .57092 L
.88095 .45187 L
F
1 g
.64286 .45187 m
.64286 .57092 L
.88095 .57092 L
.88095 .45187 L
F
0 g
.001 w
[ ] 0 setdash
.64286 .45187 m
.88095 .45187 L
.88095 .57092 L
.64286 .57092 L
.64286 .45187 L
s
% Start of sub-graphic
p
0.642857 0.451874 0.880952 0.570922 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0297619 0.297619 0.0198413 0.198413 [
[ 0 0 0 0 ]
[ 1 .5 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .5 L
0 .5 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0535714 0.0357143 0.35119 0.234127 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00748 w
[ .5 3 ] 0 Mabsdash
0 .5 m
1 .5 L
s
.00075 w
[ ] 0 setdash
.5 .5 0 2.5 Mabsadd m
.5 .5 -0.56518 .7779 Mabsadd L
.5 .5 -2.37764 .77254 Mabsadd L
.5 .5 -0.91448 -0.29713 Mabsadd L
.5 .5 -1.46946 -2.02254 Mabsadd L
.5 .5 0 -0.96154 Mabsadd L
.5 .5 1.46946 -2.02254 Mabsadd L
.5 .5 .91448 -0.29713 Mabsadd L
.5 .5 2.37764 .77254 Mabsadd L
.5 .5 .56518 .7779 Mabsadd L
.5 .5 0 2.5 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .13492 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(m) show
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0M) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% Start of sub-graphic
p
0.0535714 0.265873 0.35119 0.464286 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.5 0.5 0.5 [
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
0 g
.00748 w
[ ] 0 setdash
0 .5 m
1 .5 L
s
.00075 w
.5 .5 -1.875 0 Mabsadd m
.5 .5 0 2.5 Mabsadd L
.5 .5 1.875 0 Mabsadd L
.5 .5 0 -2.5 Mabsadd L
.5 .5 -1.875 0 Mabsadd L closepath F
MathSubEnd
P
% End of sub-graphic
0 g
gsave
.38988 .36508 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(B) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
MathSubEnd
P
% End of sub-graphic
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{452.625, 279.75},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007400015b000`400?l00000o`00003oo`3IfMW5
0=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW5
0=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW5
0=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW5
0=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW5
0=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00o`3IfMW5
0=WIf@00o`3IfMW50=WIf@00o`3IfMW50=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIfIX0fMWI
000X0=WIf@030000003IfMT0fMWI0?l0fMWIVP3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMVJ
0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIfIX0fMWI000X0=WIf@030000003IfMT0fMWI0?l0
fMWI;03IfMT00`000000fMWI0=WIf@1[0=WIf@004`3IfMT2000000@0fMWI00<000000=WIf@3IfMT0
0`3IfMT3000000H0fMWI00<000000=WIf@3IfMT0o`3IfMT[0=WIf@<00000K03IfMT00180fMWI00@0
00000=WIf@3IfMT000002P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWI
:`3IfMT3000006`0fMWI000B0=WIf@040000003IfMT0fMWI000000L0fMWI1@0000060=WIf@030000
003IfMT0fMWI0?l0fMWI:`3IfMT2000006d0fMWI000B0=WIf@040000003IfMT0fMWI000000L0fMWI
00@000000=WIf@3IfMT000001`3IfMT300000?l0fMWI:P3IfMT00`000000fMWI0=WIf@1]0=WIf@00
4P3IfMT010000000fMWI0=WIf@0000080=WIf@030000003IfMT0000000L0fMWI00<000000=WIf@3I
fMT0o`3IfMTY0=WIf@030000003IfMT0fMWI06h0fMWI000B0=WIf@040000003IfMT0fMWI000000T0
fMWI0P0000070=WIf@030000003IfMT0fMWI0?l0fMWI:03IfMT00`000000fMWI0=WIf@1_0=WIf@00
4`3IfMT2000000/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3o0=WIfBP0fMWI
00<000000=WIf@3IfMT0K`3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMTW0=WIf@030000003I
fMT0fMWI0700fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI9P3IfMT00`000000fMWI0=WIf@1a
0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIfB@0fMWI0P00001d0=WIf@00:03IfMT00`000000
fMWI0=WIf@3o0=WIfB<0fMWI0`00001d0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIfB<0fMWI
0`00001d0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIfB<0fMWI0P00001e0=WIf@00:03IfMT0
0`000000fMWI0=WIf@3o0=WIfB80fMWI00<000000=WIf@3IfMT0M@3IfMT002P0fMWI00<000000=WI
f@3IfMT0o`3IfMTR0=WIf@030000003IfMT0fMWI07D0fMWI000X0=WIf@800000o`3IfMTR0=WIf@03
0000003IfMT0fMWI07H0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI803IfMT00`000000fMWI
0=WIf@1g0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIfAl0fMWI00<000000=WIf@3IfMT0N03I
fMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMTO0=WIf@030000003IfMT0fMWI07P0fMWI000X0=WI
f@030000003IfMT0fMWI0?l0fMWI7@3IfMT2000007/0fMWI000X0=WIf@030000003IfMT0fMWI0?l0
fMWI703IfMT2000007`0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI703IfMT2000007`0fMWI
000X0=WIf@030000003IfMT0fMWI0?l0fMWI703IfMT2000007`0fMWI000X0=WIf@030000003IfMT0
fMWI0?l0fMWI6`3IfMT00`000000fMWI0=WIf@1l0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WI
fAX0fMWI00<000000=WIf@3IfMT0O@3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMTI0=WIf@03
0000003IfMT0fMWI07h0fMWI000X0=WIf@800000o`3IfMTJ0=WIf@030000003IfMT0fMWI07h0fMWI
000X0=WIf@030000003IfMT0fMWI0?l0fMWI603IfMT00`000000fMWI0=WIf@1o0=WIf@00:03IfMT0
0`000000fMWI0=WIf@3o0=WIfAL0fMWI00<000000=WIf@3IfMT0P03IfMT002P0fMWI00<000000=WI
f@3IfMT0o`3IfMTE0=WIf@800000P`3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMTD0=WIf@<0
0000P`3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMTD0=WIf@<00000P`3IfMT002P0fMWI00<0
00000=WIf@3IfMT0o`3IfMTD0=WIf@800000Q03IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMTC
0=WIf@030000003IfMT0fMWI08@0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI4P3IfMT00`00
0000fMWI0=WIf@250=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIfA40fMWI00<000000=WIf@3I
fMT0QP3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMT@0=WIf@030000003IfMT0fMWI08L0fMWI
000X0=WIf@030000003IfMT0fMWI0?l0fMWI3`3IfMT00`000000fMWI0=WIf@280=WIf@00:03IfMT2
00000?l0fMWI3P3IfMT2000008/0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI303IfMT30000
08/0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI2`3IfMT4000008/0fMWI000X0=WIf@030000
003IfMT0fMWI0?l0fMWI303IfMT3000008/0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI2`3I
fMT00`000000fMWI0000002<0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIf@X0fMWI00<00000
0=WIf@3IfMT0S@3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMT90=WIf@030000003IfMT0fMWI
08h0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT00`000000fMWI0=WIf@0P0=WIf@03
0000003IfMT0000006`0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI1`3IfMT00`000000fMWI
0=WIf@0Q0=WIf@<00000K03IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMT50=WIf@800000903I
fMT3000006`0fMWI000C0=WIf@800000103IfMT00`000000fMWI0=WIf@020=WIf@<000001`3IfMT0
0`000000fMWI0=WIf@3o0=WIf@@0fMWI0`00000U0=WIf@030000003IfMT0fMWI06/0fMWI000B0=WI
f@040000003IfMT0fMWI000000L0fMWI00D000000=WIf@3IfMT0fMWI000000060=WIf@030000003I
fMT0fMWI0?l0fMWI0`3IfMT4000002D0fMWI00<000000=WIf@3IfMT0J`3IfMT00180fMWI00@00000
0=WIf@3IfMT000001`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI0`00003o0=WIf@<0fMWI
1000000S0=WIf@030000003IfMT0fMWI06d0fMWI000B0=WIf@040000003IfMT0fMWI000000L0fMWI
100000070=WIf@030000003IfMT0fMWI0?l0fMWI0P3IfMT010000000fMWI0=WIf@00002D0=WIf@00
4P3IfMT010000000fMWI0=WIf@0000070=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3I
fMT0o`3IfMT10=WIf@030000003IfMT0fMWI09H0fMWI000B0=WIf@040000003IfMT0fMWI000000P0
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@3o0=WIf@030000003IfMT0fMWI02H0
fMWI00<000000=WIf@3IfMT0KP3IfMT001<0fMWI0P00000:0=WIf@8000001`3IfMT00`000000fMWI
0=WIf@3n0=WIf@030000003IfMT0fMWI02H0fMWI00<000000=WIf@3IfMT0K`3IfMT002P0fMWI00<0
00000=WIf@3IfMT0o03IfMT2000009/0fMWI000X0=WIf@030000003IfMT0fMWI0?/0fMWI0`00000X
0=WIf@030000003IfMT0fMWI0700fMWI000X0=WIf@030000003IfMT0fMWI0?X0fMWI1000000X0=WI
f@030000003IfMT0fMWI0700fMWI000X0=WIf@030000003IfMT0fMWI0?T0fMWI00@000000=WIf@3I
fMT00000W03IfMT002P0fMWI00<000000=WIf@3IfMT0n03IfMT00`000000fMWI0=WIf@0Y0=WIf@03
0000003IfMT0fMWI0780fMWI000X0=WIf@030000003IfMT0fMWI0?L0fMWI00<000000=WIf@3IfMT0
:P3IfMT00`000000fMWI0=WIf@1b0=WIf@00:03IfMT00`000000fMWI0=WIf@3e0=WIf@800000:`3I
fMT00`000000fMWI0000001d0=WIf@00:03IfMT200000?D0fMWI0`00000[0=WIf@@00000L`3IfMT0
02P0fMWI00<000000=WIf@3IfMT0lP3IfMT5000002`0fMWI00<000000=WIf@3IfMT0L`3IfMT002P0
fMWI00<000000=WIf@3IfMT0l03IfMT2000000<0fMWI00<000000=WIf@3IfMT0:`3IfMT00`000000
fMWI0=WIf@1c0=WIf@00:03IfMT00`000000fMWI0=WIf@3]0=WIf@<00000Z@3IfMT002P0fMWI00<0
00000=WIf@3IfMT0k03IfMT300000380fMWI00<000000=WIf@3IfMT0M@3IfMT002P0fMWI00<00000
0=WIf@3IfMT0j@3IfMT600000:X0fMWI000X0=WIf@030000003IfMT0fMWI0>D0fMWI100000030=WI
f@<00000ZP3IfMT002P0fMWI00<000000=WIf@3IfMT0g@3IfMT010000000fMWI0=WIf@3IfMT60000
00H0fMWI00<000000=WIf@3IfMT0;`3IfMT2000007P0fMWI000X0=WIf@030000003IfMT0fMWI0=X0
fMWI1`0000030=WIf@<00000/P3IfMT002P0fMWI00<000000=WIf@3IfMT0e03IfMT6000000030=WI
f@0000000000008000001P3IfMT00`000000fMWI0=WIf@2a0=WIf@00:03IfMT00`000000fMWI0=WI
f@360=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@0000001P0000050=WIf@<00000?`3I
fMT00`000000fMWI0=WIf@1h0=WIf@00:03IfMT00`000000fMWI0=WIf@2n0=WIf@040000003IfMT0
fMWI0=WIf@h000001@3IfMT2000000H0fMWI00<000000=WIf@3IfMT0^@3IfMT002P0fMWI0P00002g
0=WIf@040000003IfMT0fMWI0=WIf@P000000P3IfMT4000000D0fMWI0`0000390=WIf@00:03IfMT0
0`000000fMWI0=WIf@2c0=WIf@L000000P3IfMT4000000D0fMWI0`0000060=WIf@030000003IfMT0
fMWI04/0fMWI00<000000=WIf@3IfMT0NP3IfMT002P0fMWI00<000000=WIf@3IfMT0Y`3IfMT01000
0000fMWI0=WIf@3IfMT800000080fMWI0`0000050=WIf@<000001P3IfMT00`000000fMWI0=WIf@1B
0=WIf@030000003IfMT0fMWI07/0fMWI000X0=WIf@030000003IfMT0fMWI09l0fMWI00@000000=WI
f@3IfMT0fMWI200000020=WIf@<000001P3IfMT2000000H0fMWI00<000000=WIf@3IfMT0F@3IfMT4
000007/0fMWI000X0=WIf@030000003IfMT0fMWI09L0fMWI00@000000=WIf@3IfMT0fMWI20000002
0=WIf@@000001@3IfMT2000000H0fMWI00<000000=WIf@3IfMT0HP3IfMT00`000000fMWI0=WIf@1k
0=WIf@00:03IfMT00`000000fMWI0=WIf@2?0=WIf@040000003IfMT0fMWI0=WIf@P000000`3IfMT3
000000D0fMWI0`00003`0=WIf@00:03IfMT00`000000fMWI0=WIf@200=WIf@030000003IfMT0fMWI
00D0fMWI00@000000=WIf@3IfMT0fMWI1`0000030=WIf@<000001P3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI0>l0fMWI000X0=WIf@030000003IfMT0fMWI07P0fMWI00@000000=WI
f@3IfMT0fMWI400000020=WIf@<000001P3IfMT00`000000fMWI0=WIf@1o0=WIf@030000003IfMT0
fMWI07d0fMWI000X0=WIf@030000003IfMT0fMWI0700fMWI00@000000=WIf@3IfMT0fMWI20000002
0=WIf@@000001@3IfMT3000000D0fMWI00<000000=WIf@3IfMT0Q`3IfMT00`000000fMWI0=WIf@1m
0=WIf@00:03IfMT00`000000fMWI0=WIf@1]0=WIf@L000000P3IfMT4000000D0fMWI0`0000060=WI
f@030000003IfMT0fMWI0?l0fMWI3`3IfMT002P0fMWI00<000000=WIf@3IfMT0H@3IfMT010000000
fMWI0=WIf@3IfMT8000000030=WIf@0000000000008000001@3IfMT3000000H0fMWI00<000000=WI
f@3IfMT0U@3IfMT00`000000fMWI0=WIf@1n0=WIf@00:03IfMT00`000000fMWI0=WIf@1I0=WIf@04
0000003IfMT0fMWI0=WIf@P000000P3IfMT3000000D0fMWI0`0000060=WIf@030000003IfMT0fMWI
09`0fMWI00<000000=WIf@3IfMT0O`3IfMT002P0fMWI0P00001:0=WIf@030000003IfMT0fMWI00D0
fMWI00@000000=WIf@3IfMT0fMWI200000030=WIf@<000001@3IfMT2000000H0fMWI00<000000=WI
f@3IfMT0o`3IfMTW0=WIf@00:03IfMT00`000000fMWI0=WIf@120=WIf@040000003IfMT0fMWI0=WI
f@l000000`3IfMT3000000H0fMWI00<000000=WIf@3IfMT0/P3IfMT00`000000fMWI0=WIf@200=WI
f@00:03IfMT00`000000fMWI0=WIf@0j0=WIf@040000003IfMT0fMWI0=WIf@P000000P3IfMT30000
00D0fMWI0`0000060=WIf@030000003IfMT0fMWI0;X0fMWI00<000000=WIf@3IfMT0P03IfMT002P0
fMWI00<000000=WIf@3IfMT0<P3IfMT010000000fMWI0=WIf@3IfMT800000080fMWI100000050=WI
f@8000001P3IfMT00`000000fMWI0=WIf@3o0=WIfDH0fMWI000X0=WIf@030000003IfMT0fMWI02X0
fMWI00@000000=WIf@3IfMT0fMWI200000020=WIf@@000001@3IfMT3000000D0fMWI00<000000=WI
f@3IfMT0b03IfMT00`000000fMWI0=WIf@220=WIf@00:03IfMT00`000000fMWI0=WIf@0S0=WIf@04
0000003IfMT0fMWI0=WIf@L000000P3IfMT4000000D0fMWI0`0000060=WIf@030000003IfMT0fMWI
0<h0fMWI0P0000240=WIf@00:03IfMT00`000000fMWI0=WIf@0K0=WIf@040000003IfMT0fMWI0=WI
f@P000000P3IfMT3000000D0fMWI0`0000060=WIf@030000003IfMT0fMWI0=D0fMWI100000230=WI
f@00:03IfMT00`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00@000000=WIf@3I
fMT0fMWI200000030=WIf@8000001P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
0=h0fMWI00<000000=WIf@3IfMT0P`3IfMT002P0fMWI00<000000=WIf@3IfMT00`3IfMT010000000
fMWI0=WIf@3IfMT@000000<0fMWI0`0000060=WIf@030000003IfMT0fMWI0>`0fMWI00<000000=WI
f@3IfMT0Q03IfMT001<0fMWI0P0000040=WIf@030000003IfMT0fMWI0080fMWI0`0000060=WIf@80
00000P3IfMT700000080fMWI100000050=WIf@<000001P3IfMT00`000000fMWI0=WIf@3o0=WIfG`0
fMWI000B0=WIf@040000003IfMT0fMWI000000L0fMWI00H000000=WIf@000000fMWI0000003IfMT8
00000080fMWI0`0000050=WIf@<000001P3IfMT00`000000fMWI0=WIf@3o0=WIfH@0fMWI000B0=WI
f@040000003IfMT0fMWI000000L0fMWI1P0000020=WIf@@000001@3IfMT2000000H0fMWI00<00000
0=WIf@3IfMT0o`3IfMT40=WIf@030000003IfMT0fMWI08D0fMWI000B0=WIf@040000003IfMT0fMWI
000000P0fMWI0`0000050=WIf@D000000`3IfMT00`000000fMWI0=WIf@3o0=WIfI@0fMWI000B0=WI
f@040000003IfMT0fMWI000000L0fMWI00D000000=WIf@000000fMWI000000050=WIf@800000o`3I
fMVL0=WIf@004P3IfMT010000000fMWI0=WIf@0000070=WIf@050000003IfMT0fMWI0=WIf@000000
1P3IfMT00`000000fMWI0=WIf@3o0=WIfA00fMWI00<000000=WIf@3IfMT0Q`3IfMT001<0fMWI0P00
00090=WIf@<000001`3IfMT00`000000fMWI0=WIf@3o0=WIfIX0fMWI000X0=WIf@030000003IfMT0
fMWI0?l0fMWIVP3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMT>0=WIf@800000RP3IfMT002P0
fMWI00<000000=WIf@3IfMT0o`3IfMVJ0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIf@`0fMWI
00<000000=WIf@3IfMT0R`3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMT<0=WIf@800000S03I
fMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMT<0=WIf@<00000R`3IfMT002P0fMWI00<000000=WI
f@3IfMT0o`3IfMT=0=WIf@030000003IfMT0fMWI08X0fMWI000X0=WIf@030000003IfMT0fMWI0?l0
fMWI2`3IfMT00`000000fMWI0=WIf@2<0=WIf@00:03IfMT200000?l0fMWIV`3IfMT002P0fMWI00<0
00000=WIf@3IfMT0o`3IfMVJ0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIf@T0fMWI00<00000
0=WIf@3IfMT0SP3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMVJ0=WIf@00:03IfMT00`000000
fMWI0=WIf@3o0=WIfIX0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI1`3IfMT200000940fMWI
000X0=WIf@030000003IfMT0fMWI0?l0fMWIVP3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMVJ
0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIf@@0fMWI00<000000=WIf@000000T`3IfMT002P0
fMWI00<000000=WIf@3IfMT0o`3IfMT40=WIf@<00000T`3IfMT002P0fMWI00<000000=WIf@3IfMT0
o`3IfMT40=WIf@@00000TP3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMT40=WIf@800000U03I
fMT002P0fMWI0P00003o0=WIf@H0fMWI00<000000=WIf@3IfMT0TP3IfMT002P0fMWI00<000000=WI
f@3IfMT0o`3IfMVJ0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIf@80fMWI00<000000=WIf@3I
fMT0U@3IfMT002P0fMWI00<000000=WIf@3IfMT0o`3IfMVJ0=WIf@00:03IfMT00`000000fMWI0=WI
f@3o0=WIfIX0fMWI000X0=WIf@030000003IfMT0fMWI0?l0fMWI00<000000=WIf@3IfMT0U`3IfMT0
02P0fMWI00<000000=WIf@3IfMT0o`3IfMVJ0=WIf@00:03IfMT00`000000fMWI0=WIf@3o0=WIfIX0
fMWI000X0=WIf@030000003IfMT0fMWI0?d0fMWI00<000000=WIf@3IfMT0V@3IfMT002P0fMWI00<0
00000=WIf@3IfMT0o03IfMT2000009/0fMWI000X0=WIf@030000003IfMT0fMWI0?/0fMWI1000002J
0=WIf@00:03IfMT00`000000fMWI0=WIf@0S0=WIf@<00000103IfMT2000002<0fMWI00<000000=WI
f@3IfMT00P3IfMT3000001l0fMWI0`0000040=WIf@800000103IfMT2000001`0fMWI0`0000020=WI
f@D000000P3IfMT3000001d0fMWI0`0000030=WIf@<00000103IfMT2000001`0fMWI1@0000020=WI
f@030000003IfMT0fMWI0080fMWI0`00000K0=WIf@D000000`3IfMT2000000@0fMWI0P00001W0=WI
f@00:03IfMT2000002<0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI
00000280fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@030000003IfMT0fMWI01d0fMWI00<0
00000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000001`0
fMWI00<000000=WIf@3IfMT00P3IfMT01P000000fMWI0=WIf@000000fMWI000000<0fMWI00<00000
0=WIf@3IfMT06`3IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00@000000=WIf@3IfMT00000
0P3IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0
fMWI000000030=WIf@030000003IfMT0fMWI01T0fMWI00@000000=WIf@3IfMT000000P3IfMT01000
0000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000006H0fMWI000X0=WIf@030000003IfMT0
fMWI02H0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@0Q0=WIf@030000003I
fMT0fMWI00@0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@020=WIf@040000003I
fMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000703IfMT00`000000fMWI0=WIf@030=WIf@03
0000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@050=WIf@04
0000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT06@3IfMT2000000H0fMWI00<000000=WI
f@3IfMT0103IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WI
f@3IfMT000000P3IfMT010000000fMWI0=WIf@00001V0=WIf@00:03IfMT00`000000fMWI0=WIf@0V
0=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WI
f@0000020=WIf@040000003IfMT0fMWI000001`0fMWI00<000000=WIf@3IfMT0103IfMT00`000000
fMWI0=WIf@040=WIf@030000003IfMT0fMWI01/0fMWI00<000000=WIf@3IfMT01@3IfMT010000000
fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI01X0fMWI00<000000=WIf@3IfMT0103IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01/0fMWI00D000000=WIf@3IfMT0fMWI00000002
0=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT0I03IfMT002P0fMWI00<00000
0=WIf@3IfMT08P3IfMT4000000<0fMWI00@000000=WIf@3IfMT00000903IfMT00`000000fMWI0000
000300000200fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@0000020=WIf@040000
003IfMT0fMWI000001`0fMWI00D000000=WIf@3IfMT0fMWI000000030=WIf@030000003IfMT00000
00<000007P3IfMT010000000fMWI0=WIf@3IfMT4000000<0fMWI00@000000=WIf@3IfMT00000703I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0000000<000006`3IfMT01@000000fMWI0=WI
f@3IfMT000000080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00001V0=WI
f@00:03IfMT00`000000fMWI0=WIf@0R0=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3I
fMT00000803IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@0000008P3IfMT2000000@0fMWI00@0
00000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000K0=WIf@8000000`3IfMT01`000000
fMWI0=WIf@3IfMT000000=WIf@000000803IfMT2000000<0fMWI00<000000=WIf@3IfMT0103IfMT0
10000000fMWI0=WIf@00000I0=WIf@040000003IfMT00000000000<0fMWI00L000000=WIf@3IfMT0
fMWI0000003IfMT0000001h0fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0
fMWI00000080fMWI00@000000=WIf@3IfMT00000IP3IfMT002P0fMWI00<000000=WIf@3IfMT08P3I
fMT5000000<0fMWI0P00000Q0=WIf@D0000000<0fMWI0000000000000`00000O0=WIf@030000003I
fMT0fMWI00<0fMWI0P0000040=WIf@8000007@3IfMT00`000000fMWI0=WIf@020=WIf@<000000P3I
fMT5000001d0fMWI00@000000=WIf@3IfMT0fMWI1@0000030=WIf@800000603IfMT00`000000fMWI
0=WIf@020=WIf@040000003IfMT0fMWI0=WIf@D0000000<0fMWI0000000000000`00000K0=WIf@<0
0000103IfMT2000000@0fMWI0P00001W0=WIf@00:03IfMT00`000000fMWI0=WIf@3c0=WIf@@00000
XP3IfMT002P0fMWI00<000000=WIf@3IfMT0m03IfMT00`000000fMWI0=WIf@2R0=WIf@00:03IfMT0
0`000000fMWI0=WIf@3a0=WIf@030000003IfMT0fMWI05/0fMWI0`00000<0=WIf@8000003P3IfMT3
000001D0fMWI0P00000A0=WIf@00:03IfMT00`000000fMWI0=WIf@3a0=WIf@030000003IfMT0fMWI
05`0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0fMWI
01<0fMWI00<000000=WIf@3IfMT03`3IfMT002P0fMWI00<000000=WIf@3IfMT0k`3IfMT00`000000
fMWI0=WIf@1<0=WIf@<000000`3IfMT300000080fMWI00D000000=WIf@000000fMWI000000020=WI
f@<00000103IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0=WIf@@000000P3IfMT3
000000<0fMWI100000030=WIf@030000003IfMT0fMWI00T0fMWI0P0000040=WIf@030000003IfMT0
fMWI00l0fMWI000X0=WIf@030000003IfMT0fMWI0>/0fMWI0P0000000`3IfMT000000=WIf@1?0=WI
f@050000003IfMT0fMWI0=WIf@0000001@3IfMT01@000000fMWI0000003IfMT000000080fMWI00@0
00000=WIf@3IfMT000002P3IfMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI0000
00D0fMWI00D000000=WIf@3IfMT0fMWI0000000>0=WIf@040000003IfMT0fMWI000000<0fMWI00<0
00000=WIf@3IfMT03`3IfMT001L0fMWIo`000019000000/0fMWI00@000000=WIf@3IfMT0fMWI1@00
00001P3IfMT000000=WIf@000000fMWI00000080fMWI00@000000=WIf@3IfMT000002P3IfMT01000
0000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00D0000000<0fMWI0000003IfMT00P3IfMT0
0`000000fMWI0=WIf@0;0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT03`3IfMT0
01l0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00D0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00D0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00D0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI
00D0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WIf@020=WIf@D000001`3IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@060=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01P3IfMT00`00
0000fMWI0=WIf@0A0=WIf@050000003IfMT0fMWI0=WIf@0000000`3IfMT01`000000fMWI0000003I
fMT000000=WIf@0000000P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI0000
0080fMWI00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI000000030=WIf@030000003IfMT0
fMWI00/0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@0?0=WIf@00:03IfMT00`00
0000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI02P0fMWI00<000000=WIf@3IfMT0:03IfMT00`00
0000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3IfMT0403IfMT20000
01H0fMWI00<000000=WIf@3IfMT0:03IfMT00`000000fMWI0=WIf@0?0=WIf@050000003IfMT00000
0=WIf@0000000P3IfMT300000080fMWI0P000000103IfMT000000=WIf@3IfMT4000000/0fMWI00@0
00000=WIf@3IfMT0fMWI0`0000030=WIf@<000000`3IfMT5000000`0fMWI00<000000=WIf@3IfMT0
1@3IfMT00`000000fMWI0=WIf@0?0=WIf@00:03IfMT00`000000fMWI0=WIf@3T0=WIf@030000003I
fMT0000005H0fMWI00D000000=WIf@000000fMWI0000000L0=WIf@800000103IfMT00`000000fMWI
0=WIf@0I0=WIf@040000003IfMT0fMWI00000080fMWI0P00000A0=WIf@00:03IfMT00`000000fMWI
0=WIf@3T0=WIf@<00000EP3IfMT500000240fMWI0P00000L0=WIf@<000005@3IfMT002P0fMWI00<0
00000=WIf@3IfMT0g03IfMT00`000000fMWI000000030=WIf@040000003IfMT0fMWI00000;<0fMWI
000X0=WIf@030000003IfMT0fMWI0=`0fMWI100000050=WIf@030000003IfMT0fMWI0;40fMWI000X
0=WIf@030000003IfMT0fMWI0=@0fMWI0P0000020=WIf@030000003IfMT0fMWI00D00000^@3IfMT0
02P0fMWI00<000000=WIf@3IfMT0e03IfMT3000000030=WIf@000000fMWI00<0fMWI00<000000=WI
f@3IfMT0^@3IfMT002P0fMWI00<000000=WIf@3IfMT0c@3IfMT200000080fMWI00<000000=WIf@3I
fMT0100000050=WIf@030000003IfMT0fMWI0;T0fMWI000X0=WIf@030000003IfMT0fMWI0<@0fMWI
0P0000040=WIf@030000003IfMT0000000<000001@3IfMT00`000000fMWI0=WIf@310=WIf@00:03I
fMT200000;h0fMWI00<000000=WIf@0000001@3IfMT3000000D0fMWI00<000000=WIf@3IfMT0b@3I
fMT002P0fMWI00<000000=WIf@3IfMT0_@3IfMT400000080fMWI00<000000=WIf@0000000P00003A
0=WIf@00:03IfMT00`000000fMWI0=WIf@2e0=WIf@050000003IfMT000000=WIf@0000000P3IfMT5
000000@0fMWI0P00003B0=WIf@00:03IfMT00`000000fMWI0=WIf@2]0=WIf@8000001P3IfMT30000
00H0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@3@0=WIf@00:03IfMT00`000000
fMWI0=WIf@2U0=WIf@8000001`3IfMT200000080fMWI00<000000=WIf@3IfMT0100000050=WIf@03
0000003IfMT0fMWI0=P0fMWI000X0=WIf@030000003IfMT0fMWI0:H0fMWI0`0000020=WIf@030000
003IfMT0000000<000001@3IfMT00`000000fMWI0=WIf@3P0=WIf@00:03IfMT00`000000fMWI0=WI
f@2N0=WIf@040000003IfMT0000000000080fMWI1@0000050=WIf@030000003IfMT0fMWI0>P0fMWI
000X0=WIf@030000003IfMT0fMWI09H0fMWI00<000000=WIf@000000103IfMT4000000D0fMWI00<0
00000=WIf@3IfMT0l03IfMT002P0fMWI00<000000=WIf@3IfMT0SP3IfMT00`000000fMWI00000005
0=WIf@<0000000<0fMWI0000003IfMT00P3IfMT300000?P0fMWI000X0=WIf@030000003IfMT0fMWI
08l0fMWI0P0000020=WIf@030000003IfMT0fMWI00@000001@3IfMT00`000000fMWI0=WIf@3g0=WI
f@00:03IfMT00`000000fMWI0=WIf@270=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@00
00000`0000050=WIf@030000003IfMT0fMWI0?l0fMWI000X0=WIf@030000003IfMT0fMWI07h0fMWI
0P0000050=WIf@D000001@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0?l0fMWI
000X0=WIf@800000N03IfMT00`000000fMWI000000040=WIf@D00000103IfMT00`000000fMWI0=WI
f@050=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT002P0fMWI00<000000=WIf@3IfMT0M`3IfMT5
000000<0fMWI0`00003o0=WIfAP0fMWI000X0=WIf@030000003IfMT0fMWI06l0fMWI00<000000=WI
f@0000000P3IfMT00`000000fMWI0=WIf@04000007`0fMWIK000000f0=WIf@00:03IfMT00`000000
fMWI0=WIf@1W0=WIf@800000103IfMT00`000000fMWI00000003000000D0fMWI00<000000=WIf@3I
fMT0O03IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI000X0=WIf@030000
003IfMT0fMWI05l0fMWI0P0000050=WIf@030000003IfMT00000008000001@3IfMT00`000000fMWI
0=WIf@050=WIf@030000003IfMT0fMWI07`0fMWI00<000000?ooo`3oool0J03oool00`000000fMWI
0=WIf@0d0=WIf@00:03IfMT00`000000fMWI0=WIf@1O0=WIf@D000000`3IfMT4000000D0fMWI00<0
00000=WIf@3IfMT0Q03IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI000X
0=WIf@030000003IfMT0fMWI05P0fMWI00<000000=WIf@3IfMT00P0000020=WIf@@00000U03IfMT0
0`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI000X0=WIf@030000003IfMT0fMWI
0500fMWI00@000000=WIf@000000fMWI0P0000020=WIf@<000001@3IfMT00`000000fMWI0=WIf@2D
0=WIf@030000003oool0oooo06P0oooo00<000000=WIf@3IfMT0=03IfMT002P0fMWI00<000000=WI
f@3IfMT0B03IfMT00`000000fMWI000000030=WIf@030000003IfMT00000008000001@3IfMT20000
09d0fMWI00<000000?ooo`3oool0J03oool00`000000fMWI0=WIf@0d0=WIf@00:03IfMT00`000000
fMWI0=WIf@100=WIf@8000001@3IfMT00`000000fMWI00000002000000@0fMWI100000050=WIf@03
0000003IfMT0fMWI09/0fMWI00<000000?ooo`3oool0J03oool00`000000fMWI0=WIf@0d0=WIf@00
:03IfMT00`000000fMWI0=WIf@110=WIf@@000000P3IfMT5000000D0fMWI00<000000=WIf@3IfMT0
X`3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI000X0=WIf@030000003I
fMT0fMWI03T0fMWI00<000000=WIf@3IfMT00P0000020=WIf@@000001@3IfMT00`000000fMWI0=WI
f@2[0=WIf@030000003oool0oooo06P0oooo00<000000=WIf@3IfMT0=03IfMT002P0fMWI0P00000b
0=WIf@040000003IfMT000000=WIf@8000000P3IfMT3000000D0fMWI00<000000=WIf@3IfMT01@3I
fMT00`000000fMWI0=WIf@2[0=WIf@030000003oool0oooo02T0oooo00<000000?ooo`3oool0?03o
ool00`000000fMWI0=WIf@0d0=WIf@00:03IfMT00`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0
000000<0fMWI00<000000=WIf@0000000P0000050=WIf@030000003IfMT0fMWI0;/0fMWI00<00000
0?ooo`3oool0:@3oool00`000000oooo0?ooo`0l0?ooo`030000003IfMT0fMWI03@0fMWI000X0=WI
f@030000003IfMT0fMWI02T0fMWI100000020=WIf@030000003IfMT0000000800000``3IfMT00`00
0000oooo0?ooo`0Y0?ooo`H000000P3oool200000080oooo0P000000103oool0000000000000000]
0?ooo`030000003IfMT0fMWI03@0fMWI000X0=WIf@030000003IfMT0fMWI0280fMWI00@000000=WI
f@00000000000P3IfMT5000000D0fMWI00<000000=WIf@3IfMT0`P3IfMT00`000000oooo0?ooo`0A
0?ooo`030000003oool0000001D0oooo00D000000?ooo`3oool0oooo000000020?ooo`060000003o
ool0oooo0000003oool000000`3oool00`000000oooo0?ooo`0/0?ooo`030000003IfMT0fMWI03@0
fMWI000X0=WIf@030000003IfMT0fMWI01T0fMWI0P0000020=WIf@8000000P3IfMT4000000D0fMWI
00<000000=WIf@3IfMT0bP3IfMT00`000000oooo0?ooo`080?ooo`030000003oool0oooo00800000
0P3oool00`000000oooo0000000200000080oooo00<000000?ooo`3oool00P0000020?ooo`030000
003oool0oooo00X0oooo00@000000?ooo`3oool000000P3oool01P000000oooo0?ooo`000000oooo
000000<0oooo00<000000?ooo`3oool0;03oool00`000000fMWI0=WIf@0d0=WIf@00:03IfMT00`00
0000fMWI0=WIf@0B0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00P0000060=WI
f@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0bP3IfMT00`000000oooo0?ooo`0A0?oo
o`@000005@3oool01`000000oooo0?ooo`3oool000000?ooo`0000000P3oool00`000000oooo0000
00030?ooo`030000003oool0oooo02`0oooo00<000000=WIf@3IfMT0=03IfMT002P0fMWI00<00000
0=WIf@3IfMT02P3IfMT00`000000fMWI000000050=WIf@8000000P3IfMT00`000000fMWI0=WIf@04
00000=X0fMWI00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`0E0?ooo`070000003oool0
oooo0?ooo`000000oooo000000020?ooo`070000003oool000000?ooo`000000oooo0000000^0?oo
o`030000003IfMT0fMWI03@0fMWI000X0=WIf@030000003IfMT0fMWI00X0fMWI0`0000020=WIf@80
000000@0fMWI0000000000000000hP3IfMT00`000000oooo0?ooo`0B0?ooo`030000003oool0oooo
01/0oooo00D000000?ooo`3oool000000?ooo`02000000030?ooo`000000000002h0oooo00<00000
0=WIf@3IfMT0=03IfMT002P0fMWI00<000000=WIf@3IfMT0103IfMT300000080fMWI1@0000040=WI
f@800000h`3IfMT00`000000oooo0?ooo`0a0?ooo`8000000P3oool010000000oooo0?ooo`3oool2
000002d0oooo00<000000=WIf@3IfMT0=03IfMT002D0fMWI0P000000103IfMT000000=WIf@000002
0=WIf@@000001@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI0>40fMWI00<00000
0?ooo`3oool0J03oool00`000000fMWI0=WIf@0d0=WIf@004P3IfMT3000000@0fMWI00@000000=WI
f@3IfMT0fMWI1@0000040=WIf@@00000103IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0
fMWI0>T0fMWI00<000000?ooo`3oool0J03oool00`000000fMWI0=WIf@0d0=WIf@004`3IfMT00`00
0000fMWI0=WIf@080=WIf@80000000D0fMWI00000000000000000=WIf@04000000D0fMWI00<00000
0=WIf@3IfMT0l@3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI000C0=WI
f@030000003IfMT0fMWI00L0fMWI100000070=WIf@<00000m`3IfMT00`000000oooo0?ooo`1X0?oo
o`030000003IfMT0fMWI03@0fMWI000C0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@00
00001`3IfMT00`000000fMWI0=WIf@3g0=WIf@030000003oool0oooo06P0oooo00<000000=WIf@3I
fMT0=03IfMT001<0fMWI00<000000=WIf@3IfMT01`3IfMT01@000000fMWI0=WIf@3IfMT0000000H0
fMWI00<000000=WIf@3IfMT0m`3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0
fMWI000B0=WIf@8000002@3IfMT01@000000fMWI0=WIf@3IfMT0000000H0fMWI00<000000=WIf@3I
fMT0m`3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI000C0=WIf@030000
003IfMT0fMWI00P0fMWI0`0000070=WIf@030000003IfMT0fMWI0?L0fMWI00<000000?ooo`3oool0
J03oool00`000000fMWI0=WIf@0d0=WIf@00o`3IfMTS0=WIf@030000003oool0oooo06P0oooo00<0
00000=WIf@3IfMT0=03IfMT00?l0fMWI8`3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0
fMWI03@0fMWI003o0=WIfB<0fMWI00<000000?ooo`3oool0J03oool00`000000fMWI0=WIf@0d0=WI
f@00o`3IfMTS0=WIf@030000003oool0oooo06P0oooo00<000000=WIf@3IfMT0=03IfMT00?l0fMWI
8`3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI003o0=WIfB<0fMWI00<0
00000?ooo`3oool0J03oool00`000000fMWI0=WIf@0d0=WIf@00o`3IfMTS0=WIf@030000003oool0
oooo06P0oooo00<000000=WIf@3IfMT0=03IfMT00?l0fMWI8`3IfMT00`000000oooo0?ooo`1X0?oo
o`030000003IfMT0fMWI03@0fMWI003o0=WIfB<0fMWI00<000000?ooo`3oool0J03oool00`000000
fMWI0=WIf@0d0=WIf@003@3IfMT00`000000fMWI0=WIf@0A0=WIf@030000003IfMT0fMWI0100fMWI
0P0000080=WIf@800000hP3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI
000=0=WIf@030000003IfMT0fMWI0180fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WI
f@080=WIf@030000003IfMT0fMWI0>00fMWI00<000000?ooo`3oool0:@3oool4000003/0oooo00<0
00000=WIf@3IfMT0=03IfMT000d0fMWI1P0000020=WIf@8000000P3IfMT2000000040=WIf@000000
0000000000<0fMWI00<000000=WIf@3IfMT01000000;0=WIf@040000003IfMT0fMWI0=WIf@<00000
103IfMT00`000000fMWI0=WIf@3P0=WIf@030000003oool0oooo0180oooo00<000000?ooo`3oool0
5@3oool010000000oooo0?ooo`00000j0?ooo`030000003IfMT0fMWI03@0fMWI000=0=WIf@050000
003IfMT0fMWI0=WIf@0000000P3IfMT01P000000fMWI0=WIf@000000fMWI000000<0fMWI00<00000
0=WIf@3IfMT01P3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI0080fMWI00<0
00000=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@3P0=WIf@030000003oool0oooo00P0oooo5P00
000<0?ooo`040000003oool0oooo000003X0oooo00<000000=WIf@3IfMT0=03IfMT000h0fMWI00@0
00000=WIf@3IfMT000000P3IfMT01P000000fMWI0=WIf@000000fMWI000000<0fMWI00<000000=WI
f@3IfMT01P3IfMT010000000fMWI0=WIf@00000:0=WIf@030000003IfMT0fMWI0080fMWI00<00000
0=WIf@3IfMT00`3IfMT00`000000fMWI0=WIf@3P0=WIf@030000003oool0oooo0140oooo0`00000F
0?ooo`<00000>`3oool00`000000fMWI0=WIf@0d0=WIf@003P3IfMT01`000000fMWI0=WIf@3IfMT0
00000=WIf@0000000P3IfMT00`000000fMWI000000030=WIf@030000003IfMT0fMWI00H0fMWI0`00
000;0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT00`3IfMT00`000000fMWI0=WI
f@3P0=WIf@030000003oool0oooo0180oooo00<000000?ooo`3oool05@3oool010000000oooo0?oo
o`00000j0?ooo`030000003IfMT0fMWI03@0fMWI000>0=WIf@070000003IfMT0fMWI0=WIf@000000
fMWI000000020=WIf@070000003IfMT000000=WIf@000000fMWI000000080=WIf@040000003IfMT0
fMWI000000X0fMWI00P000000=WIf@3IfMT000000=WIf@000000fMWI000000<0fMWI00<000000=WI
f@3IfMT0h03IfMT00`000000oooo0?ooo`0Z0?ooo`040000003oool0oooo000003X0oooo00<00000
0=WIf@3IfMT0=03IfMT001@0fMWI00D000000=WIf@3IfMT000000=WIf@02000000030=WIf@000000
000000P0fMWI00@000000=WIf@3IfMT000002P3IfMT2000000060=WIf@000000fMWI0000003IfMT0
00000P3IfMT200000>80fMWI00<000000?ooo`3oool0:@3oool4000003/0oooo00<000000=WIf@3I
fMT0=03IfMT001D0fMWI0P0000020=WIf@040000003IfMT0fMWI0=WIf@8000001P3IfMT4000000h0
fMWI1@00003V0=WIf@030000003oool0oooo06P0oooo00<000000=WIf@3IfMT0=03IfMT00?l0fMWI
8`3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI003o0=WIfB<0fMWI00<0
00000?ooo`3oool0J03oool00`000000fMWI0=WIf@0d0=WIf@00o`3IfMTS0=WIf@030000003oool0
oooo06P0oooo00<000000=WIf@3IfMT0=03IfMT00?l0fMWI8`3IfMT00`000000oooo0?ooo`1X0?oo
o`030000003IfMT0fMWI03@0fMWI003o0=WIfB<0fMWI00<000000?ooo`3oool0J03oool00`000000
fMWI0=WIf@0d0=WIf@00o`3IfMTS0=WIf@030000003oool0oooo06P0oooo00<000000=WIf@3IfMT0
=03IfMT00?l0fMWI8`3IfMT00`000000oooo0?ooo`1X0?ooo`030000003IfMT0fMWI03@0fMWI003o
0=WIfB<0fMWI00<000000?ooo`3oool0J03oool00`000000fMWI0=WIf@0d0=WIf@00o`3IfMTS0=WI
fF`00000=P3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT0
0?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT0
0?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT0
0?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00?l0fMWIa@3IfMT0
0?l0fMWIa@3IfMT00?l0fMWIa@3IfMT00001\
\>"],
  ImageRangeCache->{{{0, 451.625}, {278.75, 0}} -> {-1.0514, -0.648943, \
0.00465606, 0.00465606}, {{11, 440.562}, {272.062, 6.625}} -> {1.86584, \
0.24949, 0.578309, 0.00419823}, {{290.188, 397.625}, {74.9375, 21.25}} -> \
{-9.18169, -9.66671, 0.0312925, 0.0469387}, {{295.938, 327.875}, {71.0625, \
49.75}} -> {-29.2701, -20.4899, 0.0938426, 0.0938426}, {{295.938, 327.875}, \
{46.375, 25.0625}} -> {-29.2701, -22.8067, 0.0938426, 0.0938426}}],

Cell[BoxData[
    TagBox[\(\[SkeletonIndicator]  Graphics  \[SkeletonIndicator]\),
      False,
      Editable->False]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Determine irrevesrible losses", "Subsubsection"],

Cell["\<\
The above graph shows the resulting magnetization as a function of \
the temperature, the curve has two main parts:
- a straight part corresponding to a reversible behavior (i.e cooling down \
the magnet to T0 gives initial magnetization at T0)
- a non linear part corresponding to partial demagnetization ( cooling the \
magnet back to T0 do not give initial magnetization but something lower than \
initial M(T0).
The irreversible losses are determined by removing the reversible part on the \
M vs. Temp. curve and resulting curve is normalized to the magnetization at \
initial temperature T1 corresponding to what could be measured when cooling \
the magnet to initial temperature T1 after cycling at the temperature Temp.\
\
\>", "Text",
  CellFrame->True,
  Background->RGBColor[1, 0.950011, 0.996674]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(a1Br = mat[\([4, 1]\)];\)\), "\[IndentingNewLine]", 
    \(\(a2Br = mat[\([4, 2]\)];\)\), "\[IndentingNewLine]", 
    \(\(Tirr = 
        Table[{TbM[\([i, 
                1]\)], \((TbM[\([i, 2]\)] - 
                    TbM[\([1, 2]\)]*\((1 + a1Br*\((TbM[\([i, 1]\)] - T1)\) + 
                          a2Br\ \((TbM[\([i, 1]\)] - T1)\)^2)\))\)/
                TbM[\([1, 2]\)]*100}, {i, 1, 
            Length[TbM]}];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<irrevesrible losses after temp. cycling\>"];\)\), "\
\[IndentingNewLine]", 
    \(\(MultipleListPlot[Tirr, PlotRange \[Rule] All, 
        PlotJoined \[Rule] True, 
        AxesLabel \[Rule] {"\<Temp.[deg. C]\>", "\<irr. losses \
[%]\>"}];\)\)}], "Input"],

Cell[BoxData[
    \("irrevesrible losses after temp. cycling"\)], "Print"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.0820106 0.00529101 0.603319 0.0179468 [
[.18254 .59082 -6 -9 ]
[.18254 .59082 6 0 ]
[.31481 .59082 -6 -9 ]
[.31481 .59082 6 0 ]
[.44709 .59082 -9 -9 ]
[.44709 .59082 9 0 ]
[.57937 .59082 -9 -9 ]
[.57937 .59082 9 0 ]
[.71164 .59082 -9 -9 ]
[.71164 .59082 9 0 ]
[.84392 .59082 -9 -9 ]
[.84392 .59082 9 0 ]
[.97619 .59082 -9 -9 ]
[.97619 .59082 9 0 ]
[1.025 .60332 0 -6 ]
[1.025 .60332 82 6 ]
[.03776 .06492 -18 -4.5 ]
[.03776 .06492 0 4.5 ]
[.03776 .15465 -18 -4.5 ]
[.03776 .15465 0 4.5 ]
[.03776 .24438 -18 -4.5 ]
[.03776 .24438 0 4.5 ]
[.03776 .33412 -18 -4.5 ]
[.03776 .33412 0 4.5 ]
[.03776 .42385 -18 -4.5 ]
[.03776 .42385 0 4.5 ]
[.03776 .51359 -12 -4.5 ]
[.03776 .51359 0 4.5 ]
[.05026 .64303 -47 0 ]
[.05026 .64303 47 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.18254 .60332 m
.18254 .60957 L
s
[(50)] .18254 .59082 0 1 Mshowa
.31481 .60332 m
.31481 .60957 L
s
[(75)] .31481 .59082 0 1 Mshowa
.44709 .60332 m
.44709 .60957 L
s
[(100)] .44709 .59082 0 1 Mshowa
.57937 .60332 m
.57937 .60957 L
s
[(125)] .57937 .59082 0 1 Mshowa
.71164 .60332 m
.71164 .60957 L
s
[(150)] .71164 .59082 0 1 Mshowa
.84392 .60332 m
.84392 .60957 L
s
[(175)] .84392 .59082 0 1 Mshowa
.97619 .60332 m
.97619 .60957 L
s
[(200)] .97619 .59082 0 1 Mshowa
.125 Mabswid
.07672 .60332 m
.07672 .60707 L
s
.10317 .60332 m
.10317 .60707 L
s
.12963 .60332 m
.12963 .60707 L
s
.15608 .60332 m
.15608 .60707 L
s
.20899 .60332 m
.20899 .60707 L
s
.23545 .60332 m
.23545 .60707 L
s
.2619 .60332 m
.2619 .60707 L
s
.28836 .60332 m
.28836 .60707 L
s
.34127 .60332 m
.34127 .60707 L
s
.36772 .60332 m
.36772 .60707 L
s
.39418 .60332 m
.39418 .60707 L
s
.42063 .60332 m
.42063 .60707 L
s
.47354 .60332 m
.47354 .60707 L
s
.5 .60332 m
.5 .60707 L
s
.52646 .60332 m
.52646 .60707 L
s
.55291 .60332 m
.55291 .60707 L
s
.60582 .60332 m
.60582 .60707 L
s
.63228 .60332 m
.63228 .60707 L
s
.65873 .60332 m
.65873 .60707 L
s
.68519 .60332 m
.68519 .60707 L
s
.7381 .60332 m
.7381 .60707 L
s
.76455 .60332 m
.76455 .60707 L
s
.79101 .60332 m
.79101 .60707 L
s
.81746 .60332 m
.81746 .60707 L
s
.87037 .60332 m
.87037 .60707 L
s
.89683 .60332 m
.89683 .60707 L
s
.92328 .60332 m
.92328 .60707 L
s
.94974 .60332 m
.94974 .60707 L
s
.02381 .60332 m
.02381 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Temp) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(@) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(deg) show
117.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(C) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 13.000 moveto
(D) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.05026 .06492 m
.05651 .06492 L
s
[(-30)] .03776 .06492 1 0 Mshowa
.05026 .15465 m
.05651 .15465 L
s
[(-25)] .03776 .15465 1 0 Mshowa
.05026 .24438 m
.05651 .24438 L
s
[(-20)] .03776 .24438 1 0 Mshowa
.05026 .33412 m
.05651 .33412 L
s
[(-15)] .03776 .33412 1 0 Mshowa
.05026 .42385 m
.05651 .42385 L
s
[(-10)] .03776 .42385 1 0 Mshowa
.05026 .51359 m
.05651 .51359 L
s
[(-5)] .03776 .51359 1 0 Mshowa
.125 Mabswid
.05026 .08286 m
.05401 .08286 L
s
.05026 .10081 m
.05401 .10081 L
s
.05026 .11876 m
.05401 .11876 L
s
.05026 .1367 m
.05401 .1367 L
s
.05026 .1726 m
.05401 .1726 L
s
.05026 .19054 m
.05401 .19054 L
s
.05026 .20849 m
.05401 .20849 L
s
.05026 .22644 m
.05401 .22644 L
s
.05026 .26233 m
.05401 .26233 L
s
.05026 .28028 m
.05401 .28028 L
s
.05026 .29822 m
.05401 .29822 L
s
.05026 .31617 m
.05401 .31617 L
s
.05026 .35206 m
.05401 .35206 L
s
.05026 .37001 m
.05401 .37001 L
s
.05026 .38796 m
.05401 .38796 L
s
.05026 .4059 m
.05401 .4059 L
s
.05026 .4418 m
.05401 .4418 L
s
.05026 .45974 m
.05401 .45974 L
s
.05026 .47769 m
.05401 .47769 L
s
.05026 .49564 m
.05401 .49564 L
s
.05026 .53153 m
.05401 .53153 L
s
.05026 .54948 m
.05401 .54948 L
s
.05026 .56743 m
.05401 .56743 L
s
.05026 .58537 m
.05401 .58537 L
s
.05026 .04697 m
.05401 .04697 L
s
.05026 .02902 m
.05401 .02902 L
s
.05026 .01108 m
.05401 .01108 L
s
.25 Mabswid
.05026 0 m
.05026 .61803 L
s
gsave
.05026 .64303 -108 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(irr) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(.) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(losses) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
135.000 13.000 moveto
(@) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(%) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
147.000 13.000 moveto
(D) show
153.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
.02381 .60332 m
.04762 .6031 L
.07143 .60289 L
.09524 .60269 L
.11905 .60251 L
.14286 .60234 L
.16667 .60218 L
.19048 .60204 L
.21429 .60191 L
.2381 .60179 L
.2619 .60168 L
.28571 .60159 L
.30952 .6015 L
.33333 .60143 L
.35714 .60137 L
.38095 .60132 L
.40476 .60128 L
.42857 .60124 L
.45238 .60122 L
.47619 .60121 L
.5 .6012 L
.52381 .6012 L
.54762 .60121 L
.57143 .60121 L
.59524 .60119 L
.61905 .60115 L
.64286 .60102 L
.66667 .60073 L
.69048 .60007 L
.71429 .59863 L
.7381 .59539 L
.7619 .5881 L
.78571 .57236 L
.80952 .54224 L
.83333 .49428 L
.85714 .43028 L
.88095 .35503 L
.90476 .27304 L
.92857 .18762 L
.95238 .10102 L
.97619 .01472 L
s
.0001 w
.02381 .60332 -1.875 0 Mabsadd m
.02381 .60332 0 2.5 Mabsadd L
.02381 .60332 1.875 0 Mabsadd L
.02381 .60332 0 -2.5 Mabsadd L
.02381 .60332 -1.875 0 Mabsadd L closepath F
.04762 .6031 -1.875 0 Mabsadd m
.04762 .6031 0 2.5 Mabsadd L
.04762 .6031 1.875 0 Mabsadd L
.04762 .6031 0 -2.5 Mabsadd L
.04762 .6031 -1.875 0 Mabsadd L closepath F
.07143 .60289 -1.875 0 Mabsadd m
.07143 .60289 0 2.5 Mabsadd L
.07143 .60289 1.875 0 Mabsadd L
.07143 .60289 0 -2.5 Mabsadd L
.07143 .60289 -1.875 0 Mabsadd L closepath F
.09524 .60269 -1.875 0 Mabsadd m
.09524 .60269 0 2.5 Mabsadd L
.09524 .60269 1.875 0 Mabsadd L
.09524 .60269 0 -2.5 Mabsadd L
.09524 .60269 -1.875 0 Mabsadd L closepath F
.11905 .60251 -1.875 0 Mabsadd m
.11905 .60251 0 2.5 Mabsadd L
.11905 .60251 1.875 0 Mabsadd L
.11905 .60251 0 -2.5 Mabsadd L
.11905 .60251 -1.875 0 Mabsadd L closepath F
.14286 .60234 -1.875 0 Mabsadd m
.14286 .60234 0 2.5 Mabsadd L
.14286 .60234 1.875 0 Mabsadd L
.14286 .60234 0 -2.5 Mabsadd L
.14286 .60234 -1.875 0 Mabsadd L closepath F
.16667 .60218 -1.875 0 Mabsadd m
.16667 .60218 0 2.5 Mabsadd L
.16667 .60218 1.875 0 Mabsadd L
.16667 .60218 0 -2.5 Mabsadd L
.16667 .60218 -1.875 0 Mabsadd L closepath F
.19048 .60204 -1.875 0 Mabsadd m
.19048 .60204 0 2.5 Mabsadd L
.19048 .60204 1.875 0 Mabsadd L
.19048 .60204 0 -2.5 Mabsadd L
.19048 .60204 -1.875 0 Mabsadd L closepath F
.21429 .60191 -1.875 0 Mabsadd m
.21429 .60191 0 2.5 Mabsadd L
.21429 .60191 1.875 0 Mabsadd L
.21429 .60191 0 -2.5 Mabsadd L
.21429 .60191 -1.875 0 Mabsadd L closepath F
.2381 .60179 -1.875 0 Mabsadd m
.2381 .60179 0 2.5 Mabsadd L
.2381 .60179 1.875 0 Mabsadd L
.2381 .60179 0 -2.5 Mabsadd L
.2381 .60179 -1.875 0 Mabsadd L closepath F
.2619 .60168 -1.875 0 Mabsadd m
.2619 .60168 0 2.5 Mabsadd L
.2619 .60168 1.875 0 Mabsadd L
.2619 .60168 0 -2.5 Mabsadd L
.2619 .60168 -1.875 0 Mabsadd L closepath F
.28571 .60159 -1.875 0 Mabsadd m
.28571 .60159 0 2.5 Mabsadd L
.28571 .60159 1.875 0 Mabsadd L
.28571 .60159 0 -2.5 Mabsadd L
.28571 .60159 -1.875 0 Mabsadd L closepath F
.30952 .6015 -1.875 0 Mabsadd m
.30952 .6015 0 2.5 Mabsadd L
.30952 .6015 1.875 0 Mabsadd L
.30952 .6015 0 -2.5 Mabsadd L
.30952 .6015 -1.875 0 Mabsadd L closepath F
.33333 .60143 -1.875 0 Mabsadd m
.33333 .60143 0 2.5 Mabsadd L
.33333 .60143 1.875 0 Mabsadd L
.33333 .60143 0 -2.5 Mabsadd L
.33333 .60143 -1.875 0 Mabsadd L closepath F
.35714 .60137 -1.875 0 Mabsadd m
.35714 .60137 0 2.5 Mabsadd L
.35714 .60137 1.875 0 Mabsadd L
.35714 .60137 0 -2.5 Mabsadd L
.35714 .60137 -1.875 0 Mabsadd L closepath F
.38095 .60132 -1.875 0 Mabsadd m
.38095 .60132 0 2.5 Mabsadd L
.38095 .60132 1.875 0 Mabsadd L
.38095 .60132 0 -2.5 Mabsadd L
.38095 .60132 -1.875 0 Mabsadd L closepath F
.40476 .60128 -1.875 0 Mabsadd m
.40476 .60128 0 2.5 Mabsadd L
.40476 .60128 1.875 0 Mabsadd L
.40476 .60128 0 -2.5 Mabsadd L
.40476 .60128 -1.875 0 Mabsadd L closepath F
.42857 .60124 -1.875 0 Mabsadd m
.42857 .60124 0 2.5 Mabsadd L
.42857 .60124 1.875 0 Mabsadd L
.42857 .60124 0 -2.5 Mabsadd L
.42857 .60124 -1.875 0 Mabsadd L closepath F
.45238 .60122 -1.875 0 Mabsadd m
.45238 .60122 0 2.5 Mabsadd L
.45238 .60122 1.875 0 Mabsadd L
.45238 .60122 0 -2.5 Mabsadd L
.45238 .60122 -1.875 0 Mabsadd L closepath F
.47619 .60121 -1.875 0 Mabsadd m
.47619 .60121 0 2.5 Mabsadd L
.47619 .60121 1.875 0 Mabsadd L
.47619 .60121 0 -2.5 Mabsadd L
.47619 .60121 -1.875 0 Mabsadd L closepath F
.5 .6012 -1.875 0 Mabsadd m
.5 .6012 0 2.5 Mabsadd L
.5 .6012 1.875 0 Mabsadd L
.5 .6012 0 -2.5 Mabsadd L
.5 .6012 -1.875 0 Mabsadd L closepath F
.52381 .6012 -1.875 0 Mabsadd m
.52381 .6012 0 2.5 Mabsadd L
.52381 .6012 1.875 0 Mabsadd L
.52381 .6012 0 -2.5 Mabsadd L
.52381 .6012 -1.875 0 Mabsadd L closepath F
.54762 .60121 -1.875 0 Mabsadd m
.54762 .60121 0 2.5 Mabsadd L
.54762 .60121 1.875 0 Mabsadd L
.54762 .60121 0 -2.5 Mabsadd L
.54762 .60121 -1.875 0 Mabsadd L closepath F
.57143 .60121 -1.875 0 Mabsadd m
.57143 .60121 0 2.5 Mabsadd L
.57143 .60121 1.875 0 Mabsadd L
.57143 .60121 0 -2.5 Mabsadd L
.57143 .60121 -1.875 0 Mabsadd L closepath F
.59524 .60119 -1.875 0 Mabsadd m
.59524 .60119 0 2.5 Mabsadd L
.59524 .60119 1.875 0 Mabsadd L
.59524 .60119 0 -2.5 Mabsadd L
.59524 .60119 -1.875 0 Mabsadd L closepath F
.61905 .60115 -1.875 0 Mabsadd m
.61905 .60115 0 2.5 Mabsadd L
.61905 .60115 1.875 0 Mabsadd L
.61905 .60115 0 -2.5 Mabsadd L
.61905 .60115 -1.875 0 Mabsadd L closepath F
.64286 .60102 -1.875 0 Mabsadd m
.64286 .60102 0 2.5 Mabsadd L
.64286 .60102 1.875 0 Mabsadd L
.64286 .60102 0 -2.5 Mabsadd L
.64286 .60102 -1.875 0 Mabsadd L closepath F
.66667 .60073 -1.875 0 Mabsadd m
.66667 .60073 0 2.5 Mabsadd L
.66667 .60073 1.875 0 Mabsadd L
.66667 .60073 0 -2.5 Mabsadd L
.66667 .60073 -1.875 0 Mabsadd L closepath F
.69048 .60007 -1.875 0 Mabsadd m
.69048 .60007 0 2.5 Mabsadd L
.69048 .60007 1.875 0 Mabsadd L
.69048 .60007 0 -2.5 Mabsadd L
.69048 .60007 -1.875 0 Mabsadd L closepath F
.71429 .59863 -1.875 0 Mabsadd m
.71429 .59863 0 2.5 Mabsadd L
.71429 .59863 1.875 0 Mabsadd L
.71429 .59863 0 -2.5 Mabsadd L
.71429 .59863 -1.875 0 Mabsadd L closepath F
.7381 .59539 -1.875 0 Mabsadd m
.7381 .59539 0 2.5 Mabsadd L
.7381 .59539 1.875 0 Mabsadd L
.7381 .59539 0 -2.5 Mabsadd L
.7381 .59539 -1.875 0 Mabsadd L closepath F
.7619 .5881 -1.875 0 Mabsadd m
.7619 .5881 0 2.5 Mabsadd L
.7619 .5881 1.875 0 Mabsadd L
.7619 .5881 0 -2.5 Mabsadd L
.7619 .5881 -1.875 0 Mabsadd L closepath F
.78571 .57236 -1.875 0 Mabsadd m
.78571 .57236 0 2.5 Mabsadd L
.78571 .57236 1.875 0 Mabsadd L
.78571 .57236 0 -2.5 Mabsadd L
.78571 .57236 -1.875 0 Mabsadd L closepath F
.80952 .54224 -1.875 0 Mabsadd m
.80952 .54224 0 2.5 Mabsadd L
.80952 .54224 1.875 0 Mabsadd L
.80952 .54224 0 -2.5 Mabsadd L
.80952 .54224 -1.875 0 Mabsadd L closepath F
.83333 .49428 -1.875 0 Mabsadd m
.83333 .49428 0 2.5 Mabsadd L
.83333 .49428 1.875 0 Mabsadd L
.83333 .49428 0 -2.5 Mabsadd L
.83333 .49428 -1.875 0 Mabsadd L closepath F
.85714 .43028 -1.875 0 Mabsadd m
.85714 .43028 0 2.5 Mabsadd L
.85714 .43028 1.875 0 Mabsadd L
.85714 .43028 0 -2.5 Mabsadd L
.85714 .43028 -1.875 0 Mabsadd L closepath F
.88095 .35503 -1.875 0 Mabsadd m
.88095 .35503 0 2.5 Mabsadd L
.88095 .35503 1.875 0 Mabsadd L
.88095 .35503 0 -2.5 Mabsadd L
.88095 .35503 -1.875 0 Mabsadd L closepath F
.90476 .27304 -1.875 0 Mabsadd m
.90476 .27304 0 2.5 Mabsadd L
.90476 .27304 1.875 0 Mabsadd L
.90476 .27304 0 -2.5 Mabsadd L
.90476 .27304 -1.875 0 Mabsadd L closepath F
.92857 .18762 -1.875 0 Mabsadd m
.92857 .18762 0 2.5 Mabsadd L
.92857 .18762 1.875 0 Mabsadd L
.92857 .18762 0 -2.5 Mabsadd L
.92857 .18762 -1.875 0 Mabsadd L closepath F
.95238 .10102 -1.875 0 Mabsadd m
.95238 .10102 0 2.5 Mabsadd L
.95238 .10102 1.875 0 Mabsadd L
.95238 .10102 0 -2.5 Mabsadd L
.95238 .10102 -1.875 0 Mabsadd L closepath F
.97619 .01472 -1.875 0 Mabsadd m
.97619 .01472 0 2.5 Mabsadd L
.97619 .01472 1.875 0 Mabsadd L
.97619 .01472 0 -2.5 Mabsadd L
.97619 .01472 -1.875 0 Mabsadd L closepath F
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{463.125, 286.25},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40007?00017R000`400?l00000o`00003oo`3IfMW@
0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@
0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@
0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@
0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@
0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@0=WIf@00o`3IfMW@
0=WIf@00o`3IfMW@0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfIh0fMWI000_0=WIf@030000
003IfMT0fMWI0?l0fMWIWP3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMVN0=WIf@00;`3IfMT0
0`000000fMWI0=WIf@3o0=WIfIh0fMWI000_0=WIf@800000o`3IfMTk0=WIf@030000003IfMT0fMWI
0640fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI>@3IfMT300000680fMWI000_0=WIf@030000
003IfMT0fMWI0?l0fMWI>03IfMT400000680fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI>@3I
fMT300000680fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI>@3IfMT2000006<0fMWI000_0=WI
f@030000003IfMT0fMWI0?l0fMWI>@3IfMT00`000000fMWI0=WIf@1R0=WIf@00;`3IfMT200000?l0
fMWI>P3IfMT00`000000fMWI0=WIf@1R0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfCT0fMWI
00<000000=WIf@3IfMT0HP3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTh0=WIf@030000003I
fMT0fMWI06<0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI>03IfMT00`000000fMWI0=WIf@1S
0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfCP0fMWI00<000000=WIf@3IfMT0H`3IfMT002l0
fMWI00<000000=WIf@3IfMT0o`3IfMTg0=WIf@030000003IfMT0fMWI06@0fMWI000_0=WIf@800000
o`3IfMTh0=WIf@030000003IfMT0fMWI06@0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI=`3I
fMT00`000000fMWI0=WIf@1T0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfCL0fMWI00<00000
0=WIf@3IfMT0I03IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTf0=WIf@030000003IfMT0fMWI
06D0fMWI000O0=WIf@<00000103IfMT2000000L0fMWI00<000000=WIf@3IfMT0o`3IfMTf0=WIf@03
0000003IfMT0fMWI06D0fMWI000N0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000
fMWI0=WIf@0000060=WIf@030000003IfMT0fMWI0?l0fMWI=P3IfMT00`000000fMWI0=WIf@1U0=WI
f@00603IfMT5000000D0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI0=WIf@040=WI
f@<00000o`3IfMTf0=WIf@030000003IfMT0fMWI06D0fMWI000P0=WIf@8000000`3IfMT010000000
fMWI0=WIf@0000060=WIf@030000003IfMT0fMWI0?l0fMWI=@3IfMT00`000000fMWI0=WIf@1V0=WI
f@008P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WI
f@3IfMT0o`3IfMTe0=WIf@030000003IfMT0fMWI06H0fMWI000N0=WIf@050000003IfMT0fMWI0=WI
f@0000000P3IfMT010000000fMWI0=WIf@0000060=WIf@030000003IfMT0fMWI0?l0fMWI=@3IfMT0
0`000000fMWI0=WIf@1V0=WIf@007`3IfMT3000000@0fMWI0P0000070=WIf@030000003IfMT0fMWI
0?l0fMWI=@3IfMT00`000000fMWI0=WIf@1V0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfC@0
fMWI00<000000=WIf@3IfMT0I`3IfMT002l0fMWI0P00003o0=WIfCD0fMWI00<000000=WIf@3IfMT0
I`3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTd0=WIf@030000003IfMT0fMWI06L0fMWI000_
0=WIf@030000003IfMT0fMWI0?l0fMWI<`3IfMT00`000000fMWI0=WIf@1X0=WIf@00;`3IfMT00`00
0000fMWI0=WIf@3o0=WIfC<0fMWI00<000000=WIf@3IfMT0J03IfMT002l0fMWI00<000000=WIf@3I
fMT0o`3IfMTc0=WIf@030000003IfMT0fMWI06P0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI
<`3IfMT00`000000fMWI0=WIf@1X0=WIf@00;`3IfMT200000?l0fMWI<`3IfMT00`000000fMWI0=WI
f@1Y0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfC40fMWI0`00001Z0=WIf@00;`3IfMT00`00
0000fMWI0=WIf@3o0=WIfC40fMWI0`00001Z0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfC80
fMWI00<000000=WIf@3IfMT0J@3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTa0=WIf@030000
003IfMT0fMWI06X0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI<@3IfMT00`000000fMWI0=WI
f@1Z0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfC40fMWI00<000000=WIf@3IfMT0JP3IfMT0
02l0fMWI0P00003o0=WIfC40fMWI00<000000=WIf@3IfMT0J`3IfMT002l0fMWI00<000000=WIf@3I
fMT0o`3IfMT`0=WIf@030000003IfMT0fMWI06/0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI
<03IfMT00`000000fMWI0=WIf@1[0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfC00fMWI00<0
00000=WIf@3IfMT0J`3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMT_0=WIf@030000003IfMT0
fMWI06`0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI;`3IfMT00`000000fMWI0=WIf@1/0=WI
f@00;`3IfMT200000?l0fMWI<03IfMT00`000000fMWI0=WIf@1/0=WIf@00;`3IfMT00`000000fMWI
0=WIf@3o0=WIfBl0fMWI00<000000=WIf@3IfMT0K03IfMT002l0fMWI00<000000=WIf@3IfMT0o`3I
fMT^0=WIf@030000003IfMT0fMWI06d0fMWI000N0=WIf@D000000P3IfMT3000000L0fMWI00<00000
0=WIf@3IfMT0o`3IfMT^0=WIf@030000003IfMT0fMWI06d0fMWI000O0=WIf@060000003IfMT0fMWI
0000003IfMT000000`3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWI;P3I
fMT00`000000fMWI0=WIf@1]0=WIf@00603IfMT5000000<0fMWI00<000000=WIf@3IfMT01@3IfMT0
0`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWI;@3IfMT00`000000fMWI0=WIf@1^
0=WIf@008@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00@0fMWI0`00003o0=WI
fBd0fMWI00<000000=WIf@3IfMT0KP3IfMT001h0fMWI00H000000=WIf@3IfMT0fMWI0000003IfMT4
000000L0fMWI00<000000=WIf@3IfMT0o`3IfMT]0=WIf@030000003IfMT0fMWI06h0fMWI000N0=WI
f@070000003IfMT0fMWI0=WIf@000000fMWI0000000:0=WIf@030000003IfMT0fMWI0?l0fMWI;@3I
fMT00`000000fMWI0=WIf@1^0=WIf@007`3IfMT300000080fMWI1@0000060=WIf@030000003IfMT0
fMWI0?l0fMWI;03IfMT00`000000fMWI0=WIf@1_0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WI
fB`0fMWI00<000000=WIf@3IfMT0K`3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMT/0=WIf@03
0000003IfMT0fMWI06l0fMWI000_0=WIf@800000o`3IfMT]0=WIf@030000003IfMT0fMWI06l0fMWI
000_0=WIf@030000003IfMT0fMWI0?l0fMWI:`3IfMT00`000000fMWI0=WIf@1`0=WIf@00;`3IfMT0
0`000000fMWI0=WIf@3o0=WIfB/0fMWI00<000000=WIf@3IfMT0L03IfMT002l0fMWI00<000000=WI
f@3IfMT0o`3IfMT[0=WIf@030000003IfMT0fMWI0700fMWI000_0=WIf@030000003IfMT0fMWI0?l0
fMWI:P3IfMT00`000000fMWI0=WIf@1a0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfBT0fMWI
0`00001b0=WIf@00;`3IfMT200000?l0fMWI:@3IfMT400000780fMWI000_0=WIf@030000003IfMT0
fMWI0?l0fMWI:@3IfMT300000780fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI:@3IfMT20000
07<0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI:@3IfMT00`000000fMWI0=WIf@1b0=WIf@00
;`3IfMT00`000000fMWI0=WIf@3o0=WIfBT0fMWI00<000000=WIf@3IfMT0LP3IfMT002l0fMWI00<0
00000=WIf@3IfMT0o`3IfMTX0=WIf@030000003IfMT0fMWI07<0fMWI000_0=WIf@800000o`3IfMTY
0=WIf@030000003IfMT0fMWI07<0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI:03IfMT00`00
0000fMWI0=WIf@1c0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfBP0fMWI00<000000=WIf@3I
fMT0L`3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTW0=WIf@030000003IfMT0fMWI07@0fMWI
000_0=WIf@030000003IfMT0fMWI0?l0fMWI9`3IfMT00`000000fMWI0=WIf@1d0=WIf@00;`3IfMT0
0`000000fMWI0=WIf@3o0=WIfBL0fMWI00<000000=WIf@3IfMT0M03IfMT002l0fMWI0P00003o0=WI
fBP0fMWI00<000000=WIf@3IfMT0M03IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTV0=WIf@03
0000003IfMT0fMWI07D0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI9P3IfMT00`000000fMWI
0=WIf@1e0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfBH0fMWI00<000000=WIf@3IfMT0M@3I
fMT001h0fMWI1@0000030=WIf@8000001`3IfMT00`000000fMWI0=WIf@3o0=WIfBD0fMWI00<00000
0=WIf@3IfMT0MP3IfMT001l0fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00
00060=WIf@030000003IfMT0fMWI0?l0fMWI9@3IfMT00`000000fMWI0=WIf@1f0=WIf@00603IfMT5
000000<0fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WIf@0000060=WIf@030000003I
fMT0fMWI0?l0fMWI9@3IfMT00`000000fMWI0=WIf@1f0=WIf@008@3IfMT01@000000fMWI0=WIf@3I
fMT000000080fMWI00<000000=WIf@3IfMT0103IfMT300000?l0fMWI9@3IfMT00`000000fMWI0=WI
f@1f0=WIf@007P3IfMT01@000000fMWI0=WIf@3IfMT000000080fMWI00@000000=WIf@3IfMT00000
1P3IfMT00`000000fMWI0=WIf@3o0=WIfB@0fMWI00<000000=WIf@3IfMT0M`3IfMT001h0fMWI00D0
00000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI000000H0fMWI00<000000=WIf@3I
fMT0o`3IfMTT0=WIf@030000003IfMT0fMWI07L0fMWI000O0=WIf@<00000103IfMT2000000L0fMWI
00<000000=WIf@3IfMT0o`3IfMTT0=WIf@030000003IfMT0fMWI07L0fMWI000_0=WIf@030000003I
fMT0fMWI0?l0fMWI903IfMT00`000000fMWI0=WIf@1g0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o
0=WIfB<0fMWI00<000000=WIf@3IfMT0N03IfMT002l0fMWI0P00003o0=WIfB@0fMWI00<000000=WI
f@3IfMT0N03IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTS0=WIf@030000003IfMT0fMWI07P0
fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI8P3IfMT00`000000fMWI0=WIf@1i0=WIf@00;`3I
fMT00`000000fMWI0=WIf@3o0=WIfB40fMWI0P00001k0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o
0=WIfB00fMWI0`00001k0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfB40fMWI0P00001k0=WI
f@00;`3IfMT200000?l0fMWI8P3IfMT00`000000fMWI0=WIf@1j0=WIf@00;`3IfMT00`000000fMWI
0=WIf@3o0=WIfB40fMWI00<000000=WIf@3IfMT0NP3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3I
fMTQ0=WIf@030000003IfMT0fMWI07X0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI803IfMT0
0`000000fMWI0=WIf@1k0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfB00fMWI00<000000=WI
f@3IfMT0N`3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTP0=WIf@030000003IfMT0fMWI07/0
fMWI000_0=WIf@800000o`3IfMTP0=WIf@030000003IfMT0fMWI07`0fMWI000_0=WIf@030000003I
fMT0fMWI0?l0fMWI7`3IfMT00`000000fMWI0=WIf@1l0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o
0=WIfAl0fMWI00<000000=WIf@3IfMT0O03IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTN0=WI
f@030000003IfMT0fMWI07d0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI7P3IfMT00`000000
fMWI0=WIf@1m0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfAh0fMWI00<000000=WIf@3IfMT0
O@3IfMT002l0fMWI0P00003o0=WIfAh0fMWI00<000000=WIf@3IfMT0OP3IfMT002l0fMWI00<00000
0=WIf@3IfMT0o`3IfMTM0=WIf@030000003IfMT0fMWI07h0fMWI000_0=WIf@030000003IfMT0fMWI
0?l0fMWI7@3IfMT00`000000fMWI0=WIf@1n0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfA`0
fMWI00<000000=WIf@3IfMT0O`3IfMT001l0fMWI0`0000030=WIf@<000001`3IfMT00`000000fMWI
0=WIf@3o0=WIfA`0fMWI00<000000=WIf@3IfMT0O`3IfMT00200fMWI00D000000=WIf@3IfMT0fMWI
000000030=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0o`3IfMTL0=WIf@030000
003IfMT0fMWI07l0fMWI000H0=WIf@D000000`3IfMT00`000000fMWI0=WIf@050=WIf@030000003I
fMT0fMWI00@0fMWI0`00003o0=WIfA/0fMWI00<000000=WIf@3IfMT0P03IfMT00200fMWI00<00000
0=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI0?l0fMWI6`3IfMT0
0`000000fMWI0=WIf@200=WIf@00803IfMT010000000fMWI0=WIf@3IfMT4000000L0fMWI00<00000
0=WIf@3IfMT0o`3IfMTK0=WIf@030000003IfMT0fMWI0800fMWI000O0=WIf@8000000`3IfMT00`00
0000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0?l0fMWI6P3IfMT00`000000fMWI0=WIf@210=WI
f@00803IfMT010000000fMWI0=WIf@3IfMT5000000H0fMWI00<000000=WIf@3IfMT0o`3IfMTJ0=WI
f@030000003IfMT0fMWI0840fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI6P3IfMT00`000000
fMWI0=WIf@210=WIf@00;`3IfMT200000?l0fMWI6P3IfMT00`000000fMWI0=WIf@220=WIf@00;`3I
fMT00`000000fMWI0=WIf@3o0=WIfAT0fMWI0P0000230=WIf@00;`3IfMT00`000000fMWI0=WIf@3o
0=WIfAP0fMWI0`0000230=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfAT0fMWI0P0000230=WI
f@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfAP0fMWI0P0000240=WIf@00;`3IfMT00`000000fMWI
0=WIf@3o0=WIfAP0fMWI00<000000=WIf@3IfMT0P`3IfMT002l0fMWI0P00003o0=WIfAT0fMWI00<0
00000=WIf@3IfMT0P`3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTG0=WIf@030000003IfMT0
fMWI08@0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI5`3IfMT00`000000fMWI0=WIf@240=WI
f@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfAL0fMWI00<000000=WIf@3IfMT0Q03IfMT002l0fMWI
00<000000=WIf@3IfMT0o`3IfMTF0=WIf@030000003IfMT0fMWI08D0fMWI000_0=WIf@030000003I
fMT0fMWI0?l0fMWI5P3IfMT00`000000fMWI0=WIf@250=WIf@00;`3IfMT00`000000fMWI0=WIf@3o
0=WIfAH0fMWI00<000000=WIf@3IfMT0Q@3IfMT002l0fMWI0P00003o0=WIfAH0fMWI00<000000=WI
f@3IfMT0QP3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTE0=WIf@030000003IfMT0fMWI08H0
fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI5@3IfMT00`000000fMWI0=WIf@260=WIf@00;`3I
fMT00`000000fMWI0=WIf@3o0=WIfAD0fMWI00<000000=WIf@3IfMT0QP3IfMT002l0fMWI00<00000
0=WIf@3IfMT0o`3IfMTD0=WIf@030000003IfMT0fMWI08L0fMWI000_0=WIf@030000003IfMT0fMWI
0?l0fMWI503IfMT00`000000fMWI0=WIf@270=WIf@00;`3IfMT200000?l0fMWI5@3IfMT00`000000
fMWI0=WIf@270=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfA<0fMWI00<000000=WIf@3IfMT0
R03IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMTC0=WIf@030000003IfMT0fMWI08P0fMWI000O
0=WIf@<00000103IfMT2000000L0fMWI00<000000=WIf@3IfMT0o`3IfMTC0=WIf@030000003IfMT0
fMWI08P0fMWI000P0=WIf@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000001P3IfMT0
0`000000fMWI0=WIf@3o0=WIfA80fMWI00<000000=WIf@3IfMT0R@3IfMT001P0fMWI1@0000030=WI
f@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000001P3IfMT00`000000fMWI0=WIf@3o
0=WIfA80fMWI00<000000=WIf@3IfMT0R@3IfMT00200fMWI00<000000=WIf@3IfMT00P3IfMT01000
0000fMWI0=WIf@0000060=WIf@<00000o`3IfMTB0=WIf@030000003IfMT0fMWI08T0fMWI000P0=WI
f@030000003IfMT0fMWI0080fMWI00@000000=WIf@3IfMT000001P3IfMT00`000000fMWI0=WIf@3o
0=WIfA40fMWI00<000000=WIf@3IfMT0RP3IfMT001l0fMWI0P0000040=WIf@040000003IfMT0fMWI
000000H0fMWI00<000000=WIf@3IfMT0o`3IfMT@0=WIf@<00000R`3IfMT00200fMWI00<000000=WI
f@3IfMT00`3IfMT2000000L0fMWI00<000000=WIf@3IfMT0o`3IfMT?0=WIf@@00000R`3IfMT002l0
fMWI00<000000=WIf@3IfMT0o`3IfMT@0=WIf@<00000R`3IfMT002l0fMWI00<000000=WIf@3IfMT0
o`3IfMT@0=WIf@800000S03IfMT002l0fMWI0P00003o0=WIfA40fMWI00<000000=WIf@3IfMT0R`3I
fMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMT?0=WIf@030000003IfMT0fMWI08`0fMWI000_0=WI
f@030000003IfMT0fMWI0?l0fMWI3`3IfMT00`000000fMWI0=WIf@2<0=WIf@00;`3IfMT00`000000
fMWI0=WIf@3o0=WIf@l0fMWI00<000000=WIf@3IfMT0S03IfMT002l0fMWI00<000000=WIf@3IfMT0
o`3IfMT>0=WIf@030000003IfMT0fMWI08d0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI3P3I
fMT00`000000fMWI0=WIf@2=0=WIf@00;`3IfMT200000?l0fMWI3`3IfMT00`000000fMWI0=WIf@2=
0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WIf@d0fMWI00<000000=WIf@3IfMT0SP3IfMT002l0
fMWI00<000000=WIf@3IfMT0o`3IfMT=0=WIf@030000003IfMT0fMWI08h0fMWI000_0=WIf@030000
003IfMT0fMWI0?l0fMWI303IfMT00`000000fMWI0=WIf@2?0=WIf@00;`3IfMT00`000000fMWI0=WI
f@3o0=WIf@`0fMWI00<000000=WIf@3IfMT0S`3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMT<
0=WIf@030000003IfMT0fMWI08l0fMWI000_0=WIf@800000o`3IfMT<0=WIf@030000003IfMT0fMWI
0900fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI2`3IfMT00`000000fMWI0=WIf@2@0=WIf@00
;`3IfMT00`000000fMWI0=WIf@3o0=WIf@/0fMWI00<000000=WIf@3IfMT0T03IfMT002l0fMWI00<0
00000=WIf@3IfMT0o`3IfMT:0=WIf@030000003IfMT0fMWI0940fMWI000_0=WIf@030000003IfMT0
fMWI0?l0fMWI2P3IfMT00`000000fMWI0=WIf@2A0=WIf@00;`3IfMT00`000000fMWI0=WIf@3o0=WI
f@T0fMWI0P00002C0=WIf@00;`3IfMT200000?l0fMWI2@3IfMT3000009<0fMWI000_0=WIf@030000
003IfMT0fMWI0?l0fMWI203IfMT3000009<0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI203I
fMT2000009@0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI203IfMT00`000000fMWI0=WIf@2C
0=WIf@009@3IfMT3000000L0fMWI00<000000=WIf@3IfMT0o`3IfMT70=WIf@030000003IfMT0fMWI
09@0fMWI000T0=WIf@050000003IfMT0fMWI0=WIf@0000001P3IfMT00`000000fMWI0=WIf@3o0=WI
f@L0fMWI00<000000=WIf@3IfMT0U03IfMT001h0fMWI1@0000050=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0o`3IfMT60=WIf@030000003IfMT0fMWI09D0fMWI000X0=WIf@030000
003IfMT0fMWI00@0fMWI0`00003o0=WIf@H0fMWI00<000000=WIf@3IfMT0U@3IfMT002@0fMWI1000
00070=WIf@030000003IfMT0fMWI0?l0fMWI1@3IfMT00`000000fMWI0=WIf@2F0=WIf@00903IfMT0
0`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI0?l0fMWI1@3IfMT00`000000fMWI0=WIf@2F
0=WIf@00903IfMT5000000H0fMWI00<000000=WIf@3IfMT0o`3IfMT40=WIf@030000003IfMT0fMWI
09L0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI103IfMT00`000000fMWI0=WIf@2G0=WIf@00
;`3IfMT00`000000fMWI0=WIf@3o0=WIf@<0fMWI00<000000=WIf@3IfMT0V03IfMT002l0fMWI0P00
003o0=WIf@@0fMWI00<000000=WIf@3IfMT0V03IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMT2
0=WIf@030000003IfMT0fMWI09T0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI0@3IfMT20000
09/0fMWI000_0=WIf@030000003IfMT0fMWI0?l0fMWI0`00002K0=WIf@00;`3IfMT00`000000fMWI
0=WIf@3n0=WIf@@00000V`3IfMT002l0fMWI00<000000=WIf@3IfMT0o`3IfMT3000009/0fMWI000_
0=WIf@800000o`3IfMT00`000000fMWI0000002L0=WIf@00;`3IfMT00`000000fMWI0=WIf@3m0=WI
f@030000003IfMT0fMWI09d0fMWI000_0=WIf@030000003IfMT0fMWI0?d0fMWI00<000000=WIf@3I
fMT0W@3IfMT002l0fMWI00<000000=WIf@3IfMT0o03IfMT00`000000fMWI0=WIf@2N0=WIf@00;`3I
fMT00`000000fMWI0=WIf@3k0=WIf@030000003IfMT0fMWI09l0fMWI000_0=WIf@030000003IfMT0
fMWI0?/0fMWI00<000000=WIf@3IfMT0W`3IfMT002l0fMWI0P00000V0=WIf@<00000103IfMT20000
02D0fMWI00<000000=WIf@3IfMT00P3IfMT300000240fMWI0`0000040=WIf@800000103IfMT20000
01h0fMWI0`0000020=WIf@D000000P3IfMT3000001l0fMWI0`0000030=WIf@<00000103IfMT20000
01@0fMWI00<000000=WIf@3IfMT01`3IfMT3000000@0fMWI00<000000=WIf@3IfMT00P3IfMT30000
01d0fMWI1@0000030=WIf@800000103IfMT2000005d0fMWI000_0=WIf@030000003IfMT0fMWI02@0
fMWI00D000000=WIf@3IfMT0fMWI000000020=WIf@040000003IfMT0fMWI000002@0fMWI00D00000
0=WIf@3IfMT0fMWI000000030=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT00P3I
fMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000001h0fMWI00<000000=WIf@3I
fMT00P3IfMT01P000000fMWI0=WIf@000000fMWI000000<0fMWI00<000000=WIf@3IfMT07@3IfMT0
1@000000fMWI0=WIf@3IfMT0000000<0fMWI00@000000=WIf@3IfMT000000P3IfMT00`000000fMWI
0=WIf@0?0=WIf@8000002`3IfMT00`000000fMWI0=WIf@030=WIf@050000003IfMT0fMWI0=WIf@00
00000`3IfMT00`000000fMWI0=WIf@0K0=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WI
f@3IfMT000000P3IfMT010000000fMWI0=WIf@00001L0=WIf@00;`3IfMT00`000000fMWI0=WIf@0X
0=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT08`3IfMT00`000000fMWI0=WI
f@040=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT00P3IfMT010000000fMWI0=WI
f@0000020=WIf@040000003IfMT0fMWI000001h0fMWI00<000000=WIf@3IfMT00`3IfMT00`000000
fMWI0=WIf@050=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3IfMT01@3IfMT010000000
fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00h0fMWI0`00000;0=WIf@030000003IfMT0fMWI
00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0L0=WIf@030000003IfMT0fMWI
0080fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00001L0=WIf@00;`3IfMT0
0`000000fMWI0=WIf@0X0=WIf@040000003IfMT0fMWI00000080fMWI00<000000=WIf@3IfMT08`3I
fMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01l0fMWI00<000000=WIf@3IfMT00P3I
fMT010000000fMWI0=WIf@0000020=WIf@040000003IfMT0fMWI000001h0fMWI00<000000=WIf@3I
fMT0103IfMT00`000000fMWI0=WIf@040=WIf@030000003IfMT0fMWI01d0fMWI00<000000=WIf@3I
fMT01@3IfMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI00d0fMWI1000000;0=WI
f@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT0103IfMT00`000000fMWI0=WIf@0M0=WI
f@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@0000020=WIf@030000003I
fMT0fMWI05X0fMWI000_0=WIf@030000003IfMT0fMWI02@0fMWI100000030=WIf@040000003IfMT0
fMWI000002H0fMWI00<000000=WIf@0000000`00000R0=WIf@030000003IfMT0fMWI0080fMWI00@0
00000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@00000N0=WIf@050000003IfMT0fMWI0=WI
f@0000000`3IfMT00`000000fMWI0000000300000200fMWI00@000000=WIf@3IfMT0fMWI10000003
0=WIf@040000003IfMT0fMWI000000d0fMWI0P0000020=WIf@030000003IfMT0fMWI00X0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI00000003000001d0fMWI00D000000=WIf@3IfMT0fMWI
000000020=WIf@040000003IfMT0fMWI00000080fMWI00@000000=WIf@3IfMT00000G03IfMT002l0
fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WIf@040=WIf@040000003IfMT0fMWI0000
0280fMWI00L000000=WIf@3IfMT0fMWI0000003IfMT0000002@0fMWI0P0000040=WIf@040000003I
fMT0fMWI00000080fMWI00@000000=WIf@3IfMT000007@3IfMT2000000<0fMWI00L000000=WIf@3I
fMT0fMWI0000003IfMT000000280fMWI0P0000030=WIf@030000003IfMT0fMWI00@0fMWI00@00000
0=WIf@3IfMT000002`3IfMT200000100fMWI0P0000030=WIf@070000003IfMT0fMWI0=WIf@000000
fMWI0000000P0=WIf@050000003IfMT0fMWI0=WIf@0000000P3IfMT010000000fMWI0=WIf@000002
0=WIf@040000003IfMT0fMWI000005`0fMWI000_0=WIf@8000009@3IfMT5000000<0fMWI0P00000S
0=WIf@D0000000<0fMWI0000000000000`00000Q0=WIf@030000003IfMT0fMWI00<0fMWI0P000004
0=WIf@8000007`3IfMT00`000000fMWI0=WIf@020=WIf@<000000P3IfMT5000001l0fMWI00@00000
0=WIf@3IfMT0fMWI1@0000030=WIf@8000002P3IfMT2000001<0fMWI00@000000=WIf@3IfMT0fMWI
1@0000000`3IfMT0000000000003000001d0fMWI0`0000040=WIf@800000103IfMT2000005d0fMWI
000_0=WIf@030000003IfMT0fMWI0>h0fMWI1000002[0=WIf@00;`3IfMT00`000000fMWI0=WIf@3Z
0=WIf@@0000000@0fMWI0000000000000000K03IfMT3000000`0fMWI0P00000>0=WIf@<000005@3I
fMT2000000H0fMWI000_0=WIf@030000003IfMT0fMWI0>H0fMWI100000060=WIf@030000003IfMT0
fMWI06`0fMWI00<000000=WIf@3IfMT02`3IfMT00`000000fMWI0=WIf@0@0=WIf@030000003IfMT0
fMWI01<0fMWI00<000000=WIf@3IfMT0103IfMT002l0fMWI00<000000=WIf@3IfMT0MP3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@0>0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI00000007000006@0fMWI0`0000030=WIf@<000000P3IfMT01@000000fMWI0000003IfMT0
00000080fMWI0`0000040=WIf@030000003IfMT0fMWI00@0fMWI00@000000=WIf@3IfMT0fMWI1000
00020=WIf@<000000`3IfMT4000000<0fMWI00<000000=WIf@3IfMT02@3IfMT2000000@0fMWI00<0
00000=WIf@3IfMT0103IfMT002D0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@04
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@06
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@05
0=WIf@030000003IfMT0fMWI0080fMWIM`0000060=WIf@800000I@3IfMT01@000000fMWI0=WIf@3I
fMT0000000D0fMWI00D000000=WIf@000000fMWI000000020=WIf@040000003IfMT0fMWI000000X0
fMWI00@000000=WIf@3IfMT000000P3IfMT010000000fMWI0=WIf@0000050=WIf@050000003IfMT0
fMWI0=WIf@0000003P3IfMT010000000fMWI0=WIf@0000030=WIf@030000003IfMT0fMWI00@0fMWI
000M0=WIfOl00000F000000<0=WIf@040000003IfMT0fMWI0=WIf@D0000000H0fMWI0000003IfMT0
00000=WIf@0000020=WIf@040000003IfMT0fMWI000000X0fMWI00@000000=WIf@3IfMT000000P3I
fMT00`000000fMWI0=WIf@05000000030=WIf@000000fMWI0080fMWI00<000000=WIf@3IfMT02`3I
fMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00@0fMWI000T0=WIf@<000001@3IfMT4
000000@0fMWI1@0000040=WIf@<0000000<0fMWI0000003IfMT00P3IfMT300000080fMWI00<00000
0=WIf@3IfMT00`0000030=WIf@030000003IfMT0000000800000103IfMT4000000D0fMWI0`000006
0=WIf@<000001@3IfMT3000000D0fMWI0`0000050=WIf@@00000103IfMT3000000030=WIf@000000
fMWI0080fMWI0`0000020=WIf@040000003IfMT0fMWI0=WIf@8000000`3IfMT00`000000fMWI0=WI
f@03000000<0fMWI00<000000=WIf@0000000P0000040=WIf@@000001@3IfMT3000000D0fMWI0`00
00050=WIf@<000001P3IfMT3000000D0fMWI0P0000000`3IfMT000000=WIf@030=WIf@<0000000<0
fMWI0000003IfMT00P3IfMT300000080fMWI00<000000=WIf@3IfMT00`0000030=WIf@030000003I
fMT0000000800000103IfMT4000000H0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@060=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01P3IfMT00`000000fMWI0=WI
f@0B0=WIf@050000003IfMT0fMWI0=WIf@0000000`3IfMT01`000000fMWI0000003IfMT000000=WI
f@0000000P3IfMT010000000fMWI0=WIf@00000:0=WIf@040000003IfMT0fMWI00000080fMWI00@0
00000=WIf@3IfMT000000`3IfMT00`000000fMWI000000030=WIf@030000003IfMT0fMWI00/0fMWI
00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@040=WIf@009@3IfMT2000000H0fMWI0`00
00050=WIf@<000001P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0000000P0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI000000050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@0000001`3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@080=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI00D0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@050=WIf@030000003IfMT0fMWI02X0fMWI00<0
00000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@0@0=WIf@050000003IfMT000000=WIf@000000
0P3IfMT300000080fMWI0P000000103IfMT000000=WIf@3IfMT4000000/0fMWI00@000000=WIf@3I
fMT0fMWI0`0000030=WIf@<000000`3IfMT5000000`0fMWI00<000000=WIf@3IfMT01@3IfMT00`00
0000fMWI0=WIf@040=WIf@009@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00@0
fMWI00<000000=WIf@3IfMT0o`3IfMU60=WIf@050000003IfMT000000=WIf@000000703IfMT20000
00@0fMWI00<000000=WIf@3IfMT06@3IfMT010000000fMWI0=WIf@0000020=WIf@8000001P3IfMT0
02l0fMWI00<000000=WIf@3IfMT0o`3IfMU=0=WIf@D000008@3IfMT2000001`0fMWI0`00000:0=WI
f@00;`3IfMT00`000000fMWI0=WIf@3o0=WIfIh0fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o
0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o
0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI001=0=WIf@800000203IfMT200000?l0fMWI
M`3IfMT004d0fMWI00<000000=WIf@3IfMT0203IfMT00`000000fMWI0=WIf@3o0=WIfGD0fMWI0002
0=WIf@D0000000@0fMWI00000000000000000`3IfMT3000000D0fMWI00<000000=WIf@3IfMT01`3I
fMT500000080fMWI0`0000020=WIf@@000000P3IfMT4000000<0fMWI0`0000020=WIf@@000002`3I
fMT010000000fMWI0=WIf@0000020=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0
o`3IfMUe0=WIf@00103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI00<0
00000=WIf@3IfMT0403IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3IfMT0
0`3IfMT00`000000fMWI0=WIf@030=WIf@030000003IfMT0000000T0fMWI00<000000=WIf@3IfMT0
203IfMT010000000fMWI0=WIf@3IfMT2000000030=WIf@000000fMWI0080fMWI00<000000=WIf@3I
fMT0o`3IfMUe0=WIf@00103IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00<0fMWI
00<000000=WIf@3IfMT0403IfMT01@000000fMWI0=WIf@3IfMT0000000<0fMWI00<000000=WIf@3I
fMT00`0000030=WIf@<000000P3IfMT500000080fMWI0`00000;0=WIf@040000003IfMT0fMWI0=WI
f@80000000<0fMWI0000003IfMT00P3IfMT00`000000fMWI0=WIf@3o0=WIfGD0fMWI00040=WIf@03
0000003IfMT0fMWI0080fMWI0P0000040=WIf@8000004@3IfMT01@000000fMWI0=WIf@3IfMT00000
00<0fMWI00<000000=WIf@0000001@3IfMT00`000000fMWI0=WIf@030=WIf@070000003IfMT0fMWI
0=WIf@000000fMWI0000000>0=WIf@030000003IfMT0fMWI0080fMWI0P0000040=WIf@030000003I
fMT0fMWI0?l0fMWIM@3IfMT00080fMWI0`0000030=WIf@80000000@0fMWI000000000000fMWI0P00
00000`3IfMT000000000000?0=WIf@030000003IfMT0fMWI0080fMWI0`0000030=WIf@@000000P3I
fMT400000080fMWI0`0000030=WIf@@000002P3IfMT01`000000fMWI0=WIf@3IfMT000000=WIf@00
0000103IfMT00`000000fMWI0=WIf@3o0=WIfGD0fMWI000R0=WIf@030000003IfMT0fMWI02P0fMWI
0P0000001P3IfMT000000=WIf@000000fMWI00000080fMWI0P00003o0=WIfGL0fMWI00040=WIf@03
0000003IfMT0fMWI01T0fMWI0`00000]0=WIf@030000003IfMT000000080fMWI00<000000=WIf@3I
fMT0o`3IfMUh0=WIf@00D@3IfMT00`000000fMWI0=WIf@3o0=WIfG`0fMWI003o0=WIfM00fMWI003o
0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o
0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o
0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o
0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o
0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o0=WIfM00fMWI003o
0=WIfM00fMWI0000\
\>"],
  ImageRangeCache->{{{0, 462.125}, {285.25, 0}} -> {-0.994128, -37.9778, \
0.553028, 0.163042}}]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plot the Magnetic Structure", "Section"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(RadPlot3DOptions[];\)\), "\[IndentingNewLine]", 
    \(\(Dwg = radObjDrw[g];\)\), "\n", 
    \(\(Show[Graphics3D[Dwg], ViewPoint -> {1, 1, \ 1}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12  scalefont  setfont
% Scaling calculations
0 1 0 1 [
[.49542 .86397 -9.15114 0 ]
[.49542 .86397 9.09886 14 ]
[.41577 .84435 -14.3511 0 ]
[.41577 .84435 12.8989 14 ]
[.32348 .82159 -5.56661 0 ]
[.32348 .82159 4.43339 14 ]
[.21527 .79484 -11.2668 0 ]
[.21527 .79484 7.73318 14 ]
[.08666 .76297 -6.37863 0 ]
[.08666 .76297 3.62137 14 ]
[.31418 .88314 -8.70905 0 ]
[.31418 .88314 6.91595 14 ]
[.50536 .86336 -9.0944 0 ]
[.50536 .86336 9.1556 14 ]
[.58526 .84365 -12.8897 0 ]
[.58526 .84365 14.3603 14 ]
[.67788 .82077 -4.42873 0 ]
[.67788 .82077 5.57127 14 ]
[.78652 .79388 -7.72097 0 ]
[.78652 .79388 11.279 14 ]
[.9157 .76181 -3.61243 0 ]
[.9157 .76181 6.38757 14 ]
[.68498 .88287 -6.91989 0 ]
[.68498 .88287 8.70511 14 ]
[.81583 .32384 0 -11.0102 ]
[.81583 .32384 18.25 2.98978 ]
[.83858 .40286 0 -10.5529 ]
[.83858 .40286 27.25 3.44705 ]
[.86491 .49446 0 -10.0411 ]
[.86491 .49446 10 3.95893 ]
[.89573 .60191 0 -9.46416 ]
[.89573 .60191 19 4.53584 ]
[.9323 .72969 0 -8.80901 ]
[.9323 .72969 10 5.19099 ]
[.92223 .46955 0 -10.0411 ]
[.92223 .46955 14.3125 3.95893 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.003 w
[ ] 0 setdash
.49917 .85239 m
.07671 .74763 L
s
.25 Mabswid
.49545 .85147 m
.49547 .84522 L
s
gsave
.49542 .86397 -70.1511 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.41644 .83187 m
.41677 .82563 L
s
gsave
.41577 .84435 -75.3511 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.32488 .80917 m
.32559 .80296 L
s
gsave
.32348 .82159 -66.5666 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.21756 .78255 m
.2187 .77641 L
s
gsave
.21527 .79484 -72.2668 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.08999 .75092 m
.09165 .74489 L
s
gsave
.08666 .76297 -67.3786 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.48053 .84776 m
.48057 .84401 L
s
.46518 .84396 m
.46526 .84021 L
s
.4494 .84004 m
.44952 .8363 L
s
.43316 .83602 m
.43332 .83227 L
s
.39922 .8276 m
.39946 .82386 L
s
.38148 .8232 m
.38176 .81946 L
s
.3632 .81867 m
.36352 .81493 L
s
.34434 .81399 m
.34471 .81026 L
s
.3048 .80419 m
.30527 .80047 L
s
.28406 .79905 m
.28459 .79533 L
s
.26263 .79373 m
.26321 .79003 L
s
.24048 .78824 m
.24111 .78454 L
s
.19383 .77667 m
.19458 .77299 L
s
.16926 .77058 m
.17006 .76691 L
s
.1438 .76426 m
.14466 .76061 L
s
.11739 .75771 m
.11832 .75408 L
s
gsave
.31418 .88314 -69.7091 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(X) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.49917 .85239 m
.92421 .74682 L
s
.25 Mabswid
.50532 .85086 m
.5053 .84461 L
s
gsave
.50536 .86336 -70.0944 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.58459 .83117 m
.58425 .82493 L
s
gsave
.58526 .84365 -73.8897 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67646 .80835 m
.67575 .80214 L
s
gsave
.67788 .82077 -65.4287 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.78422 .78159 m
.78307 .77545 L
s
gsave
.78652 .79388 -68.721 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.91235 .74976 m
.91068 .74374 L
s
gsave
.9157 .76181 -64.6124 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.52029 .84714 m
.52024 .84339 L
s
.53569 .84332 m
.5356 .83957 L
s
.55152 .83938 m
.5514 .83564 L
s
.56781 .83534 m
.56765 .83159 L
s
.60186 .82688 m
.60162 .82314 L
s
.61966 .82246 m
.61938 .81872 L
s
.63801 .8179 m
.63768 .81417 L
s
.65694 .8132 m
.65656 .80947 L
s
.69662 .80335 m
.69614 .79963 L
s
.71744 .79817 m
.71691 .79446 L
s
.73895 .79283 m
.73838 .78913 L
s
.7612 .78731 m
.76057 .78361 L
s
.80804 .77567 m
.80729 .772 L
s
.83272 .76954 m
.83191 .76588 L
s
.8583 .76319 m
.85742 .75954 L
s
.88482 .7566 m
.88389 .75297 L
s
gsave
.68498 .88287 -67.9199 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.003 w
.80291 .32279 m
.92421 .74682 L
s
.25 Mabswid
.80499 .33005 m
.79956 .33316 L
s
gsave
.81583 .32384 -61 -15.0102 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.82743 .40851 m
.82186 .41134 L
s
gsave
.83858 .40286 -61 -14.5529 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.85344 .49944 m
.84771 .50193 L
s
gsave
.86491 .49446 -61 -14.0411 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.88394 .60606 m
.87805 .60813 L
s
gsave
.89573 .60191 -61 -13.4642 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.9202 .73281 m
.91415 .73438 L
s
gsave
.9323 .72969 -61 -12.809 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.80923 .34487 m
.80596 .34671 L
s
.81359 .36011 m
.8103 .36191 L
s
.81807 .37578 m
.81476 .37755 L
s
.82268 .39191 m
.81936 .39364 L
s
.83232 .42561 m
.82896 .42727 L
s
.83736 .44323 m
.83398 .44485 L
s
.84256 .46139 m
.83916 .46297 L
s
.84792 .48012 m
.8445 .48165 L
s
.85915 .51939 m
.85569 .52083 L
s
.86504 .53999 m
.86156 .54139 L
s
.87113 .56128 m
.86763 .56263 L
s
.87743 .58329 m
.87391 .58459 L
s
.89068 .62963 m
.88713 .63082 L
s
.89767 .65404 m
.89409 .65517 L
s
.90491 .67934 m
.90131 .68041 L
s
.91241 .70558 m
.9088 .70659 L
s
gsave
.92223 .46955 -61 -14.0411 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Z) show
73.312 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.001 w
[ .01 .01 ] 0 setdash
.49935 .49857 m
.49917 .85239 L
s
.49917 .85239 m
.92421 .74682 L
s
.92421 .74682 m
.80291 .32279 L
s
.80291 .32279 m
.49935 .49857 L
s
.19756 .32403 m
.50116 .01017 L
s
.50116 .01017 m
.50193 .50426 L
s
.50193 .50426 m
.07671 .74763 L
s
.07671 .74763 m
.19756 .32403 L
s
.49935 .49857 m
.49917 .85239 L
s
.49917 .85239 m
.07671 .74763 L
s
.07671 .74763 m
.19756 .32403 L
s
.19756 .32403 m
.49935 .49857 L
s
.80291 .32279 m
.50116 .01017 L
s
.50116 .01017 m
.50193 .50426 L
s
.50193 .50426 m
.92421 .74682 L
s
.92421 .74682 m
.80291 .32279 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
[ ] 0 setdash
.5216 .46087 m .52505 .49448 L .58541 .48111 L p 0 .318 .676 r
F P
0 g
s
.5276 .52414 m .52505 .49448 L .46229 .49257 L p 0 .336 .63 r
F P
0 g
s
.52505 .49448 m .5276 .52414 L .59467 .50999 L p 0 .291 .632 r
F P
0 g
s
.59467 .50999 m .58541 .48111 L .52505 .49448 L p 0 .291 .632 r
F P
0 g
s
.46805 .45914 m .46229 .49257 L .52505 .49448 L p 0 .358 .673 r
F P
0 g
s
.52505 .49448 m .5216 .46087 L .46805 .45914 L p 0 .358 .673 r
F P
0 g
s
.52951 .55133 m .5276 .52414 L .45807 .52211 L p 0 .316 .589 r
F P
0 g
s
.46229 .49257 m .45807 .52211 L .5276 .52414 L p 0 .336 .63 r
F P
0 g
s
.5276 .52414 m .52951 .55133 L .60165 .53682 L p 0 .265 .59 r
F P
0 g
s
.60165 .53682 m .59467 .50999 L .5276 .52414 L p 0 .265 .59 r
F P
0 g
s
.41836 .44379 m .40366 .47542 L .46229 .49257 L p 0 .402 .678 r
F P
0 g
s
.46229 .49257 m .46805 .45914 L .41836 .44379 L p 0 .402 .678 r
F P
0 g
s
.45807 .52211 m .46229 .49257 L .40366 .47542 L p 0 .386 .634 r
F P
0 g
s
.58541 .48111 m .57289 .44887 L .5216 .46087 L p 0 .318 .676 r
F P
0 g
s
.51649 .4195 m .5216 .46087 L .57289 .44887 L p 0 .349 .724 r
F P
0 g
s
.47661 .41814 m .46805 .45914 L .5216 .46087 L p 0 .381 .72 r
F P
0 g
s
.5216 .46087 m .51649 .4195 L .47661 .41814 L p 0 .381 .72 r
F P
0 g
s
.4549 .54926 m .45807 .52211 L .39277 .50396 L p 0 .369 .591 r
F P
0 g
s
.45807 .52211 m .4549 .54926 L .52951 .55133 L p 0 .316 .589 r
F P
0 g
s
.40366 .47542 m .39277 .50396 L .45807 .52211 L p 0 .386 .634 r
F P
0 g
s
.43999 .40607 m .41836 .44379 L .46805 .45914 L p 0 .418 .726 r
F P
0 g
s
.46805 .45914 m .47661 .41814 L .43999 .40607 L p 0 .418 .726 r
F P
0 g
s
.52951 .55133 m .53093 .57683 L .60681 .56226 L p 0 .24 .547 r
F P
0 g
s
.60681 .56226 m .60165 .53682 L .52951 .55133 L p 0 .24 .547 r
F P
0 g
s
.53093 .57683 m .52951 .55133 L .4549 .54926 L p 0 .295 .547 r
F P
0 g
s
.4549 .54926 m .45258 .57475 L .53093 .57683 L p 0 .295 .547 r
F P
0 g
s
.39277 .50396 m .38457 .53061 L .4549 .54926 L p 0 .369 .591 r
F P
0 g
s
.45258 .57475 m .4549 .54926 L .38457 .53061 L p 0 .351 .547 r
F P
0 g
s
.53093 .57683 m .53191 .60111 L .61035 .58673 L p 0 .214 .501 r
F P
0 g
s
.61035 .58673 m .60681 .56226 L .53093 .57683 L p 0 .214 .501 r
F P
0 g
s
.53191 .60111 m .53093 .57683 L .45258 .57475 L p 0 .273 .503 r
F P
0 g
s
.57289 .44887 m .55445 .41005 L .51649 .4195 L p 0 .349 .724 r
F P
0 g
s
.47661 .41814 m .51649 .4195 L .5016 .33184 L closepath p 0 .42 .802 r
F P
0 g
s
.51649 .4195 m .55445 .41005 L .5016 .33184 L closepath p 0 .405 .804 r
F P
0 g
s
.58541 .48111 m .59467 .50999 L .65212 .48001 L p 0 .247 .642 r
F P
0 g
s
.65212 .48001 m .6365 .45296 L .58541 .48111 L p 0 .247 .642 r
F P
0 g
s
.57289 .44887 m .58541 .48111 L .6365 .45296 L p 0 .282 .688 r
F P
0 g
s
.43999 .40607 m .47661 .41814 L .5016 .33184 L closepath p 0 .439 .806 r
F P
0 g
s
.6365 .45296 m .61561 .42388 L .57289 .44887 L p 0 .282 .688 r
F P
0 g
s
.55445 .41005 m .57289 .44887 L .61561 .42388 L p 0 .323 .737 r
F P
0 g
s
.38457 .53061 m .37851 .55602 L .45258 .57475 L p 0 .351 .547 r
F P
0 g
s
.451 .59905 m .45258 .57475 L .37851 .55602 L p 0 .331 .5 r
F P
0 g
s
.45258 .57475 m .451 .59905 L .53191 .60111 L p 0 .273 .503 r
F P
0 g
s
.59467 .50999 m .60165 .53682 L .664 .50591 L p 0 .214 .595 r
F P
0 g
s
.664 .50591 m .65212 .48001 L .59467 .50999 L p 0 .214 .595 r
F P
0 g
s
.4118 .38442 m .37897 .41579 L .41836 .44379 L p 0 .458 .742 r
F P
0 g
s
.41836 .44379 m .43999 .40607 L .4118 .38442 L p 0 .458 .742 r
F P
0 g
s
.40366 .47542 m .41836 .44379 L .37897 .41579 L p 0 .451 .692 r
F P
0 g
s
.39277 .50396 m .40366 .47542 L .35622 .44377 L p 0 .44 .645 r
F P
0 g
s
.37897 .41579 m .35622 .44377 L .40366 .47542 L p 0 .451 .692 r
F P
0 g
s
.53247 .62445 m .53191 .60111 L .451 .59905 L p 0 .249 .455 r
F P
0 g
s
.53191 .60111 m .53247 .62445 L .61233 .61047 L p 0 .185 .452 r
F P
0 g
s
.61233 .61047 m .61035 .58673 L .53191 .60111 L p 0 .185 .452 r
F P
0 g
s
.61561 .42388 m .58531 .39063 L .55445 .41005 L p 0 .323 .737 r
F P
0 g
s
.55445 .41005 m .58531 .39063 L .5016 .33184 L closepath p 0 .394 .812 r
F P
0 g
s
.60165 .53682 m .60681 .56226 L .67283 .5311 L p 0 .181 .547 r
F P
0 g
s
.67283 .5311 m .664 .50591 L .60165 .53682 L p 0 .181 .547 r
F P
0 g
s
.38457 .53061 m .39277 .50396 L .33917 .47016 L p 0 .427 .597 r
F P
0 g
s
.35622 .44377 m .33917 .47016 L .39277 .50396 L p 0 .44 .645 r
F P
0 g
s
.451 .59905 m .45014 .62246 L .53247 .62445 L p 0 .249 .455 r
F P
0 g
s
.45014 .62246 m .451 .59905 L .37437 .58056 L p 0 .309 .449 r
F P
0 g
s
.37851 .55602 m .37437 .58056 L .451 .59905 L p 0 .331 .5 r
F P
0 g
s
.4118 .38442 m .43999 .40607 L .5016 .33184 L closepath p 0 .458 .815 r
F P
0 g
s
.33917 .47016 m .32618 .4957 L .38457 .53061 L p 0 .427 .597 r
F P
0 g
s
.37851 .55602 m .38457 .53061 L .32618 .4957 L p 0 .411 .546 r
F P
0 g
s
.60681 .56226 m .61035 .58673 L .67891 .55588 L p 0 .147 .495 r
F P
0 g
s
.67891 .55588 m .67283 .5311 L .60681 .56226 L p 0 .147 .495 r
F P
0 g
s
.53247 .62445 m .53258 .64705 L .61268 .63367 L p 0 .154 .396 r
F P
0 g
s
.61268 .63367 m .61233 .61047 L .53247 .62445 L p 0 .154 .396 r
F P
0 g
s
.53258 .64705 m .53247 .62445 L .45014 .62246 L p 0 .222 .401 r
F P
0 g
s
.45003 .64514 m .45014 .62246 L .37209 .60447 L p 0 .283 .391 r
F P
0 g
s
.45014 .62246 m .45003 .64514 L .53258 .64705 L p 0 .222 .401 r
F P
0 g
s
.37437 .58056 m .37209 .60447 L .45014 .62246 L p 0 .309 .449 r
F P
0 g
s
.37437 .58056 m .37851 .55602 L .31653 .52077 L p 0 .392 .491 r
F P
0 g
s
.32618 .4957 m .31653 .52077 L .37851 .55602 L p 0 .411 .546 r
F P
0 g
s
.61561 .42388 m .6365 .45296 L .67042 .41174 L p 0 .252 .707 r
F P
0 g
s
.67042 .41174 m .64292 .38786 L .61561 .42388 L p 0 .252 .707 r
F P
0 g
s
.58531 .39063 m .61561 .42388 L .64292 .38786 L p 0 .304 .758 r
F P
0 g
s
.58531 .39063 m .60396 .36329 L .5016 .33184 L closepath p 0 .389 .825 r
F P
0 g
s
.64292 .38786 m .60396 .36329 L .58531 .39063 L p 0 .304 .758 r
F P
0 g
s
.61035 .58673 m .61233 .61047 L .68232 .58044 L p 0 .111 .437 r
F P
0 g
s
.68232 .58044 m .67891 .55588 L .61035 .58673 L p 0 .111 .437 r
F P
0 g
s
.6365 .45296 m .65212 .48001 L .69133 .43558 L p 0 .205 .656 r
F P
0 g
s
.69133 .43558 m .67042 .41174 L .6365 .45296 L p 0 .205 .656 r
F P
0 g
s
.37897 .41579 m .4118 .38442 L .39707 .3556 L p 0 .499 .765 r
F P
0 g
s
.39707 .3556 m .4118 .38442 L .5016 .33184 L closepath p 0 .475 .829 r
F P
0 g
s
.35622 .44377 m .37897 .41579 L .35676 .37756 L p 0 .501 .713 r
F P
0 g
s
.39707 .3556 m .35676 .37756 L .37897 .41579 L p 0 .499 .765 r
F P
0 g
s
.53221 .66899 m .53258 .64705 L .45003 .64514 L p 0 .19 .339 r
F P
0 g
s
.53258 .64705 m .53221 .66899 L .6112 .65642 L p 0 .119 .33 r
F P
0 g
s
.6112 .65642 m .61268 .63367 L .53258 .64705 L p 0 .119 .33 r
F P
0 g
s
.37209 .60447 m .37437 .58056 L .30989 .54563 L p 0 .368 .43 r
F P
0 g
s
.31653 .52077 m .30989 .54563 L .37437 .58056 L p 0 .392 .491 r
F P
0 g
s
.65212 .48001 m .664 .50591 L .70742 .45967 L p 0 .16 .6 r
F P
0 g
s
.70742 .45967 m .69133 .43558 L .65212 .48001 L p 0 .16 .6 r
F P
0 g
s
.45003 .64514 m .45076 .6672 L .53221 .66899 L p 0 .19 .339 r
F P
0 g
s
.37209 .60447 m .37175 .62793 L .45003 .64514 L p 0 .283 .391 r
F P
0 g
s
.45076 .6672 m .45003 .64514 L .37175 .62793 L p 0 .251 .324 r
F P
0 g
s
.61233 .61047 m .61268 .63367 L .6829 .60493 L p 0 .071 .372 r
F P
0 g
s
.6829 .60493 m .68232 .58044 L .61233 .61047 L p 0 .071 .372 r
F P
0 g
s
.33917 .47016 m .35622 .44377 L .32815 .39981 L p 0 .496 .659 r
F P
0 g
s
.35676 .37756 m .32815 .39981 L .35622 .44377 L p 0 .501 .713 r
F P
0 g
s
.664 .50591 m .67283 .5311 L .7195 .48417 L p 0 .114 .54 r
F P
0 g
s
.7195 .48417 m .70742 .45967 L .664 .50591 L p 0 .114 .54 r
F P
0 g
s
.32618 .4957 m .33917 .47016 L .3063 .4226 L p 0 .486 .6 r
F P
0 g
s
.32815 .39981 m .3063 .4226 L .33917 .47016 L p 0 .496 .659 r
F P
0 g
s
.37175 .62793 m .37209 .60447 L .3062 .57046 L p 0 .34 .36 r
F P
0 g
s
.30989 .54563 m .3062 .57046 L .37209 .60447 L p 0 .368 .43 r
F P
0 g
s
.50791 .26826 m .46027 .27425 L .5016 .33184 L closepath p 0 .466 .878 r
F P
0 g
s
.42178 .29443 m .39986 .3237 L .5016 .33184 L closepath p 0 .49 .861 r
F P
0 g
s
.39986 .3237 m .39707 .3556 L .5016 .33184 L closepath p 0 .487 .845 r
F P
0 g
s
.60396 .36329 m .60596 .33168 L .5016 .33184 L closepath p 0 .392 .841 r
F P
0 g
s
.55414 .27812 m .50791 .26826 L .5016 .33184 L closepath p 0 .443 .877 r
F P
0 g
s
.46027 .27425 m .42178 .29443 L .5016 .33184 L closepath p 0 .483 .872 r
F P
0 g
s
.60596 .33168 m .5889 .30115 L .5016 .33184 L closepath p 0 .402 .857 r
F P
0 g
s
.5889 .30115 m .55414 .27812 L .5016 .33184 L closepath p 0 .42 .87 r
F P
0 g
s
.53221 .66899 m .53123 .69028 L .60749 .67872 L p 0 .077 .251 r
F P
0 g
s
.60749 .67872 m .6112 .65642 L .53221 .66899 L p 0 .077 .251 r
F P
0 g
s
.53123 .69028 m .53221 .66899 L .45076 .6672 L p 0 .152 .263 r
F P
0 g
s
.60396 .36329 m .64292 .38786 L .64802 .34496 L p 0 .296 .785 r
F P
0 g
s
.64802 .34496 m .60596 .33168 L .60396 .36329 L p 0 .296 .785 r
F P
0 g
s
.61268 .63367 m .6112 .65642 L .68031 .62942 L p 0 .05 .295 r
F P
0 g
s
.68031 .62942 m .6829 .60493 L .61268 .63367 L p 0 .05 .295 r
F P
0 g
s
.67283 .5311 m .67891 .55588 L .72788 .50921 L p 0 .066 .474 r
F P
0 g
s
.72788 .50921 m .7195 .48417 L .67283 .5311 L p 0 .066 .474 r
F P
0 g
s
.37175 .62793 m .37359 .65102 L .45076 .6672 L p 0 .251 .324 r
F P
0 g
s
.45252 .68863 m .45076 .6672 L .37359 .65102 L p 0 .212 .243 r
F P
0 g
s
.45076 .6672 m .45252 .68863 L .53123 .69028 L p 0 .152 .263 r
F P
0 g
s
.31653 .52077 m .32618 .4957 L .28944 .44606 L p 0 .471 .535 r
F P
0 g
s
.3063 .4226 m .28944 .44606 L .32618 .4957 L p 0 .486 .6 r
F P
0 g
s
.35676 .37756 m .39707 .3556 L .39986 .3237 L p 0 .531 .792 r
F P
0 g
s
.64292 .38786 m .67042 .41174 L .67853 .3616 L p 0 .23 .73 r
F P
0 g
s
.67853 .3616 m .64802 .34496 L .64292 .38786 L p 0 .23 .73 r
F P
0 g
s
.37359 .65102 m .37175 .62793 L .30564 .59537 L p 0 .304 .279 r
F P
0 g
s
.3062 .57046 m .30564 .59537 L .37175 .62793 L p 0 .34 .36 r
F P
0 g
s
.67891 .55588 m .68232 .58044 L .73258 .53489 L p 0 .05 .398 r
F P
0 g
s
.73258 .53489 m .72788 .50921 L .67891 .55588 L p 0 .05 .398 r
F P
0 g
s
.30989 .54563 m .31653 .52077 L .27677 .47028 L p 0 .449 .462 r
F P
0 g
s
.28944 .44606 m .27677 .47028 L .31653 .52077 L p 0 .471 .535 r
F P
0 g
s
.6112 .65642 m .60749 .67872 L .67388 .65396 L p 0 .05 .203 r
F P
0 g
s
.67388 .65396 m .68031 .62942 L .6112 .65642 L p 0 .05 .203 r
F P
0 g
s
.39986 .3237 m .35832 .33392 L .35676 .37756 L p 0 .531 .792 r
F P
0 g
s
.32815 .39981 m .35676 .37756 L .35832 .33392 L p 0 .541 .734 r
F P
0 g
s
.67042 .41174 m .69133 .43558 L .70221 .38066 L p 0 .166 .666 r
F P
0 g
s
.70221 .38066 m .67853 .3616 L .67042 .41174 L p 0 .166 .666 r
F P
0 g
s
.53123 .69028 m .52946 .71075 L .6008 .70044 L p 0 .05 .151 r
F P
0 g
s
.6008 .70044 m .60749 .67872 L .53123 .69028 L p 0 .05 .151 r
F P
0 g
s
.52946 .71075 m .53123 .69028 L .45252 .68863 L p 0 .103 .166 r
F P
0 g
s
.45252 .68863 m .45564 .70927 L .52946 .71075 L p 0 .103 .166 r
F P
0 g
s
.45564 .70927 m .45252 .68863 L .37809 .67376 L p 0 .161 .139 r
F P
0 g
s
.37359 .65102 m .37809 .67376 L .45252 .68863 L p 0 .212 .243 r
F P
0 g
s
.27677 .47028 m .26799 .49535 L .30989 .54563 L p 0 .449 .462 r
F P
0 g
s
.3062 .57046 m .30989 .54563 L .26799 .49535 L p 0 .421 .38 r
F P
0 g
s
.37809 .67376 m .37359 .65102 L .30858 .62045 L p 0 .258 .181 r
F P
0 g
s
.30564 .59537 m .30858 .62045 L .37359 .65102 L p 0 .304 .279 r
F P
0 g
s
.68232 .58044 m .6829 .60493 L .73338 .56131 L p 0 .05 .312 r
F P
0 g
s
.73338 .56131 m .73258 .53489 L .68232 .58044 L p 0 .05 .312 r
F P
0 g
s
.60596 .33168 m .64802 .34496 L .62604 .30219 L p 0 .304 .81 r
F P
0 g
s
.62604 .30219 m .5889 .30115 L .60596 .33168 L p 0 .304 .81 r
F P
0 g
s
.69133 .43558 m .70742 .45967 L .72073 .4018 L p 0 .102 .592 r
F P
0 g
s
.72073 .4018 m .70221 .38066 L .69133 .43558 L p 0 .102 .592 r
F P
0 g
s
.3063 .4226 m .32815 .39981 L .32799 .34851 L p 0 .54 .664 r
F P
0 g
s
.35832 .33392 m .32799 .34851 L .32815 .39981 L p 0 .541 .734 r
F P
0 g
s
.35832 .33392 m .39986 .3237 L .42178 .29443 L p 0 .539 .814 r
F P
0 g
s
.60749 .67872 m .6008 .70044 L .66238 .67848 L p 0 .05 .088 r
F P
0 g
s
.66238 .67848 m .67388 .65396 L .60749 .67872 L p 0 .05 .088 r
F P
0 g
s
.30564 .59537 m .3062 .57046 L .26309 .52133 L p 0 .383 .285 r
F P
0 g
s
.26799 .49535 m .26309 .52133 L .3062 .57046 L p 0 .421 .38 r
F P
0 g
s
.6829 .60493 m .68031 .62942 L .72978 .58854 L p 0 .05 .212 r
F P
0 g
s
.72978 .58854 m .73338 .56131 L .6829 .60493 L p 0 .05 .212 r
F P
0 g
s
.70742 .45967 m .7195 .48417 L .73479 .42488 L p 0 .05 .508 r
F P
0 g
s
.73479 .42488 m .72073 .4018 L .70742 .45967 L p 0 .05 .508 r
F P
0 g
s
.28944 .44606 m .3063 .4226 L .30434 .36615 L p 0 .527 .583 r
F P
0 g
s
.32799 .34851 m .30434 .36615 L .3063 .4226 L p 0 .54 .664 r
F P
0 g
s
.52646 .72983 m .52946 .71075 L .45564 .70927 L p 0 .05 .08 r
F P
0 g
s
.52946 .71075 m .52646 .72983 L .58964 .72112 L p 0 .05 .08 r
F P
0 g
s
.58964 .72112 m .6008 .70044 L .52946 .71075 L p 0 .05 .08 r
F P
0 g
s
.30858 .62045 m .31576 .64575 L .37809 .67376 L p 0 .258 .181 r
F P
0 g
s
.38611 .69602 m .37809 .67376 L .31576 .64575 L p 0 .197 .08 r
F P
0 g
s
.37809 .67376 m .38611 .69602 L .45564 .70927 L p 0 .161 .139 r
F P
0 g
s
.46085 .72858 m .45564 .70927 L .38611 .69602 L p 0 .089 .08 r
F P
0 g
s
.45564 .70927 m .46085 .72858 L .52646 .72983 L p 0 .05 .08 r
F P
0 g
s
.64802 .34496 m .67853 .3616 L .65372 .31045 L p 0 .224 .74 r
F P
0 g
s
.65372 .31045 m .62604 .30219 L .64802 .34496 L p 0 .224 .74 r
F P
0 g
s
.30858 .62045 m .30564 .59537 L .26233 .54832 L p 0 .335 .177 r
F P
0 g
s
.26309 .52133 m .26233 .54832 L .30564 .59537 L p 0 .383 .285 r
F P
0 g
s
.5889 .30115 m .62604 .30219 L .57741 .26902 L p 0 .335 .821 r
F P
0 g
s
.57741 .26902 m .55414 .27812 L .5889 .30115 L p 0 .335 .821 r
F P
0 g
s
.7195 .48417 m .72788 .50921 L .74462 .44987 L p 0 .05 .412 r
F P
0 g
s
.74462 .44987 m .73479 .42488 L .7195 .48417 L p 0 .05 .412 r
F P
0 g
s
.30434 .36615 m .2858 .38638 L .28944 .44606 L p 0 .527 .583 r
F P
0 g
s
.27677 .47028 m .28944 .44606 L .2858 .38638 L p 0 .504 .489 r
F P
0 g
s
.68031 .62942 m .67388 .65396 L .72089 .61665 L p 0 .05 .095 r
F P
0 g
s
.72089 .61665 m .72978 .58854 L .68031 .62942 L p 0 .05 .095 r
F P
0 g
s
.32799 .34851 m .35832 .33392 L .38748 .2926 L p 0 .545 .737 r
F P
0 g
s
.42178 .29443 m .38748 .2926 L .35832 .33392 L p 0 .539 .814 r
F P
0 g
s
.38748 .2926 m .42178 .29443 L .46027 .27425 L p 0 .511 .821 r
F P
0 g
s
.6008 .70044 m .58964 .72112 L .6434 .70273 L p 0 .05 .08 r
F P
0 g
s
.6434 .70273 m .66238 .67848 L .6008 .70044 L p 0 .05 .08 r
F P
0 g
s
.67853 .3616 m .70221 .38066 L .67565 .32362 L p 0 .141 .649 r
F P
0 g
s
.67565 .32362 m .65372 .31045 L .67853 .3616 L p 0 .141 .649 r
F P
0 g
s
.72788 .50921 m .73258 .53489 L .75017 .47677 L p 0 .05 .304 r
F P
0 g
s
.75017 .47677 m .74462 .44987 L .72788 .50921 L p 0 .05 .304 r
F P
0 g
s
.39943 .71741 m .38611 .69602 L .32851 .67124 L p 0 .114 .08 r
F P
0 g
s
.38611 .69602 m .39943 .71741 L .46085 .72858 L p 0 .089 .08 r
F P
0 g
s
.31576 .64575 m .32851 .67124 L .38611 .69602 L p 0 .197 .08 r
F P
0 g
s
.26799 .49535 m .27677 .47028 L .27169 .40898 L p 0 .469 .382 r
F P
0 g
s
.2858 .38638 m .27169 .40898 L .27677 .47028 L p 0 .504 .489 r
F P
0 g
s
.31576 .64575 m .30858 .62045 L .26622 .57638 L p 0 .274 .08 r
F P
0 g
s
.26233 .54832 m .26622 .57638 L .30858 .62045 L p 0 .335 .177 r
F P
0 g
s
.55414 .27812 m .57741 .26902 L .51077 .25457 L p 0 .387 .82 r
F P
0 g
s
.51077 .25457 m .50791 .26826 L .55414 .27812 L p 0 .387 .82 r
F P
0 g
s
.52114 .74568 m .52646 .72983 L .46085 .72858 L p 0 .05 .08 r
F P
0 g
s
.52646 .72983 m .52114 .74568 L .57008 .73919 L p 0 .05 .08 r
F P
0 g
s
.57008 .73919 m .58964 .72112 L .52646 .72983 L p 0 .05 .08 r
F P
0 g
s
.67388 .65396 m .66238 .67848 L .70515 .64569 L p 0 .05 .08 r
F P
0 g
s
.70515 .64569 m .72089 .61665 L .67388 .65396 L p 0 .05 .08 r
F P
0 g
s
.46027 .27425 m .44189 .26336 L .38748 .2926 L p 0 .511 .821 r
F P
0 g
s
.44189 .26336 m .46027 .27425 L .50791 .26826 L p 0 .452 .82 r
F P
0 g
s
.46085 .72858 m .46999 .74475 L .52114 .74568 L p 0 .05 .08 r
F P
0 g
s
.46999 .74475 m .46085 .72858 L .39943 .71741 L p 0 .05 .08 r
F P
0 g
s
.38748 .2926 m .36177 .29882 L .32799 .34851 L p 0 .545 .737 r
F P
0 g
s
.30434 .36615 m .32799 .34851 L .36177 .29882 L p 0 .529 .635 r
F P
0 g
s
.50791 .26826 m .51077 .25457 L .44189 .26336 L p 0 .452 .82 r
F P
0 g
s
.73258 .53489 m .73338 .56131 L .75111 .50562 L p 0 .05 .183 r
F P
0 g
s
.75111 .50562 m .75017 .47677 L .73258 .53489 L p 0 .05 .183 r
F P
0 g
s
.70221 .38066 m .72073 .4018 L .69309 .34085 L p 0 .054 .538 r
F P
0 g
s
.69309 .34085 m .67565 .32362 L .70221 .38066 L p 0 .054 .538 r
F P
0 g
s
.26309 .52133 m .26799 .49535 L .26182 .43389 L p 0 .423 .263 r
F P
0 g
s
.27169 .40898 m .26182 .43389 L .26799 .49535 L p 0 .469 .382 r
F P
0 g
s
.62604 .30219 m .65372 .31045 L .59513 .26995 L p 0 .247 .722 r
F P
0 g
s
.59513 .26995 m .57741 .26902 L .62604 .30219 L p 0 .247 .722 r
F P
0 g
s
.26622 .57638 m .27571 .6056 L .31576 .64575 L p 0 .274 .08 r
F P
0 g
s
.32851 .67124 m .31576 .64575 L .27571 .6056 L p 0 .195 .08 r
F P
0 g
s
.58964 .72112 m .57008 .73919 L .61068 .72571 L p 0 .05 .08 r
F P
0 g
s
.61068 .72571 m .6434 .70273 L .58964 .72112 L p 0 .05 .08 r
F P
0 g
s
.36177 .29882 m .38748 .2926 L .44189 .26336 L p 0 .488 .712 r
F P
0 g
s
.2858 .38638 m .30434 .36615 L .34132 .3105 L p 0 .494 .511 r
F P
0 g
s
.36177 .29882 m .34132 .3105 L .30434 .36615 L p 0 .529 .635 r
F P
0 g
s
.73338 .56131 m .72978 .58854 L .74685 .53648 L p 0 .05 .08 r
F P
0 g
s
.74685 .53648 m .75111 .50562 L .73338 .56131 L p 0 .05 .08 r
F P
0 g
s
.66238 .67848 m .6434 .70273 L .67952 .67566 L p 0 .05 .08 r
F P
0 g
s
.67952 .67566 m .70515 .64569 L .66238 .67848 L p 0 .05 .08 r
F P
0 g
s
.32851 .67124 m .34945 .69671 L .39943 .71741 L p 0 .114 .08 r
F P
0 g
s
.42263 .73645 m .39943 .71741 L .34945 .69671 L p 0 .05 .08 r
F P
0 g
s
.39943 .71741 m .42263 .73645 L .46999 .74475 L p 0 .05 .08 r
F P
0 g
s
.26182 .43389 m .25629 .46107 L .26309 .52133 L p 0 .423 .263 r
F P
0 g
s
.26233 .54832 m .26309 .52133 L .25629 .46107 L p 0 .364 .134 r
F P
0 g
s
.72073 .4018 m .73479 .42488 L .7065 .36177 L p 0 .05 .411 r
F P
0 g
s
.7065 .36177 m .69309 .34085 L .72073 .4018 L p 0 .05 .411 r
F P
0 g
s
.27571 .6056 m .29241 .63605 L .32851 .67124 L p 0 .195 .08 r
F P
0 g
s
.34945 .69671 m .32851 .67124 L .29241 .63605 L p 0 .095 .08 r
F P
0 g
s
.65372 .31045 m .67565 .32362 L .6094 .2777 L p 0 .149 .586 r
F P
0 g
s
.6094 .2777 m .59513 .26995 L .65372 .31045 L p 0 .149 .586 r
F P
0 g
s
.57741 .26902 m .59513 .26995 L .51298 .25208 L p 0 .305 .691 r
F P
0 g
s
.51298 .25208 m .51077 .25457 L .57741 .26902 L p 0 .305 .691 r
F P
0 g
s
.72978 .58854 m .72089 .61665 L .73639 .56947 L p 0 .05 .08 r
F P
0 g
s
.73639 .56947 m .74685 .53648 L .72978 .58854 L p 0 .05 .08 r
F P
0 g
s
.25629 .46107 m .25542 .49057 L .26233 .54832 L p 0 .364 .134 r
F P
0 g
s
.26622 .57638 m .26233 .54832 L .25542 .49057 L p 0 .05 .163 r
F P
0 g
s
.34132 .3105 m .32502 .32671 L .2858 .38638 L p 0 .494 .511 r
F P
0 g
s
.27169 .40898 m .2858 .38638 L .32502 .32671 L p 0 .05 .08 r
F P
0 g
s
.73479 .42488 m .74462 .44987 L .71597 .38624 L p 0 .218 .08 r
F P
0 g
s
.71597 .38624 m .7065 .36177 L .73479 .42488 L p 0 .218 .08 r
F P
0 g
s
.42786 .26297 m .44189 .26336 L .51077 .25457 L p 0 .393 .685 r
F P
0 g
s
.44189 .26336 m .42786 .26297 L .36177 .29882 L p 0 .488 .712 r
F P
0 g
s
.5022 .73402 m .52114 .74568 L .46999 .74475 L closepath p 0 .372 .719 r
F P
0 g
s
.5022 .73402 m .57008 .73919 L .52114 .74568 L closepath p 0 .41 .728 r
F P
0 g
s
.5022 .73402 m .46999 .74475 L .42263 .73645 L closepath p 0 .348 .735 r
F P
0 g
s
.34132 .3105 m .36177 .29882 L .42786 .26297 L p 0 .05 .08 r
F P
0 g
s
.6434 .70273 m .61068 .72571 L .6364 .70636 L p 0 .459 .551 r
F P
0 g
s
.6364 .70636 m .67952 .67566 L .6434 .70273 L p 0 .459 .551 r
F P
0 g
s
.51077 .25457 m .51298 .25208 L .42786 .26297 L p 0 .393 .685 r
F P
0 g
s
.27571 .6056 m .26622 .57638 L .25983 .52245 L p 0 .05 .303 r
F P
0 g
s
.25542 .49057 m .25983 .52245 L .26622 .57638 L p 0 .05 .163 r
F P
0 g
s
.72089 .61665 m .70515 .64569 L .71807 .60473 L p 0 .468 .392 r
F P
0 g
s
.71807 .60473 m .73639 .56947 L .72089 .61665 L p 0 .468 .392 r
F P
0 g
s
.5022 .73402 m .61068 .72571 L .57008 .73919 L closepath p 0 .454 .759 r
F P
0 g
s
.26182 .43389 m .27169 .40898 L .31248 .34704 L p 0 .05 .08 r
F P
0 g
s
.32502 .32671 m .31248 .34704 L .27169 .40898 L p 0 .05 .08 r
F P
0 g
s
.34945 .69671 m .38528 .72135 L .42263 .73645 L p 0 .05 .08 r
F P
0 g
s
.29241 .63605 m .31944 .66779 L .34945 .69671 L p 0 .095 .08 r
F P
0 g
s
.38528 .72135 m .34945 .69671 L .31944 .66779 L p 0 .133 .588 r
F P
0 g
s
.74462 .44987 m .75017 .47677 L .72135 .41417 L p 0 .296 .08 r
F P
0 g
s
.72135 .41417 m .71597 .38624 L .74462 .44987 L p 0 .296 .08 r
F P
0 g
s
.5022 .73402 m .42263 .73645 L .38528 .72135 L closepath p 0 .34 .77 r
F P
0 g
s
.67565 .32362 m .69309 .34085 L .6209 .29114 L p 0 .05 .08 r
F P
0 g
s
.6209 .29114 m .6094 .2777 L .67565 .32362 L p 0 .05 .08 r
F P
0 g
s
.25983 .52245 m .2705 .55681 L .27571 .6056 L p 0 .05 .303 r
F P
0 g
s
.29241 .63605 m .27571 .6056 L .2705 .55681 L p 0 .05 .442 r
F P
0 g
s
.59513 .26995 m .6094 .2777 L .51479 .25724 L p 0 .05 .08 r
F P
0 g
s
.51479 .25724 m .51298 .25208 L .59513 .26995 L p 0 .05 .08 r
F P
0 g
s
.32502 .32671 m .34132 .3105 L .41654 .26972 L p 0 .05 .08 r
F P
0 g
s
.42786 .26297 m .41654 .26972 L .34132 .3105 L p 0 .05 .08 r
F P
0 g
s
.70515 .64569 m .67952 .67566 L .68876 .64251 L p 0 .513 .538 r
F P
0 g
s
.68876 .64251 m .71807 .60473 L .70515 .64569 L p 0 .513 .538 r
F P
0 g
s
.75017 .47677 m .75111 .50562 L .72227 .4456 L p 0 .365 .168 r
F P
0 g
s
.72227 .4456 m .72135 .41417 L .75017 .47677 L p 0 .365 .168 r
F P
0 g
s
.31248 .34704 m .30362 .3713 L .26182 .43389 L p 0 .05 .08 r
F P
0 g
s
.25629 .46107 m .26182 .43389 L .30362 .3713 L p 0 .05 .08 r
F P
0 g
s
.41654 .26972 m .42786 .26297 L .51298 .25208 L p 0 .05 .08 r
F P
0 g
s
.5022 .73402 m .6364 .70636 L .61068 .72571 L closepath p 0 .492 .8 r
F P
0 g
s
.69309 .34085 m .7065 .36177 L .62984 .3098 L p 0 .14 .08 r
F P
0 g
s
.62984 .3098 m .6209 .29114 L .69309 .34085 L p 0 .14 .08 r
F P
0 g
s
.51298 .25208 m .51479 .25724 L .41654 .26972 L p 0 .05 .08 r
F P
0 g
s
.2705 .55681 m .28908 .59383 L .29241 .63605 L p 0 .05 .442 r
F P
0 g
s
.31944 .66779 m .29241 .63605 L .28908 .59383 L p 0 .078 .576 r
F P
0 g
s
.5022 .73402 m .38528 .72135 L .36452 .70084 L closepath p 0 .346 .811 r
F P
0 g
s
.31944 .66779 m .36452 .70084 L .38528 .72135 L p 0 .133 .588 r
F P
0 g
s
.75111 .50562 m .74685 .53648 L .71814 .48057 L p 0 .423 .302 r
F P
0 g
s
.71814 .48057 m .72227 .4456 L .75111 .50562 L p 0 .423 .302 r
F P
0 g
s
.25542 .49057 m .25629 .46107 L .29863 .39945 L p 0 .05 .215 r
F P
0 g
s
.30362 .3713 m .29863 .39945 L .25629 .46107 L p 0 .05 .08 r
F P
0 g
s
.67952 .67566 m .6364 .70636 L .64087 .68344 L p 0 .539 .679 r
F P
0 g
s
.64087 .68344 m .68876 .64251 L .67952 .67566 L p 0 .539 .679 r
F P
0 g
s
.31248 .34704 m .32502 .32671 L .40743 .28245 L p 0 .05 .08 r
F P
0 g
s
.41654 .26972 m .40743 .28245 L .32502 .32671 L p 0 .05 .08 r
F P
0 g
s
.6094 .2777 m .6209 .29114 L .51626 .26881 L p 0 .05 .08 r
F P
0 g
s
.51626 .26881 m .51479 .25724 L .6094 .2777 L p 0 .05 .08 r
F P
0 g
s
.7065 .36177 m .71597 .38624 L .63621 .33346 L p 0 .219 .08 r
F P
0 g
s
.63621 .33346 m .62984 .3098 L .7065 .36177 L p 0 .219 .08 r
F P
0 g
s
.74685 .53648 m .73639 .56947 L .70807 .5192 L p 0 .471 .427 r
F P
0 g
s
.70807 .5192 m .71814 .48057 L .74685 .53648 L p 0 .471 .427 r
F P
0 g
s
.28908 .59383 m .31861 .63382 L .31944 .66779 L p 0 .078 .576 r
F P
0 g
s
.36452 .70084 m .31944 .66779 L .31861 .63382 L p 0 .191 .705 r
F P
0 g
s
.29863 .39945 m .29786 .43147 L .25542 .49057 L p 0 .05 .215 r
F P
0 g
s
.25983 .52245 m .25542 .49057 L .29786 .43147 L p 0 .05 .343 r
F P
0 g
s
.40743 .28245 m .41654 .26972 L .51479 .25724 L p 0 .05 .08 r
F P
0 g
s
.5022 .73402 m .64087 .68344 L .6364 .70636 L closepath p 0 .514 .836 r
F P
0 g
s
.40743 .28245 m .40035 .30066 L .31248 .34704 L p 0 .05 .08 r
F P
0 g
s
.30362 .3713 m .31248 .34704 L .40035 .30066 L p 0 .05 .08 r
F P
0 g
s
.51479 .25724 m .51626 .26881 L .40743 .28245 L p 0 .05 .08 r
F P
0 g
s
.73639 .56947 m .71807 .60473 L .69062 .56168 L p 0 .507 .543 r
F P
0 g
s
.69062 .56168 m .70807 .5192 L .73639 .56947 L p 0 .507 .543 r
F P
0 g
s
.2705 .55681 m .25983 .52245 L .30185 .46744 L p 0 .05 .459 r
F P
0 g
s
.29786 .43147 m .30185 .46744 L .25983 .52245 L p 0 .05 .343 r
F P
0 g
s
.71597 .38624 m .72135 .41417 L .63985 .36206 L p 0 .285 .185 r
F P
0 g
s
.63985 .36206 m .63621 .33346 L .71597 .38624 L p 0 .285 .185 r
F P
0 g
s
.5022 .73402 m .36452 .70084 L .36642 .67756 L closepath p 0 .363 .843 r
F P
0 g
s
.31861 .63382 m .36642 .67756 L .36452 .70084 L p 0 .191 .705 r
F P
0 g
s
.6209 .29114 m .62984 .3098 L .51742 .28629 L p 0 .077 .08 r
F P
0 g
s
.51742 .28629 m .51626 .26881 L .6209 .29114 L p 0 .077 .08 r
F P
0 g
s
.71807 .60473 m .68876 .64251 L .66321 .60845 L p 0 .532 .65 r
F P
0 g
s
.66321 .60845 m .69062 .56168 L .71807 .60473 L p 0 .532 .65 r
F P
0 g
s
.40035 .30066 m .40743 .28245 L .51626 .26881 L p 0 .05 .08 r
F P
0 g
s
.28908 .59383 m .2705 .55681 L .31146 .50745 L p 0 .097 .566 r
F P
0 g
s
.30185 .46744 m .31146 .50745 L .2705 .55681 L p 0 .05 .459 r
F P
0 g
s
.29863 .39945 m .30362 .3713 L .39533 .32414 L p 0 .05 .213 r
F P
0 g
s
.40035 .30066 m .39533 .32414 L .30362 .3713 L p 0 .05 .08 r
F P
0 g
s
.72135 .41417 m .72227 .4456 L .64049 .3956 L p 0 .34 .308 r
F P
0 g
s
.64049 .3956 m .63985 .36206 L .72135 .41417 L p 0 .34 .308 r
F P
0 g
s
.68876 .64251 m .64087 .68344 L .61972 .66072 L p 0 .543 .75 r
F P
0 g
s
.61972 .66072 m .66321 .60845 L .68876 .64251 L p 0 .543 .75 r
F P
0 g
s
.51626 .26881 m .51742 .28629 L .40035 .30066 L p 0 .05 .08 r
F P
0 g
s
.5022 .73402 m .5108 .63557 L .57363 .64318 L closepath p 0 .471 .87 r
F P
0 g
s
.5022 .73402 m .36642 .67756 L .39437 .65564 L closepath p 0 .386 .861 r
F P
0 g
s
.5022 .73402 m .61972 .66072 L .64087 .68344 L closepath p 0 .514 .858 r
F P
0 g
s
.5022 .73402 m .39437 .65564 L .44588 .6402 L closepath p 0 .413 .868 r
F P
0 g
s
.5022 .73402 m .57363 .64318 L .61972 .66072 L closepath p 0 .497 .867 r
F P
0 g
s
.5022 .73402 m .44588 .6402 L .5108 .63557 L closepath p 0 .442 .87 r
F P
0 g
s
.31146 .50745 m .32799 .55171 L .28908 .59383 L p 0 .097 .566 r
F P
0 g
s
.31861 .63382 m .28908 .59383 L .32799 .55171 L p 0 .174 .665 r
F P
0 g
s
.62984 .3098 m .63621 .33346 L .51826 .30948 L p 0 .149 .135 r
F P
0 g
s
.51826 .30948 m .51742 .28629 L .62984 .3098 L p 0 .149 .135 r
F P
0 g
s
.29786 .43147 m .29863 .39945 L .39249 .35284 L p 0 .05 .33 r
F P
0 g
s
.39533 .32414 m .39249 .35284 L .29863 .39945 L p 0 .05 .213 r
F P
0 g
s
.72227 .4456 m .71814 .48057 L .63773 .43413 L p 0 .385 .416 r
F P
0 g
s
.63773 .43413 m .64049 .3956 L .72227 .4456 L p 0 .385 .416 r
F P
0 g
s
.32799 .55171 m .35378 .60066 L .31861 .63382 L p 0 .174 .665 r
F P
0 g
s
.36642 .67756 m .31861 .63382 L .35378 .60066 L p 0 .257 .758 r
F P
0 g
s
.39533 .32414 m .40035 .30066 L .51742 .28629 L p 0 .05 .145 r
F P
0 g
s
.35378 .60066 m .39437 .65564 L .36642 .67756 L p 0 .257 .758 r
F P
0 g
s
.71814 .48057 m .70807 .5192 L .63099 .47776 L p 0 .422 .513 r
F P
0 g
s
.63099 .47776 m .63773 .43413 L .71814 .48057 L p 0 .422 .513 r
F P
0 g
s
.39249 .35284 m .39207 .38675 L .29786 .43147 L p 0 .05 .33 r
F P
0 g
s
.30185 .46744 m .29786 .43147 L .39207 .38675 L p 0 .093 .432 r
F P
0 g
s
.51742 .28629 m .51826 .30948 L .39533 .32414 L p 0 .05 .145 r
F P
0 g
s
.63621 .33346 m .63985 .36206 L .51876 .33831 L p 0 .21 .259 r
F P
0 g
s
.51876 .33831 m .51826 .30948 L .63621 .33346 L p 0 .21 .259 r
F P
0 g
s
.39249 .35284 m .39533 .32414 L .51826 .30948 L p 0 .105 .267 r
F P
0 g
s
.70807 .5192 m .69062 .56168 L .6194 .52666 L p 0 .453 .602 r
F P
0 g
s
.6194 .52666 m .63099 .47776 L .70807 .5192 L p 0 .453 .602 r
F P
0 g
s
.39207 .38675 m .39439 .42593 L .30185 .46744 L p 0 .093 .432 r
F P
0 g
s
.31146 .50745 m .30185 .46744 L .39439 .42593 L p 0 .15 .524 r
F P
0 g
s
.66321 .60845 m .61972 .66072 L .57363 .64318 L p 0 .498 .769 r
F P
0 g
s
.69062 .56168 m .66321 .60845 L .60145 .58129 L p 0 .479 .686 r
F P
0 g
s
.60145 .58129 m .6194 .52666 L .69062 .56168 L p 0 .479 .686 r
F P
0 g
s
.63985 .36206 m .64049 .3956 L .51889 .3728 L p 0 .26 .365 r
F P
0 g
s
.51889 .3728 m .51876 .33831 L .63985 .36206 L p 0 .26 .365 r
F P
0 g
s
.57363 .64318 m .60145 .58129 L .66321 .60845 L p 0 .498 .769 r
F P
0 g
s
.51826 .30948 m .51876 .33831 L .39249 .35284 L p 0 .105 .267 r
F P
0 g
s
.32799 .55171 m .31146 .50745 L .39989 .47047 L p 0 .205 .608 r
F P
0 g
s
.39439 .42593 m .39989 .47047 L .31146 .50745 L p 0 .15 .524 r
F P
0 g
s
.42368 .57659 m .44588 .6402 L .39437 .65564 L p 0 .32 .77 r
F P
0 g
s
.39437 .65564 m .35378 .60066 L .42368 .57659 L p 0 .32 .77 r
F P
0 g
s
.39207 .38675 m .39249 .35284 L .51876 .33831 L p 0 .16 .371 r
F P
0 g
s
.39989 .47047 m .40926 .52054 L .32799 .55171 L p 0 .205 .608 r
F P
0 g
s
.35378 .60066 m .32799 .55171 L .40926 .52054 L p 0 .26 .689 r
F P
0 g
s
.40926 .52054 m .42368 .57659 L .35378 .60066 L p 0 .26 .689 r
F P
0 g
s
.64049 .3956 m .63773 .43413 L .51859 .41301 L p 0 .303 .457 r
F P
0 g
s
.51859 .41301 m .51889 .3728 L .64049 .3956 L p 0 .303 .457 r
F P
0 g
s
.51876 .33831 m .51889 .3728 L .39207 .38675 L p 0 .16 .371 r
F P
0 g
s
.39439 .42593 m .39207 .38675 L .51889 .3728 L p 0 .208 .461 r
F P
0 g
s
.60145 .58129 m .57363 .64318 L .5108 .63557 L p 0 .439 .77 r
F P
0 g
s
.63773 .43413 m .63099 .47776 L .51779 .459 L p 0 .341 .539 r
F P
0 g
s
.51779 .459 m .51859 .41301 L .63773 .43413 L p 0 .341 .539 r
F P
0 g
s
.51419 .56926 m .5108 .63557 L .44588 .6402 L p 0 .379 .769 r
F P
0 g
s
.44588 .6402 m .42368 .57659 L .51419 .56926 L p 0 .379 .769 r
F P
0 g
s
.5108 .63557 m .51419 .56926 L .60145 .58129 L p 0 .439 .77 r
F P
0 g
s
.51889 .3728 m .51859 .41301 L .39439 .42593 L p 0 .208 .461 r
F P
0 g
s
.39989 .47047 m .39439 .42593 L .51859 .41301 L p 0 .252 .542 r
F P
0 g
s
.63099 .47776 m .6194 .52666 L .51638 .51094 L p 0 .375 .616 r
F P
0 g
s
.51638 .51094 m .51779 .459 L .63099 .47776 L p 0 .375 .616 r
F P
0 g
s
.6194 .52666 m .60145 .58129 L .51419 .56926 L p 0 .407 .691 r
F P
0 g
s
.51419 .56926 m .51638 .51094 L .6194 .52666 L p 0 .407 .691 r
F P
0 g
s
.51638 .51094 m .51419 .56926 L .42368 .57659 L p 0 .335 .691 r
F P
0 g
s
.42368 .57659 m .40926 .52054 L .51638 .51094 L p 0 .335 .691 r
F P
0 g
s
.40926 .52054 m .39989 .47047 L .51779 .459 L p 0 .294 .617 r
F P
0 g
s
.51859 .41301 m .51779 .459 L .39989 .47047 L p 0 .252 .542 r
F P
0 g
s
.51779 .459 m .51638 .51094 L .40926 .52054 L p 0 .294 .617 r
F P
0 g
s
[ .01 .01 ] 0 setdash
.19756 .32403 m
.50116 .01017 L
s
.50116 .01017 m
.50193 .50426 L
s
.50193 .50426 m
.07671 .74763 L
s
.07671 .74763 m
.19756 .32403 L
s
.80291 .32279 m
.50116 .01017 L
s
.50116 .01017 m
.50193 .50426 L
s
.50193 .50426 m
.92421 .74682 L
s
.92421 .74682 m
.80291 .32279 L
s
.003 w
[ ] 0 setdash
.49917 .85239 m
.92421 .74682 L
s
.25 Mabswid
.50532 .85086 m
.5053 .84461 L
s
gsave
.50536 .86336 -70.0944 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.58459 .83117 m
.58425 .82493 L
s
gsave
.58526 .84365 -73.8897 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Math1
%%IncludeFont: Math1
/Math1 findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
71.250 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.67646 .80835 m
.67575 .80214 L
s
gsave
.67788 .82077 -65.4287 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
1.000 setlinewidth
grestore
.78422 .78159 m
.78307 .77545 L
s
gsave
.78652 .79388 -68.721 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.5) show
1.000 setlinewidth
grestore
.91235 .74976 m
.91068 .74374 L
s
gsave
.9157 .76181 -64.6124 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
1.000 setlinewidth
grestore
.125 Mabswid
.52029 .84714 m
.52024 .84339 L
s
.53569 .84332 m
.5356 .83957 L
s
.55152 .83938 m
.5514 .83564 L
s
.56781 .83534 m
.56765 .83159 L
s
.60186 .82688 m
.60162 .82314 L
s
.61966 .82246 m
.61938 .81872 L
s
.63801 .8179 m
.63768 .81417 L
s
.65694 .8132 m
.65656 .80947 L
s
.69662 .80335 m
.69614 .79963 L
s
.71744 .79817 m
.71691 .79446 L
s
.73895 .79283 m
.73838 .78913 L
s
.7612 .78731 m
.76057 .78361 L
s
.80804 .77567 m
.80729 .772 L
s
.83272 .76954 m
.83191 .76588 L
s
.8583 .76319 m
.85742 .75954 L
s
.88482 .7566 m
.88389 .75297 L
s
gsave
.68498 .88287 -67.9199 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 22 translate 1 -1 scale
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Y) show
74.625 14.000 moveto
%%IncludeResource: font Times
%%IncludeFont: Times
/Times findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{380, 380},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005l0001O2000`400?l00000o`00003oo`3IfMUm
0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00_@3IfMT00`000000fMWI0=WI
f@2l0=WIf@00_@3IfMT00`000000fMWI0=WIf@2l0=WIf@00_03IfMT2000000030=WIf@000000fMWI
0;/0fMWI002k0=WIf@030000003IfMT000000080fMWI00<000000=WIf@3IfMT0^@3IfMT00;X0fMWI
00@000000=WIf@3IfMT000000`3IfMT00`000000fMWI0=WIf@2h0=WIf@00^@3IfMT00`000000fMWI
0=WIf@300=WIf@00o`3IfMUm0=WIf@00a03IfMT00`000000fMWI0=WIf@2e0=WIf@00]P3IfMT00`00
0000fMWI0=WIf@040=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0]03IfMT00;D0
fMWI00<000000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@060=WIf@030000003IfMT0fMWI0;<0
fMWI002d0=WIf@030000003IfMT0fMWI00H0fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI
0=WIf@2b0=WIf@00_@3IfMT00`000000fMWI0=WIf@2l0=WIf@00_@3IfMT00`000000fMWI0=WIf@09
0=WIf@030000003IfMT0fMWI0;00fMWI002a0=WIf@030000003IfMT0fMWI01H0fMWI00<000000=WI
f@3IfMT0[`3IfMT00;40fMWI00<000000=WIf@3IfMT05`3IfMT00`000000fMWI0=WIf@2^0=WIf@00
/03IfMT00`000000fMWI0=WIf@0I0=WIf@030000003IfMT0fMWI0:d0fMWI002_0=WIf@030000003I
fMT0fMWI00/0fMWI00<000000=WIf@3IfMT0_03IfMT00;d0fMWI00<000000=WIf@3IfMT0_03IfMT0
0;d0fMWI00<000000=WIf@3IfMT03P3IfMT00`000000fMWI0=WIf@2[0=WIf@00Z`3IfMT200000100
fMWI00<000000=WIf@3IfMT03`3IfMT00`000000fMWI0=WIf@2Z0=WIf@00ZP3IfMT00`000000fMWI
0=WIf@0S0=WIf@030000003IfMT0fMWI0:T0fMWI002Y0=WIf@030000003IfMT0fMWI02D0fMWI00<0
00000=WIf@3IfMT0Z03IfMT00?l0fMWIO@3IfMT00;d0fMWI00<000000=WIf@3IfMT0503IfMT00`00
0000fMWI0=WIf@2U0=WIf@00Y`3IfMT00`000000fMWI0=WIf@0C0=WIf@030000003IfMT0fMWI01@0
fMWI00<000000=WIf@3IfMT0Y@3IfMT00:H0fMWI00<000000=WIf@3IfMT0503IfMT00`000000fMWI
0=WIf@0E0=WIf@030000003IfMT0fMWI0:@0fMWI002U0=WIf@030000003IfMT0fMWI01D0fMWI00<0
00000=WIf@3IfMT05P3IfMT00`000000fMWI0=WIf@2S0=WIf@00Y03IfMT00`000000fMWI0=WIf@0F
0=WIf@030000003IfMT0fMWI0;`0fMWI003o0=WIfGd0fMWI002Q0=WIf@030000003IfMT0fMWI03D0
fMWI00<000000=WIf@3IfMT0X03IfMT00:40fMWI00<000000=WIf@3IfMT0=P3IfMT00`000000fMWI
0=WIf@2O0=WIf@00X03IfMT00`000000fMWI0=WIf@0J0=WIf@030000003IfMT0fMWI01/0fMWI00<0
00000=WIf@3IfMT0WP3IfMT009l0fMWI00<000000=WIf@3IfMT06`3IfMT00`000000fMWI0=WIf@0L
0=WIf@030000003IfMT0fMWI09d0fMWI002m0=WIf@030000003IfMT0fMWI0;`0fMWI002m0=WIf@03
0000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT0V`3IfMT009`0fMWI00<000000=WIf@3IfMT0
@03IfMT00`000000fMWI0=WIf@2J0=WIf@00V`3IfMT00`000000fMWI0=WIf@120=WIf@030000003I
fMT0fMWI09T0fMWI002J0=WIf@030000003IfMT0fMWI04@0fMWI00<000000=WIf@3IfMT0V03IfMT0
09T0fMWI00<000000=WIf@3IfMT08@3IfMT00`000000fMWI0=WIf@2l0=WIf@00_@3IfMT00`000000
fMWI0=WIf@2l0=WIf@00U`3IfMT00`000000fMWI0=WIf@0S0=WIf@030000003IfMT0fMWI02<0fMWI
0P00002G0=WIf@00UP3IfMT00`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI02D0fMWI00<0
00000=WIf@3IfMT0U03IfMT009D0fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI0=WIf@0V
0=WIf@030000003IfMT0fMWI09<0fMWI002D0=WIf@030000003IfMT0fMWI0>D0fMWI003o0=WIfGd0
fMWI003Y0=WIf@030000003IfMT0fMWI0900fMWI002A0=WIf@800000:`3IfMT00`000000fMWI0=WI
f@0X0=WIf@030000003IfMT0fMWI0900fMWI002@0=WIf@030000003IfMT0fMWI02/0fMWI00<00000
0=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@2?0=WIf@00S`3IfMT00`000000fMWI0=WIf@0/0=WI
f@030000003IfMT0fMWI02X0fMWI00<000000=WIf@3IfMT0SP3IfMT00;h0fMWI00<000000=WIf@3I
fMT0^`3IfMT00;h0fMWI00<000000=WIf@3IfMT0^`3IfMT008`0fMWI00<000000=WIf@3IfMT0G`3I
fMT2000008`0fMWI002<0=WIf@030000003IfMT0fMWI0640fMWI00<000000=WIf@3IfMT0R@3IfMT0
08/0fMWI00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0`0=WIf@030000003IfMT0fMWI
08P0fMWI002:0=WIf@030000003IfMT0fMWI0340fMWI00<000000=WIf@3IfMT0^`3IfMT00;h0fMWI
00<000000=WIf@3IfMT0^`3IfMT00;h0fMWI00<000000=WIf@3IfMT0<P3IfMT00`000000fMWI0=WI
f@260=WIf@00QP3IfMT2000003H0fMWI00<000000=WIf@3IfMT0<`3IfMT00`000000fMWI0=WIf@25
0=WIf@00Q@3IfMT00`000000fMWI0=WIf@1]0=WIf@030000003IfMT0fMWI08@0fMWI00240=WIf@03
0000003IfMT0fMWI06l0fMWI00<000000=WIf@3IfMT0P`3IfMT00?l0fMWIO@3IfMT00;h0fMWI00<0
00000=WIf@3IfMT0^`3IfMT00880fMWI00<000000=WIf@3IfMT0>@3IfMT00`000000fMWI0=WIf@0g
0=WIf@800000PP3IfMT00840fMWI00<000000=WIf@3IfMT0>P3IfMT00`000000fMWI0=WIf@0i0=WI
f@030000003IfMT0fMWI07l0fMWI00200=WIf@030000003IfMT0fMWI03/0fMWI00<000000=WIf@3I
fMT0>P3IfMT00`000000fMWI0=WIf@1n0=WIf@00O`3IfMT00`000000fMWI0=WIf@0l0=WIf@030000
003IfMT0fMWI0;/0fMWI003o0=WIfGd0fMWI003n0=WIf@030000003IfMT0fMWI07/0fMWI001l0=WI
f@030000003IfMT0fMWI07l0fMWI00<000000=WIf@3IfMT0N`3IfMT007/0fMWI00<000000=WIf@3I
fMT0@03IfMT00`000000fMWI0=WIf@0n0=WIf@030000003IfMT0fMWI07X0fMWI001j0=WIf@030000
003IfMT0fMWI0440fMWI00<000000=WIf@3IfMT0?`3IfMT00`000000fMWI0=WIf@1i0=WIf@00_P3I
fMT00`000000fMWI0=WIf@2k0=WIf@00_P3IfMT00`000000fMWI0=WIf@2k0=WIf@00M`3IfMT00`00
0000fMWI0=WIf@290=WIf@800000M`3IfMT007L0fMWI00<000000=WIf@3IfMT0R`3IfMT00`000000
fMWI0=WIf@1d0=WIf@00MP3IfMT00`000000fMWI0=WIf@2=0=WIf@030000003IfMT0fMWI07<0fMWI
001e0=WIf@030000003IfMT0fMWI04H0fMWI00<000000=WIf@3IfMT0^`3IfMT00;h0fMWI00<00000
0=WIf@3IfMT0^`3IfMT00780fMWI00<000000=WIf@3IfMT0B@3IfMT00`000000fMWI0=WIf@170=WI
f@030000003IfMT0fMWI0740fMWI001a0=WIf@030000003IfMT0fMWI04X0fMWI00<000000=WIf@3I
fMT0B03IfMT00`000000fMWI0=WIf@1`0=WIf@00L03IfMT00`000000fMWI0=WIf@1;0=WIf@030000
003IfMT0fMWI04T0fMWI00<000000=WIf@3IfMT0K`3IfMT006l0fMWI00<000000=WIf@3IfMT0V@3I
fMT00`000000fMWI0=WIf@1^0=WIf@00o`3IfMUm0=WIf@00o`3IfMT?0=WIf@030000003IfMT0fMWI
06/0fMWI001]0=WIf@030000003IfMT0fMWI04h0fMWI00<000000=WIf@3IfMT0C@3IfMT00`000000
fMWI0=WIf@1[0=WIf@00K03IfMT00`000000fMWI0=WIf@1?0=WIf@030000003IfMT0fMWI04h0fMWI
00<000000=WIf@3IfMT0JP3IfMT006/0fMWI00<000000=WIf@3IfMT0D03IfMT00`000000fMWI0=WI
f@1?0=WIf@030000003IfMT0fMWI06T0fMWI001Z0=WIf@030000003IfMT0fMWI0540fMWI00<00000
0=WIf@3IfMT0^`3IfMT00;h0fMWI00<000000=WIf@3IfMT0^`3IfMT006L0fMWI00<000000=WIf@3I
fMT0Z@3IfMT00`000000fMWI0=WIf@1V0=WIf@00I`3IfMT00`000000fMWI0=WIf@2Y0=WIf@030000
003IfMT0fMWI06H0fMWI001V0=WIf@030000003IfMT0fMWI05D0fMWI00<000000=WIf@3IfMT0D`3I
fMT00`000000fMWI0=WIf@1U0=WIf@00I@3IfMT00`000000fMWI0=WIf@1F0=WIf@L00000D03IfMT0
0`000000fMWI0=WIf@1T0=WIf@00]P3IfMT9000000<000`D00<00000000<500031@01@00002b0=WI
f@00[P3IfMT8000000P000`D20000004000<50@00000BP3IfMT00`000000fMWI0=WIf@1Q0=WIf@00
HP3IfMT00`000000fMWI0=WIf@110=WIf@P000002P0031@7000000@000`D00<00000000<500031@0
1@000003000<50D00000AP3IfMT00`000000fMWI0=WIf@1P0=WIf@00H@3IfMT00`000000fMWI0=WI
f@0m0=WIf@D000002P0031@8000000/000`D00<00000000<500031@01@0031@4000000@000`D1000
00130=WIf@030000003IfMT0fMWI05l0fMWI001P0=WIf@030000003IfMT0fMWI03`0fMWI0P000007
000<50P000004`0031@00`00000000`D000<5009000<50@00000100031@400000400fMWI00<00000
0=WIf@3IfMT0GP3IfMT005l0fMWI00<000000=WIf@3IfMT0?03IfMT00`00000000`D000<50070000
01P000`D1P00000=000<50D000000`0031@5000009`0fMWI002L0=WIf@D00000600031@7000000<0
00`D00<00000000C50004a@01@00000=000<50@00000100031@3000009T0fMWI001M0=WIf@030000
003IfMT0fMWI03X0fMWI0P0000000`0031@00000000<500C000<50L000001@0031@00`00000000`D
000<5002000<5003000000004a@001<D00D001<D1000000=000<50@000000`0031@2000003P0fMWI
00<000000=WIf@3IfMT0G03IfMT005`0fMWI00<000000=WIf@3IfMT0>@3IfMT20000008000`D00<0
0000000<500031@0300031@7000000`000`D00<00000000<500031@00P0031@00`00000001<D000C
5009000C50D00000300031@6000003P0fMWI00<000000=WIf@3IfMT0F`3IfMT005/0fMWI00<00000
0=WIf@3IfMT0>03IfMT2000000<000`D00<00000000<500031@01P0031@7000001<000`D00<00000
000<500031@00`0031@00`00000001<D000C500=000C50@000003@0031@3000003L0fMWI00<00000
0=WIf@3IfMT0FP3IfMT005X0fMWI00<000000=WIf@3IfMT0>03IfMT00`00000000`D000<5003000<
50030000000031@0000000H000006P0031@00`00000000`D000<5003000<5003000000004a@001<D
014001<D1000000;000<50800000=`3IfMT00`000000fMWI0=WIf@1I0=WIf@00T`3IfMT2000000@0
00`D1000000W000<5003000000004a@001<D01D001<D1@000007000<50<00000T@3IfMT00940fMWI
0P000004000<5080000000<000`D0000000031@0900031@7000001X001<D10000004000<50030000
000031@0000003L0fMWI00<000000=WIf@3IfMT0EP3IfMT005L0fMWI0P00000f0=WIf@8000001000
31@20000008000`D00<00000000<500031@06`0031@9000000@000`U00<00000000V8P009R801@00
000I000C50H0000000<000`D000000000000=@3IfMT00`000000fMWI0=WIf@1F0=WIf@00EP3IfMT0
0`000000fMWI0=WIf@0d0=WIf@800000100031@2000000@000`D00<00000000<500031@04P0031@9
000000L000`U00<00000000<9@0032D00`0032D00`00000002HR000V8P05000V8PD000006@004a@3
00000003000<50000000fMWI03@0fMWI00<000000=WIf@3IfMT0E@3IfMT005D0fMWI00<000000=WI
f@3IfMT0<`3IfMT2000000@000`D0P000005000<50030000000031@000`D00X000`D2@00000@000<
9@030000000032D000`U00<000`U00<00000000V8P009R802P009R84000001H001<D00@00000000S
5000000000`D0P00000d0=WIf@030000003IfMT0fMWI05@0fMWI00290=WIf@800000100031@20000
00L000`D00@00000000<500031@000`D2@00000I000<9@030000000032D000`U00<000`U00<00000
000V8P009R803P009R850000018001<D00H00000000S500000000000000<5000002:0=WIf@00R03I
fMT00`00000000`D000<5002000<508000001`0031@60000028000`U00<00000000<9@0032D00`00
32D00`00000002HR000V8P0C000V8PD000003@004a@01P00000002<D000S50008a@00000000<5080
0000R03IfMT00580fMWI00<000000=WIf@3IfMT0<@3IfMT2000000<000`D0P000007000<50800000
00<000`D0000000032D0:`0032D00`00000002HR000V8P0H000V8P@000002P004a@01@00000002<D
000S50008a@00000008000`D0P00000b0=WIf@030000003IfMT0fMWI0540fMWI001B0=WIf@030000
003IfMT0fMWI02l0fMWI0P000004000<50030000000031@000`D00D000`D0P000003000<50030000
000032D000`U02X000`U00<00000000V8P009R8070009R85000000D001<D00<00000000S50008a@0
0P008a@20000008000`D00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@1@0=WIf@00D@3I
fMT00`000000fMWI0=WIf@0^0=WIf@800000100031@2000000L000`D00<00000000<500031@00P00
31@00`00000000`U000<9@0[000<9@03000000009R8002HR024002HR1P000006000S500300000000
31@000`D00800000<@3IfMT00`000000fMWI0=WIf@0C0=WIf@<00000>@3IfMT00500fMWI00<00000
0=WIf@3IfMT0;P3IfMT00`00000000`D000<5002000<508000001`0031@2000000D000`D00<00000
000<9@0032D09@0032D:000002D002HR0`000005000S508000000P0031@00`000000fMWI0=WIf@15
0=WIf@030000003IfMT0fMWI03P0fMWI00200=WIf@040000000031@000`D000<508000001`0031@2
000000L000`D00<00000000<9@0032D07@0032D9000000D001Y400@00000000e@P00=D8003E21@00
000Q000V8P0300000000>1@0000000H002<D00<00000000<500031@00P0000150=WIf@030000003I
fMT0fMWI03P0fMWI001o0=WIf@030000000031@000`D008000001`0031@2000000T000`D00<00000
000<9@0032D04`0032D:000000P001Y400<00000000JA0006T@00`006T@00`00000003E2000e@P06
000e@PD000007@009R801000000003PD000000000005000S508000000P0031@00`000000fMWI0=WI
f@0^0=WIf@030000003IfMT0fMWI00P0fMWI1`0000020=WIf@030000003IfMT0fMWI03P0fMWI001<
0=WIf@800000<03IfMT01000000000`D000000000007000<508000002`0031@00`00000000`U000<
9@0:000<9@T000004P006T@00`00000001Y4000JA003000JA00300000000=D8003E200/003E21@00
000H000V8P0500000000>1@003PD000h500000001P008a@00`00000000`D000<5002000002l0fMWI
00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@0h0=WIf@00B`3IfMT00`000000fMWI0=WI
f@0_0=WIf@<000001`0031@2000000`000`D00<00000000<9@0032D00P0032D9000001/001Y400<0
0000000JA0006T@00`006T@00`00000003E2000e@P0@000e@PD000004`009R800`00000003PD000h
5002000h508000001@008a@01@00000000`D000<500031@0000002l0fMWI00<000000=WIf@3IfMT0
3`3IfMT00`000000fMWI0=WIf@0h0=WIf@00BP3IfMT200000300fMWI0P000008000<500300000000
31@000`D00/000`D1P00000Z000JA00300000000=D8003E201D003E21@00000?000V8P0300000000
>1@003PD00<003PD00<00000000S50008a@00`008a@20000008000`D00<000000=WIf@3IfMT0;03I
fMT2000000l0fMWI0P00000j0=WIf@00BP3IfMT010000000fMWI00000000000]0=WIf@0300000000
31@000`D00H000`D0P00000<000<5080000000<000`f000000006T@0;@006T@00`00000003E2000e
@P0J000e@PD000002P009R800`00000003PD000h5004000h5003000000008a@002<D00@002<D00<0
0000000<50000000;03IfMT2000000030=WIf@000000fMWI00l0fMWI00<000000=WIf@3IfMT0>03I
fMT004h0fMWI00<000000=WIf@3IfMT0:P3IfMT00`00000000`D000<5004000<50800000300031@2
000000<000`f00<00000000JA0006T@0;0006T@00`00000003E2000e@P0O000e@PD000001@009R80
0`00000003PD000h5005000h508000001@008a@3000002X0fMWI00D000000=WIf@3IfMT0fMWI0000
001;0=WIf@00NP3IfMT00`00000000`D000<5003000<50800000300031@2000000D000`f00<00000
000JA0006T@09P006T@00`00000001Y4000JA003000JA00300000000=D8003E202@003E21@000000
0`009R800000000h5007000h5003000000008a@002<D00@002<D0P00000]0=WIf@800000BP3IfMT0
04T0fMWI00<000000=WIf@3IfMT01@3IfMT2000002H0fMWI00<00000000<500031@00P0031@20000
00`000`D0P000007000<=P03000000006T@001Y402H001Y400<00000000JA0006T@00`006T@00`00
000003E2000e@P0Y000e@P<000002000>1@2000000D002<D0P00000T0=WIf@8000001@3IfMT00`00
0000fMWI0000001:0=WIf@00B@3IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI02<0
fMWI00<00000000<500031@00P00000=000<50030000000033H000`f00L000`f00<00000000JA000
6T@09P006T@00`00000001Y4000JA003000JA00300000000=D8003E202X003E200<000000018;`00
00002@00>1@00`00000002<D000S5003000S508000008P3IfMT00`000000fMWI0=WIf@070=WIf@03
0000003IfMT0fMWI04P0fMWI00190=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0
8@3IfMT01000000000`D000<5000000=000<508000002@0033H00`00000001Y4000JA00W000JA0X0
0000:@00=D800`00000004P_0018;`02000000P003PD0P000005000S50030000003IfMT0fMWI01h0
fMWI00<000000=WIf@3IfMT0203IfMT2000004T0fMWI00180=WIf@030000003IfMT0fMWI02`0fMWI
1000000<000<508000002`0033H00`00000001Y4000JA00O000JA0T000001@00:5h010000000049M
0012G@00@Ud5000002@003E200<000000018;`00B2l00P00B2l00`00000003PD000h5007000h5003
000000008a@002<D00<002<D00<000000=WIf@3IfMT06@3IfMT2000000h0fMWI00<000000=WIf@3I
fMT0A`3IfMT004P0fMWI00<000000=WIf@3IfMT0303IfMT2000001h0fMWI0P00000<000<50800000
3@0033H00`00000001Y4000JA00E000JA0X000003P00:5h00`000000049M0012G@060012G@D00000
7`00=D800`00000004P_0018;`030018;`8000002000>1@2000000<002<D00<000000=WIf@3IfMT0
5`3IfMT200000100fMWI00<000000=WIf@3IfMT0A`3IfMT005T0fMWI0P00000K0=WIf@0300000000
31@000`D00X000`D0P00000?000<=P03000000006T@001Y400/001Y42P00000H000XGP0300000000
@Ud0049M00/0049M1@00000J000e@P0300000000B2l004P_00D004P_00<00000000h5000>1@01`00
>1@01@00000002<D000S50008a@0000001L0fMWI00<000000=WIf@3IfMT03`3IfMT2000004T0fMWI
001K0=WIf@030000003IfMT0fMWI01L0fMWI0P00000:000<508000004@0033H00`00000001Y4000J
A002000JA0T000007000:5h00`00000002QN000XGP03000XGP0300000000@Ud0049M0100049M1@00
000F000e@P0300000000B2l004P_00D004P_0P000008000h5005000000008a@002<D000S50000000
:P3IfMT00`000000fMWI0=WIf@160=WIf@00A`3IfMT00`000000fMWI0=WIf@0[0=WIf@0300000000
31@000`D00L000`D0P00000B000<=PH000009@00:5h00`00000002QN000XGP03000XGP0300000000
@Ud0049M01D0049M1@00000A000e@P0300000000B2l004P_00L004P_00<00000000h5000>1@01P00
>1@200000003000S50000000fMWI0140fMWI0P00000F0=WIf@030000003IfMT0fMWI04H0fMWI0017
0=WIf@030000003IfMT0fMWI01@0fMWI0P00000D0=WIf@8000001`0031@20000018000`f0P000000
0`0035@00000000XGP0X000XGP0300000000:5h002QN00<002QN00<000000012G@00@Ud06P00@Ud5
000000`003E200<000000018;`00B2l02000B2l2000000P003PD00<00000000S50000000403IfMT0
0`000000fMWI0=WIf@0F0=WIf@030000003IfMT0fMWI04H0fMWI00170=WIf@030000003IfMT0fMWI
01H0fMWI00<000000=WIf@3IfMT0403IfMT3000000D000`D0P00000B000<=P8000000`0035@00`00
000002QN000XGP0W000XGP0300000000:5h002QN00<002QN00<000000012G@00@Ud07`00@Ud50000
00L003E200<000000018;`00B2l02P00B2l00`00000003PD000h5006000h508000003`3IfMT00`00
0000fMWI0=WIf@0G0=WIf@800000A`3IfMT004H0fMWI00<000000=WIf@3IfMT0603IfMT00`000000
fMWI0=WIf@0?0=WIf@8000001@0031@00`00000000`f000<=P0@000<=P8000001@0035@00`000000
02QN000XGP0W000XGP0300000000:5h002QN00<002QN00<000000012G@00@Ud09000@Ud500000080
03E200<000000018;`00B2l02`00B2l2000000P003PD00<000000=WIf@3IfMT09`3IfMT00`000000
fMWI0=WIf@150=WIf@00AP3IfMT00`000000fMWI0=WIf@0L0=WIf@8000002`3IfMT00`00000000`D
00000003000<508000004@0033H2000000L000aD00<00000000XGP00:5h0;@00:5h00`000000049M
0012G@0Y0012G@@000003P00B2l00`00000003PD000h5006000h50030000003IfMT0fMWI00L0fMWI
0P00000L0=WIf@800000A`3IfMT006L0fMWI00<000000=WIf@3IfMT0203IfMT01000000000`D0000
000031@20000014000`f0P000009000<E00300000000:5h002QN02d002QN00<000000012G@00@Ud0
:`00@Ud00`00000005M>0000000>0018;`8000001P00>1@00`000000fMWI0=WIf@050=WIf@800000
7`3IfMT00`000000fMWI0=WIf@150=WIf@00J03IfMT00`000000fMWI0=WIf@060=WIf@0300000000
31@00000008000004@0033H2000000/000aD00<00000000XGP00:5h0;@00:5h00`000000049M0012
G@0[0012G@0300000000Edh005M>008000003P00B2l00`00000003PD000h5004000h50030000003I
fMT0fMWI00<0fMWI00<000000=WIf@3IfMT0803IfMT00`000000fMWI0=WIf@140=WIf@00L03IfMT0
1000000000`D000<5000000A000<=P8000003@0035@00`00000002QN000XGP0W000XGP0300000000
:5h002QN00<002QN00<000000012G@00@Ud0:`00@Ud00`00000005M>001GCP02001GCP8000003@00
B2l2000000@003PD00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@140=WIf@00A@3IfMT0
0`000000fMWI0=WIf@0S0=WIf@8000000`3IfMT01000000000`D000<5000000?000<=P8000003`00
35@00`00000002QN000XGP0W000XGPX00000:P00@Ud00`00000005M>001GCP04001GCP0300000000
B2l004P_00`004P_00<00000000h5000>1@00P00>1@3000002D0fMWI00<000000=WIf@3IfMT0A03I
fMT004D0fMWI00<000000=WIf@3IfMT09@3IfMT00`000000fMWI00000002000<508000003P0033H0
0`00000000aD000<E00?000<E00300000000:5h002QN01l002QN2@000005000eMP0400000000CG@0
04ed001=M0H000009000@Ud00`00000005M>001GCP05001GCP8000003@00B2l20000008003PD00<0
00000=WIf@3IfMT09@3IfMT2000004D0fMWI00140=WIf@030000003IfMT0fMWI02L0fMWI00H00000
000<500031@00000000<5000000<000<=P8000004P0035@00`00000002QN000XGP0E000XGPX00000
2000=GH00`00000003Ef000eMP03000eMP0300000000CG@004ed00L004ed1@00000O0012G@030000
0000Edh005M>00L005M>0P00000=0018;`0400000000>1@00000000002D0fMWI00<000000=WIf@00
0000A@3IfMT004@0fMWI00<000000=WIf@3IfMT09`3IfMT00`00000000`D000<5002000000/000`f
0P00000D000<E00300000000:5h002QN00/002QN2P00000B000eMP0300000000=GH003Ef00<003Ef
00<00000001=M000CG@03000CG@6000001T0049M00<00000001GCP00Edh02@00Edh00`00000004P_
0018;`0;0018;`<000009`3IfMT00`000000fMWI0=WIf@130=WIf@00K@3IfMT01P00000000`D000<
5000000000`D000000T000`f0P00000F000<E00300000000:5h002QN008002QN2@00000R000eMP03
00000000CG@004ed018004ed1P00000C0012G@0300000000Edh005M>00X005M>0P00000=0018;`03
0000003IfMT0fMWI02D0fMWI00<000000=WIf@3IfMT0@`3IfMT006`0fMWI00@00000000<500031@0
00000P0031@00`00000000`f000<=P05000<=P8000005`0035@6000002/003Ef00<00000001=M000
CG@06000CG@6000000d0049M00<00000001GCP00Edh03000Edh2000000`004P_00<000000=WIf@3I
fMT09@3IfMT00`000000fMWI0=WIf@120=WIf@00K03IfMT01000000000`D000<50000002000<5003
0000000033H000`f00<000`f0P00000G000<E080000000<001M^00000000=GH0:000=GH00`000000
03Ef000eMP03000eMP0300000000CG@004ed01h004ed1@0000080012G@0300000000Edh005M>00h0
05M>00<000000018;`00B2l02@00B2l00`000000fMWI0=WIf@0U0=WIf@030000003IfMT0fMWI00l0
fMWI0`0000030=WIf@040000003IfMT0fMWI0=WIf@<000009P3IfMT004<0fMWI00<000000=WIf@3I
fMT09@3IfMT01000000000`D000<50000003000<50040000000033H000`f000<=P8000005`0035@2
000000<001M^00<00000000eMP00=GH09`00=GH00`00000003Ef000eMP03000eMP0300000000CG@0
04ed02<004ed1P0000020012G@0300000000Edh005M>00l005M>0P0000090018;`8000009P3IfMT0
0`000000fMWI0=WIf@0>0=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT01@000000fMWI0=WI
f@3IfMT0000002D0fMWI00130=WIf@030000003IfMT0fMWI02@0fMWI00@00000000<500031@00000
0`0031@00`00000000`f000<=P02000001L000aD0P000005000GKP0300000000=GH003Ef02L003Ef
00<00000000eMP00=GH00`00=GH00`00000004ed001=M00Y001=M0@000004P00Edh00`00000004P_
0018;`070018;`030000003IfMT0fMWI02<0fMWI0`00000?0=WIf@050000003IfMT0fMWI0=WIf@00
00002@3IfMT00`000000fMWI0=WIf@0S0=WIf@00@`3IfMT00`000000fMWI0=WIf@0T0=WIf@040000
000031@000`D000000<000`D0`00000F000<E0<000001`005fh00`00000003Ef000eMP0W000eMP03
00000000=GH003Ef00<003Ef00<00000001=M000CG@0:`00CG@00`000000069Z0000000B001GCP80
00001`00B2l2000002H0fMWI00<000000=WIf@3IfMT01@3IfMT7000000030=WIf@000000fMWI0080
fMWI00<000000=WIf@3IfMT01`3IfMT00`000000fMWI0=WIf@0S0=WIf@00@P3IfMT00`000000fMWI
0=WIf@0T0=WIf@040000000031@000`D000000@000`D00<00000000<E00035@0500035@2000000X0
01M^00<00000000eMP00=GH09`00=GH00`00000003Ef000eMP03000eMP0300000000CG@004ed02/0
04ed00<00000001RJP00HVX00P00000B001GCP8000001@00B2l2000002H0fMWI00<000000=WIf@3I
fMT03@3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI1000000V0=WIf@00@P3IfMT00`000000
fMWI0=WIf@0S0=WIf@040000000031@000`D000000D000`D00<00000000<E00035@04P0035@20000
00`001M^00<00000000eMP00=GH0;@00=GH00`00000004ed001=M00[001=M00300000000HVX0069Z
0080069Z0P00000B001GCP0300000000B2l004P_008004P_00<00000001;500000009@3IfMT00`00
0000fMWI0=WIf@0=0=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@0W
0=WIf@00J03IfMT01000000000`D000<50000004000<508000004P0035@2000000h001M^00<00000
000eMP00=GH0;@00=GH00`00000004ed001=M00[001=M00300000000HVX0069Z00@0069Z00<00000
001GCP00Edh04000Edh20000008004P_00<00000001;500000009P3IfMT00`000000fMWI0=WIf@0<
0=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@0W0=WIf@00I`3IfMT0
1000000000`D000<50000004000<50030000000033L00000010000aD0P00000A000GKP0300000000
=GH003Ef02`003Ef00<00000001=M000CG@0:`00CG@00`000000069Z001RJP05001RJP8000004P00
Edh2000000040018;`0000000000000002@0fMWI0P00000?0=WIf@<000001P3IfMT5000002D0fMWI
00110=WIf@030000003IfMT0fMWI0280fMWI00@00000000<500031@000001@0031@00`00000000`g
0000000>000<E08000004`005fh00`00000003Ef000eMP0V000eMP0300000000=GH003Ef00<003Ef
00<00000001=M000CG@0:`00CG@00`000000069Z001RJP07001RJP8000004P00Edh200000003001;
50000000fMWI0280fMWI00<000000=WIf@000000@P3IfMT00440fMWI00<000000=WIf@3IfMT08P3I
fMT01000000000`D000<50000004000<50040000000033L000`g000000`000aD0P00000E000GKP03
00000000=GH003Ef02H003Ef2P00000Z001=M00300000000HVX0069Z00T0069Z00<00000001GCP00
Edh04000Edh00`00000004/D0000000U0=WIf@800000@@3IfMT00440fMWI00<000000=WIf@3IfMT0
8@3IfMT01000000000`D000<50000004000<50050000000033L000`g000<=`0000002P0035@20000
01L001M^00<00000000eMP00=GH07P00=GH9000000D0042:00@00000001GR@00EhT005N91@00000T
001=M00300000000HVX0069Z00/0069Z0P00000@001GCP0400000000Ba@004/D000002@0fMWI0P00
00110=WIf@00@03IfMT00`000000fMWI0=WIf@0R0=WIf@030000000031@0000000@000`D00D00000
000<=`0033L000`g00000009000<E08000006@005fh00`00000003Ef000eMP0D000eMPX000002000
@8X00`000000042:0010RP030010RP0300000000EhT005N900H005N91P00000N001=M00300000000
HVX0069Z00d0069Z0P00000>001GCP80000000<004/D0000003IfMT0903IfMT00`000000fMWI0=WI
f@0o0=WIf@00@03IfMT00`000000fMWI0=WIf@0R0=WIf@030000000031@0000000@000`D00D00000
000<=`0033L000`g00000006000<E0<000006`005fh00`00000003Ef000eMP0;000eMPT000004P00
@8X00`000000042:0010RP030010RP0300000000EhT005N900`005N91P00000H001=M00300000000
HVX0069Z00l0069Z00<00000001GCP00Edh02`00Edh20000008004/D00<000000=WIf@3IfMT08P3I
fMT00`000000fMWI0=WIf@0o0=WIf@00I03IfMT00`00000000`D00000004000<50030000000033L0
00`g008000`g00<00000000<E00035@00P0035@2000001h001M^00<00000000eMP00=GH00P00=GH9
00000240042:00<00000001GR@00EhT04P00EhT5000001<004ed00<00000001RJP00HVX04000HVX2
000000/005M>00D00000001M:`00000004/D0000000U0=WIf@030000003IfMT0fMWI03h0fMWI001T
0=WIf@800000100031@00`00000000`g000<=`03000<=`030000000035@000aD008000007`005fh6
000002X0042:00<00000001GR@00EhT05`00EhT6000000d004ed00<00000001RJP00HVX04P00HVX0
0`00000005M>001GCP08001GCP0300000000GB/00000008004/D00<000000=WIf@3IfMT08@3IfMT2
00000400fMWI001T0=WIf@800000100031@00`00000000`g000<=`03000<=`<000007`005fh20000
0003000VQP000000042:02d0042:00<00000001GR@00EhT07@00EhT6000000L004ed00<00000001R
JP00HVX04`00HVX2000000P005M>00H00000001M:`00GB/00000001;5000000T0=WIf@030000003I
fMT0fMWI03h0fMWI000o0=WIf@030000003IfMT0fMWI0240fMWI0P000004000<50030000000033L0
00`g00@000`g00<00000000GKP005fh07@005fh2000000<002J600<000000010RP00@8X09P00@8X0
0`000000042:0010RP030010RP0300000000EhT005N902<005N91@000002001=M00300000000HVX0
069Z01D0069Z0P000006001GCP0400000000GB/005d[0000008004/D00<000000=WIf@3IfMT08@3I
fMT2000003l0fMWI000o0=WIf@030000003IfMT0fMWI0240fMWI00<00000000<500031@00P0031@0
0`00000000`g000<=`05000<=`03000000005fh001M^01X001M^0`000005000VQP0300000000@8X0
042:02H0042:00<000000010RP00@8X00`00@8X00`00000005N9001GR@0X001GR@@000006000HVX0
0`00000005M>001GCP03001GCP0400000000GB/005d[0000008004/D00<000000=WIf@3IfMT08@3I
fMT2000003l0fMWI000n0=WIf@030000003IfMT0fMWI0280fMWI00<00000000<500031@00P0031@0
0`00000000`g000<=`04000<=`8000006P005fh2000000P002J600<000000010RP00@8X09P00@8X0
0`000000042:0010RP030010RP0300000000EhT005N902X005N900@00000001/P`00000000005`00
HVX2000000<005M>00H00000001M:`00GB/005d[00000000Ba@2000002<0fMWI00<000000=WIf@3I
fMT0?@3IfMT003h0fMWI00<000000=WIf@3IfMT08P3IfMT01@00000000`D000<500031@0000000H0
00`g00<00000000<E`00000060005fh2000000/002J600<000000010RP00@8X09@00@8X00`000000
042:0010RP030010RP0300000000EhT005N902X005N900D00000001/P`00K8<006b30000000H001R
JP80000000<005M>00000000GB/00P00GB/01000000004/D001;5000000S0=WIf@030000003IfMT0
fMWI03d0fMWI001R0=WIf@050000000031@000`D000<500000001P0033L01@00000000aG000<E`00
35L0000001D001M^0P00000=000VQP0300000000@8X0042:02/0042:00<00000001GR@00EhT0:P00
EhT00`00000006b3001/P`02001/P`8000006000HVX2000000@005d[00<00000001;50000000903I
fMT00`000000fMWI0=WIf@0l0=WIf@00HP3IfMT01@00000000`D000<500031@0000000H000`g00D0
0000000<E`0035L000aG0000000C000GKP8000003`009XH00`000000042:0010RP0[0010RP030000
0000EhT005N902X005N900<00000001/P`00K8<01000K8<2000001L0069Z00<00000001M:`00GB/0
0P00GB/01000000004/D001;5000000R0=WIf@800000?P3IfMT00680fMWI00@00000000<500031@0
00001P0033L00`00000000aG000<E`02000<E`03000000005fh001M^00h001M^0`00000A000VQP03
00000000@8X0042:02/0042:00<00000001GR@00EhT0:@00EhT00`00000006b3001/P`07001/P`03
00000000HVX0069Z01@0069Z00<00000001M:`00GB/00`00GB/00`00000004/D0000000S0=WIf@03
0000003IfMT0fMWI03`0fMWI000m0=WIf@030000003IfMT0fMWI0280fMWI00<00000000<50000000
1P0033L00`00000000aG000<E`03000<E`03000000005fh001M^00`001M^0P00000D000VQP030000
0000@8X0042:02D0042:00<000000010RP00@8X00`00@8X00`00000005N9001GR@0Y001GR@030000
0000K8<006b300P006b30P00000D001RJP8000001000GB/01000000004/D001;5000000R0=WIf@80
0000?@3IfMT003d0fMWI00<000000=WIf@3IfMT08P3IfMT2000000L000`g00<00000000<E`0035L0
0`0035L00`00000001M^000GKP0:000GKP8000005P009XH00`000000042:0010RP0U0010RP030000
0000@8X0042:00<0042:00<00000001GR@00EhT0:@00EhT00`00000006b3001/P`0:001/P`800000
4P00HVX2000000D005d[00<00000001;500000008P3IfMT2000003d0fMWI000m0=WIf@030000003I
fMT0fMWI0240fMWI00<00000000<500000001P0033L00`00000000aG000<E`04000<E`0300000000
5fh001M^00P001M^0P00000H000VQP0300000000@8X0042:02D0042:00<000000010RP00@8X00`00
@8X00`00000005N9001GR@0Y001GR@0300000000K8<006b300`006b30P00000@001RJP0300000000
K4d0000000@005d[00<00000001;500000008`3IfMT00`000000fMWI0=WIf@0N0=WIf@H000005`3I
fMT003`0fMWI00<000000=WIf@3IfMT08P3IfMT2000000H000`g00<00000000<E`0035L01@0035L0
0`00000001M^000GKP06000GKP8000006P009XH00`000000042:0010RP0U0010RP0300000000@8X0
000000L00000:000EhT00`00000006b3001/P`0>001/P`0300000000HVX0069Z00d0069Z00<00000
001/C@0000001@00GB/00`00000004/D0000000R0=WIf@030000003IfMT0fMWI01h0fMWI00<00000
0=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@0E0=WIf@00?03IfMT00`000000fMWI0=WIf@0R0=WI
f@030000000033L000`g00@000`g00<00000000<E`0035L01`0035L00`00000001M^000GKP02000G
KP<0000070009XH00`000000042:0010RP0N0010RPT000001000Bid01000000005nM001OW@00Gid5
000002<005N900<00000001/P`00K8<03`00K8<2000000d0069Z00@00000001/C@00K4d000001000
GB/00`00000004/D0000000S0=WIf@030000003IfMT0fMWI01h0fMWI00<000000=WIf@3IfMT06@3I
fMT00640fMWI00<00000000<=`0033L0100033L00`00000000aG000<E`07000<E`03000000005fh0
01M^0080000080009XH00`000000042:0010RP0D0010RPT000003@00Bid00`00000005nM001OW@06
001OW@D000007P00EhT00`00000006b3001/P`0A001/P`8000002`00HVX01000000006a=001/C@00
0004001M:`0300000000Ba@000000280fMWI0P00000Q0=WIf@030000003IfMT0fMWI01P0fMWI001Q
0=WIf@030000000033L000`g00<000`g00<00000000<E`0035L0200035L30000028002J600<00000
0010RP00@8X02`00@8X9000001H004^M00<00000001OW@00Gid02`00Gid6000001P005N900<00000
001/P`00K8<04`00K8<2000000P0069Z00<00000001/C@00K4d00P00K4d00`00000005d[001M:`02
001M:`8000008`3IfMT00`000000fMWI0=WIf@0P0=WIf@030000003IfMT0fMWI01L0fMWI000k0=WI
f@030000003IfMT0fMWI02<0fMWI00<00000000<=`0033L00P0033L00`00000000aG000<E`09000<
E`03000000009XH002J6028002J600<000000010RP00@8X00P00@8X9000001l004^M00<00000001O
W@00Gid04@00Gid5000001<005N900<00000001/P`00K8<05@00K8<00`000000069Z001RJP05001R
JP0300000000K4d006a=008006a=00<00000001M:`00GB/00P00GB/2000002@0fMWI00<000000=WI
f@3IfMT0803IfMT00`000000fMWI0=WIf@0F0=WIf@00>`3IfMT00`000000fMWI0=WIf@0S0=WIf@05
0000000033L000`g000<=`000000300035L00`00000002J6000VQP0Q000VQPH000008P00Bid00`00
000004^M001;W@03001;W@0300000000Gid005nM01H005nM1P00000<001GR@0300000000K8<006b3
01L006b30P000005001RJP0300000000K4d006a=00<006a=00<00000001M:`00GB/00P00GB/20000
02<0fMWI00<000000=WIf@3IfMT0703IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI
01D0fMWI000k0=WIf@030000003IfMT0fMWI02<0fMWI00D00000000<=`0033L000`g0000000;000<
E`80000080009XH300000003000dV`00000004^M02D004^M00<00000001;W@00Bid00`00Bid00`00
000005nM001OW@0L001OW@D000001`00EhT00`00000006b3001/P`0I001/P`8000000`00HVX00`00
000006a=001/C@03001/C@0300000000GB/005d[008005d[0P00000S0=WIf@030000003IfMT0fMWI
01`0fMWI1P00000G0=WIf@00>P3IfMT00`000000fMWI0=WIf@0S0=WIf@050000000033L000`g000<
=`0000002`0035L01000000000ae000<M@00000M000VQP8000001000=9/00`00000004^M001;W@0T
001;W@0300000000Bid004^M00<004^M00<00000001OW@00Gid08@00Gid50000008005N900<00000
001/P`00K8<06`00K8<010000000069Z001RJP000006001/C@0300000000GB/005d[008005d[00<0
00000=WIf@3IfMT08@3IfMT2000003X0fMWI000j0=WIf@030000003IfMT0fMWI02<0fMWI00@00000
000<=`0033L000002`0035L01@00000000ae000<M@0037D0000001/002J60P000007000dV`030000
0000Bid004^M02<004^M00<00000001;W@00Bid00`00Bid00`00000005nM001OW@0V001OW@@00000
7@00K8<3000000H006a=00<00000001M:`00GB/00P00GB/00`000000fMWI0=WIf@0R0=WIf@030000
003IfMT0fMWI03P0fMWI001P0=WIf@040000000033L000`g000000/000aG00D00000000<M@0037D0
00ae0000000H000VQP<000002@00=9/00`00000004^M001;W@0S001;W@0300000000Bid004^M00<0
04^M00<00000001OW@00Gid0:000Gid01000000007>J00000000000M001/P`0300000000K4d006a=
00@006a=00<00000001M:`00GB/00P00GB/00`000000fMWI0=WIf@0Q0=WIf@800000203IfMT30000
02l0fMWI001P0=WIf@030000000033L0000000/000aG00<00000000<M@0037D00P0037D00`000000
02J6000VQP0D000VQP8000003000=9/00`00000004^M001;W@0Y001;W@0300000000Gid005nM02P0
05nM00@00000001cVP00LiX007>J0P00000K001/P`0300000000K4d006a=00D006a=00D00000001M
:`00GB/005d[0000000T0=WIf@030000003IfMT0fMWI00D0fMWI00D000000=WIf@3IfMT0fMWI0000
000^0=WIf@00>@3IfMT00`000000fMWI0=WIf@0T0=WIf@8000002`0035L00`00000000ae000<M@04
000<M@03000000009XH002J6014002J60P00000>000dV`0300000000Bid004^M02P004^M00<00000
001OW@00Gid0:000Gid00`00000007>J001cVP04001cVP8000006@00K8<2000000H006a=00D00000
001M:`00GB/005d[0000000U0=WIf@030000003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI
0000000^0=WIf@00>@3IfMT00`000000fMWI0=WIf@0T0=WIf@030000000035L000aG00T000aG00<0
0000000<M@0037D01@0037D00`00000002J6000VQP0>000VQP<000004000=9/00`00000004^M001;
W@0S001;W@0300000000Bid004^M008004^M00<00000001OW@00Gid0:000Gid00`00000007>J001c
VP06001cVP8000005P00K8<00`00000007Q]00000007001/C@0400000000GB/005d[000002D0fMWI
00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000002h0fMWI000i0=WIf@030000
003IfMT0fMWI02@0fMWI00<00000000<E`0035L02@0035L00`00000000ae000<M@05000<M@030000
00009XH002J600`002J60P00000D000dV`0300000000Bid004^M028004^M00<00000001;W@00Bid0
0P00Bid00`00000005nM001OW@0X001OW@0300000000LiX007>J00P007>J0P00000D001/P`040000
0000N6d007Q]000000H006a=00@00000001M:`00GB/000009@3IfMT00`000000fMWI0=WIf@040=WI
f@050000003IfMT0fMWI0=WIf@000000;P3IfMT003P0fMWI00<000000=WIf@3IfMT09@3IfMT00`00
000000aG000<E`08000<E`030000000037D000ae00L000ae00<00000000VQP009XH02@009XH20000
01H003BK00<00000001;W@00Bid08P00Bid00`00000004^M001;W@02001;W@0300000000Gid005nM
02L005nM00<00000001cVP00LiX02`00LiX20000018006b300@00000001hK@00N6d000001`00K4d0
0`00000005d[0000000U0=WIf@8000001@3IfMT01@000000fMWI0=WIf@3IfMT0000002h0fMWI000h
0=WIf@030000003IfMT0fMWI02D0fMWI00<00000000<E`0035L01`0035L00`00000000ae000<M@08
000<M@03000000009XH002J600H002J60`00000H000dV`0300000000Bid004^M028004^M00<00000
001;W@00Bid00P00Bid00`00000005nM001OW@0W001OW@0300000000LiX007>J00d007>J0P00000?
001/P`0300000000N6d007Q]008007Q]00<00000001/C@00K4d01000K4d00`00000005d[0000000V
0=WIf@030000003IfMT0fMWI00<0fMWI00D000000=WIf@3IfMT0fMWI0000000^0=WIf@00H03IfMT0
0`0032T00000000<E`06000<E`030000000037D000ae00T000ae00<00000000VQP009XH010009XH2
000001/003BK00<00000001;W@00Bid08P00Bid00`00000004^M001;W@02001;W@0300000000Gid0
05nM02L005nM00<00000001cVP00LiX03`00LiX00`00000006b3001/P`0<001/P`0300000000N6d0
07Q]008007Q]00<00000001/C@00K4d01@00K4d2000002D0fMWI0P0000060=WIf@<00000;`3IfMT0
0640fMWI00<00000000<E`0035L0100035L00`00000000ae000<M@0:000<M@03000000009XH002J6
008002J60P00000M000dV`0300000000Bid004^M02L004^M00<00000001OW@00Gid09`00Gid00`00
000007>J001cVP0@001cVP8000003000K8<00`00000007Q]001hK@03001hK@0300000000K4d006a=
00@006a=0P00000T0=WIf@030000003IfMT0000003P0fMWI001Q0=WIf@030000000035L000aG00@0
00aG00<00000000<M@0037D02`0037D40000020003BK00<00000001;W@00Bid08000Bid3000000<0
04^M00<00000001OW@00Gid09P00Gid00`00000007>J001cVP0C001cVP8000002P00K8<00`000000
07Q]001hK@03001hK@0300000000K4d006a=00D006a=00<000000=WIf@3IfMT09@3IfMT00`000000
fMWI0=WIf@0e0=WIf@00=`3IfMT00`000000fMWI0=WIf@0W0=WIf@030000000035L000aG00<000aG
00<00000000<M@0037D0300037D00`00000003BK000dV`0Q000dV`0300000000Bid004^M01h004^M
0P000003001;W@0400000000Bid004^M000002P005nM00<00000001cVP00LiX05@00LiX2000000L0
06b300<00000001hK@00N6d01@00N6d00`00000006a=001/C@04001/C@030000003IfMT0fMWI02D0
fMWI00<000000=WIf@3IfMT0=@3IfMT003L0fMWI00<000000=WIf@3IfMT09`3IfMT00`00000000aG
000<E`02000<E`030000000037D000ae00d000ae00<00000000dV`00=9/08@00=9/00`00000004^M
001;W@0M001;W@0400000000Bid004^M001;W@T000009@00Gid00`00000007>J001cVP0G001cVP80
00001@00K8<00`00000007Q]001hK@06001hK@0300000000K4d006a=00<006a=00<000000=WIf@3I
fMT09@3IfMT00`000000fMWI0=WIf@0e0=WIf@00=P3IfMT00`000000fMWI0=WIf@0X0=WIf@050000
000035L000aG000<E`0000003`0037D00`00000001R@0000000R000dV`0300000000Bid004^M01L0
04^M2P000005001E/0<0000000<006R`0000000000001@00000N001OW@0300000000LiX007>J01T0
07>J0P000003001/P`0300000000N6d007Q]00H007Q]00<00000001/C@00K4d00`00K4d00`000000
fMWI0=WIf@0U0=WIf@800000=P3IfMT003H0fMWI00<000000=WIf@3IfMT0:03IfMT01@00000000aG
000<E`0035L0000000h000ae00@00000000HT000690000008P00=9/00`00000004^M001;W@0=001;
W@X0000000<005F`00000000EK003000EK000`00000006R`001X/002000000H006R`1P00000G001O
W@0300000000LiX007>J01`007>J0`00000:001hK@0300000000K4d006a=008006a=00<000000=WI
f@3IfMT09P3IfMT00`000000fMWI0=WIf@0d0=WIf@00H@3IfMT0100032T00000000<E`00000>000<
M@0500000000690001R@000HT00000008`00=9/00`00000004^M001;W@02001;W@X000002P00EK00
0`00000005F`001E/00<001E/00300000000J;0006R`008006R`00<00000001X/000J;002@00J;07
0000010005nM00<00000001cVP00LiX07P00LiX00`00000007Q]001hK@08001hK@0300000000K4d0
06a=008006a=00<000000=WIf@3IfMT09P3IfMT00`000000fMWI0=WIf@0d0=WIf@00H@3IfMT00`00
32T000000000000>000<M@0300000000690001R@00<001R@00<00000000dV`00=9/07`00=9/60000
02<005F`00<00000001X/000J;005@00J;06000000X005nM00<00000001cVP00LiX07P00LiX00`00
000007Q]001hK@09001hK@0500000000K4d006a=001/C@0000009`3IfMT2000003H0fMWI001R0=WI
f@030000000037D000ae00`000ae00<00000000HT0006900100069000`00000003BK000dV`0L000d
V`<0000000<004:`00000000EK004`00EK020000014005F`00<00000001X/000J;001@00J;020000
01@006R`1`000002001OW@0300000000LiX007>J01h007>J00<000000021R`0000002P00N6d01000
000006a=001/C@00000Z0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI
02/0fMWI00<00000000<M@0037D0300037D00`00000001R@000HT004000HT00300000000=9/003BK
01X003BK0P0000040012/00300000000EK0005F`010005F`0P00000C001E/00300000000J;0006R`
00L006R`00<00000001X/000J;006000J;04000001l007>J00<000000021R`0000002`00N6d00`00
000006a=0000000Z0=WIf@030000003IfMT0fMWI03<0fMWI000d0=WIf@030000003IfMT0fMWI02/0
fMWI00<00000000<M@0037D02`0037D00`00000001R@000HT006000HT00300000000=9/003BK01H0
03BK0`0000070012/00300000000EK0005F`00h005F`00<00000001E/000EK004`00EK000`000000
06R`001X/008001X/00300000000J;0006R`01T006R`00@00000001j[`00000000007000LiX01@00
0000086;0021R`00PH/0000000X007Q]00<00000001/C@000000:P3IfMT00`000000fMWI0=WIf@0c
0=WIf@00=03IfMT00`000000fMWI0=WIf@0[0=WIf@03000<C@00000000ae00X000ae00<00000000H
T00069001`0069000`00000003BK000dV`0C000dV`<000002P00@[000`00000005F`001E/00T001E
/00300000000J;0006R`02<006R`00<00000001j[`00NZl00P00NZl2000001X007>J00<000000021
R`00PH/00P00PH/00`00000007Q]001hK@08001hK@800000:P3IfMT2000003@0fMWI000c0=WIf@03
0000003IfMT0fMWI02`0fMWI0P00000:000<M@0300000000690001R@00P001R@00<00000000dV`00
=9/04@00=9/2000000d004:`00<00000001E/000EK002P00EK02000001P005F`00<00000001X/000
J;002`00J;02000001H006R`00<00000001j[`00NZl01000NZl2000001P007>J00<000000021R`00
PH/00P00PH/00`00000007Q]001hK@08001hK@800000:`3IfMT00`000000fMWI0=WIf@0b0=WIf@00
<`3IfMT00`000000fMWI0=WIf@0/0=WIf@8000002@0037D00`00000001R@000HT00:000HT0030000
0000=9/003BK00d003BK0`00000?0012/00300000000EK0005F`00T005F`00<00000001E/000EK00
6000EK000`00000006R`001X/00=001X/08000005000J;000`00000007Z_001j[`06001j[`800000
5@00LiX00`000000086;0021R`040021R`0300000000N6d007Q]00P007Q]00<000000=WIf@3IfMT0
:@3IfMT00`000000fMWI0=WIf@0b0=WIf@00HP3IfMT00`0032T000a=00000007000<M@0300000000
690001R@00/001R@00<00000000dV`00=9/02`00=9/2000001<004:`00<00000001E/000EK001`00
EK000`00000005F`001E/00I001E/00300000000J;0006R`00l006R`00<00000001X/000J;004000
J;000`00000007Z_001j[`09001j[`8000004`00LiX00`000000086;0021R`040021R`0300000000
N6d007Q]00P007Q]00<000000=WIf@3IfMT0:@3IfMT00`000000fMWI0=WIf@0b0=WIf@00HP3IfMT0
0`0032T000a=00000006000<M@0300000000690001R@00`001R@00<00000000dV`00=9/02000=9/3
000001D004:`00<00000001E/000EK008P00EK000`00000006R`001X/00S001X/00300000000NZl0
07Z_00/007Z_0`00000?001cVP0300000000PH/0086;00H0086;00<00000001hK@00N6d01P00N6d0
0`000000fMWI0=WIf@0Y0=WIf@030000003IfMT0000003<0fMWI000b0=WIf@030000003IfMT0fMWI
02d0fMWI00<000`Y000<C@0000001P0037D00`00000001R@000HT00=000HT00300000000=9/003BK
00@003BK0`00000H0012/00300000000EK0005F`008005F`0P00000N001E/00300000000J;0006R`
01<006R`0P00000>001X/00300000000NZl007Z_00h007Z_0P00000=001cVP0300000000PH/0086;
00L0086;00<00000001hK@00N6d01@00N6d00`000000fMWI0=WIf@0[0=WIf@030000003IfMT0fMWI
0340fMWI000b0=WIf@030000003IfMT0fMWI02h0fMWI00<00000000<C@000000100037D00`000000
01R@000HT00>000HT00300000000=9/003BK008003BK0P00000K0012/00500000000EK0005F`001E
/00000008000EK000`00000006R`001X/00E001X/00300000000J;0006R`00X006R`00<00000001j
[`00NZl04@00NZl2000000X007>J00<000000021R`00PH/02000PH/00`00000007Q]001hK@05001h
K@030000003IfMT0fMWI02/0fMWI00<000000=WIf@3IfMT0<@3IfMT00380fMWI00<000000=WIf@3I
fMT0;P3IfMT00`00000000a=00000003000<M@0300000000690001R@00l001R@00<00000000dV`00
00000P00000N0012/00300000000EK000000024005F`00<00000001X/000J;005P00J;000`000000
06R`001X/009001X/00300000000NZl007Z_01<007Z_0P000008001cVP0300000000PH/0086;00T0
086;00<00000001hK@00N6d00`00N6d00`000000fMWI0=WIf@0/0=WIf@030000003IfMT0fMWI0340
fMWI000a0=WIf@030000003IfMT0fMWI02l0fMWI00<00000000<C@0000000P0037D00`00000001R@
000HT00A000HT00300000000@[0004:`01d004:`0`00000S001E/00300000000J;0006R`01X006R`
0P000006001X/00300000000NZl007Z_01D007Z_0P000006001cVP0300000000PH/0086;00T0086;
00<00000001hK@00N6d00`00N6d00`000000fMWI0=WIf@0]0=WIf@030000003IfMT0fMWI0300fMWI
000a0=WIf@030000003IfMT0fMWI02l0fMWI00<00000000<C@0034d00P00000D000HT00300000000
@[0004:`01`004:`00@000000012/000@[0000008`00EK000`00000006R`001X/00L001X/0030000
0000J;0006R`008006R`00<00000001j[`00NZl06000NZl2000000<007>J00<000000021R`00PH/0
2`00PH/00`00000007Q]001hK@02001hK@030000003IfMT0fMWI02d0fMWI00<000000=WIf@3IfMT0
<03IfMT006<0fMWI00@00000000<C@0034d00000500069000`00000002bZ0000000L0012/0050000
0000@[0004:`0012/00000008`00EK000`00000006R`001X/00M001X/00500000000J;0006R`001X
/00000007000NZl200000003001cVP000000086;00`0086;00D00000001hK@00N6d007Q]0000000`
0=WIf@030000003IfMT0fMWI0300fMWI001S0=WIf@040000000034d000a=000001<001R@00@00000
000/ZP00;:X000008000@[000`00000005F`001E/00Q001E/00300000000J;0006R`024006R`00<0
0000001j[`00NZl07000NZl00`000000086;0021R`0=0021R`0400000000N6d007Q]00000300fMWI
0P00000a0=WIf@00H`3IfMT01@00000000a=000<C@0037400000014001R@00<00000000/ZP00;:X0
0P00;:X00`00000004:`0012/00D0012/08000002000@[000`00000005F`001E/00P001E/0030000
0000J;0006R`020006R`0P00000N001j[`0300000000PH/0086;00h0086;00<00000001hK@000000
;`3IfMT00`000000fMWI0000000a0=WIf@00<03IfMT00`000000fMWI0=WIf@0`0=WIf@03000<:@00
000000a=00800000400069000`00000002bZ000/ZP04000/ZP0300000000@[0004:`018004:`00<0
00000012/000@[002000@[000`00000005F`001E/00P001E/00300000000J;0006R`020006R`00<0
0000001j[`0000007000NZl00`00000008RV0000000?0021R`800000<P3IfMT00`000000fMWI0=WI
f@0_0=WIf@00<03IfMT00`000000fMWI0=WIf@0a0=WIf@050000000034d00000000<L@0000003P00
69000`00000002bZ000/ZP05000/ZP0300000000@[0004:`014004:`00<000000012/000@[002@00
@[000`00000005F`001E/00J001E/0X000007`00J;001000000007Z_001j[`00000K001j[`040000
0000R:H008RV000000l0086;00<000000=WIf@3IfMT0<03IfMT00`000000fMWI0=WIf@0_0=WIf@00
;`3IfMT00`000000fMWI0=WIf@0b0=WIf@050000000034d000a=000<L@0000003@0069000`000000
02bZ000/ZP07000/ZP0300000000@[0004:`01`004:`00<00000001E/000EK003`00EK0;000000H0
067400@00000001`a@00L<D007351`00000G001X/00300000000NZl007Z_01`007Z_00D000000028
YP00R:H008RV0000000?0021R`030000003IfMT0fMWI0340fMWI00<000000=WIf@3IfMT0;P3IfMT0
02l0fMWI00<000000=WIf@3IfMT0<P3IfMT00`00000000a=000<C@02000<L@0300000000690001R@
00T001R@00<00000000/ZP00;:X02000;:X00`00000004:`0012/00<0012/08000003`00@[000`00
000005F`001E/003001E/0/000004@00HL@00`0000000735001`a@08001`a@L000004000J;000`00
000007Z_001j[`05001j[`8000005000NZl00`00000008RV0028YP030028YP0300000000PH/0086;
00/0086;00<000000=WIf@3IfMT0<P3IfMT00`000000fMWI0=WIf@0^0=WIf@00I03IfMT01P000000
00a=000<C@00000000aa000000X001R@00<00000000/ZP00;:X02P00;:X00`00000004:`0012/009
0012/08000004000@[07000001`0067400<00000001`a@00L<D03`00L<D6000000X006R`00<00000
001j[`00NZl01`00NZl00`00000007Z_001j[`0A001j[`0300000000R:H008RV00@008RV00<00000
0021R`00PH/02P00PH/00`000000fMWI0=WIf@0b0=WIf@030000003IfMT0fMWI02h0fMWI001T0=WI
f@040000000034d000a=0000008000aa00<00000000HT00069001P0069000`00000002bZ000/ZP0;
000/ZP0300000000@[0004:`00P004:`00<000000012/000@[003@00@[0300000003001Aa@000000
06740200067400<00000001`a@00L<D05@00L<D70000008006R`00<00000001j[`00NZl02@00NZl0
0`00000007Z_001j[`0?001j[`0300000000R:H008RV00D008RV00<000000021R`00PH/02@00PH/2
000003D0fMWI00<000000=WIf@3IfMT0;@3IfMT006D0fMWI00<00000000<C@0000000P0037400`00
000001R@000HT005000HT00300000000;:X002bZ00d002bZ00<000000012/000@[005000@[030000
00D0057500<00000001Qa000HL@07P00HL@00`0000000735001`a@0L001`a@@000007000NZl00`00
000008RV0028YP060028YP0300000000PH/0086;00P0086;00<000000=WIf@3IfMT0=03IfMT00`00
0000fMWI0=WIf@0]0=WIf@00;P3IfMT00`000000fMWI0=WIf@0d0=WIf@030000000034d0000000<0
00aa00<00000000HT00069000`0069000`00000002bZ000/ZP0>000/ZP0300000000@[0004:`00<0
04:`0P00000<0012/0<000002000DLD00`0000000674001Qa00N001Qa00300000000L<D0073501h0
073500<00000001oa00000000P00000:001j[`8000003000NZl00`00000008RV0028YP080028YP03
00000000PH/0086;00H0086;0P00000e0=WIf@800000;`3IfMT002h0fMWI00<000000=WIf@3IfMT0
=03IfMT00`00000000a=00000003000<L@0300000000690001R@008001R@00<00000000/ZP00;:X0
4000;:X01@00000004:`0012/000@[00000000/004:`0`00000;001Aa@0300000000HL@0067401h0
067400<00000001`a@00L<D07@00L<D00`00000007o4001oa003001oa08000002P00NZl2000000X0
07Z_00<000000028YP00R:H02000R:H00`000000086;0021R`060021R`800000=P3IfMT00`000000
fMWI0=WIf@0]0=WIf@00;P3IfMT00`000000fMWI0=WIf@0e0=WIf@800000100037401000000001R@
000HT000000D000/ZP0300000000@[00000000T004:`0`00000?001Aa@0300000000HL@0067401d0
067400<00000001`a@00L<D07@00L<D00`00000007o4001oa005001oa08000002P00NZl00`000000
07Z_001j[`06001j[`0300000000R:H008RV00X008RV00<000000021R`00PH/01000PH/2000003P0
fMWI00<000000=WIf@3IfMT01P3IfMT3000000<0fMWI00@000000=WIf@3IfMT0fMWI0`00000I0=WI
f@00;@3IfMT00`000000fMWI0=WIf@0f0=WIf@800000100037400`00000001R@0000000E000/ZP03
00000000@[0004:`00H004:`0`00000B001Aa@0300000000HL@0067401d0067400<00000001`a@00
L<D07000L<D00`00000007o4001oa008001oa0<000004000NZl00`00000008RV0028YP0:0028YP03
00000000PH/0086;00@0086;0P00000h0=WIf@030000003IfMT0fMWI00D0fMWI00D000000=WIf@3I
fMT0fMWI000000050=WIf@050000003IfMT0fMWI0=WIf@000000603IfMT002d0fMWI00<000000=WI
f@3IfMT0=P3IfMT00`00000000a=00000004000<L@0300000000;:X002bZ014002bZ0P000002000/
ZP0300000000@[0004:`008004:`0`00000E001Aa@0300000000HL@0067401d0067400<00000001`
a@00L<D07000L<D00`00000007o4001oa00;001oa08000002000NZl30000008007Z_00<000000028
YP00R:H03000R:H00`000000086;0021R`020021R`0300000000Mf@0000003P0fMWI00<000000=WI
f@3IfMT01@3IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT05P3IfMT0
06L0fMWI00<000a=0000000037400`0037400`00000002bZ000/ZP0?000/ZP8000001000;:X00`00
000004:`00000002000001T0057500<00000001Qa000HL@07000HL@00`0000000735001`a@0L001`
a@0300000000Ol@007o400d007o40`000008001j[`8000004000R:H010000000086;0021R`00PH/2
000003X0fMWI00<000000=WIf@3IfMT0103IfMT01@000000fMWI0=WIf@3IfMT0000000T0fMWI00<0
00000=WIf@3IfMT05P3IfMT006L0fMWI0P000004000<L@8000005P00;:X2000001`0057500<00000
001Qa000HL@07000HL@00`0000000735001`a@0K001`a@0300000000Ol@007o4014007o40P000007
001j[`0300000000R:H008RV00h008RV00H000000021R`00PH/00000001gI000000j0=WIf@030000
003IfMT0fMWI00@0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@@000006@3IfMT002`0fMWI
00<000000=WIf@3IfMT0>03IfMT2000000@000aa00<00000000CT`0000002`00;:X2000000L002bZ
00<000000011`P0000007000DLD00`0000000674001Qa00K001Qa00300000000L<D0073501`00735
00<00000001oa000Ol@04`00Ol@2000000@007Z_00<000000028YP00R:H00P00000>0028YP050000
0000PH/00000001gI0000000>P3IfMT00`000000fMWI0=WIf@040=WIf@050000003IfMT0fMWI0=WI
f@0000001@3IfMT00`000000fMWI0=WIf@0J0=WIf@00;03IfMT00`000000fMWI0=WIf@0i0=WIf@03
00000000374000aa008000aa00@00000000CT`004i<000002@00;:X00`00000002bZ000/ZP06000/
ZP0500000000@L8004720011`P0000007000DLD00`0000000674001Qa00J001Qa00300000000L<D0
073501/0073500<00000001oa000Ol@05P00Ol@300000003001j[`00000008RV00<008RV0P00000=
0028YP0300000000Mf@0000003/0fMWI0P0000050=WIf@050000003IfMT0fMWI0=WIf@0000001@3I
fMT00`000000fMWI0=WIf@0J0=WIf@00;03IfMT00`000000fMWI0=WIf@0i0=WIf@03000000003740
00aa008000aa00@00000000CT`004i<000002000;:X00`00000002bZ000/ZP06000/ZP0300000000
@L80047200<0047200<00000001Aa@00DLD06@00DLD00`0000000674001Qa00J001Qa00300000000
L<D0073501/0073500<00000001oa000Ol@06@00Ol@00`00000008RV0028YP050028YP0300000000
R:H008RV00X008RV00<00000001gI0000000>@3IfMT4000000H0fMWI0`0000060=WIf@D00000603I
fMT002/0fMWI00<000000=WIf@3IfMT0>`3IfMT01@00000000aa000<L@003740000000<001>C00<0
0000000/ZP00;:X03@00;:X00`00000004720011`P050011`P0300000000DLD0057501P0057500<0
0000001Qa000HL@06P00HL@00`0000000735001`a@0J001`a@0300000000Ol@007o401X007o400<0
00000028YP00R:H04@00R:H01000000007MT001gI000000l0=WIf@030000003IfMT0fMWI02X0fMWI
000[0=WIf@030000003IfMT0fMWI03/0fMWI00D00000000<L@00374000aa00000004000CT`040000
0000;:X00000000000X002bZ00<000000011`P00@L801P00@L800`0000000575001Aa@0I001Aa@03
00000000HL@0067401T0067400<00000001`a@00L<D06P00L<D00`00000007o4001oa00I001oa003
00000000Rkl0000000T008RV0P0000060028YP80000000<007MT0000003IfMT0?03IfMT00`000000
fMWI0=WIf@0Z0=WIf@00JP3IfMT01000000000aa000<L@000005000CT`0300000000;:X002bZ00T0
02bZ00<000000011`P00@L802000@L800`0000000575001Aa@0H001Aa@0300000000HL@0067401T0
067400<00000001`a@00L<D06P00L<D00`00000007o4001oa00H001oa00500000000Rkl008^o002;
_`0000002P00R:H00`00000008RV0028YP020028YP0500000000PhT00000001gI0000000?P3IfMT0
0`000000fMWI0=WIf@0Y0=WIf@00JP3IfMT01@00000000aa000<L@003740000000<001>C0P00000:
000/ZP0300000000@L80047200X0047200<00000001Aa@00DLD05`00DLD00`0000000674001Qa00I
001Qa00300000000L<D0073501T0073500<00000001oa000Ol@06000Ol@00`00000008^o002;_`03
002;_`0300000000R:H008RV00P008RV00H000000028YP00R:H000000023R@000002001gI0030000
003IfMT0fMWI03`0fMWI00<000000=WIf@3IfMT0:@3IfMT002X0fMWI00<000000=WIf@3IfMT0?P3I
fMT01000000000aa000<L@000005000CT`0300000000;:X002bZ00H002bZ00<000000011`P00@L80
2`00@L800`0000000575001Aa@0H001Aa@0300000000HL@0067401P0067400<00000001`a@00L<D0
6@00L<D00`00000007o4001oa00G001oa00300000000Rkl008^o00@008^o00<000000028YP00R:H0
2`00R:H01@00000008>900000000Mf@0000003l0fMWI00<000000=WIf@3IfMT0:@3IfMT002X0fMWI
00<000000=WIf@3IfMT0?P3IfMT00`00000000aa000<L@02000000D001>C00<00000000/ZP00;:X0
1000;:X00`00000004720011`P0=0011`P0300000000DLD0057501L0057500<00000001Qa000HL@0
6000HL@00`0000000735001`a@0H001`a@0300000000Ol@007o401L007o400<00000002;_`00Rkl0
1P00Rkl00`00000008RV0028YP090028YP0600000000PhT0000000000000Mf@00000?`3IfMT00`00
0000fMWI0=WIf@0Y0=WIf@00:P3IfMT00`000000fMWI0=WIf@0o0=WIf@<000001P004i<00`000000
02bZ000/ZP03000/ZP0300000000@L80047200l0047200<00000001Aa@00DLD05P00DLD00`000000
0674001Qa00H001Qa00300000000L<D0073501P0073500<00000001oa000Ol@05P00Ol@00`000000
08^o002;_`08002;_`0300000000R:H008RV00L008RV00H000000023R@00PhT00000001gI0000010
0=WIf@800000:P3IfMT002T0fMWI00<000000=WIf@3IfMT0?`3IfMT200000003000<L@00000001>C
00H001>C00D00000000/ZP00;:X002bZ0000000C0011`P0300000000DLD0057501H0057500<00000
001Qa000HL@05`00HL@00`0000000735001`a@0G001`a@0300000000Ol@007o401L007o400<00000
002;_`00Rkl02@00Rkl00`00000008RV0028YP050028YP0600000000PhT008>90023R@00000007MT
0P0000100=WIf@030000003IfMT0fMWI02P0fMWI000Y0=WIf@030000003IfMT0fMWI0440fMWI00<0
00aa000000004i<01`004i<00`00000002bZ0000000D0011`P0300000000DLD0057501H0057500<0
0000001Qa000HL@05`00HL@00`0000000735001`a@0G001`a@0300000000Ol@007o401H007o400<0
0000002;_`00Rkl02`00Rkl00`00000008RV0028YP040028YP0400000000PhT008>90023R@800000
@@3IfMT2000002X0fMWI001W0=WIf@800000103IfMT2000000T001>C0P00000E0011`P0300000000
DLD0057501D0057500<00000001Qa000HL@04@00HL@;000001D0073500<00000001oa000Ol@05@00
Ol@00`00000008^o002;_`0<002;_`0300000000R:H008RV00<008RV00@000000023R@00PhT008>9
0P0000050=WIf@800000?@3IfMT00`000000fMWI0=WIf@0W0=WIf@00I@3IfMT2000000L0fMWI00<0
0000000CT`004i<01`004i<2000`]00300000000@L80047201<0047200<00000001Aa@00DLD05@00
DLD00`0000000674001Qa003001Qa0d000001P00LMh00`00000007SN001hgP02001hgPP000003000
L<D00`00000007o4001oa00E001oa00300000000Rkl008^o00h008^o00D000000028YP00R:H008RV
000000040023R@8000001`3IfMT00`000000fMWI0=WIf@0j0=WIf@030000003IfMT0fMWI02L0fMWI
001^0=WIf@03000000004i<001>C00L001>C00@00000000`]000<;@000005000@L800`0000000575
001Aa@0C001Aa@P000004`00LMh00`00000007SN001hgP0:001hgPP000001000L<D00`00000007o4
001oa00D001oa00300000000Rkl008^o010008^o00<000000028YP0000001@00PhT00`000000fMWI
0=WIf@070=WIf@030000003IfMT0fMWI03T0fMWI00<000000=WIf@3IfMT09`3IfMT002P0fMWI00<0
00000=WIf@3IfMT0=P3IfMT2000000`0fMWI00<00000000CT`004i<01P004i<01@000000032d000`
]000<;@0000001@0047200<00000001Aa@00DLD03`00DLD30000008006WN00<00000001agP00LMh0
5P00LMh00`00000007SN001hgP0B001hgPD000005@00Ol@00`00000008^o002;_`0B002;_`030000
0000PhT008>900<008>90P00000=0=WIf@800000=P3IfMT00`000000fMWI0=WIf@0W0=WIf@00:03I
fMT00`000000fMWI0=WIf@0d0=WIf@8000003`3IfMT00`00000001>C000CT`05000CT`0300000000
<;@0032d0080032d00<000000011`P00@L804P00@L800`0000000575001Aa@0;001Aa@<000001P00
JMh00`000000077N001agP0E001agP0300000000N=h007SN01D007SN00<00000001og@0000000P00
000B001oa00300000000Rkl008^o010008^o00<000000029[@0000001@00PhT00`000000fMWI0=WI
f@0>0=WIf@030000003IfMT0fMWI03<0fMWI0P00000X0=WIf@009`3IfMT00`000000fMWI0=WIf@0d
0=WIf@030000003IfMT0fMWI0100fMWI00<00000000CT`004i<010004i<00`000000032d000`]003
000`]00300000000@L8004720180047200<00000001Aa@00DLD01`00DLD3000000X006WN00<00000
001agP00LMh05000LMh00`00000007SN001hgP0D001hgP0300000000Omd007oM00<007oM0P00000?
001oa00300000000Rkl008^o010008^o00@000000029[@00RJd000001@00PhT00`000000fMWI0=WI
f@0?0=WIf@030000003IfMT0fMWI03<0fMWI00<000000=WIf@3IfMT09P3IfMT002L0fMWI00<00000
0=WIf@3IfMT0B03IfMT00`00000001>C000CT`03000CT`0300000000<;@0032d00@0032d00<00000
0011`P00@L804@00@L800`0000000575001Aa@04001Aa@<000003@00JMh00`000000077N001agP0D
001agP0300000000N=h007SN01<007SN00<00000001og@00Omd01P00Omd3000000/007o400<00000
002;_`00Rkl04000Rkl01000000008V]0029[@0000050023R@030000003IfMT0fMWI04H0fMWI00<0
00000=WIf@3IfMT09P3IfMT005X0fMWI0P00000G0=WIf@03000000004i<001>C00<001>C00<00000
000`]000<;@01000<;@00`00000004720011`P0A0011`P0300000000DLD0057500<000004@00JMh0
0`000000077N001agP0B001agP0300000000N=h007SN01<007SN00<00000001og@00Omd02P00Omd2
000000P007o400<00000002;_`00Rkl04000Rkl01@00000008V]0029[@00RJd0000000@008>900<0
00000=WIf@3IfMT0503IfMT200000340fMWI0P00000W0=WIf@00F@3IfMT00`000000fMWI0=WIf@0H
0=WIf@03000000004i<001>C008001>C00<00000000`]000<;@01@00<;@20000014004720`00000D
001YgP0300000000LMh0077N0180077N00<00000001hgP00N=h04`00N=h00`00000007oM001og@0<
001og@8000001@00Ol@00`00000008^o002;_`0?002;_`8000001000RJd01@00000008>90023R@00
PhT0000001T0fMWI0P00000^0=WIf@030000003IfMT0000002L0fMWI001H0=WIf@030000003IfMT0
fMWI01X0fMWI00D00000000CT`004i<001>C00000009000`]00300000000@L80047200d0047200D0
0000001Rg000H]`006;L0000000D001YgP0300000000LMh0077N0140077N00<00000001hgP00N=h0
4P00N=h00`00000007oM001og@0?001og@<0000000<007o400000000Rkl04000Rkl00`00000008V]
0029[@030029[@0500000000PhT008>90023R@000000703IfMT00`000000fMWI0=WIf@0]0=WIf@03
0000003IfMT0fMWI02D0fMWI000V0=WIf@030000003IfMT0fMWI04d0fMWI00@00000000CT`004i<0
00002P00<;@00`00000004720011`P0;0011`P0300000000H]`006;L00<006;L00<00000001YgP00
JMh04P00JMh00`000000077N001agP0@001agP0300000000N=h007SN014007SN00<00000001og@00
Omd04P00Omd20000014008^o00<000000029[@00RJd01000RJd01000000008>90023R@00001=0=WI
f@030000003IfMT0fMWI02D0fMWI000V0=WIf@030000003IfMT0fMWI02X0fMWI0P00000R0=WIf@03
000000004i<0000000/0032d00<000000011`P00@L802000@L82000000L006;L0P00000B001YgP03
00000000LMh0077N0100077N00<00000001hgP00N=h04000N=h00`00000007oM001og@0B001og@03
00000000Pm/00000010008^o00<000000029[@00RJd01@00RJd01000000008>90023R@00000P0=WI
f@800000:`3IfMT2000002H0fMWI000V0=WIf@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3I
fMT08`3IfMT00`004i<00000000`]00;000`]00300000000@L80047200H0047200<00000001Rg000
H]`02@00H]`00`00000006WN001YgP0@001YgP0300000000LMh0077N00l0077N00<00000001hgP00
N=h03`00N=h00`00000007oM001og@0A001og@8000000`00Pm/00`00000008^o002;_`0<002;_`03
00000000RJd008V]00D008V]00@000000023R@00PhT000008`3IfMT00`000000fMWI0=WIf@0Y0=WI
f@030000003IfMT0fMWI02@0fMWI000U0=WIf@030000003IfMT0fMWI02T0fMWI00<000000=WIf@3I
fMT09@3IfMT2000000`0032d00<000000011`P00@L800`00@L82000000d006;L0P00000@001YgP03
00000000LMh0077N00l0077N00<00000001hgP00N=h03`00N=h00`00000007oM001og@0?001og@80
00001P00Pm/00`00000008^o002;_`0:002;_`0300000000RJd008V]00H008V]00<000000023R@00
00009@3IfMT00`000000fMWI0=WIf@0X0=WIf@030000003IfMT0fMWI02@0fMWI000U0=WIf@030000
003IfMT0fMWI0580fMWI0P00000<000`]00500000000@L8004720011`P0000004@00H]`00`000000
06WN001YgP0>001YgP0300000000LMh0077N00h0077N00<00000001hgP00N=h03P00N=h00`000000
07oM001og@0?001og@0300000000Pm/008?K00L008?K00<00000002;_`00Rkl01`00Rkl2000000T0
08V]0P00001B0=WIf@030000003IfMT0fMWI02<0fMWI001=0=WIf@800000;03IfMT3000000/0032d
00<000000011`P0000004`00H]`00`00000006WN001YgP0>001YgP0300000000LMh0077N00d0077N
00<00000001hgP00N=h03@00N=h00`00000007oM001og@0>001og@8000002`00Pm/00`00000008^o
002;_`05002;_`0300000000RJd008V]00P008V]0P00000Z0=WIf@8000009`3IfMT00`000000fMWI
0=WIf@0S0=WIf@00C03IfMT00`000000fMWI0=WIf@0]0=WIf@03000000008YH0000000/0032d0P00
000D001Rg08000003P00JMh00`000000077N001agP0=001agP0300000000N=h007SN00`007SN00<0
0000001og@00Omd03P00Omd00`00000008?K0023f`0<0023f`0300000000Rkl008^o00<008^o00<0
00000029[@00RJd02@00RJd00`000000fMWI0=WIf@0[0=WIf@8000009@3IfMT00`000000fMWI0=WI
f@0S0=WIf@00903IfMT00`000000fMWI0=WIf@0T0=WIf@030000003IfMT0fMWI02l0fMWI00<00000
000RUP0000002P00<;@00`00000005cG00000002000001<006;L00<00000001YgP00JMh03000JMh0
0`000000077N001agP0<001agP0300000000N=h007SN00`007SN00<00000001og@00Omd03000Omd2
0000010008?K00D00000002;_`00Rkl008^o0000000:0029[@030000003IfMT0fMWI02l0fMWI00<0
00000=WIf@3IfMT08@3IfMT2000002D0fMWI000T0=WIf@030000003IfMT0fMWI01l0fMWI0P00000f
0=WIf@04000000008YH00000000000P0032d00<00000001Le`00G=L00P00G=L20000018006;L00<0
0000001YgP00JMh02`00JMh00`000000077N001agP0<001agP0300000000N=h007SN00/007SN00<0
0000001og@00Omd03000Omd00`00000008?K0023f`0A0023f`0300000000Rkl0000000T008V]0P00
001G0=WIf@800000903IfMT002@0fMWI00<000000=WIf@3IfMT07P3IfMT00`000000fMWI0=WIf@0g
0=WIf@04000000008YH002:F000000L0032d00<00000001Le`00G=L01000G=L20000014006;L0P00
000<001YgP0300000000LMh0077N00/0077N00<00000001hgP00N=h02P00N=h00`00000007oM001o
g@0;001og@8000005000Pm/2000000T008V]00<000000=WIf@3IfMT0=@3IfMT3000001l0fMWI0P00
000T0=WIf@008`3IfMT00`000000fMWI0=WIf@0N0=WIf@030000003IfMT0fMWI03T0fMWI00<00000
000RUP008YH00P000005000`]00300000000G=L005cG00H005cG0`00000@001Rg00300000000JMh0
06WN00X006WN00<00000001agP00LMh02@00LMh00`00000007SN001hgP0:001hgP0300000000Omd0
07oM00X007oM0P00000C0023f`<0000000<008?F00000000RJd01P00RJd2000003/0fMWI00<00000
0=WIf@3IfMT07@3IfMT00`000000fMWI0=WIf@0R0=WIf@008`3IfMT00`000000fMWI0=WIf@1K0=WI
f@05000000008YH002:F000RUP0000001000<;@00`00000005cG001Le`09001Le`8000003`00H]`0
0`00000006WN001YgP09001YgP0300000000LMh0077N00T0077N00<00000001hgP00N=h02@00N=h0
0`00000007oM001og@0:001og@0300000000Pm/008?K010008?K0`0000040023eP0300000000RJd0
08V]00@008V]0P00001L0=WIf@8000008`3IfMT00400fMWI0P0000100=WIf@05000000008YH002:F
000RUP0000000`00<;@00`00000005cG001Le`0;001Le`8000003P00H]`2000000X006WN00<00000
001agP00LMh02000LMh00`00000007SN001hgP09001hgP0300000000Omd007oM00P007oM0P00000@
0023f`<000001`00PmH00`00000008V]0029[@030029[@030000003IfMT0fMWI0400fMWI0P00000K
0=WIf@030000003IfMT0fMWI0240fMWI000n0=WIf@800000@`3IfMT01@00000002:F000RUP008YH0
00000080032d00<00000001Le`00G=L03@00G=L3000000d006;L00<00000001YgP00JMh02000JMh0
0`000000077N001agP07001agP0300000000N=h007SN00P007SN00<00000001og@00Omd02000Omd0
0`00000008?K0023f`0>0023f`8000002P00PmH01000000008V]0029[@00RJd2000004D0fMWI00<0
00000=WIf@3IfMT0603IfMT00`000000fMWI0=WIf@0Q0=WIf@00?@3IfMT00`000000fMWI0=WIf@14
0=WIf@8000000`008YH00`00<;@00000001Le`0A001Le`8000003000H]`2000000P006WN00<00000
001agP00LMh01`00LMh00`00000007SN001hgP07001hgP0300000000Omd007oM00L007oM0P00000>
0023f`<000002`00PmH01@00000008V]0029[@00RJd0000004P0fMWI00<000000=WIf@3IfMT05`3I
fMT200000280fMWI000R0=WIf@030000003IfMT0fMWI0640fMWI00@00000000RUP008YH002:F0`00
000B001Le`8000003000H]`00`00000006WN001YgP06001YgP0300000000LMh0077N00H0077N00<0
0000001hgP00N=h01P00N=h00`00000007oM001og@07001og@0300000000Pm/008?K00/008?K0`00
000>0023eP0400000000RJd00000000006@0fMWI00<000000=WIf@3IfMT0803IfMT00280fMWI00<0
00000=WIf@3IfMT0503IfMT2000004`0fMWI0P000002000RUP0300000000F<l0000000<000004000
G=L3000000X006;L00<00000001YgP00JMh01@00JMh00`000000077N001agP06001agP0300000000
N=h007SN00H007SN00<00000001og@00Omd01@00Omd2000000/008?K0`00000A0023eP<00000C@3I
fMT2000001H0fMWI00<000000=WIf@3IfMT0803IfMT00240fMWI00<000000=WIf@3IfMT0503IfMT0
0`000000fMWI0=WIf@1>0=WIf@04000000008YH002:F000000@005S?1000000?001Le`8000002@00
H]`2000000H006WN00<00000001agP00LMh01@00LMh00`00000007SN001hgP05001hgP0300000000
Omd007oM00@007oM0P00000;0023f`8000004P00PmH300000540fMWI00<000000=WIf@3IfMT04P3I
fMT300000240fMWI000Q0=WIf@030000003IfMT0fMWI01<0fMWI00<000000=WIf@3IfMT0D03IfMT2
00000003000RUP00000005S?00H005S?1000000=001Le`<000002000H]`00`00000006WN001YgP04
001YgP0300000000LMh0077N00@0077N00<00000001hgP00N=h01000N=h00`00000007oM001og@04
001og@0300000000Pm/008?K00P008?K0`00000?0023ePL00000D`3IfMT00`000000fMWI0=WIf@0C
0=WIf@030000003IfMT0fMWI01l0fMWI002<0=WIf@03000000008YH0000000X005S?1000000<001L
e`8000001`00H]`00`00000006WN001YgP03001YgP0300000000LMh0077N00@0077N00<00000001h
gP00N=h00`00N=h00`00000007oM001og@03001og@8000002000Pm/3000000d008?F1@000004001m
c0800000JP3IfMT00`000000fMWI0=WIf@0O0=WIf@00<`3IfMT2000005T0fMWI0P00000=001Hc`@0
00002P00G=L2000000H006;L0P000004001YgP0300000000LMh0077N00<0077N00<00000001hgP00
N=h00`00N=h00`00000007oM001og@02001og@0300000000Pm/008?K00H008?K0P00000<0023eP@0
00002000OL`00`000000fMWI0=WIf@1H0=WIf@800000403IfMT00`000000fMWI0=WIf@0O0=WIf@00
<@3IfMT2000005`0fMWI0P00000@001Hc`@000002000G=L3000000D006;L00D00000001YgP00JMh0
06WN00000005001agP0300000000N=h007SN008007SN00@00000001og@00Omd007oM0P0000060023
f`<000002@00PmH5000000X007g<0P00001M0=WIf@030000003IfMT0fMWI00d0fMWI00<000000=WI
f@3IfMT07`3IfMT00200fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@1N0=WIf@03
00000000F<l005S?014005S?10000007001Le`8000001000H]`01@00000006WN001YgP00JMh00000
00@0077N00D00000001hgP00N=h007SN00000003001og@0300000000Pm/008?K00<008?K0`000007
0023ePD000003P00OL`2000005l0fMWI00<000000=WIf@3IfMT03@3IfMT00`000000fMWI0=WIf@06
0=WIf@<000005@3IfMT00200fMWI00<000000=WIf@3IfMT02@3IfMT2000006@0fMWI1@00000B001H
c`@000001@00G=L2000000<006;L0P000002001YgP0400000000LMh0077N000000<007SN00<00000
001og@00Omd00P0000030023f`<000001P00PmH40000018007g<00<000000=WIf@3IfMT0K`3IfMT0
0`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI01@0fMWI000P0=WIf@030000003IfMT0fMWI
00P0fMWI00<000000=WIf@3IfMT0IP3IfMT<000000d005S?10000003001Le`<000000P00H]`00`00
000006WN00000002001agP0500000000N=h007SN00000000Omd00P0000030023f`8000001000PmH5
000001D007g<00<000000=WIf@3IfMT0H`3IfMT2000000/0fMWI0P0000080=WIf@030000003IfMT0
fMWI01@0fMWI000O0=WIf@030000003IfMT0fMWI00P0fMWI00<000000=WIf@3IfMT0JP3IfMT20000
00L005O52@000008001Hc`@000000P00G=L200000006001Rg0000000000000000000LMh000000P00
N=h20000008008?K0`0000020023eP@000004P00OL`8000006P0fMWI0P00000:0=WIf@030000003I
fMT0fMWI00H0fMWI00<000000=WIf@3IfMT0503IfMT001l0fMWI00<000000=WIf@3IfMT0M`3IfMT2
000000h005O52@000003001Hc`H0000000D006;L00000000LMh00000001hgP0:000000P007g<3P00
0003001d`P<00000K03IfMT00`000000fMWI0=WIf@070=WIf@030000003IfMT0fMWI00H0fMWI00<0
00000=WIf@3IfMT0503IfMT002D0fMWI0P00001d0=WIf@<000005000ElDP000000h007C20`00001b
0=WIf@800000103IfMT2000000P0fMWI00<000000=WIf@3IfMT0503IfMT002@0fMWI00<000000=WI
f@3IfMT0M`3IfMT2000000l005O55`00000G001d`P<00000M`3IfMT01P000000fMWI0=WIf@000000
fMWI000000L0fMWI0P00000F0=WIf@007P3IfMT00`000000fMWI0=WIf@020=WIf@030000003IfMT0
fMWI07X0fMWI3`00000;001I_0<000000`00GkP2000000@006Rj3@000007001d`P<00000N`3IfMT0
0`000000fMWI0=WIf@020=WIf@030000003IfMT0fMWI00D0fMWI00<000000=WIf@3IfMT0503IfMT0
01h0fMWI00<000000=WIf@3IfMT0P`3IfMT6000000d005Vl0`000008001O^00300000000J;X006Rj
00h006Rj1`0000230=WIf@030000003IfMT0fMWI01`0fMWI000N0=WIf@<00000R@3IfMT6000000@0
05Vl0`00000<001O^08000001@00J;X9000008H0fMWI00<000000=WIf@0000000P00000N0=WIf@00
7@3IfMT2000000<0fMWI00<000000=WIf@3IfMT0R`3IfMTJ000008l0fMWI00@000000=WIf@3IfMT0
fMWI0P00000M0=WIf@007@3IfMT4000000030=WIf@000000fMWI09T0fMWI00<000000=WIf@3IfMT0
V@3IfMT6000001d0fMWI000P0=WIf@@00000o`3IfMTd0=WIf@D00000803IfMT002@0fMWI1@000003
0=WIf@030000003IfMT0fMWI0?l0fMWI803IfMT010000000fMWI0=WIf@3IfMT6000002@0fMWI000X
0=WIf@D00000o`3IfMTS0=WIf@D00000:03IfMT002`0fMWI1000002=0=WIf@030000003IfMT0fMWI
08@0fMWI00<000000=WIf@3IfMT00`3IfMT6000002`0fMWI000`0=WIf@@000000P3IfMT00`000000
fMWI0=WIf@240=WIf@030000003IfMT0fMWI08@0fMWI00@000000=WIf@3IfMT0fMWI1000000`0=WI
f@00=03IfMT4000008D0fMWI00<000000=WIf@3IfMT0P`3IfMT5000003@0fMWI000h0=WIf@@00000
103IfMT00`000000fMWI0=WIf@1j0=WIf@030000003IfMT0fMWI07/0fMWI00<000000=WIf@3IfMT0
0P3IfMT4000003P0fMWI000l0=WIf@D00000O03IfMT00`000000fMWI0=WIf@1k0=WIf@D00000?03I
fMT003l0fMWI1`0000030=WIf@030000003IfMT0fMWI0>D0fMWI00<000000=WIf@3IfMT00`000000
0`3IfMT000000000000200000400fMWI00140=WIf@@0000000<0fMWI0000003IfMT0g@3IfMT00`00
0000fMWI0=WIf@070=WIf@H000008P3IfMT3000001l0fMWI000M0=WIf@<00000:03IfMT6000000@0
fMWI00<000000=WIf@3IfMT0d`3IfMT00`000000fMWI0=WIf@020=WIf@L000009`3IfMT00`000000
fMWI0=WIf@0N0=WIf@007P3IfMT00`000000fMWI0=WIf@0[0=WIf@@000000P3IfMT00`000000fMWI
0=WIf@1X0=WIf@030000003IfMT0fMWI06T0fMWI00<000000=WIf@0000001000000[0=WIf@030000
003IfMT0fMWI01h0fMWI000N0=WIf@030000003IfMT0fMWI02l0fMWI1@00001X0=WIf@030000003I
fMT0fMWI0600fMWI00<000000=WIf@3IfMT00`3IfMT6000002l0fMWI00<000000=WIf@3IfMT07P3I
fMT001h0fMWI00<000000=WIf@3IfMT0<`3IfMT4000000<0fMWI00<000000=WIf@3IfMT0G`3IfMT0
0`000000fMWI0=WIf@1P0=WIf@040000003IfMT0fMWI0=WIf@@00000<`3IfMT00`000000fMWI0=WI
f@0N0=WIf@007P3IfMT00`000000fMWI0=WIf@0g0=WIf@@00000H@3IfMT00`000000fMWI0=WIf@1N
0=WIf@H00000=`3IfMT00`000000fMWI0=WIf@0N0=WIf@007P3IfMT00`000000fMWI0=WIf@0k0=WI
f@@000000`3IfMT00`000000fMWI0=WIf@2a0=WIf@030000003IfMT0fMWI0080fMWI1000000j0=WI
f@800000803IfMT001d0fMWI0P0000110=WIf@@00000/`3IfMT5000003l0fMWI00<000000=WIf@3I
fMT07P3IfMT001h0fMWI00<000000=WIf@3IfMT0@`3IfMT4000000<0fMWI00<000000=WIf@3IfMT0
X@3IfMT00`000000fMWI0=WIf@020=WIf@@00000I03IfMT006P0fMWI1@00001@0=WIf@030000003I
fMT0fMWI04h0fMWI1P00001X0=WIf@00K03IfMT6000000030=WIf@000000fMWI04P0fMWI00<00000
0=WIf@3IfMT0A`3IfMT9000006`0fMWI001`0=WIf@@000001`3IfMT00`000000fMWI0=WIf@0o0=WI
f@030000003IfMT0fMWI0400fMWI00<000000=WIf@3IfMT00`3IfMT500000740fMWI001d0=WIf@H0
000000<0fMWI0000003IfMT0@03IfMT00`000000fMWI0=WIf@100=WIf@L000007P3IfMT3000000<0
fMWI00@000000=WIf@3IfMT0fMWI0`00001:0=WIf@00B@3IfMT3000000<0fMWI00@000000=WIf@3I
fMT0fMWI0`00000R0=WIf@@00000@@3IfMT00`000000fMWI0=WIf@0h0=WIf@030000003IfMT0fMWI
00@0fMWI1000000Q0=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT01@000000fMWI0=WIf@3I
fMT0000004T0fMWI00180=WIf@050000003IfMT0fMWI0=WIf@0000001@3IfMT01@000000fMWI0=WI
f@3IfMT0000002D0fMWI1@0000000`3IfMT000000=WIf@1d0=WIf@L000009@3IfMT01@000000fMWI
0=WIf@3IfMT0000000T0fMWI00<000000=WIf@3IfMT0A`3IfMT004P0fMWI00D000000=WIf@3IfMT0
fMWI000000090=WIf@030000003IfMT0fMWI02L0fMWI100000050=WIf@030000003IfMT0fMWI06D0
fMWI00<000000=WIf@3IfMT00`3IfMT4000002T0fMWI00D000000=WIf@3IfMT0fMWI000000090=WI
f@030000003IfMT0fMWI04L0fMWI00180=WIf@050000003IfMT0fMWI0=WIf@0000002@3IfMT00`00
0000fMWI0=WIf@0[0=WIf@@0000000<0fMWI0000003IfMT0IP3IfMT6000002d0fMWI00D000000=WI
f@3IfMT0fMWI000000050=WIf@@00000BP3IfMT004P0fMWI00D000000=WIf@3IfMT0fMWI00000005
0=WIf@@00000<P3IfMT4000000@0fMWI00<000000=WIf@3IfMT0:P3IfMT00`000000fMWI0=WIf@0Z
0=WIf@030000003IfMT0fMWI0080fMWI1000000a0=WIf@050000003IfMT0fMWI0=WIf@0000001@3I
fMT00`000000fMWI0=WIf@1;0=WIf@00B03IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<0
00000=WIf@3IfMT0=`3IfMT5000002`0fMWI00<000000=WIf@3IfMT0903IfMT00`000000fMWI0=WI
f@030=WIf@D00000=@3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI00<000000=WIf@3IfMT0
B`3IfMT004P0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000003IfMT0fMWI03/0fMWI
100000030=WIf@030000003IfMT0fMWI00<0fMWI00<000000=WIf@3IfMT07@3IfMT00`000000fMWI
0=WIf@0M0=WIf@030000003IfMT0fMWI00@0fMWI00<000000=WIf@3IfMT01000000j0=WIf@<00000
1P3IfMT5000004T0fMWI00190=WIf@<000001P3IfMT5000003d0fMWI1@0000040=WIf@030000003I
fMT0fMWI01d0fMWI00<000000=WIf@3IfMT07@3IfMT010000000fMWI0=WIf@3IfMT6000009D0fMWI
002H0=WIf@L000007P3IfMT00`000000fMWI0=WIf@0L0=WIf@L00000V@3IfMT009`0fMWI10000004
0=WIf@030000003IfMT0fMWI0300fMWI00<000000=WIf@3IfMT01@00002M0=WIf@00N03IfMT30000
02D0fMWI1P0000040=WIf@030000003IfMT0fMWI02<0fMWI00<000000=WIf@3IfMT00P3IfMT60000
02@0fMWI0`00001j0=WIf@00M`3IfMT01@000000fMWI0=WIf@3IfMT0000002P0fMWI100000020=WI
f@030000003IfMT0fMWI0100fMWI00<000000=WIf@3IfMT0403IfMT00`000000fMWI0=WIf@040000
02L0fMWI00D000000=WIf@3IfMT0fMWI0000001i0=WIf@00M`3IfMT01@000000fMWI0=WIf@3IfMT0
000002`0fMWI1@0000030=WIf@030000003IfMT0fMWI00X0fMWI00<000000=WIf@3IfMT02P3IfMT0
0`000000fMWI0=WIf@06000002/0fMWI00D000000=WIf@3IfMT0fMWI0000001i0=WIf@00M`3IfMT0
1@000000fMWI0=WIf@3IfMT000000300fMWI1@0000050=WIf@030000003IfMT0fMWI00@0fMWI00<0
00000=WIf@3IfMT01@3IfMT00`000000fMWI0=WIf@030=WIf@@00000;`3IfMT01@000000fMWI0=WI
f@3IfMT0000007T0fMWI001g0=WIf@050000003IfMT0fMWI0=WIf@000000=03IfMT5000000030=WI
f@000000fMWI00<0fMWI00D000000=WIf@000000fMWI000000050=WIf@H00000<`3IfMT01@000000
fMWI0=WIf@3IfMT0000007T0fMWI001g0=WIf@050000003IfMT0fMWI0=WIf@000000>03IfMT40000
00<0fMWI00D000000=WIf@000000fMWI000000030=WIf@@00000=`3IfMT01@000000fMWI0=WIf@3I
fMT0000007T0fMWI001g0=WIf@050000003IfMT0fMWI0=WIf@000000?03IfMT4000000<0fMWI1000
000k0=WIf@050000003IfMT0fMWI0=WIf@000000N@3IfMT007P0fMWI0`0000110=WIf@<00000@03I
fMT3000007X0fMWI003L0=WIf@<000000`3IfMT010000000fMWI0=WIf@3IfMT3000009<0fMWI002J
0=WIf@<000000`3IfMT010000000fMWI0=WIf@3IfMT3000003@0fMWI00D000000=WIf@3IfMT0fMWI
000000050=WIf@050000003IfMT0fMWI0=WIf@000000TP3IfMT009T0fMWI00D000000=WIf@3IfMT0
fMWI000000050=WIf@050000003IfMT0fMWI0=WIf@000000<`3IfMT01@000000fMWI0=WIf@3IfMT0
000000T0fMWI00<000000=WIf@3IfMT0T03IfMT009T0fMWI00D000000=WIf@3IfMT0fMWI00000009
0=WIf@030000003IfMT0fMWI02T0fMWI1`0000000`3IfMT000000=WIf@020=WIf@030000003IfMT0
fMWI00L0fMWI00<000000=WIf@3IfMT0T03IfMT00980fMWI200000030=WIf@030000003IfMT0fMWI
00L0fMWI00<000000=WIf@3IfMT0<@3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI1000002C
0=WIf@00V@3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI1000000d0=WIf@050000003IfMT0
fMWI0=WIf@0000001@3IfMT00`000000fMWI0=WIf@2D0=WIf@00V@3IfMT01@000000fMWI0=WIf@3I
fMT0000000D0fMWI00<000000=WIf@3IfMT0=@3IfMT01@000000fMWI0=WIf@3IfMT0000000D0fMWI
00<000000=WIf@3IfMT0U03IfMT009T0fMWI00D000000=WIf@3IfMT0fMWI000000050=WIf@030000
003IfMT0fMWI03H0fMWI0`0000060=WIf@D00000TP3IfMT009X0fMWI0`0000060=WIf@D000005@3I
fMT3000000040=WIf@000000000000000;P0fMWI002n0=WIf@050000003IfMT0fMWI0=WIf@000000
^@3IfMT00;h0fMWI00D000000=WIf@3IfMT0fMWI0000002i0=WIf@00]@3IfMT;00000080fMWI00<0
00000=WIf@3IfMT0]`3IfMT00;h0fMWI00D000000=WIf@3IfMT0fMWI0000002i0=WIf@00_P3IfMT0
1@000000fMWI0=WIf@3IfMT000000;T0fMWI002m0=WIf@8000000P3IfMT200000;T0fMWI001`0=WI
f@<000000P3IfMT3000004H0fMWI00D000000=WIf@3IfMT0fMWI0000000m0=WIf@<00000N@3IfMT0
0740fMWI00<000000=WIf@3IfMT00P3IfMT00`000000fMWI0=WIf@280=WIf@030000003IfMT0fMWI
07P0fMWI001b0=WIf@040000003IfMT0fMWI000008/0fMWI00<000000=WIf@3IfMT0N03IfMT007<0
fMWI0P00002<0=WIf@030000003IfMT0fMWI07P0fMWI001c0=WIf@800000R`3IfMT00`000000fMWI
0000001i0=WIf@00LP3IfMT010000000fMWI0=WIf@00002:0=WIf@030000003IfMT0000007T0fMWI
001a0=WIf@030000003IfMT0fMWI0080fMWI00<000000=WIf@3IfMT0QP3IfMT01@000000fMWI0=WI
f@3IfMT0000007P0fMWI001`0=WIf@<000000P3IfMT3000008H0fMWI0`000000103IfMT000000000
0000001g0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00
o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00
o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00
o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00
o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00
o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00
o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00o`3IfMUm0=WIf@00\
\>"],
  ImageRangeCache->{{{0, 379}, {379, 0}} -> {-5.00005*^-6, -5.00005*^-6, \
0.00263855, 0.00263855}}]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1280}, {0, 940}},
Evaluator->"Local",
WindowSize->{724, 583},
WindowMargins->{{188, Automatic}, {Automatic, 86}},
ShowCellLabel->False,
StyleDefinitions -> "Report.nb",
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon@3:`8f0dL5NP?N0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@0000000000000006P801T1T00000000000
00000000004000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 184, 6, 84, "Title"],
Cell[1926, 59, 37, 0, 66, "Author"],

Cell[CellGroupData[{
Cell[1988, 63, 33, 0, 70, "Section 1"],

Cell[CellGroupData[{
Cell[2046, 67, 32, 0, 40, "Subsection"],
Cell[2081, 69, 1376, 22, 198, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3494, 96, 42, 0, 40, "Subsection"],
Cell[3539, 98, 2729, 42, 440, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6305, 145, 40, 0, 40, "Subsection"],
Cell[6348, 147, 2480, 56, 500, "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[8877, 209, 32, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[8934, 213, 150, 3, 64, "Input"],
Cell[9087, 218, 220, 4, 37, "Print"],
Cell[9310, 224, 121, 2, 52, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[9480, 232, 28, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[9533, 236, 37, 0, 40, "Subsection"],
Cell[9573, 238, 1283, 21, 208, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[10893, 264, 58, 0, 24, "Subsection"],
Cell[10954, 266, 1870, 32, 480, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[12861, 303, 38, 0, 24, "Subsection"],
Cell[12902, 305, 802, 16, 192, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[13753, 327, 38, 0, 41, "Section"],
Cell[13794, 329, 455, 8, 80, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[14286, 342, 69, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[14380, 346, 616, 11, 160, "Input"],
Cell[14999, 359, 335, 6, 37, "Print"],
Cell[15337, 367, 38213, 819, 287, 6511, 423, "GraphicsData", "PostScript", \
"Graphics"],
Cell[53553, 1188, 130, 3, 46, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[53732, 1197, 26, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[53783, 1201, 96, 3, 40, "Subsection"],

Cell[CellGroupData[{
Cell[53904, 1208, 2274, 42, 576, "Input"],
Cell[56181, 1252, 194, 4, 37, "Print"],
Cell[56378, 1258, 67675, 1651, 318, 30292, 1185, "GraphicsData", \
"PostScript", "Graphics"],
Cell[124056, 2911, 130, 3, 46, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[124235, 2920, 42, 0, 40, "Subsection"],

Cell[CellGroupData[{
Cell[124302, 2924, 44, 0, 30, "Subsubsection"],

Cell[CellGroupData[{
Cell[124371, 2928, 2495, 48, 624, "Input"],
Cell[126869, 2978, 194, 4, 37, "Print"],
Cell[127066, 2984, 84, 1, 37, "Print"],
Cell[127153, 2987, 68586, 1790, 296, 37903, 1407, "GraphicsData", \
"PostScript", "Graphics"],
Cell[195742, 4779, 130, 3, 46, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[195921, 4788, 54, 0, 30, "Subsubsection"],
Cell[195978, 4790, 819, 15, 126, "Text"],

Cell[CellGroupData[{
Cell[196822, 4809, 744, 15, 192, "Input"],
Cell[197569, 4826, 74, 1, 37, "Print"],
Cell[197646, 4829, 41744, 1036, 303, 15804, 711, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[239463, 5873, 46, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[239534, 5877, 184, 3, 64, "Input"],
Cell[239721, 5882, 122364, 3769, 396, 53546, 2915, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

